@@ -29,8 +29,8 @@ local function Domoticz(settings)
 
 	-- check if the user set a lat/lng
 	-- if not, then daytime, nighttime is incorrect
-	if (_G.timeofday['SunriseInMinutes'] == 0 and _G.timeofday['SunsetInMinutes'] == 0) then
-		utils.log('No information about sunrise and sunset available. Please set lat/lng information in settings.', utils.LOG_ERROR)
+	if not(globalvariables.locationSet) then
+		utils.log('No information about longitude / latitude available. Please set lat/lng information in settings.', utils.LOG_ERROR)
 	end
 
 	nowTime['isDayTime'] = timeofday['Daytime']
@@ -39,6 +39,7 @@ local function Domoticz(settings)
 	nowTime['isNightTime'] = timeofday['Nighttime']
 	nowTime['sunriseInMinutes'] = timeofday['SunriseInMinutes']
 	nowTime['sunsetInMinutes'] = timeofday['SunsetInMinutes']
+	nowTime['solarnoonInMinutes'] = timeofday['SunAtSouthInMinutes']
 	nowTime['civTwilightStartInMinutes'] = timeofday['CivTwilightStartInMinutes']
 	nowTime['civTwilightEndInMinutes'] = timeofday['CivTwilightEndInMinutes']
 
@@ -49,6 +50,7 @@ local function Domoticz(settings)
 		['devices'] = {},
 		['scenes'] = {},
 		['groups'] = {},
+		['hardware'] = {},
 		['changedDevices'] = {},
 		['changedVariables'] = {},
 		['security'] = globalvariables['Security'],
@@ -70,16 +72,19 @@ local function Domoticz(settings)
 	merge(self, constants)
 	merge(self.utils, utils)
 
-	-- add domoticz commands to the commandArray
-	function self.sendCommand(command, value)
-		table.insert(self.commandArray, { [command] = value })
-
+	-- add domoticz commands to the commandArray or delay
+	function self.sendCommand(command, value, delay)
+		if delay and tonumber(delay) then
+			self.emitEvent('___' .. command .. '__' , value ).afterSec(delay)
+		else
+			table.insert(self.commandArray, { [command] = value })
+		end
 		-- return a reference to the newly added item
-		return self.commandArray[#self.commandArray], command, value
+		return self.commandArray[#self.commandArray], command, value, delay
 	end
 
 	-- have domoticz send a push notification
-	function self.notify(subject, message, priority, sound, extra, subSystems)
+	function self.notify(subject, message, priority, sound, extra, subSystems, delay)
 		-- set defaults
 		if (priority == nil) then priority = self.PRIORITY_NORMAL end
 		if (message == nil) then message = '' end
@@ -117,47 +122,75 @@ local function Domoticz(settings)
 				.. '#' .. strip(sound)
 				.. '#' .. strip(extra)
 				.. '#' .. strip(_subSystem)
-				self.sendCommand('SendNotification', data)
-	
+				self.sendCommand('SendNotification', data, delay)
+
 	end
 
 	-- have domoticz send an email
-	function self.email(subject, message, mailTo)
+	function self.email(subject, message, mailTo, delay)
 		if (mailTo == nil) then
 			utils.log('No mail-to is provided', utils.LOG_ERROR)
 		else
 			if (subject == nil) then subject = '' end
 			if (message == nil) then message = '' end
-			self.sendCommand('SendEmail', subject .. '#' .. message .. '#' .. mailTo)
+			self.sendCommand('SendEmail', subject .. '#' .. message .. '#' .. mailTo, delay)
 		end
 	end
 
+	function self.triggershellCommandResponse(shellCommandResponse, delay, message)
+		local shellCommandResponse = shellCommandResponse or _G.moduleLabel
+		local delay = delay or 0
+		local message = 'triggerShellCommandResponse: ' .. (message or shellCommandResponse)
+		local command = 'echo '..message
+		self.executeShellCommand
+		(
+			{
+				command = command,
+				callback = shellCommandResponse,
+			}
+		).afterSec(delay)
+	end
+
 	function self.triggerHTTPResponse(httpResponse, delay, message)
 		local httpResponse = httpResponse or _G.moduleLabel
 		local delay = delay or 0
 		local message = 'triggerHTTPResponse: ' .. (message or httpResponse)
 		local url = self.settings['Domoticz url'] .. '/json.htm?type=command&param=addlogmessage&message=' .. self.utils.urlEncode(message)
-				self.openURL
-				(
-					{
-						url = url,
-						callback = httpResponse,
-					}
-				).afterSec(delay)
+		self.openURL
+		(
+			{
+				url = url,
+				callback = httpResponse,
+			}
+		).afterSec(delay)
 	end
 
 	-- have domoticz send snapshot
-	function self.snapshot(cameraID, subject)
-		if tostring(cameraID):match("%a") then
-			cameraID = self.cameras(cameraID).id
+	function self.snapshot(cameraIDS, subject)
+		local subject = subject or 'domoticz'
+		local cameraIDS = cameraIDS or 1
+
+		local cameraIDS = ( type(cameraIDS) == 'table' and cameraIDS ) or utils.stringSplit(cameraIDS,'%p')
+
+		for index, camera in ipairs(cameraIDS) do
+			if tostring(camera):match('%a') then
+				cameraIDS[index] = self.cameras(camera).id
+			end
+		end
+
+		if not( cameraIDS[2] ) then
+			local snapshotCommand = "SendCamera:" .. cameraIDS[1]
+			return TimedCommand(self, snapshotCommand , subject, 'camera')
+		else
+			cameraIDS = table.concat(cameraIDS, ';')
+			subject = self.utils.urlEncode(subject)
+			return TimedCommand(self, 'OpenURL', self.settings['Domoticz url'] .. "/json.htm?type=command&param=emailcamerasnapshot&camidx=" .. cameraIDS .. '&subject=' .. subject , 'camera')
 		end
-		local snapshotCommand = "SendCamera:" .. cameraID
-		return TimedCommand(self, snapshotCommand , subject, 'camera') -- works with afterXXX
 	end
 
 	-- have domoticz send an sms
-	function self.sms(message)
-		self.sendCommand('SendSMS', message)
+	function self.sms(message, delay)
+		self.sendCommand('SendSMS', message, delay)
 	end
 
 	function self.emitEvent(eventname, data)
@@ -175,6 +208,39 @@ local function Domoticz(settings)
 		return TimedCommand(self, 'CustomEvent', eventinfo, 'emitEvent')
 	end
 
+	-- have domoticz execute a script
+	function self.executeShellCommand(options)
+		if (type(options)== 'string') then
+			options = {
+				command = options,
+			}
+		end
+		if (type(options)=='table') then
+			local command = options.command
+			local callback = options.callback
+			local sep = '/'
+			local dataFolderPath = _G.dataFolderPath or ""  -- or needed for testing
+			if dataFolderPath:find(string.char(92)) then sep = string.char(92) end -- Windows \
+			local path = dataFolderPath .. sep
+
+			local request = {
+				command = options.command,
+				callback = options.callback,
+				timeout = options.timeout,
+				path = path
+			}
+
+			utils.log('ExecuteShellCommand: command = ' .. utils.toStr(request.command), utils.LOG_DEBUG)
+			utils.log('ExecuteShellCommand: callback = ' .. utils.toStr(request.callback), utils.LOG_DEBUG)
+			utils.log('ExecuteShellCommand: timeout = ' .. utils.toStr(request.timeout), utils.LOG_DEBUG)
+			utils.log('ExecuteShellcommand: path = ' .. utils.toStr(request.path),utils.LOG_DEBUG)
+			return TimedCommand(self, 'ExecuteShellCommand', request, 'updatedevice')
+		else
+			utils.log('executeShellCommand: Invalid arguments, use either a string or a table with options', utils.LOG_ERROR)
+		end
+
+	end
+
 	-- have domoticz open a url
 	function self.openURL(options)
 
@@ -190,13 +256,13 @@ local function Domoticz(settings)
 			local url = options.url
 			local method = string.upper(options.method or 'GET')
 			local callback = options.callback
-			local postData
+			local postData, headers
 
 			-- process body data
-			if (method ~= 'GET') then
+			if method ~= 'GET' then
 				postData = ''
-				if (options.postData ~= nil) then
-					if (type(options.postData) == 'table') then
+				if options.postData then
+					if type(options.postData) == 'table' then
 						postData = utils.toJSON(options.postData)
 
 						if (options.headers == nil) then
@@ -208,19 +274,30 @@ local function Domoticz(settings)
 				end
 			end
 
+			-- process headers
+			if options.headers then
+				if type(options.headers) == 'string' then
+					option.headers = utils.fromJSON(options.headers)
+				end
+				headers = ''
+				for key, value in pairs(options.headers) do
+					headers = headers .. '!#' .. key .. ': ' .. tostring(value)
+				end
+			end
+
 			local request = {
 				URL = url,
 				method = method,
-				headers = options.headers,
+				headers = headers,
 				postdata = postData,
 				_trigger = callback,
 			}
 
-			utils.log('OpenURL: url = ' .. _.str(request.URL), utils.LOG_DEBUG)
-			utils.log('OpenURL: method = ' .. _.str(request.method), utils.LOG_DEBUG)
-			utils.log('OpenURL: post data = ' .. _.str(request.postdata), utils.LOG_DEBUG)
-			utils.log('OpenURL: headers = ' .. _.str(request.headers), utils.LOG_DEBUG)
-			utils.log('OpenURL: callback = ' .. _.str(request._trigger), utils.LOG_DEBUG)
+			utils.log('OpenURL: url = ' .. utils.toStr(request.URL), utils.LOG_DEBUG)
+			utils.log('OpenURL: method = ' .. utils.toStr(request.method), utils.LOG_DEBUG)
+			utils.log('OpenURL: post data = ' .. utils.toStr(request.postdata), utils.LOG_DEBUG)
+			utils.log('OpenURL: headers = ' .. utils.toStr(request.headers), utils.LOG_DEBUG)
+			utils.log('OpenURL: callback = ' .. utils.toStr(request._trigger), utils.LOG_DEBUG)
 
 			return TimedCommand(self, 'OpenURL', request, 'updatedevice')
 
@@ -248,6 +325,31 @@ local function Domoticz(settings)
 		end
 	end
 
+	-- get information from hardware
+	function self.hardwareInfo( id )
+		local hardware, deviceNames, deviceIds = {}, {}, {}
+
+		local hardwareDevices = self.devices().filter(function(dv)
+			return dv.hardwareId == id or dv.hardwareName == id
+		end).forEach(function(sdv)
+			table.insert(deviceNames, sdv.name)
+			table.insert(deviceIds, sdv.id)
+		end)
+
+		if #deviceNames > 0 then
+			local aDevice = self.devices(deviceNames[1])
+
+			hardware.name = aDevice.hardwareName
+			hardware.id = aDevice.hardwareID
+			hardware.type = aDevice.hardwareType
+			hardware.typeValue = aDevice.TypeValue
+			hardware.deviceNames = deviceNames
+			hardware.deviceIds = deviceIds
+		end
+
+		return hardware
+	end
+
 	-- send a scene switch command
 	function self.setScene(scene, value)
 		utils.log('setScene is deprecated. Please use the scene object directly.', utils.LOG_INFO)
@@ -259,7 +361,6 @@ local function Domoticz(settings)
 		utils.log('switchGroup is deprecated. Please use the group object directly.', utils.LOG_INFO)
 		return TimedCommand(self, 'Group:' .. group, value, 'device', group.state)
 	end
-
 	if (_G.TESTMODE) then
 		function self._getUtilsInstance()
 			return utils
@@ -289,18 +390,15 @@ local function Domoticz(settings)
 		self.utils.dumpTable(settings, '> ', file)
 	end
 
-	function self.logDevice(device, file)
-		self.utils.dumpTable(device, '> ', file)
-	end
-
-	function self.logCamera(camera, file)
-		self.utils.dumpTable(camera, '> ', file)
+	function self.logObject(object, file, objectType )
+		self.utils.dumpTable(object, objectType .. '> ', file)
 	end
 
 	self.__cameras = {}
 	self.__devices = {}
 	self.__scenes = {}
 	self.__groups = {}
+	self.__hardware = {}
 	self.__variables = {}
 
 	function self._getItemFromData(baseType, id)
@@ -341,6 +439,9 @@ local function Domoticz(settings)
 		elseif (baseType == 'camera') then
 			cache = self.__cameras
 			constructor = Camera
+		elseif (baseType == 'hardware') then
+			cache = self.__hardware
+			constructor = Device
 		else
 			-- ehhhh
 		end
@@ -365,10 +466,10 @@ local function Domoticz(settings)
 
 		local noObjectMessage = 'There is no ' .. baseType .. ' with that name or id: ' .. tostring(id)
 
-		if (baseType == 'scene' or baseType == 'group') then
-			-- special case for scenes and groups
-			-- as they may not be in the collection if Domoticz wasn't restarted after creating the scene or group.
-				noObjectMessage = noObjectMessage .. '. If you just created the '.. baseType .. ' you may have to restart Domoticz to make it become visible to dzVents.'
+		if (baseType == 'scene' or baseType == 'group' or baseType == 'hardware') then
+			-- special case for hardware, scenes and groups
+			-- as they may not be in the collection if Domoticz wasn't restarted after creating the hardware, scene or group.
+			noObjectMessage = noObjectMessage .. '. If you just created the '.. baseType .. ' you may have to restart Domoticz to make it become visible to dzVents.'
 		end
 		utils.log(noObjectMessage, utils.LOG_ERROR)
 	end
@@ -535,6 +636,14 @@ local function Domoticz(settings)
 		end
 	end
 
+	function self.hardware(id)
+		if (id ~= nil) then
+			return self._getObject('hardware', id)
+		else
+			return self._setIterators({}, true, 'hardware', false)
+		end
+	end
+
 	function self.changedDevices(id)
 		if (id ~= nil) then
 			return self._getObject('device', id)
