@@ -49,6 +49,13 @@ describe('System events', function()
 			assert.is_true( os.execute('cat ' .. dumpfile .. ' |  grep "type: stop"  > /dev/null' ))
 		end)
 
+		it('should log resetAllEvents ', function()
+			assert.is_true(os.execute('cat ' .. dumpfile .. ' |  grep "type: resetAllEvents"  > /dev/null ' ))
+		end)
+
+		it('should log resetAllDeviceStatus ', function()
+			assert.is_true(os.execute('cat ' .. dumpfile .. ' |  grep "type: resetAllDevice"   > /dev/null ' ))
+		end)
 	end)
 
 end)
