@@ -15,20 +15,24 @@
 
 // Plugwise Anna Thermostat
 // Anna Sensors
-
 // Anna Switches
 
-#define sAnneBoilerState 8				 
+#define sAnneBoilerState 8
 #define sAnnaFlameState  9
 #define sAnnaProximity   10
 #define sAnnaPresets     11
 #define sAnnaComfort     12
 
-const std::string ANNA_GET_STATUS = "/core/appliances";
-const std::string ANNA_LOCATION = "/cache/domain_objects;class=Location";
-const std::string ANNA_SET_LOCATION = "/core/locations";
+const std::string ANNA_VERSION       = "1.0.1";
+const std::string ANNA_GET_STATUS    = "/core/appliances";
+const std::string ANNA_LOCATION      = "/cache/domain_objects;class=Location";
+const std::string ANNA_SET_LOCATION  = "/core/locations";
+const std::string ANNA_LEVEL_NAMES   = "Off|Home|Away|Night|Vacation|Frost";
+const std::string ANNA_LEVEL_ACTIONS = "00|10|20|30|40|50";
 
 
+
+//#define _DEBUG // toggle for reading and writing local files
 #ifdef _DEBUG
 //#define DEBUG_AnnaThermostat
 #define DEBUG_ANNA_APPLIANCE_READ  "/tmp/anna/appliances.xml"
@@ -73,16 +77,11 @@ CAnnaThermostat::CAnnaThermostat(const int ID, const std::string& IPAddress, con
 {
 	m_HwdID = ID;
 	Init();
-	GetMeterDetails();
 }
 
-CAnnaThermostat::~CAnnaThermostat(void)
+void CAnnaThermostat::OnError(const std::exception &e)
 {
-}
-
-void CAnnaThermostat::OnError(const std::exception e)
-{
-	_log.Log(LOG_ERROR, "AnnaTherm: Error: %s", e.what());
+	Log(LOG_ERROR, "Error: %s", e.what());
 }
 void CAnnaThermostat::CAnnaThermostat::Init()
 {
@@ -95,12 +94,11 @@ void CAnnaThermostat::CAnnaThermostat::Init()
 
 bool CAnnaThermostat::StartHardware()
 {
+
 	RequestStart();
-
 	Init();
-
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CAnnaThermostat::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -131,13 +129,18 @@ void CAnnaThermostat::Do_Work()
 		sec_counter++;
 		if (sec_counter % 12 == 0)
 		{
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if ((sec_counter % ANNA_POLL_INTERVAL == 0) || (bFirstTime))
 		{
 			sec_counter = 0;
-			bFirstTime = false;
+			if (bFirstTime)
+			{
+				FixUnit(); // Making sure the unit ID's are set to 1.  Req for future extensions
+				InitialMessageMigrateCheck();
+				bFirstTime = false;
+			}
 			GetMeterDetails();
 		}
 
@@ -153,9 +156,9 @@ void CAnnaThermostat::SendSetPointSensor(const unsigned char Idx, const float Te
 	thermos.id2 = 0;
 	thermos.id3 = 0;
 	thermos.id4 = Idx;
-	thermos.dunit = 0;
+	thermos.dunit = 1;
 	thermos.temp = Temp;
-	sDecodeRXMessage(this, (const unsigned char*)&thermos, defaultname.c_str(), 255);
+	sDecodeRXMessage(this, (const unsigned char *)&thermos, defaultname.c_str(), 255, nullptr);
 }
 
 bool CAnnaThermostat::WriteToHardware(const char* pdata, const unsigned char /*length*/)
@@ -168,9 +171,9 @@ bool CAnnaThermostat::WriteToHardware(const char* pdata, const unsigned char /*l
 		bool bIsOn = (pCmd->LIGHTING2.cmnd == light2_sOn);
 		if (node_id == sAnneBoilerState || node_id == sAnnaFlameState)
 		{
-			return false; // just return Error as these are not supposed to be switches 
+			return false; // just return Error as these are not supposed to be switches
 		}
-		else if (node_id == sAnnaProximity)
+		if (node_id == sAnnaProximity)
 		{
 			return AnnaToggleProximity(bIsOn);
 		}
@@ -206,12 +209,9 @@ void CAnnaThermostat::SetSetpoint(const int /*idx*/, const float temp)
 	std::vector<std::string> ExtraHeaders;
 	std::string sResult;
 
-	char szTemp[10];
-	sprintf(szTemp, "%.1f", temp);
-
 	sPostData << "<thermostat>";
 	sPostData << "<setpoint>";
-	sPostData << szTemp;
+	sPostData << fmt::format("{:.1f}", temp);
 	sPostData << "</setpoint>";
 	sPostData << "</thermostat>";
 
@@ -221,6 +221,7 @@ void CAnnaThermostat::SetSetpoint(const int /*idx*/, const float temp)
 		return;
 	}
 }
+
 bool CAnnaThermostat::AnnaSetPreset(uint8_t level)
 {
 	std::stringstream szURL;
@@ -228,7 +229,7 @@ bool CAnnaThermostat::AnnaSetPreset(uint8_t level)
 	if (!CheckLoginData())
 		return false;
 
-	if (m_AnnaLocation.m_ALocationID.size() == 0)
+	if (m_AnnaLocation.m_ALocationID.empty())
 		AnnaGetLocation();
 
 	if (m_Password.empty())
@@ -249,7 +250,7 @@ bool CAnnaThermostat::AnnaSetPreset(uint8_t level)
 
 	char szTemp[10];
 	switch (level) {
-	case  0:
+	case 0:
 		strcpy(szTemp, "none");
 		break;
 	case 10:
@@ -264,10 +265,14 @@ bool CAnnaThermostat::AnnaSetPreset(uint8_t level)
 	case 40:
 		strcpy(szTemp, "vacation");
 		break;
-	default:
-		strcpy(szTemp, "none");
+	case 50:
+		strcpy(szTemp, "no_frost");
 		break;
+	default:
+		Log(LOG_STATUS, "AnnaTherm: Invalid value for Preset %i .. Aborting Switch", level);
+		return false;
 	}
+	Log(LOG_STATUS, "Switching Anna gateway preset to: %s", szTemp);
 	sPostData << "<locations>";
 	sPostData << "<location id=\"";
 	sPostData << m_AnnaLocation.m_ALocationID;
@@ -289,14 +294,14 @@ bool CAnnaThermostat::AnnaSetPreset(uint8_t level)
 	SaveString2Disk(sPostData.str(), DEBUG_ANNA_WRITE);
 	SaveString2Disk(DEBUG_ANNA_CRLF, DEBUG_ANNA_WRITE);
 
-#else 
+#else
 	if (!HTTPClient::PUT(szURL.str(), sPostData.str(), ExtraHeaders, sResult, true))
 	{
 		Log(LOG_ERROR, "AnnaTherm: Error setting Preset State !");
 		return false;
 	}
-#endif	
-	return true;
+#endif
+	 return true;
 }
 
 bool CAnnaThermostat::AnnaToggleProximity(bool bToggle)
@@ -306,7 +311,7 @@ bool CAnnaThermostat::AnnaToggleProximity(bool bToggle)
 	if (!CheckLoginData())
 		return false;
 
-	if (m_ProximityID.size() == 0)
+	if (m_ProximityID.empty())
 		GetMeterDetails();
 
 	if (m_Password.empty())
@@ -343,17 +348,17 @@ bool CAnnaThermostat::AnnaToggleProximity(bool bToggle)
 
 #ifdef DEBUG_AnnaThermostat
 	SaveString2Disk("<-- ANNA - TogglePRoximitySensor-->", DEBUG_ANNA_WRITE);
-	SaveString2Disk(DEBUG_ANNN_CRLF, DEBUG_ANNA_WRITE);
+	SaveString2Disk(DEBUG_ANNA_CRLF, DEBUG_ANNA_WRITE);
 	SaveString2Disk(szURL.str(), DEBUG_ANNA_WRITE);
-	SaveString2Disk(DEBUG_ANNN_CRLF, DEBUG_ANNA_WRITE);
+	SaveString2Disk(DEBUG_ANNA_CRLF, DEBUG_ANNA_WRITE);
 	SaveString2Disk(sPostData.str(), DEBUG_ANNA_WRITE);
-#else 
+#else
 	if (!HTTPClient::PUT(szURL.str(), sPostData.str(), ExtraHeaders, sResult, true))
 	{
 		Log(LOG_ERROR, "AnnaTherm: Error setting toggle Proximity !");
 		return false;
 	}
-#endif	
+#endif
 	return true;
 }
 bool CAnnaThermostat::SetAway(const bool /*bIsAway*/)
@@ -431,7 +436,7 @@ void CAnnaThermostat::GetMeterDetails()
 		return;
 	}
 	TiXmlDocument doc;
-	if (doc.Parse(sResult.c_str(), 0, TIXML_ENCODING_UTF8) && doc.Error())
+	if (doc.Parse(sResult.c_str(), nullptr, TIXML_ENCODING_UTF8) && doc.Error())
 	{
 		Log(LOG_ERROR, "AnnaTherm: Cannot parse XML");
 		return;
@@ -454,7 +459,7 @@ void CAnnaThermostat::GetMeterDetails()
 		TiXmlHandle hAppliance = TiXmlHandle(pAppliance);
 
 		pElem = pAppliance->FirstChildElement("name");
-		if (pElem == NULL)
+		if (pElem == nullptr)
 		{
 			Log(LOG_ERROR, "AnnaTherm: Cannot find appliance attributes");
 			return;
@@ -464,7 +469,7 @@ void CAnnaThermostat::GetMeterDetails()
 		if ((m_ThermostatID.empty()) && ((ApplianceName == "Anna") || (ApplianceName == "Adam")))
 		{
 			pAttribute = pAppliance->FirstAttribute();
-			if (pAttribute != NULL)
+			if (pAttribute != nullptr)
 			{
 				std::string aName = pAttribute->Name();
 				if (aName == "id")
@@ -490,7 +495,10 @@ void CAnnaThermostat::GetMeterDetails()
 		}
 		for (pElem; pElem; pElem = pElem->NextSiblingElement())
 		{
+
 			sname = GetElementChildValue(pElem, "type");
+			//tmpstr = GetPeriodMeasurement(pElem);
+			//Log (LOG_NORM,"%s : %s ", sname.c_str(), tmpstr.c_str());
 			if (sname == "temperature")
 			{
 				tmpstr = GetPeriodMeasurement(pElem);
@@ -561,11 +569,11 @@ void CAnnaThermostat::GetMeterDetails()
 				{
 					if (strcmp(tmpstr.c_str(), "on") == 0)
 					{
-						SendSwitch(sAnneBoilerState, 1, 255, true, 0, sname);
+						SendSwitch(sAnneBoilerState, 1, 255, true, 0, sname, m_Name);
 					}
 					else
 					{
-						SendSwitch(sAnneBoilerState, 1, 255, false, 0, sname);
+						SendSwitch(sAnneBoilerState, 1, 255, false, 0, sname, m_Name);
 					}
 				}
 			}
@@ -577,24 +585,13 @@ void CAnnaThermostat::GetMeterDetails()
 					if (strcmp(tmpstr.c_str(), "on") == 0)
 					{
 
-						SendSwitch(sAnnaFlameState, 1, 255, true, 0, sname);
+						SendSwitch(sAnnaFlameState, 1, 255, true, 0, sname, m_Name);
 					}
 					else
 					{
-						SendSwitch(sAnnaFlameState, 1, 255, false, 0, sname);
+						SendSwitch(sAnnaFlameState, 1, 255, false, 0, sname, m_Name);
 					}
-					//make device ID
-					const int NodeID = sAnnaFlameState;
-					unsigned char ID1 = (unsigned char)((NodeID & 0xFF000000) >> 24);
-					unsigned char ID2 = (unsigned char)((NodeID & 0xFF0000) >> 16);
-					unsigned char ID3 = (unsigned char)((NodeID & 0xFF00) >> 8);
-					unsigned char ID4 = (unsigned char)NodeID & 0xFF;
-
-					char szIdx[10];
-					sprintf(szIdx, "%X%02X%02X%02X", ID1, ID2, ID3, ID4);
-					//m_sql.safe_query("UPDATE DeviceStatus SET SwitchType=%d WHERE (HardwareID==%d) AND (DeviceID=='%q')", 5, m_HwdID,szIdx);
 				}
-
 			}
 			else if (sname == "proximity_sensor_state")
 			{
@@ -602,7 +599,7 @@ void CAnnaThermostat::GetMeterDetails()
 				if (m_ProximityID.empty())
 				{
 					pAttribute = pAppliance->FirstAttribute();
-					if (pAttribute != NULL)
+					if (pAttribute != nullptr)
 					{
 						std::string aName = pAttribute->Name();
 						if (aName == "id")
@@ -627,8 +624,7 @@ void CAnnaThermostat::GetMeterDetails()
 					{
 						bSwitch = false;
 					}
-					SendSwitch(sAnnaProximity, 0, 255, bSwitch, 0, sname);
-					//m_sql.safe_query("UPDATE DeviceStatus SET CustomImage=%d WHERE (HardwareID==%d) AND (DeviceID=='%08X')", 12, m_HwdID,sAnnaProximity);
+					SendSwitch(sAnnaProximity, 1, 255, bSwitch, 0, sname, m_Name);
 				}
 			}
 			else if (sname == "preset_state")
@@ -664,40 +660,29 @@ void CAnnaThermostat::GetMeterDetails()
 				}
 				else if (strcmp(tmpstr.c_str(), "no_frost") == 0)
 				{
-					strncpy(sPreset, "00", sizeof(sPreset));
-				}
-				int customImage = 16;//Frost
-				std::vector<std::vector<std::string> > result;
-				result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%08X')", m_HwdID, sAnnaPresets);
-				if (result.empty()) //Switch is not yet in the system so create it
-				{
-					std::string options_str = m_sql.FormatDeviceOptions(m_sql.BuildDeviceOptions("SelectorStyle:0;LevelNames:Off|Home|Away|Night|Vacation;LevelOffHidden:true;LevelActions:00|10|20|30|40", false));
-					m_sql.safe_query(
-						"INSERT INTO DeviceStatus (HardwareID, DeviceID, Unit, Type, SubType, SwitchType, Used, SignalLevel, BatteryLevel, Name, nValue, sValue, CustomImage, Options) "
-						"VALUES (%d, '%08X', %d, %d, %d, %d, %d, 12, 255, '%q', 0, '%q', %d, '%q')", m_HwdID, sAnnaPresets, 0, pTypeGeneralSwitch, sSwitchTypeSelector, STYPE_Selector, 0, "Anna Presets", sPreset, customImage, options_str.c_str());
-				}
-				else
-				{
-					result = m_sql.safe_query("UPDATE DeviceStatus SET sValue = '%q' where (HardwareID==%d) AND (DeviceID=='%08X')", sPreset, m_HwdID, sAnnaPresets);
+					strncpy(sPreset, "50", sizeof(sPreset));
 				}
+				else strncpy(sPreset, "50", sizeof(sPreset));
+
+				std::string PresetName = "Anna Preset";
+				SendSelectorSwitch(sAnnaPresets, 1, sPreset, PresetName, 16, false, ANNA_LEVEL_NAMES, ANNA_LEVEL_ACTIONS, true, m_Name);
 			}
 		}
 		pAppliance = pAppliance->NextSiblingElement("appliance");
 	}
-	return;
 }
 
-// Checks if the USername and password are filled in
+// Checks if the Username and password are filled in
 bool CAnnaThermostat::CheckLoginData()
 {
-	if (m_UserName.size() == 0)
+	if (m_UserName.empty())
 		return false;
-	if (m_Password.size() == 0)
+	if (m_Password.empty())
 		return false;
 	return true;
 }
 
-// Fetched the location information (id,name and type)from the  first location given by the Anna/Adam Gateway					
+// Fetched the location information (id,name and type)from the  first location given by the Anna/Adam Gateway
 bool CAnnaThermostat::AnnaGetLocation()
 {
 	std::string sResult;
@@ -732,7 +717,7 @@ bool CAnnaThermostat::AnnaGetLocation()
 		return false;
 	}
 	TiXmlDocument doc;
-	if (doc.Parse(sResult.c_str(), 0, TIXML_ENCODING_UTF8) && doc.Error())
+	if (doc.Parse(sResult.c_str(), nullptr, TIXML_ENCODING_UTF8) && doc.Error())
 	{
 		Log(LOG_ERROR, "AnnaTherm: Cannot parse XML");
 		return false;
@@ -754,7 +739,7 @@ bool CAnnaThermostat::AnnaGetLocation()
 	if (m_AnnaLocation.m_ALocationID.empty())
 	{
 		pAttribute = pLocation->FirstAttribute();
-		if (pAttribute != NULL)
+		if (pAttribute != nullptr)
 		{
 			std::string aName = pAttribute->Name();
 			if (aName == "id")
@@ -769,17 +754,54 @@ bool CAnnaThermostat::AnnaGetLocation()
 		}
 	}
 	pElem = pLocation->FirstChildElement("name");
-	if (pElem == NULL)
+	if (pElem == nullptr)
 	{
 		Log(LOG_ERROR, "AnnaTherm: Cannot find Location name");
 		return false;
 	}
 	m_AnnaLocation.m_ALocationName = pElem->GetText();
 	pElem = pLocation->FirstChildElement("type");
-	if (pElem == NULL)
+	if (pElem == nullptr)
 	{
 		Log(LOG_ERROR, "AnnaTherm: Cannot find Location type");
 		return false;
-	}	m_AnnaLocation.m_ALocationType = pElem->GetText();
+	}
+	m_AnnaLocation.m_ALocationType = pElem->GetText();
 	return true;
 }
+
+
+bool CAnnaThermostat::InitialMessageMigrateCheck()
+{
+	bool retval = false;
+	// Showing we are starting Annatherm and
+	// notify users in the log how to use the event system once per startup
+	Log(LOG_NORM, "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~");
+	Log(LOG_NORM, "Plugwise Plugin Version: %s", ANNA_VERSION.c_str() );
+	Log(LOG_NORM, "Notice: To change the preset by way of scripts/events, please use the following percentages levels:");
+	Log(LOG_NORM, "10%% for Home, 20%% for Away, 30%% for Night, 40%% for Vacation & 50%% for Frost (Lua use 'Set Level: 20')");
+	Log(LOG_NORM, "Any other value will be refused! ");
+	Log(LOG_NORM, "To Detect changes in scripts use 'Off, Home, Away, Night, Vacation, Frost'");
+	Log(LOG_NORM, "Adjusting the Temp manually on the ANNA or via App, forces the ANNA to set Scenes to Off!!");
+	Log(LOG_NORM, "KNOWN ISSUE: The Gateway will not send an correct update if the previous scene is choosen again!");
+	Log(LOG_NORM, "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~");
+
+	if( MigrateSelectorSwitch(sAnnaPresets, 1, ANNA_LEVEL_NAMES, ANNA_LEVEL_ACTIONS,true)== 1)
+	{
+		Log(LOG_STATUS, "Scene Selector switch updated to Version: %s ! ", ANNA_VERSION.c_str());
+		retval = true;
+	}
+	return retval;
+}
+void CAnnaThermostat::FixUnit()
+{   // This function will make sure that from now on  that the Preset switch in the Plugwise plugin will be using unit 0
+	std::vector<std::vector<std::string> > result;
+	result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d) AND (Unit == '%d')", m_HwdID,  0);
+	if (result.empty())
+		return;  // switch doen not exist yet
+	
+	for (const auto &it : result)
+	{
+		m_sql.safe_query("UPDATE DeviceStatus SET unit = 1 WHERE (ID==%s)", it.at(0).c_str());
+	}
+}
