@@ -13,27 +13,26 @@
 
 struct STR_DEVICE {
 	int			unit;
-	std::string api_name;
-	std::string name;
+	const char *api_name;
+	const char *name;
 	int			deviceID;
 	uint8_t		subType;
 	int			switchType;
-	std::string api_state;
+	const char *api_state;
 };
 
-#define TOT_DEVICE_TYPES 9
-
-const STR_DEVICE DevicesType[TOT_DEVICE_TYPES] =
-{
-	{ 0, "switchBox", "Switch Box",pTypeLighting2, sTypeAC, STYPE_OnOff, "relay" },
-	{ 1, "shutterBox", "Shutter Box", pTypeLighting2, sTypeAC, STYPE_BlindsPercentageInverted, "shutter" },
-	{ 2, "wLightBoxS", "Light Box S", pTypeLighting2, sTypeAC, STYPE_Dimmer, "light" },
-	{ 3, "wLightBox", "Light Box", pTypeColorSwitch, sTypeColor_RGB_W, STYPE_Dimmer, "rgbw" },
-	{ 4, "gateBox", "Gate Box", pTypeGeneral, sTypePercentage, 0, "gate" },
-	{ 5, "dimmerBox", "Dimmer Box", pTypeLighting2, sTypeAC, STYPE_Dimmer, "dimmer" },
-	{ 6, "switchBoxD", "Switch Box D", pTypeLighting2, sTypeAC, STYPE_OnOff, "relay" },
-	{ 7, "airSensor", "Air Sensor", pTypeAirQuality, sTypeVoltcraft, 0, "air" },
-	{ 8, "tempSensor", "Temp Sensor", pTypeGeneral, sTypeTemperature, 0, "tempsensor" },
+constexpr std::array<STR_DEVICE, 9> DevicesType{
+	{
+		{ 0, "switchBox", "Switch Box", pTypeLighting2, sTypeAC, STYPE_OnOff, "relay" },
+		{ 1, "shutterBox", "Shutter Box", pTypeLighting2, sTypeAC, STYPE_BlindsPercentageInverted, "shutter" },
+		{ 2, "wLightBoxS", "Light Box S", pTypeLighting2, sTypeAC, STYPE_Dimmer, "light" },
+		{ 3, "wLightBox", "Light Box", pTypeColorSwitch, sTypeColor_RGB_W, STYPE_Dimmer, "rgbw" },
+		{ 4, "gateBox", "Gate Box", pTypeGeneral, sTypePercentage, 0, "gate" },
+		{ 5, "dimmerBox", "Dimmer Box", pTypeLighting2, sTypeAC, STYPE_Dimmer, "dimmer" },
+		{ 6, "switchBoxD", "Switch Box D", pTypeLighting2, sTypeAC, STYPE_OnOff, "relay" },
+		{ 7, "airSensor", "Air Sensor", pTypeAirQuality, sTypeVoltcraft, 0, "air" },
+		{ 8, "tempSensor", "Temp Sensor", pTypeGeneral, sTypeTemperature, 0, "tempsensor" },
+	},
 };
 
 BleBox::BleBox(const int id, const int pollIntervalsec)
@@ -44,17 +43,13 @@ BleBox::BleBox(const int id, const int pollIntervalsec)
 	SetSettings(pollIntervalsec);
 }
 
-BleBox::~BleBox()
-{
-}
-
 bool BleBox::StartHardware()
 {
 	RequestStart();
 
 	LoadNodes();
 
-	m_thread = std::make_shared<std::thread>(&BleBox::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -84,7 +79,7 @@ void BleBox::Do_Work()
 		sec_counter++;
 
 		if (sec_counter % 12 == 0) {
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (sec_counter % m_PollInterval == 0)
@@ -99,182 +94,168 @@ void BleBox::GetDevicesState()
 {
 	std::lock_guard<std::mutex> l(m_mutex);
 
-	for (const auto& itt : m_devices)
+	for (const auto &device : m_devices)
 	{
 		std::stringstream sstr;
-		sstr << "/api/" << DevicesType[itt.second].api_state << "/state";
+		sstr << "/api/" << DevicesType[device.second].api_state << "/state";
 		std::string command = sstr.str();
 
-		Json::Value root = SendCommand(itt.first, command, 2);
+		Json::Value root = SendCommand(device.first, command, 2);
 		if (root.empty())
 			continue;
 
-		int IP = IPToUInt(itt.first);
+		int IP = IPToUInt(device.first);
 		if (IP != 0)
 		{
-			switch (itt.second)
+			switch (device.second)
 			{
-			case 0:
-			{
-				if (DoesNodeExists(root, "state") == false)
-					break;
-
-				const bool state = root["state"].asBool();
-
-				SendSwitch(IP, 0, 255, state, 0, DevicesType[itt.second].name);
-				break;
-			}
-			case 1:
-			{
-				if (DoesNodeExists(root, "shutter") == false)
-					break;
-
-				root = root["shutter"];
-
-				if (DoesNodeExists(root, "state") == false)
-					break;
-
-				const int state = root["state"].asInt();
-
-				if (DoesNodeExists(root, "currentPos", "position") == false)
-					break;
-
-				const int currentPos = root["currentPos"]["position"].asInt();
-				const int pos = currentPos;
-
-				bool opened = true;
-				if ((state == 2 && pos == 100) || (state == 3))
-					opened = false;
-
-				SendSwitch(IP, 0, 255, opened, 100 - pos, DevicesType[itt.second].name);
-				break;
-			}
-			case 2:
-			{
-				if (DoesNodeExists(root, "light", "currentColor") == false)
-					break;
-
-				const std::string currentColor = root["light"]["currentColor"].asString();
-				unsigned int hexNumber;
-				sscanf(currentColor.c_str(), "%x", &hexNumber);
-				int level = (int)(hexNumber / (255.0 / 100.0));
-
-				SendSwitch(IP, 0, 255, level > 0, level, DevicesType[itt.second].name);
-				break;
-			}
-			case 3:
-			{
-				if (DoesNodeExists(root, "rgbw", "currentColor") == false)
-					break;
-
-				const std::string currentColor = root["rgbw"]["currentColor"].asString();
-				unsigned int hexNumber;
-				sscanf(currentColor.c_str(), "%x", &hexNumber);
-
-				SendRGBWSwitch(IP, 0, 255, hexNumber, true, DevicesType[itt.second].name);
-				break;
-			}
-			case 4:
-			{
-				if (DoesNodeExists(root, "currentPos") == false)
-					break;
-
-				const float level = root["currentPos"].asFloat();
-
-				SendPercentageSensor(IP, 1, 255, level, DevicesType[itt.second].name);
-				break;
-			}
-			case 5:
-			{
-				if (DoesNodeExists(root, "dimmer", "currentBrightness") == false)
-					break;
-
-				const int currentPos = root["dimmer"]["currentBrightness"].asInt();
-				int level = (int)(currentPos / (255.0 / 100.0));
-
-				SendSwitch(IP, 0, 255, level > 0, level, DevicesType[itt.second].name);
-				break;
-			}
-			case 6:
-			{
-				if ((DoesNodeExists(root, "relays") == false) || (!root["relays"].isArray()))
-					break;
-
-				Json::Value relays = root["relays"];
-				Json::ArrayIndex count = relays.size();
-				for (Json::ArrayIndex index = 0; index < count; index++)
+				case 1:
 				{
-					Json::Value relay = relays[index];
-					if ((DoesNodeExists(relay, "relay") == false) || (DoesNodeExists(relay, "state") == false))
+					if (DoesNodeExists(root, "shutter") == false)
 						break;
-					uint8_t relayNumber = (uint8_t)relay["relay"].asInt(); // 0 or 1
-					bool currentState = relay["state"].asBool(); // 0 or 1
-					//std::string name = DevicesType[itt.second].name + " " + relay["state"].asString();
-					SendSwitch(IP, relayNumber, 255, currentState, 0, DevicesType[itt.second].name);
+
+					root = root["shutter"];
+
+					if (DoesNodeExists(root, "state") == false)
+						break;
+
+					const int state = root["state"].asInt();
+
+					if (DoesNodeExists(root, "currentPos", "position") == false)
+						break;
+
+					const int currentPos = root["currentPos"]["position"].asInt();
+					const int pos = currentPos;
+
+					bool opened = true;
+					if ((state == 2 && pos == 100) || (state == 3))
+						opened = false;
+
+					SendSwitch(IP, 0, 255, opened, 100 - pos, DevicesType[device.second].name);
+					break;
 				}
-
-				break;
-			}
-			case 7:
-			{
-				if (DoesNodeExists(root, "air") == false)
-					break;
-
-				root = root["air"];
-
-				if ((DoesNodeExists(root, "sensors") == false) || (!root["sensors"].isArray()))
-					break;
-
-				Json::Value sensors = root["sensors"];
-				Json::ArrayIndex count = sensors.size();
-				for (Json::ArrayIndex index = 0; index < count; index++)
+				case 2:
 				{
-					Json::Value sensor = sensors[index];
-					if ((DoesNodeExists(sensor, "type") == false) || (DoesNodeExists(sensor, "value") == false))
+					if (DoesNodeExists(root, "light", "currentColor") == false)
 						break;
-					uint8_t value = (uint8_t)sensor["value"].asInt();
-					std::string type = sensor["type"].asString();
 
-					//TODO - how save IP address ??
-					SendAirQualitySensor(IP, index + 1, 255, value, type);
+					const std::string currentColor = root["light"]["currentColor"].asString();
+					unsigned int hexNumber;
+					sscanf(currentColor.c_str(), "%x", &hexNumber);
+					int level = (int)(hexNumber / (255.0 / 100.0));
+
+					SendSwitch(IP, 0, 255, level > 0, level, DevicesType[device.second].name);
+					break;
 				}
-
-				break;
-			}
-			case 8:
-			{
-				if (DoesNodeExists(root, "tempSensor") == false)
-					break;
-
-				root = root["tempSensor"];
-
-				if ((DoesNodeExists(root, "sensors") == false) || (!root["sensors"].isArray()))
-					break;
-
-				Json::Value sensors = root["sensors"];
-				Json::ArrayIndex count = sensors.size();
-				for (Json::ArrayIndex index = 0; index < count; index++)
+				case 3:
 				{
-					Json::Value sensor = sensors[index];
-
-					if ((DoesNodeExists(sensor, "value") == false) || (DoesNodeExists(sensor, "state") == false))
+					if (DoesNodeExists(root, "rgbw", "currentColor") == false)
 						break;
 
-					if (sensor["state"] != 2)
+					const std::string currentColor = root["rgbw"]["currentColor"].asString();
+					unsigned int hexNumber;
+					sscanf(currentColor.c_str(), "%x", &hexNumber);
+
+					SendRGBWSwitch(IP, 0, 255, hexNumber, true, DevicesType[device.second].name, m_Name);
+					break;
+				}
+				case 4:
+				{
+					if (DoesNodeExists(root, "currentPos") == false)
+						break;
+
+					const float level = root["currentPos"].asFloat();
+
+					SendPercentageSensor(IP, 1, 255, level, DevicesType[device.second].name);
+					break;
+				}
+				case 5:
+				{
+					if (DoesNodeExists(root, "dimmer", "currentBrightness") == false)
+						break;
+
+					const int currentPos = root["dimmer"]["currentBrightness"].asInt();
+					int level = (int)(currentPos / (255.0 / 100.0));
+
+					SendSwitch(IP, 0, 255, level > 0, level, DevicesType[device.second].name);
+					break;
+				}
+				case 0:
+				case 6:
+				{
+					if ((DoesNodeExists(root, "relays") == false) || (!root["relays"].isArray()))
+						break;
+
+					for (const auto &relay : root["relays"])
 					{
-						Log(LOG_ERROR, "temp sensor error!");
-						break;
+						if ((DoesNodeExists(relay, "relay") == false) || (DoesNodeExists(relay, "state") == false))
+							break;
+						uint8_t relayNumber = (uint8_t)relay["relay"].asInt(); // 0 or 1
+						bool currentState = relay["state"].asBool();	       // 0 or 1
+						// std::string name = DevicesType[device.second].name + " " + relay["state"].asString();
+						SendSwitch(IP, relayNumber, 255, currentState, 0, DevicesType[device.second].name);
 					}
 
-					std::string temperature = sensor["value"].asString(); // xxxx (xx.xx = temperature)
-					float ftemp = static_cast<float>(std::stoi(temperature.substr(0, 2)) + std::stoi(temperature.substr(2, 2)) / 100.0);
-
-					//TODO - how save IP address ??
-					SendTempSensor(IP, 255, ftemp, DevicesType[itt.second].name);
+					break;
 				}
+				case 7:
+				{
+					if (DoesNodeExists(root, "air") == false)
+						break;
 
-				break;
-			}
+					root = root["air"];
+
+					if ((DoesNodeExists(root, "sensors") == false) || (!root["sensors"].isArray()))
+						break;
+
+					Json::Value sensors = root["sensors"];
+					Json::ArrayIndex count = sensors.size();
+					for (Json::ArrayIndex index = 0; index < count; index++)
+					{
+						Json::Value sensor = sensors[index];
+						if ((DoesNodeExists(sensor, "type") == false) || (DoesNodeExists(sensor, "value") == false))
+							break;
+						uint8_t value = (uint8_t)sensor["value"].asInt();
+						std::string type = sensor["type"].asString();
+
+						// TODO - how save IP address ??
+						SendAirQualitySensor(IP, index + 1, 255, value, type);
+					}
+
+					break;
+				}
+				case 8:
+				{
+					if (DoesNodeExists(root, "tempSensor") == false)
+						break;
+
+					root = root["tempSensor"];
+
+					if ((DoesNodeExists(root, "sensors") == false) || (!root["sensors"].isArray()))
+						break;
+
+					for (const auto &sensor : root["sensors"])
+					{
+						if ((DoesNodeExists(sensor, "value") == false)
+						    || (DoesNodeExists(sensor, "state") == false))
+							break;
+
+						if (sensor["state"] != 2)
+						{
+							Log(LOG_ERROR, "temp sensor error!");
+							break;
+						}
+
+						std::string temperature = sensor["value"].asString(); // xxxx (xx.xx = temperature)
+						float ftemp = static_cast<float>(std::stoi(temperature.substr(0, 2))
+										 + std::stoi(temperature.substr(2, 2)) / 100.0);
+
+						// TODO - how save IP address ??
+						SendTempSensor(IP, 255, ftemp, DevicesType[device.second].name);
+					}
+
+					break;
+				}
 			}
 			SetHeartbeatReceived();
 		}
@@ -283,40 +264,28 @@ void BleBox::GetDevicesState()
 
 std::string BleBox::GetDeviceIP(const tRBUF * id)
 {
-	char ip[20];
-
-	sprintf(ip, "%d.%d.%d.%d", id->LIGHTING2.id1, id->LIGHTING2.id2, id->LIGHTING2.id3, id->LIGHTING2.id4);
-	return ip;
+	return fmt::format("{}.{}.{}.{}", id->LIGHTING2.id1, id->LIGHTING2.id2, id->LIGHTING2.id3, id->LIGHTING2.id4);
 }
 
 std::string BleBox::GetDeviceRevertIP(const tRBUF * id)
 {
-	char ip[20];
-
-	sprintf(ip, "%d.%d.%d.%d", id->LIGHTING2.id4, id->LIGHTING2.id3, id->LIGHTING2.id2, id->LIGHTING2.id1);
-	return ip;
+	return fmt::format("{}.{}.{}.{}", id->LIGHTING2.id4, id->LIGHTING2.id3, id->LIGHTING2.id2, id->LIGHTING2.id1);
 }
 
 std::string BleBox::GetDeviceIP(const std::string & id)
 {
 	BYTE id1, id2, id3, id4;
-	char ip[20];
-
 	sscanf(id.c_str(), "%2hhx%2hhx%2hhx%2hhx", &id1, &id2, &id3, &id4);
-	sprintf(ip, "%d.%d.%d.%d", id1, id2, id3, id4);
 
-	return ip;
+	return fmt::format("{}.{}.{}.{}", id1, id2, id3, id4);
 }
 
 int BleBox::GetDeviceTypeByApiName(const std::string & apiName)
 {
-	for (unsigned int i = 0; i < TOT_DEVICE_TYPES; ++i)
-	{
-		if (DevicesType[i].api_name == apiName)
-		{
-			return DevicesType[i].unit;
-		}
-	}
+	for (const auto &i : DevicesType)
+		if (i.api_name == apiName)
+			return i.unit;
+
 	Log(LOG_ERROR, "unknown device api name(%s)", apiName.c_str());
 	return -1;
 }
@@ -328,18 +297,14 @@ std::string BleBox::IPToHex(const std::string & IPAddress, const int type)
 	if (strarray.size() != 4)
 		return "";
 
-	char szIdx[10];
 	// because exists inconsistency when comparing deviceID in method decode_xxx in mainworker(Limitless uses small letter, lighting2 etc uses capital letter)
 	if (type != pTypeColorSwitch)
 	{
 		uint32_t sID = (uint32_t)(atoi(strarray[0].c_str()) << 24) | (uint32_t)(atoi(strarray[1].c_str()) << 16) | (atoi(strarray[2].c_str()) << 8) | atoi(strarray[3].c_str());
-		sprintf(szIdx, "%08X", (unsigned int)sID);
+		return fmt::format("{:08X}", sID);
 	}
-	else
-	{
-		sprintf(szIdx, "%X%02X%02X%02X", atoi(strarray[0].data()), atoi(strarray[1].data()), atoi(strarray[2].data()), atoi(strarray[3].data()));
-	}
-	return szIdx;
+
+	return fmt::format("{:X}{:02X}{:02X}{:02X}", atoi(strarray[0].data()), atoi(strarray[1].data()), atoi(strarray[2].data()), atoi(strarray[3].data()));
 }
 
 bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
@@ -356,33 +321,6 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 		{
 			switch (type)
 			{
-			case 0:
-			{
-				std::string state;
-				if (output->LIGHTING2.cmnd == light2_sOn)
-				{
-					state = "1";
-				}
-				else
-				{
-					state = "0";
-				}
-
-				Json::Value root = SendCommand(IPAddress, "/s/" + state);
-				if (root.empty())
-					return false;
-
-				if (DoesNodeExists(root, "state") == false)
-					return false;
-
-				if (root["state"].asString() != state)
-				{
-					Log(LOG_ERROR, "state not changed!");
-					return false;
-				}
-				break;
-			}
-
 			case 1: // shutterbox
 			{
 				int percentage = 0;
@@ -432,10 +370,7 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 					else
 					{
 						uint8_t percentage = static_cast<uint8_t>(output->LIGHTING2.level * 255 / 15);
-
-						char value[4];
-						sprintf(value, "%x", percentage);
-						level = value;
+						level = fmt::format("{:x}", percentage);
 					}
 
 				Json::Value root = SendCommand(IPAddress, "/s/" + level);
@@ -469,10 +404,7 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 					else
 					{
 						uint8_t percentage = static_cast<uint8_t>(output->LIGHTING2.level * 255 / 15);
-
-						char value[4];
-						sprintf(value, "%x", percentage);
-						level = value;
+						level = fmt::format("{:x}", percentage);
 					}
 
 				Json::Value root = SendCommand(IPAddress, "/s/" + level);
@@ -495,7 +427,8 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 				break;
 			}
 
-			case 6: //switchboxd
+			case 0: // switchbox
+			case 6: // switchboxd
 			{
 				std::string state;
 				std::string relayNumber;
@@ -606,9 +539,9 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 		case Color_LedOn: {
 			if (m_RGBWColorState.mode != ColorModeNone && !m_RGBWisWhiteState)
 			{
-				red = int(round(m_RGBWColorState.r * m_RGBWbrightnessState / 255.0f));
-				green = int(round(m_RGBWColorState.g * m_RGBWbrightnessState / 255.0f));
-				blue = int(round(m_RGBWColorState.b * m_RGBWbrightnessState / 255.0f));
+				red = int(round(m_RGBWColorState.r * m_RGBWbrightnessState / 255.0F));
+				green = int(round(m_RGBWColorState.g * m_RGBWbrightnessState / 255.0F));
+				blue = int(round(m_RGBWColorState.b * m_RGBWbrightnessState / 255.0F));
 				white = 0;
 			}
 			else
@@ -650,7 +583,7 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 		}
 		case Color_SetBrightnessLevel: {
 			int BrightnessBase = (int)pLed->value;
-			int dMax_Send = (int)(round((255.0f / 100.0f) * float(BrightnessBase)));
+			int dMax_Send = (int)(round((255.0F / 100.0F) * float(BrightnessBase)));
 
 			m_RGBWbrightnessState = dMax_Send;
 
@@ -663,9 +596,9 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 			}
 			else
 			{
-				red = int(round(m_RGBWColorState.r * dMax_Send / 255.0f));
-				green = int(round(m_RGBWColorState.g * dMax_Send / 255.0f));
-				blue = int(round(m_RGBWColorState.b * dMax_Send / 255.0f));
+				red = int(round(m_RGBWColorState.r * dMax_Send / 255.0F));
+				green = int(round(m_RGBWColorState.g * dMax_Send / 255.0F));
+				blue = int(round(m_RGBWColorState.b * dMax_Send / 255.0F));
 				white = 0;
 			}
 			break;
@@ -678,9 +611,7 @@ bool BleBox::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 		if (!setColor)
 			return false;
 
-		char level[10];
-		sprintf(level, "%02x%02x%02x%02x", red, green, blue, white);
-		std::string state(level);
+		std::string state = fmt::format("{:02x}{:02x}{:02x}{:02x}", red, green, blue, white);
 
 		Json::Value root = SendCommand(IPAddress, "/s/" + state);
 		if (root.empty())
@@ -742,11 +673,10 @@ void BleBox::SendSwitch(const int NodeID, const uint8_t ChildID, const int Batte
 	unsigned char ID3 = (unsigned char)((NodeID & 0xFF00) >> 8);
 	unsigned char ID4 = (unsigned char)NodeID & 0xFF;
 
-	char szIdx[10];
-	sprintf(szIdx, "%X%02X%02X%02X", ID1, ID2, ID3, ID4);
+	std::string szIdx = fmt::format("{:X}{:02X}{:02X}{:02X}");
 	std::vector<std::vector<std::string> > result;
-	result = m_sql.safe_query("SELECT Name,nValue,sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit == %d) AND (Type==%d) AND (Subtype==%d)",
-		m_HwdID, szIdx, ChildID, int(pTypeLighting2), int(sTypeAC));
+	result = m_sql.safe_query("SELECT Name,nValue,sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit == %d) AND (Type==%d) AND (Subtype==%d)", m_HwdID, szIdx.c_str(),
+				  ChildID, int(pTypeLighting2), int(sTypeAC));
 	if (!result.empty())
 	{
 		//check if we have a change, if not do not update it
@@ -787,7 +717,7 @@ void BleBox::SendSwitch(const int NodeID, const uint8_t ChildID, const int Batte
 	lcmd.LIGHTING2.level = level;
 	lcmd.LIGHTING2.filler = 0;
 	lcmd.LIGHTING2.rssi = 12;
-	sDecodeRXMessage(this, (const unsigned char*)& lcmd.LIGHTING2, defaultname.c_str(), BatteryLevel);
+	sDecodeRXMessage(this, (const unsigned char *)&lcmd.LIGHTING2, defaultname.c_str(), BatteryLevel, m_Name.c_str());
 }
 
 
@@ -804,7 +734,7 @@ namespace http {
 
 			std::string hwid = request::findValue(&req, "idx");
 			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 
 			root["status"] = "OK";
@@ -815,14 +745,11 @@ namespace http {
 			if (!result.empty())
 			{
 				int ii = 0;
-				for (const auto& itt : result)
+				for (const auto &sd : result)
 				{
-					std::vector<std::string> sd = itt;
-
 					BYTE id1, id2, id3, id4;
-					char ip[20];
 					sscanf(sd[2].c_str(), "%2hhx%2hhx%2hhx%2hhx", &id1, &id2, &id3, &id4);
-					sprintf(ip, "%d.%d.%d.%d", id1, id2, id3, id4);
+					std::string ip = fmt::format("{}.{}.{}.{}", id1, id2, id3, id4);
 
 					root["result"][ii]["idx"] = sd[0];
 					root["result"][ii]["Name"] = sd[1];
@@ -869,14 +796,10 @@ namespace http {
 			std::string hwid = request::findValue(&req, "idx");
 			std::string mode1 = request::findValue(&req, "mode1");
 			std::string mode2 = request::findValue(&req, "mode2");
-			if (
-				(hwid == "") ||
-				(mode1 == "") ||
-				(mode2 == "")
-				)
+			if ((hwid.empty()) || (mode1.empty()) || (mode2.empty()))
 				return;
 			CDomoticzHardwareBase * pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
 
@@ -903,14 +826,10 @@ namespace http {
 			std::string hwid = request::findValue(&req, "idx");
 			std::string name = HTMLSanitizer::Sanitize(request::findValue(&req, "name"));
 			std::string ip = HTMLSanitizer::Sanitize(request::findValue(&req, "ip"));
-			if (
-				(hwid == "") ||
-				(name == "") ||
-				(ip == "")
-				)
+			if ((hwid.empty()) || (name.empty()) || (ip.empty()))
 				return;
 			CDomoticzHardwareBase * pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
 
@@ -929,13 +848,10 @@ namespace http {
 
 			std::string hwid = request::findValue(&req, "idx");
 			std::string nodeid = request::findValue(&req, "nodeid");
-			if (
-				(hwid == "") ||
-				(nodeid == "")
-				)
+			if ((hwid.empty()) || (nodeid.empty()))
 				return;
 			CDomoticzHardwareBase * pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
 
@@ -955,7 +871,7 @@ namespace http {
 
 			std::string hwid = request::findValue(&req, "idx");
 			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
 
@@ -974,13 +890,10 @@ namespace http {
 
 			std::string hwid = request::findValue(&req, "idx");
 			std::string ipmask = request::findValue(&req, "ipmask");
-			if (
-				(hwid == "") ||
-				(ipmask == "")
-				)
+			if ((hwid.empty()) || (ipmask.empty()))
 				return;
 			CDomoticzHardwareBase * pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
 
@@ -999,7 +912,7 @@ namespace http {
 
 			std::string hwid = request::findValue(&req, "idx");
 			CDomoticzHardwareBase* pBaseHardware = m_mainworker.GetHardwareByIDType(hwid, HTYPE_BleBox);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			BleBox * pHardware = reinterpret_cast<BleBox*>(pBaseHardware);
 
@@ -1008,8 +921,8 @@ namespace http {
 			pHardware->UpdateFirmware();
 		}
 
-	}
-}
+	} // namespace server
+} // namespace http
 
 Json::Value BleBox::SendCommand(const std::string & IPAddress, const std::string & command, const int timeOut)
 {
@@ -1034,7 +947,7 @@ Json::Value BleBox::SendCommand(const std::string & IPAddress, const std::string
 		return root;
 	}
 
-	if (root.size() == 0)
+	if (root.empty())
 	{
 		Log(LOG_ERROR, "Json is empty!");
 		return root;
@@ -1056,10 +969,10 @@ std::string BleBox::IdentifyDevice(const std::string & IPAddress)
 
 	if (root["device"].empty() == true)
 	{
-		if (DoesNodeExists(root, "type") == false)
+		if (!DoesNodeExists(root, "type"))
 			return "";
-		else
-			result = root["type"].asString();
+
+		result = root["type"].asString();
 	}
 	else
 	{
@@ -1085,10 +998,8 @@ Json::Value BleBox::GetApiDeviceState(const std::string & IPAddress)
 	{
 		return root;
 	}
-	else
-	{
-		return root["device"];
-	}
+
+	return root["device"];
 }
 
 std::string BleBox::GetUptime(const std::string & IPAddress)
@@ -1127,24 +1038,19 @@ std::string BleBox::GetUptime(const std::string & IPAddress)
 	int hours = static_cast<int>(total_minutes / 60 - days * 24);
 	int mins = static_cast<int>(total_minutes - days * 24 * 60 - hours * 60);   //sec / 60 - day * (24 * 60) - hour * 60;
 
-	char timestring[32];
-	sprintf(timestring, "%d:%02d:%02d", days, hours, mins);
-
-	return timestring;
+	return fmt::format("{}:{:02}:{:02}", days, hours, mins);
 }
 
 int BleBox::GetDeviceType(const std::string & IPAddress)
 {
-	std::map<const std::string, const int>::const_iterator itt = m_devices.find(IPAddress);
+	auto itt = m_devices.find(IPAddress);
 	if (itt == m_devices.end())
 	{
 		Log(LOG_ERROR, "unknown device (%s)", IPAddress.c_str());
 		return -1;
 	}
-	else
-	{
-		return itt->second;
-	}
+
+	return itt->second;
 }
 
 void BleBox::AddNode(const std::string & name, const std::string & IPAddress, bool reloadNodes)
@@ -1157,7 +1063,7 @@ void BleBox::AddNode(const std::string & name, const std::string & IPAddress, bo
 	if (deviceTypeID == -1)
 		return;
 
-	STR_DEVICE deviceType = DevicesType[deviceTypeID];
+	const auto deviceType = DevicesType[deviceTypeID];
 
 	std::string szIdx = IPToHex(IPAddress, deviceType.deviceID);
 
@@ -1213,9 +1119,8 @@ bool BleBox::LoadNodes()
 	result = m_sql.safe_query("SELECT ID,DeviceID FROM DeviceStatus WHERE (HardwareID==%d)", m_HwdID);
 	if (!result.empty())
 	{
-		for (const auto& itt : result)
+		for (const auto &sd : result)
 		{
-			const std::vector<std::string>& sd = itt;
 			std::string addressIP = GetDeviceIP(sd[1]);
 
 			std::string deviceApiName = IdentifyDevice(addressIP);
@@ -1230,11 +1135,9 @@ bool BleBox::LoadNodes()
 		}
 		return true;
 	}
-	else
-	{
-		Log(LOG_ERROR, "Cannot find any devices...");
-		return false;
-	}
+
+	Log(LOG_ERROR, "Cannot find any devices...");
+	return false;
 }
 
 void BleBox::ReloadNodes()
@@ -1245,9 +1148,9 @@ void BleBox::ReloadNodes()
 
 void BleBox::UpdateFirmware()
 {
-	for (const auto& itt : m_devices)
+	for (const auto &device : m_devices)
 	{
-		Json::Value root = SendCommand(itt.first, "/api/ota/update", 2);
+		Json::Value root = SendCommand(device.first, "/api/ota/update", 2);
 	}
 }
 
@@ -1263,7 +1166,7 @@ void BleBox::SearchNodes(const std::string & pattern)
 	std::vector<std::thread> searchingThreads;
 	for(auto&& host : hosts)
 		if (m_devices.find(host) == m_devices.end())
-			searchingThreads.emplace_back(&BleBox::AddNode, this, "unknown", std::ref(host), false);
+			searchingThreads.emplace_back([this, &host] { AddNode("unknown", host, false); });
 
 	for (auto&& thread : searchingThreads)
 	{
