@@ -4,12 +4,13 @@
 
 class CBuienRadar : public CDomoticzHardwareBase
 {
-public:
-	CBuienRadar(const int ID, const int iForecast, const int iThreshold, const std::string &Location);
-	~CBuienRadar(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
+      public:
+	CBuienRadar(int ID, int iForecast, int iThreshold, const std::string &Location);
+	~CBuienRadar() override = default;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
 	std::string GetForecastURL();
-private:
+
+      private:
 	void Init();
 	bool StartHardware() override;
 	bool StopHardware() override;
@@ -17,7 +18,8 @@ private:
 	bool GetStationDetails();
 	void GetMeterDetails();
 	void GetRainPrediction();
-private:
+
+      private:
 	std::string m_szMyLatitude;
 	std::string m_szMyLongitude;
 	std::string m_sStationName;
@@ -26,7 +28,7 @@ private:
 	int m_iForecast = 15;
 	int m_iThreshold = 25;
 	int m_iStationID = 0;
+	bool m_stationidprovided = false;
 	bool m_itIsRaining = false;
 	int m_rainShowerLeadTime = 0;
 };
-
