@@ -5,30 +5,34 @@
 
 class Comm5TCP : public CDomoticzHardwareBase, ASyncTCP
 {
-public:
-	Comm5TCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort);
+      public:
+	Comm5TCP(int ID, const std::string &IPAddress, unsigned short usIPPort);
 
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-public: // signals
-	boost::signals2::signal<void()>	sDisconnected;
-private:
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+
+      public: // signals
+	boost::signals2::signal<void()> sDisconnected;
+
+      private:
 	bool StartHardware() override;
 	bool StopHardware() override;
-protected:
+
+      protected:
 	void OnConnect() override;
 	void OnDisconnect() override;
 	void OnData(const unsigned char *pData, size_t length) override;
-	void OnError(const boost::system::error_code& error) override;
+	void OnError(const boost::system::error_code &error) override;
 
 	void Do_Work();
-	void ParseData(const unsigned char *data, const size_t len);
+	void ParseData(const unsigned char *data, size_t len);
 
 	void queryRelayState();
 	void querySensorState();
 	void enableNotifications();
 
-	void processSensorData(const std::string& line);
-private:
+	void processSensorData(const std::string &line);
+
+      private:
 	std::string m_szIPAddress;
 	unsigned short m_usIPPort;
 
@@ -42,4 +46,3 @@ private:
 
 	std::shared_ptr<std::thread> m_thread;
 };
-
