@@ -4,18 +4,17 @@
 
 class CurrentCostMeterBase : public CDomoticzHardwareBase
 {
-public:
-	CurrentCostMeterBase(void);
-	virtual ~CurrentCostMeterBase(void);
+      public:
+	CurrentCostMeterBase();
+	~CurrentCostMeterBase() override = default;
 
-protected:
+      protected:
 	void ParseData(const char *pData, int Len);
 	void Init();
 
-private:
+      private:
 	void ExtractReadings();
 	bool ExtractNumberBetweenStrings(const char *startString, const char *endString, float *pResult);
 	std::string m_buffer;
-	unsigned int m_tempuratureCounter;
+	unsigned int m_tempuratureCounter{ 0 };
 };
-
