@@ -39,18 +39,17 @@
 // 12 : shum : description: represents the target humidity
 // 20 : SetPoint
 
-
 #define Daikin_POLL_INTERVAL 300
 
 #ifdef _DEBUG
-	//#define DEBUG_DaikinR
-	#define DEBUG_DaikinW
+//#define DEBUG_DaikinR
+//#define DEBUG_DaikinW
 #endif
 
 #ifdef DEBUG_DaikinW
 void SaveString2Disk(std::string str, std::string filename)
 {
-	FILE* fOut = fopen(filename.c_str(), "wb+");
+	FILE *fOut = fopen(filename.c_str(), "wb+");
 	if (fOut)
 	{
 		fwrite(str.c_str(), 1, str.size(), fOut);
@@ -78,10 +77,10 @@ std::string ReadFile(std::string filename)
 }
 #endif
 
-CDaikin::CDaikin(const int ID, const std::string& IPAddress, const unsigned short usIPPort, const std::string& username, const std::string& password) :
-	m_szIPAddress(IPAddress),
-	m_Username(CURLEncode::URLEncode(username)),
-	m_Password(CURLEncode::URLEncode(password))
+CDaikin::CDaikin(const int ID, const std::string &IPAddress, const unsigned short usIPPort, const std::string &username, const std::string &password)
+	: m_szIPAddress(IPAddress)
+	, m_Username(CURLEncode::URLEncode(username))
+	, m_Password(CURLEncode::URLEncode(password))
 {
 	m_HwdID = ID;
 	m_usIPPort = usIPPort;
@@ -89,10 +88,6 @@ CDaikin::CDaikin(const int ID, const std::string& IPAddress, const unsigned shor
 	Init();
 }
 
-CDaikin::~CDaikin(void)
-{
-}
-
 void CDaikin::Init()
 {
 }
@@ -102,8 +97,8 @@ bool CDaikin::StartHardware()
 	RequestStart();
 
 	Init();
-	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CDaikin::Do_Work, this);
+	// Start worker thread
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -127,7 +122,7 @@ void CDaikin::Do_Work()
 	time_t last_sci_update = 0;
 	time_t current_time = 0;
 	m_sec_counter = Daikin_POLL_INTERVAL - 2; // Trigger immediatly (in 2s) a POLL after startup.
-	m_last_setcontrolinfo = 0; // no set request occured at this point
+	m_last_setcontrolinfo = 0;		  // no set request occured at this point
 	m_force_sci = false;
 
 	Log(LOG_STATUS, "Worker started %s ...", m_szIPAddress.c_str());
@@ -135,8 +130,9 @@ void CDaikin::Do_Work()
 	{
 		m_sec_counter++;
 
-		if (m_sec_counter % 12 == 0) {
-			m_LastHeartbeat = mytime(NULL);
+		if (m_sec_counter % 12 == 0)
+		{
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (m_sec_counter % Daikin_POLL_INTERVAL == 0)
@@ -144,9 +140,10 @@ void CDaikin::Do_Work()
 			GetMeterDetails();
 		}
 
-		current_time = mytime(NULL);
+		current_time = mytime(nullptr);
 
-		if (m_force_sci || ((current_time - m_last_setcontrolinfo > 2) && (last_sci_update < m_last_setcontrolinfo))) {
+		if (m_force_sci || ((current_time - m_last_setcontrolinfo > 2) && (last_sci_update < m_last_setcontrolinfo)))
+		{
 			HTTPSetControlInfo(); // Fire HTTP request
 			m_force_sci = false;
 			m_last_setcontrolinfo = 0;
@@ -156,19 +153,19 @@ void CDaikin::Do_Work()
 	Log(LOG_STATUS, "Worker stopped %s ...", m_szIPAddress.c_str());
 }
 
-bool CDaikin::WriteToHardware(const char* pdata, const unsigned char /*length*/)
+bool CDaikin::WriteToHardware(const char *pdata, const unsigned char /*length*/)
 {
 	Debug(DEBUG_HARDWARE, "Worker %s, Write to Hardware...", m_szIPAddress.c_str());
-	const tRBUF* pCmd = reinterpret_cast<const tRBUF*>(pdata);
+	const tRBUF *pCmd = reinterpret_cast<const tRBUF *>(pdata);
 	unsigned char packettype = pCmd->ICMND.packettype;
 	unsigned char subtype = pCmd->ICMND.subtype;
 	bool result = true;
 
 	if (packettype == pTypeLighting2)
 	{
-		//Light command
+		// Light command
 		int node_id = pCmd->LIGHTING2.id4;
-		//int child_sensor_id = pCmd->LIGHTING2.unitcode;
+		// int child_sensor_id = pCmd->LIGHTING2.unitcode;
 		bool command = pCmd->LIGHTING2.cmnd;
 		if (node_id == 1)
 		{
@@ -181,10 +178,10 @@ bool CDaikin::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 	}
 	else if (packettype == pTypeGeneralSwitch)
 	{
-		//Light command
-		const _tGeneralSwitch* pSwitch = reinterpret_cast<const _tGeneralSwitch*>(pdata);
+		// Light command
+		const _tGeneralSwitch *pSwitch = reinterpret_cast<const _tGeneralSwitch *>(pdata);
 		int node_id = pSwitch->id;
-		//int child_sensor_id = pSwitch->unitcode;
+		// int child_sensor_id = pSwitch->unitcode;
 		bool command = pSwitch->cmnd;
 
 		Debug(DEBUG_HARDWARE, "Worker %s, Set General Switch ID %d, command : %d, value : %d", m_szIPAddress.c_str(), node_id, command, pSwitch->level);
@@ -212,15 +209,13 @@ bool CDaikin::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 	}
 	else if ((packettype == pTypeThermostat) && (subtype == sTypeThermSetpoint))
 	{
-		//Set Point
-		const _tThermostat* pMeter = reinterpret_cast<const _tThermostat*>(pCmd);
+		// Set Point
+		const _tThermostat *pMeter = reinterpret_cast<const _tThermostat *>(pCmd);
 		int node_id = pMeter->id2;
-		//int child_sensor_id = pMeter->id3;
+		// int child_sensor_id = pMeter->id3;
 
 		Debug(DEBUG_HARDWARE, "Worker %s, Thermostat %.1f", m_szIPAddress.c_str(), pMeter->temp);
 
-		char szTmp[10];
-		sprintf(szTmp, "%.1f", pMeter->temp);
 		result = SetSetpoint(node_id, pMeter->temp);
 	}
 	else
@@ -232,7 +227,7 @@ bool CDaikin::WriteToHardware(const char* pdata, const unsigned char /*length*/)
 	return result;
 }
 
-void CDaikin::UpdateSwitchNew(const unsigned char Idx, const int /*SubUnit*/, const bool bOn, const double Level, const std::string& defaultname)
+void CDaikin::UpdateSwitchNew(const unsigned char Idx, const int /*SubUnit*/, const bool bOn, const double Level, const std::string &defaultname)
 {
 	_tGeneralSwitch gswitch;
 	gswitch.subtype = sSwitchGeneralSwitch;
@@ -247,7 +242,7 @@ void CDaikin::UpdateSwitchNew(const unsigned char Idx, const int /*SubUnit*/, co
 		gswitch.cmnd = gswitch_sOn;
 	gswitch.level = static_cast<uint8_t>(Level);
 	gswitch.rssi = 12;
-	sDecodeRXMessage(this, (const unsigned char*)&gswitch, defaultname.c_str(), 255);
+	sDecodeRXMessage(this, (const unsigned char *)&gswitch, defaultname.c_str(), 255, m_Name.c_str());
 }
 
 void CDaikin::GetMeterDetails()
@@ -255,6 +250,7 @@ void CDaikin::GetMeterDetails()
 	GetBasicInfo();
 	GetControlInfo();
 	GetSensorInfo();
+	GetYearPower();
 }
 
 void CDaikin::GetBasicInfo()
@@ -307,20 +303,19 @@ void CDaikin::GetBasicInfo()
 		return;
 	}
 
-	for (const auto& itt : results)
+	for (const auto &sVar : results)
 	{
-		std::string sVar = itt;
 		std::vector<std::string> results2;
 		StringSplit(sVar, "=", results2);
 		if (results2.size() != 2)
 			continue;
 		if (results2[0] == "led")
 		{
-			if (m_led != results2[1]) { // update only if device led state was changed from other source than domoticz : direct http command for example
+			if (m_led != results2[1])
+			{ // update only if device led state was changed from other source than domoticz : direct http command for example
 				m_led = results2[1];
 				UpdateSwitchNew(2, -1, (m_led[0] == '0') ? true : false, 100, "Led indicator");
 			}
-
 		}
 	}
 }
@@ -346,7 +341,7 @@ void CDaikin::GetControlInfo()
 		return;
 	}
 #ifdef DEBUG_DaikinW
-		SaveString2Disk(sResult, "E:\\daikin_get_control_info.txt");
+	SaveString2Disk(sResult, "E:\\daikin_get_control_info.txt");
 #endif
 
 	/*	ret = OK,
@@ -379,9 +374,8 @@ void CDaikin::GetControlInfo()
 		Log(LOG_ERROR, "Invalid data received");
 		return;
 	}
-	for (const auto& itt : results)
+	for (const auto &sVar : results)
 	{
-		std::string sVar = itt;
 		std::vector<std::string> results2;
 		StringSplit(sVar, "=", results2);
 		if (results2.size() != 2)
@@ -411,7 +405,7 @@ void CDaikin::GetControlInfo()
 		}
 		else if (results2[0] == "pow")
 		{
-			if (m_pow != results2[1])// update only if device led state was changed from other source than domoticz : direct http command or daikin remote IR/wifi controller
+			if (m_pow != results2[1]) // update only if device led state was changed from other source than domoticz : direct http command or daikin remote IR/wifi controller
 			{
 				m_pow = results2[1];
 				UpdateSwitchNew(1, -1, (results2[1][0] == '1') ? false : true, 100, "Power");
@@ -543,9 +537,8 @@ void CDaikin::GetSensorInfo()
 	}
 	float htemp = -1;
 	int hhum = -1;
-	for (const auto& itt : results)
+	for (const auto &sVar : results)
 	{
-		std::string sVar = itt;
 		std::vector<std::string> results2;
 		StringSplit(sVar, "=", results2);
 		if (results2.size() != 2)
@@ -562,7 +555,6 @@ void CDaikin::GetSensorInfo()
 		else if (results2[0] == "otemp")
 		{
 			SendTempSensor(10, -1, static_cast<float>(atof(results2[1].c_str())), "Outside Temperature");
-
 		}
 	}
 	if (htemp != -1)
@@ -574,6 +566,81 @@ void CDaikin::GetSensorInfo()
 	}
 }
 
+void CDaikin::GetYearPower()
+{
+	std::string sResult;
+#ifdef DEBUG_DaikinR
+	sResult = ReadFile("E:\\Daikin_get_year_power.txt");
+#else
+	std::stringstream szURL;
+
+	if (m_Password.empty())
+	{
+		szURL << "http://" << m_szIPAddress << ":" << m_usIPPort;
+	}
+	else
+	{
+		szURL << "http://" << m_Username << ":" << m_Password << "@" << m_szIPAddress << ":" << m_usIPPort;
+	}
+
+	szURL << "/aircon/get_year_power_ex";
+
+	if (!HTTPClient::GET(szURL.str(), sResult))
+	{
+		Log(LOG_ERROR, "Error connecting to: %s", m_szIPAddress.c_str());
+		return;
+	}
+#endif
+#ifdef DEBUG_DaikinW
+	SaveString2Disk(sResult, "E:\\daikin_get_year_power.txt");
+#endif
+	// ret=OK,htemp=21.0,hhum=-,otemp=9.0,err=0,cmpfreq=35
+	// grp.update('compressorfreq', tonumber(data.cmpfreq))
+
+	if (sResult.find("ret=OK") == std::string::npos)
+	{
+		Log(LOG_ERROR, "Error getting data (check IP/Port)");
+		return;
+	}
+	std::vector<std::string> results;
+	StringSplit(sResult, ",", results);
+	if (results.size() < 4)
+	{
+		Log(LOG_ERROR, "Invalid data received");
+		return;
+	}
+
+	float cooltotalkWh = 0;
+	float heattotalkWh = 0;
+	for (const auto &sVar : results)
+	{
+		std::vector<std::string> results2;
+		StringSplit(sVar, "=", results2);
+		if (results2.size() != 2)
+			continue;
+		if (results2[0] == "curr_year_cool")
+		{
+			std::vector<std::string> months;
+			StringSplit(results2[1], "/", months);
+			for (const auto &month : months)
+			{
+				cooltotalkWh += std::stof(month) / 10; // energy saved as 0.1 kWh units
+			}
+			SendKwhMeter(30, 30, 255, 0, cooltotalkWh, "Cool kWh");
+		}
+		else if (results2[0] == "curr_year_heat")
+		{
+			std::vector<std::string> months;
+			StringSplit(results2[1], "/", months);
+			for (const auto &month : months)
+			{
+				heattotalkWh += std::stof(month) / 10; // energy saved as 0.1 kWh units
+			}
+			SendKwhMeter(31, 31, 255, 0, heattotalkWh, "Heat kWh");
+		}
+	}
+}
+
 bool CDaikin::SetLedOnOFF(const bool OnOFF)
 {
 	std::string sResult;
@@ -619,18 +686,11 @@ bool CDaikin::SetLedOnOFF(const bool OnOFF)
 	return true;
 }
 
-void CDaikin::InsertUpdateSwitchSelector(const unsigned char Idx, const bool bIsOn, const int level, const std::string& defaultname)
+void CDaikin::InsertUpdateSwitchSelector(uint32_t Idx, const bool bIsOn, const int level, const std::string &defaultname)
 {
-	unsigned int sID = Idx;
-
-	char szTmp[300];
-	std::string ID;
-	sprintf(szTmp, "%c", Idx);
-	ID = szTmp;
-
 	_tGeneralSwitch xcmd;
 	xcmd.len = sizeof(_tGeneralSwitch) - 1;
-	xcmd.id = sID;
+	xcmd.id = Idx;
 	xcmd.type = pTypeGeneralSwitch;
 	xcmd.subtype = sSwitchGeneralSwitch;
 	xcmd.unitcode = 1;
@@ -640,58 +700,76 @@ void CDaikin::InsertUpdateSwitchSelector(const unsigned char Idx, const bool bIs
 	//		customimage = 8; //speaker
 	//	}
 
-	if (bIsOn) {
+	if (bIsOn)
+	{
 		xcmd.cmnd = gswitch_sOn;
 	}
-	else {
+	else
+	{
 		xcmd.cmnd = gswitch_sOff;
 	}
 	_eSwitchType switchtype;
 	switchtype = STYPE_Selector;
 
 	xcmd.subtype = sSwitchTypeSelector;
-	if (level > 0) {
+	if (level > 0)
+	{
 		xcmd.level = (uint8_t)level;
 	}
 
-	//check if this switch is already in the database
-	std::vector<std::vector<std::string> > result;
+	// check if this switch is already in the database
+	std::vector<std::vector<std::string>> result;
 
 	// block this device if it is already added for another gateway hardware id
-	result = m_sql.safe_query("SELECT nValue FROM DeviceStatus WHERE (HardwareID!=%d) AND (DeviceID=='%d') AND (Type==%d) AND (Unit == '%d')", m_HwdID, sID, xcmd.type, xcmd.unitcode);
+	result = m_sql.safe_query("SELECT nValue FROM DeviceStatus WHERE (HardwareID!=%d) AND (DeviceID=='%d') AND (Type==%d) AND (Unit == '%d')", m_HwdID, Idx, xcmd.type, xcmd.unitcode);
 
-	if (!result.empty()) {
+	if (!result.empty())
+	{
 		return;
 	}
 
-	result = m_sql.safe_query("SELECT nValue, BatteryLevel FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='0000000%d') AND (Type==%d) AND (Unit == '%d')", m_HwdID, sID, xcmd.type, xcmd.unitcode);
-	m_mainworker.PushAndWaitRxMessage(this, (const unsigned char*)&xcmd, defaultname.c_str(), 255);
+	result = m_sql.safe_query("SELECT nValue, BatteryLevel FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='0000000%d') AND (Type==%d) AND (Unit == '%d')", m_HwdID, Idx, xcmd.type,
+				  xcmd.unitcode);
+	m_mainworker.PushAndWaitRxMessage(this, (const unsigned char *)&xcmd, defaultname.c_str(), 255, m_Name.c_str());
 	if (result.empty())
 	{
 		// New Hardware -> Create the corresponding devices Selector
-		if (customimage == 0) {
-			if (sID == 5) {
-				customimage = 16; //wall socket
+		if (customimage == 0)
+		{
+			if (Idx == 5)
+			{
+				customimage = 16; // wall socket
 			}
-			else if ((sID == 6) || (sID == 7)) {
+			else if ((Idx == 6) || (Idx == 7))
+			{
 				customimage = 7;
 			}
 		}
-		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q', SwitchType=%d, CustomImage=%i WHERE(HardwareID == %d) AND (DeviceID == '0000000%d') AND (Unit == '%d')", defaultname.c_str(), (switchtype), customimage, m_HwdID, sID, xcmd.unitcode);
+		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q', SwitchType=%d, CustomImage=%i WHERE(HardwareID == %d) AND (DeviceID == '0000000%d') AND (Unit == '%d')", defaultname.c_str(),
+				 (switchtype), customimage, m_HwdID, Idx, xcmd.unitcode);
 
-		result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='0000000%d') AND (Type==%d) AND (Unit == '%d')", m_HwdID, sID, xcmd.type, xcmd.unitcode);
+		result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='0000000%d') AND (Type==%d) AND (Unit == '%d')", m_HwdID, Idx, xcmd.type, xcmd.unitcode);
 		// SelectorStyle:0;LevelNames:Off|Main|Sub|Main+Sub;LevelOffHidden:true;LevelActions:00|01|02|03"
-		if (!result.empty()) {
+		if (!result.empty())
+		{
 			std::string sIdx = result[0][0];
-			if (defaultname == "Mode") {
-				m_sql.SetDeviceOptions(atoi(sIdx.c_str()), m_sql.BuildDeviceOptions("SelectorStyle:0;LevelNames:Off|AUTO|DEHUMDIFICATOR|COLD|HOT|FAN;LevelOffHidden:true;LevelActions:00|01|02|03|04|06", false));
+			if (defaultname == "Mode")
+			{
+				m_sql.SetDeviceOptions(
+					atoi(sIdx.c_str()),
+					m_sql.BuildDeviceOptions("SelectorStyle:0;LevelNames:Off|AUTO|DEHUMDIFICATOR|COLD|HOT|FAN;LevelOffHidden:true;LevelActions:00|01|02|03|04|06", false));
 			}
-			else if (defaultname == "Ventillation") {
-				//for the Fans
-				m_sql.SetDeviceOptions(atoi(sIdx.c_str()), m_sql.BuildDeviceOptions("SelectorStyle:0;LevelNames:Off|AUTO|Silence|Lev 1|Lev 2|Lev 3|Lev 4|Lev 5;LevelOffHidden:true;LevelActions:00|10|20|30|40|50|60|70", false));
+			else if (defaultname == "Ventillation")
+			{
+				// for the Fans
+				m_sql.SetDeviceOptions(
+					atoi(sIdx.c_str()),
+					m_sql.BuildDeviceOptions("SelectorStyle:0;LevelNames:Off|AUTO|Silence|Lev 1|Lev 2|Lev 3|Lev 4|Lev 5;LevelOffHidden:true;LevelActions:00|10|20|30|40|50|60|70",
+								 false));
 			}
-			else if (defaultname == "Winds") {
-				//for the Wings
+			else if (defaultname == "Winds")
+			{
+				// for the Wings
 				m_sql.SetDeviceOptions(atoi(sIdx.c_str()), m_sql.BuildDeviceOptions("SelectorStyle:0;LevelNames:Off|Stopped|Vert|Horiz|Both;LevelOffHidden:true", false));
 			}
 		}
@@ -705,9 +783,8 @@ bool CDaikin::SetSetpoint(const int /*idx*/, const float temp)
 	Debug(DEBUG_HARDWARE, "Set Point...");
 
 	// cible température
-	char szTmp[100];
-	sprintf(szTmp, "%.1f", temp);
-	AggregateSetControlInfo(szTmp, NULL, NULL, NULL, NULL, NULL);
+	std::string sTmp = fmt::format("{:.1f}", temp);
+	AggregateSetControlInfo(sTmp.c_str(), nullptr, nullptr, nullptr, nullptr, nullptr);
 
 	SendSetPointSensor(20, 1, 1, temp, "Target Temperature"); // Suppose request succeed to keep reactive web interface
 	return true;
@@ -722,7 +799,7 @@ bool CDaikin::SetGroupOnOFF(const bool OnOFF)
 		pow = "1";
 	else
 		pow = "0";
-	AggregateSetControlInfo(NULL, pow.c_str(), NULL, NULL, NULL, NULL);
+	AggregateSetControlInfo(nullptr, pow.c_str(), nullptr, nullptr, nullptr, nullptr);
 	return true;
 }
 
@@ -734,36 +811,38 @@ bool CDaikin::SetModeLevel(const int NewLevel)
 	Debug(DEBUG_HARDWARE, "Mode Level...");
 
 	if (NewLevel == 0)
-		mode = "0"; //szURL << "&mode=0";
+		mode = "0"; // szURL << "&mode=0";
 	else if (NewLevel == 10)
-		mode = "1"; //szURL << "&mode=1"; /* 10-AUTO  1 */
+		mode = "1"; // szURL << "&mode=1"; /* 10-AUTO  1 */
 	else if (NewLevel == 20)
-		mode = "2"; //szURL << "&mode=2"; /* 20-DEHUM 2 */
+		mode = "2"; // szURL << "&mode=2"; /* 20-DEHUM 2 */
 	else if (NewLevel == 30)
-		mode = "3"; //szURL << "&mode=3"; /* 30-COLD  3 */
+		mode = "3"; // szURL << "&mode=3"; /* 30-COLD  3 */
 	else if (NewLevel == 40)
-		mode = "4"; //szURL << "&mode=4"; /* 40-HOT   4 */
+		mode = "4"; // szURL << "&mode=4"; /* 40-HOT   4 */
 	else if (NewLevel == 50)
-		mode = "6"; //szURL << "&mode=6"; /* 50-FAN   6 */
+		mode = "6"; // szURL << "&mode=6"; /* 50-FAN   6 */
 	else
 		return false;
 
 	if (NewLevel == 0) // 0 is AUTO, but there is no dt0! So in case lets force to dt1 and dh1
 	{
-		stemp = m_dt[1]; //szURL << "&stemp=" << m_dt[1];
-		shum = m_dh[1]; //szURL << "&shum=" << m_dh[1];
+		stemp = m_dt[1]; // szURL << "&stemp=" << m_dt[1];
+		shum = m_dh[1];	 // szURL << "&shum=" << m_dh[1];
 	}
 	else if (NewLevel == 6) // FAN mode, there is no temp/hum memorized.
 	{
-		stemp = "20"; //szURL << "&stemp=" << "20";
-		shum = "0"; //szURL << "&shum=" << "0";
+		stemp = "20"; // szURL << "&stemp=" << "20";
+		shum = "0";   // szURL << "&shum=" << "0";
 	}
 	else // DEHUMDIFICATOR, COLD, HOT ( 2,3,6 )
 	{
-		stemp = m_dt[(NewLevel / 10)]; //szURL << "&stemp=" << m_dt[(NewLevel/10)];
-		shum = m_dh[(NewLevel / 10)]; //szURL << "&shum=" << m_dh[(NewLevel/10)];
+		stemp = m_dt[(NewLevel / 10)]; // szURL << "&stemp=" << m_dt[(NewLevel/10)];
+		shum = m_dh[(NewLevel / 10)];  // szURL << "&shum=" << m_dh[(NewLevel/10)];
 	}
-	AggregateSetControlInfo(stemp.c_str(), NULL, mode.c_str(), NULL, NULL, shum.c_str()); // temp & hum are memorized value from the device itself, they can be modified by another command safely (does not have to fire 2 different http request in case of instantly modification on temp or hum
+	AggregateSetControlInfo(stemp.c_str(), nullptr, mode.c_str(), nullptr, nullptr,
+				shum.c_str()); // temp & hum are memorized value from the device itself, they can be modified by another command safely
+					       // (does not have to fire 2 different http request in case of instantly modification on temp or hum
 	return true;
 }
 
@@ -773,22 +852,22 @@ bool CDaikin::SetF_RateLevel(const int NewLevel)
 	Debug(DEBUG_HARDWARE, "Rate ...");
 
 	if (NewLevel == 10)
-		f_rate = "A"; //szURL << "&f_rate=A";
+		f_rate = "A"; // szURL << "&f_rate=A";
 	else if (NewLevel == 20)
-		f_rate = "B"; //szURL << "&f_rate=B";
+		f_rate = "B"; // szURL << "&f_rate=B";
 	else if (NewLevel == 30)
-		f_rate = "3"; //szURL << "&f_rate=3";
+		f_rate = "3"; // szURL << "&f_rate=3";
 	else if (NewLevel == 40)
-		f_rate = "4"; //szURL << "&f_rate=4";
+		f_rate = "4"; // szURL << "&f_rate=4";
 	else if (NewLevel == 50)
-		f_rate = "5"; //szURL << "&f_rate=5";
+		f_rate = "5"; // szURL << "&f_rate=5";
 	else if (NewLevel == 60)
-		f_rate = "6"; //szURL << "&f_rate=6";
+		f_rate = "6"; // szURL << "&f_rate=6";
 	else if (NewLevel == 70)
-		f_rate = "7"; //szURL << "&f_rate=7";
+		f_rate = "7"; // szURL << "&f_rate=7";
 	else
 		return false;
-	AggregateSetControlInfo(NULL, NULL, NULL, f_rate.c_str(), NULL, NULL);
+	AggregateSetControlInfo(nullptr, nullptr, nullptr, f_rate.c_str(), nullptr, nullptr);
 	return true;
 }
 
@@ -798,66 +877,69 @@ bool CDaikin::SetF_DirLevel(const int NewLevel)
 	Debug(DEBUG_HARDWARE, "Dir Level ...");
 
 	if (NewLevel == 10)
-		f_dir = "0"; //szURL << "&f_dir=0"; // All wings motion
+		f_dir = "0"; // szURL << "&f_dir=0"; // All wings motion
 	else if (NewLevel == 20)
-		f_dir = "1"; //szURL << "&f_dir=1"; // Vertical wings motion
+		f_dir = "1"; // szURL << "&f_dir=1"; // Vertical wings motion
 	else if (NewLevel == 30)
-		f_dir = "2"; //szURL << "&f_dir=2"; // Horizontal wings motion
+		f_dir = "2"; // szURL << "&f_dir=2"; // Horizontal wings motion
 	else if (NewLevel == 40)
-		f_dir = "3"; //szURL << "&f_dir=3"; // vertical + horizontal wings motion
+		f_dir = "3"; // szURL << "&f_dir=3"; // vertical + horizontal wings motion
 	else
 		return false;
-	AggregateSetControlInfo(NULL, NULL, NULL, NULL, f_dir.c_str(), NULL);
+	AggregateSetControlInfo(nullptr, nullptr, nullptr, nullptr, f_dir.c_str(), nullptr);
 	return true;
 }
 
-void CDaikin::AggregateSetControlInfo(const char* Temp/* setpoint */, const char* OnOFF /* group on/off */, const char* ModeLevel, const char* FRateLevel, const char* FDirLevel, const char* Hum)
+void CDaikin::AggregateSetControlInfo(const char *Temp /* setpoint */, const char *OnOFF /* group on/off */, const char *ModeLevel, const char *FRateLevel, const char *FDirLevel, const char *Hum)
 {
-	time_t cmd_time = mytime(NULL);
-	if (cmd_time - m_last_setcontrolinfo < 2) {
+	time_t cmd_time = mytime(nullptr);
+	if (cmd_time - m_last_setcontrolinfo < 2)
+	{
 		// another set request so keep old values, and update only the settled ones
-		if (Temp != NULL)
+		if (Temp != nullptr)
 			m_sci_Temp = Temp;
-		if (OnOFF != NULL)
+		if (OnOFF != nullptr)
 			m_sci_OnOFF = OnOFF;
-		if (ModeLevel != NULL)
+		if (ModeLevel != nullptr)
 			m_sci_ModeLevel = ModeLevel;
-		if (FRateLevel != NULL)
+		if (FRateLevel != nullptr)
 			m_sci_FRateLevel = FRateLevel;
-		if (FDirLevel != NULL)
+		if (FDirLevel != nullptr)
 			m_sci_FDirLevel = FDirLevel;
-		if (Hum != NULL)
+		if (Hum != nullptr)
 			m_sci_Hum = Hum;
 
 		m_last_setcontrolinfo = cmd_time;
-		if (cmd_time - m_first_setcontrolinfo > 5) { // force http set request every 5 seconds in case of continious set resquest (which could be a bug, a external entry request (json) or  a misprogrammed lua script)
+		if (cmd_time - m_first_setcontrolinfo > 5)
+		{ // force http set request every 5 seconds in case of continious set resquest (which could be a bug, a external entry request (json) or  a misprogrammed lua script)
 			m_force_sci = true;
 			m_first_setcontrolinfo = cmd_time;
 			Log(LOG_STATUS, "Daikin worker HTTPSetControlInfo : HTTP resquest forced, may be a bug ?"); // [JCJ] remark to github : where is the LOG_WARNING ?
 		}
 	}
-	else {
-		if (Temp != NULL)
+	else
+	{
+		if (Temp != nullptr)
 			m_sci_Temp = Temp;
 		else
 			m_sci_Temp = m_stemp;
-		if (OnOFF != NULL)
+		if (OnOFF != nullptr)
 			m_sci_OnOFF = OnOFF;
 		else
 			m_sci_OnOFF = m_pow;
-		if (ModeLevel != NULL)
+		if (ModeLevel != nullptr)
 			m_sci_ModeLevel = ModeLevel;
 		else
 			m_sci_ModeLevel = m_mode;
-		if (FRateLevel != NULL)
+		if (FRateLevel != nullptr)
 			m_sci_FRateLevel = FRateLevel;
 		else
 			m_sci_FRateLevel = m_f_rate;
-		if (FDirLevel != NULL)
+		if (FDirLevel != nullptr)
 			m_sci_FDirLevel = FDirLevel;
 		else
 			m_sci_FDirLevel = m_f_dir;
-		if (Hum != NULL)
+		if (Hum != nullptr)
 			m_sci_Hum = Hum;
 		else
 			m_sci_Hum = m_shum;
