@@ -76,19 +76,13 @@ CEcoDevices::CEcoDevices(const int ID, const std::string &IPAddress, const unsig
 	Init();
 }
 
-
-CEcoDevices::~CEcoDevices(void)
-{
-}
-
-
 void CEcoDevices::Init()
 {
 	m_bFirstRun = true;
 
 	// Is the device we poll password protected?
 	m_ssURL.str("");
-	if ((m_username.size() > 0) && (m_password.size() > 0))
+	if ((!m_username.empty()) && (!m_password.empty()))
 		m_ssURL << "http://" << m_username << ":" << m_password << "@";
 	else
 		m_ssURL << "http://";
@@ -103,7 +97,7 @@ bool CEcoDevices::StartHardware()
 
 	Init();
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CEcoDevices::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -125,7 +119,7 @@ bool CEcoDevices::StopHardware()
 void CEcoDevices::Do_Work()
 {
 	int sec_counter = m_iRateLimit - 2; // Make sure we update once soon after restart
-	_log.Log(LOG_STATUS, "(%s): Worker started...", m_Name.c_str());
+	Log(LOG_STATUS, "Worker started...");
 	while (!IsStopRequested(1000))
 	{
 		sec_counter++;
@@ -139,7 +133,7 @@ void CEcoDevices::Do_Work()
 				GetMeterRT2Details();
 		}
 	}
-	_log.Log(LOG_STATUS, "(%s): Worker stopped...", m_Name.c_str());
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 bool CEcoDevices::WriteToHardware(const char* /*pdata*/, const unsigned char /*length*/)
@@ -151,10 +145,10 @@ void CEcoDevices::DecodeXML2Teleinfo(const std::string &sResult, Teleinfo &telei
 {
 	TiXmlDocument XMLdoc("Teleinfo.xml");
 
-	XMLdoc.Parse(sResult.c_str(), 0, TIXML_ENCODING_UTF8);
+	XMLdoc.Parse(sResult.c_str(), nullptr, TIXML_ENCODING_UTF8);
 	if (XMLdoc.Error())
 	{
-		_log.Log(LOG_ERROR, "Error parsing XML for /protect/settings/teleinfo?.xml: %s", XMLdoc.ErrorDesc());
+		Log(LOG_ERROR, "Error parsing XML for /protect/settings/teleinfo?.xml: %s", XMLdoc.ErrorDesc());
 		return;
 	}
 
@@ -165,6 +159,9 @@ void CEcoDevices::DecodeXML2Teleinfo(const std::string &sResult, Teleinfo &telei
 	teleinfo.DEMAIN = S_xpath_string(XMLdoc.RootElement(), "/response/DEMAIN/text()").c_str();
 	teleinfo.ISOUSC = i_xpath_int(XMLdoc.RootElement(), "/response/ISOUSC/text()");
 	teleinfo.PAPP = i_xpath_int(XMLdoc.RootElement(), "/response/PAPP/text()");
+	if ( teleinfo.PAPP > 0 ) {
+		teleinfo.withPAPP = true;
+	}
 	teleinfo.BASE = i_xpath_int(XMLdoc.RootElement(), "/response/BASE/text()");
 	teleinfo.HCHC = i_xpath_int(XMLdoc.RootElement(), "/response/HCHC/text()");
 	teleinfo.HCHP = i_xpath_int(XMLdoc.RootElement(), "/response/HCHP/text()");
@@ -185,15 +182,15 @@ void CEcoDevices::DecodeXML2Teleinfo(const std::string &sResult, Teleinfo &telei
 	teleinfo.ADPS = i_xpath_int(XMLdoc.RootElement(), "/response/ADPS/text()");
 
 #ifdef DEBUG_EcoDevices
-	_log.Log(LOG_NORM, "DEBUG: OPTARIF: '%s'", teleinfo.OPTARIF.c_str());
-	_log.Log(LOG_NORM, "DEBUG: PTEC:    '%s'", teleinfo.PTEC.c_str());
-	_log.Log(LOG_NORM, "DEBUG: DEMAIN:  '%s'", teleinfo.DEMAIN.c_str());
+	Log(LOG_NORM, "DEBUG: OPTARIF: '%s'", teleinfo.OPTARIF.c_str());
+	Log(LOG_NORM, "DEBUG: PTEC:    '%s'", teleinfo.PTEC.c_str());
+	Log(LOG_NORM, "DEBUG: DEMAIN:  '%s'", teleinfo.DEMAIN.c_str());
 #endif
 }
 
 void CEcoDevices::GetMeterDetails()
 {
-	if (m_szIPAddress.size() == 0)
+	if (m_szIPAddress.empty())
 		return;
 	// From http://xx.xx.xx.xx/status.xml we get the pulse counters indexes and current flow
 	// From http://xx.xx.xx.xx/protect/settings/teleinfoX.xml we get a complete feed of Teleinfo data
@@ -203,7 +200,7 @@ void CEcoDevices::GetMeterDetails()
 	std::string::size_type len, pos;
 	std::stringstream sstr;
 	TiXmlDocument XMLdoc("Teleinfo.xml");
-	time_t atime = mytime(NULL);
+	time_t atime = mytime(nullptr);
 	int   major, minor, release;
 	int min_major = MAJOR, min_minor = MINOR, min_release = RELEASE;
 
@@ -213,19 +210,19 @@ void CEcoDevices::GetMeterDetails()
 	if (m_status.hostname.empty()) m_status.hostname = m_szIPAddress;
 	if (HTTPClient::GET(sstr.str(), ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_NORM, "(%s) Fetching counters and status data", m_Name.c_str());
+		Log(LOG_NORM, "Fetching counters and status data");
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "(%s) Error getting data from: %s", m_Name.c_str(), sstr.str().c_str());
+		Log(LOG_ERROR, "Error getting data from: %s", sstr.str().c_str());
 		return;
 	}
 
 	// Process XML result
-	XMLdoc.Parse(sResult.c_str(), 0, TIXML_ENCODING_UTF8);
+	XMLdoc.Parse(sResult.c_str(), nullptr, TIXML_ENCODING_UTF8);
 	if (XMLdoc.Error())
 	{
-		_log.Log(LOG_ERROR, "(%s) Error parsing XML at /status.xml: %s", m_Name.c_str(), XMLdoc.ErrorDesc());
+		Log(LOG_ERROR, "Error parsing XML at /status.xml: %s", XMLdoc.ErrorDesc());
 		return;
 	}
 
@@ -234,15 +231,15 @@ void CEcoDevices::GetMeterDetails()
 	m_status.version = S_xpath_string(XMLdoc.RootElement(), "/response/version/text()").c_str();
 
 #ifdef DEBUG_EcoDevices
-	_log.Log(LOG_NORM, "DEBUG: XML output for /status.xml\n%s", MakeHtml(sResult).c_str());
+	Log(LOG_NORM, "DEBUG: XML output for /status.xml\n%s", MakeHtml(sResult).c_str());
 #endif
 
 	m_status.version = m_status.version + "..";
-	major = atoi(m_status.version.substr(0, m_status.version.find(".")).c_str());
-	m_status.version.erase(0, m_status.version.find(".") + 1);
-	minor = atoi(m_status.version.substr(0, m_status.version.find(".")).c_str());
-	m_status.version.erase(0, m_status.version.find(".") + 1);
-	release = atoi(m_status.version.substr(0, m_status.version.find(".")).c_str());
+	major = atoi(m_status.version.substr(0, m_status.version.find('.')).c_str());
+	m_status.version.erase(0, m_status.version.find('.') + 1);
+	minor = atoi(m_status.version.substr(0, m_status.version.find('.')).c_str());
+	m_status.version.erase(0, m_status.version.find('.') + 1);
+	release = atoi(m_status.version.substr(0, m_status.version.find('.')).c_str());
 	m_status.version = S_xpath_string(XMLdoc.RootElement(), "/response/version/text()").c_str();
 
 	if ((major > min_major) || ((major == min_major) && (minor > min_minor)) || ((major == min_major) && (minor == min_minor) && (release >= min_release)))
@@ -268,7 +265,7 @@ void CEcoDevices::GetMeterDetails()
 			m_status.pindex1 = m_status.index1;
 			m_status.pflow1 = m_status.flow1;
 			m_status.time1 = atime;
-			SendMeterSensor(m_HwdID, 1, 255, m_status.index1 / 1000.0f, m_status.hostname + " Counter 1");
+			SendMeterSensor(m_HwdID, 1, 255, m_status.index1 / 1000.0F, m_status.hostname + " Counter 1");
 			SendWaterflowSensor(m_HwdID, 2, 255, (float)m_status.flow1, m_status.hostname + " Flow counter 1");
 		}
 
@@ -279,7 +276,7 @@ void CEcoDevices::GetMeterDetails()
 			m_status.pindex2 = m_status.index2;
 			m_status.pflow2 = m_status.flow2;
 			m_status.time2 = atime;
-			SendMeterSensor(m_HwdID, 3, 255, m_status.index2 / 1000.0f, m_status.hostname + " Counter 2");
+			SendMeterSensor(m_HwdID, 3, 255, m_status.index2 / 1000.0F, m_status.hostname + " Counter 2");
 			SendWaterflowSensor(m_HwdID, 4, 255, (float)m_status.flow2, m_status.hostname + " Flow counter 2");
 		}
 	}
@@ -288,7 +285,7 @@ void CEcoDevices::GetMeterDetails()
 		message = "EcoDevices firmware needs to be at least version ";
 		message = message + std::to_string(min_major) + "." + std::to_string(min_minor) + "." + std::to_string(min_release);
 		message = message + ", current version is " + m_status.version;
-		_log.Log(LOG_ERROR, "(%s) %s", m_Name.c_str(), message.c_str());
+		Log(LOG_ERROR, "%s", message.c_str());
 		return;
 	}
 
@@ -300,14 +297,14 @@ void CEcoDevices::GetMeterDetails()
 		sstr.str("");
 		sstr << m_ssURL.str() << "/protect/settings/teleinfo1.xml";
 
-		_log.Log(LOG_NORM, "(%s) Fetching Teleinfo 1 data", m_Name.c_str());
+		Log(LOG_NORM, "Fetching Teleinfo 1 data");
 		if (!HTTPClient::GET(sstr.str(), ExtraHeaders, sResult))
 		{
-			_log.Log(LOG_ERROR, "(%s) Error getting teleinfo1.xml from EcoDevices!", m_Name.c_str());
+			Log(LOG_ERROR, "Error getting teleinfo1.xml from EcoDevices!");
 			return;
 		}
 #ifdef DEBUG_EcoDevices
-		_log.Log(LOG_NORM, "DEBUG: XML output for Teleinfo1:\n%s", MakeHtml(sResult).c_str());
+		Log(LOG_NORM, "DEBUG: XML output for Teleinfo1:\n%s", MakeHtml(sResult).c_str());
 #endif
 
 		// Remove all "T1_"s from output as it prevents writing generic code for both counters
@@ -325,14 +322,14 @@ void CEcoDevices::GetMeterDetails()
 		sstr.str("");
 		sstr << m_ssURL.str() << "/protect/settings/teleinfo2.xml";
 
-		_log.Log(LOG_NORM, "(%s) Fetching Teleinfo 2 data", m_Name.c_str());
+		Log(LOG_NORM, "Fetching Teleinfo 2 data");
 		if (!HTTPClient::GET(sstr.str(), ExtraHeaders, sResult))
 		{
-			_log.Log(LOG_ERROR, "(%s) Error getting teleinfo2.xml!", m_Name.c_str());
+			Log(LOG_ERROR, "Error getting teleinfo2.xml!");
 			return;
 		}
 #ifdef DEBUG_EcoDevices
-		_log.Log(LOG_NORM, "DEBUG: XML output for Teleinfo2:\n%s", MakeHtml(sResult).c_str());
+		Log(LOG_NORM, "DEBUG: XML output for Teleinfo2:\n%s", MakeHtml(sResult).c_str());
 #endif
 
 		// Remove all "T2_"s from output as it prevents writing generic code for both counters
@@ -349,7 +346,7 @@ void CEcoDevices::GetMeterDetails()
 
 void CEcoDevices::GetMeterRT2Details()
 {
-	if (m_szIPAddress.size() == 0)
+	if (m_szIPAddress.empty())
 		return;
 
 	// From http://xx.xx.xx.xx/admin/status.xml we get the Teleinfo data
@@ -361,7 +358,7 @@ void CEcoDevices::GetMeterRT2Details()
 	std::stringstream sstr;
 	std::map<std::string, std::string> XMLmap;
 	TiXmlDocument XMLdoc("Teleinfo.xml");
-	//time_t atime = mytime(NULL);
+	// time_t atime = mytime(nullptr);
 	int   i, major, minor, release;
 	int min_major = MAJOR_RT2, min_minor = MINOR_RT2, min_release = RELEASE_RT2;
 
@@ -372,7 +369,7 @@ void CEcoDevices::GetMeterRT2Details()
 	std::string sURL = sstr.str();
 	if (!HTTPClient::GET(sURL, ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_ERROR, "(%s) Error getting system information from: %s", m_Name.c_str(), sstr.str().c_str());
+		Log(LOG_ERROR, "Error getting system information from: %s", sstr.str().c_str());
 		return;
 	}
 
@@ -380,12 +377,12 @@ void CEcoDevices::GetMeterRT2Details()
 	bool bRet = ParseJSon(sResult, root);
 	if ((!bRet) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "(%s) Invalid JSON data received from /admin/system.json", m_Name.c_str());
+		Log(LOG_ERROR, "Invalid JSON data received from /admin/system.json");
 		return;
 	}
 	if (root["confighostname"].empty() == true)
 	{
-		_log.Log(LOG_ERROR, "(%s) Invalid JSON data received from /admin/system.json, hostname missing", m_Name.c_str());
+		Log(LOG_ERROR, "Invalid JSON data received from /admin/system.json, hostname missing");
 	}
 	else
 	{
@@ -405,19 +402,19 @@ void CEcoDevices::GetMeterRT2Details()
 
 	if (HTTPClient::GET(sstr.str(), ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_NORM, "(%s) Fetching data from /admin/status.xml", m_Name.c_str());
+		Log(LOG_NORM, "Fetching data from /admin/status.xml");
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "(%s) Error getting status.xml!", m_Name.c_str());
+		Log(LOG_ERROR, "Error getting status.xml!");
 		return;
 	}
 
 	// Process XML result
-	XMLdoc.Parse(sResult.c_str(), 0, TIXML_ENCODING_UTF8);
+	XMLdoc.Parse(sResult.c_str(), nullptr, TIXML_ENCODING_UTF8);
 	if (XMLdoc.Error())
 	{
-		_log.Log(LOG_ERROR, "(%s) Error parsing XML at /admin/status.xml: %s", m_Name.c_str(), XMLdoc.ErrorDesc());
+		Log(LOG_ERROR, "Error parsing XML at /admin/status.xml: %s", XMLdoc.ErrorDesc());
 		return;
 	}
 
@@ -426,21 +423,21 @@ void CEcoDevices::GetMeterRT2Details()
 	std::string product = S_xpath_string(XMLdoc.RootElement(), "/response/product/text()").c_str();
 	if (product != "ECODEVICES RT 2")
 	{
-		_log.Log(LOG_ERROR, "(%s) Product information found in XML file is not 'ECODEVICES RT 2' as expected, but '%s'", m_Name.c_str(), product.c_str());
+		Log(LOG_ERROR, "Product information found in XML file is not 'ECODEVICES RT 2' as expected, but '%s'", product.c_str());
 		return;
 	}
 	m_status.version = S_xpath_string(XMLdoc.RootElement(), "/response/infofirm/text()").c_str();
 
 #ifdef DEBUG_EcoDevices
-	_log.Log(LOG_NORM, "DEBUG: XML output for /admin/status.xml\n%s", MakeHtml(sResult).c_str());
+	Log(LOG_NORM, "DEBUG: XML output for /admin/status.xml\n%s", MakeHtml(sResult).c_str());
 #endif
 
 	m_status.version = m_status.version + "..";
-	major = atoi(m_status.version.substr(0, m_status.version.find(".")).c_str());
-	m_status.version.erase(0, m_status.version.find(".") + 1);
-	minor = atoi(m_status.version.substr(0, m_status.version.find(".")).c_str());
-	m_status.version.erase(0, m_status.version.find(".") + 1);
-	release = atoi(m_status.version.substr(0, m_status.version.find(".")).c_str());
+	major = atoi(m_status.version.substr(0, m_status.version.find('.')).c_str());
+	m_status.version.erase(0, m_status.version.find('.') + 1);
+	minor = atoi(m_status.version.substr(0, m_status.version.find('.')).c_str());
+	m_status.version.erase(0, m_status.version.find('.') + 1);
+	release = atoi(m_status.version.substr(0, m_status.version.find('.')).c_str());
 	m_status.version = S_xpath_string(XMLdoc.RootElement(), "/response/version/text()").c_str();
 
 	if (!((major > min_major) || ((major == min_major) && (minor > min_minor)) || ((major == min_major) && (minor == min_minor) && (release >= min_release))))
@@ -448,7 +445,7 @@ void CEcoDevices::GetMeterRT2Details()
 		message = "EcoDevices RT2 firmware needs to be at least version ";
 		message = message + std::to_string(min_major) + "." + std::to_string(min_minor) + "." + std::to_string(min_release);
 		message = message + ", current version is " + m_status.version;
-		_log.Log(LOG_ERROR, "(%s) %s", m_Name.c_str(), message.c_str());
+		Log(LOG_ERROR, "%s", message.c_str());
 		return;
 	}
 
@@ -463,7 +460,8 @@ void CEcoDevices::GetMeterRT2Details()
 		label = S_xpath_string(XMLdoc.RootElement(), XMLLabel).c_str();
 		sprintf(XMLLabel, "/response/etiquetteEC%i/text()", i);
 		value = S_xpath_string(XMLdoc.RootElement(), XMLLabel).c_str();
-		if (label == "") break;
+		if (label.empty())
+			break;
 		XMLmap[label] = value;
 	}
 	m_teleinfo1.OPTARIF = XMLmap["OPTARIF"];
@@ -471,6 +469,9 @@ void CEcoDevices::GetMeterRT2Details()
 	m_teleinfo1.DEMAIN = XMLmap["DEMAIN"];
 	m_teleinfo1.ISOUSC = atoi(XMLmap["ISOUSC"].c_str());
 	m_teleinfo1.PAPP = atoi(XMLmap["PAPP"].c_str());
+	if ( m_teleinfo1.PAPP > 0 ) {
+		m_teleinfo1.withPAPP = true;
+	}
 	m_teleinfo1.BASE = atoi(XMLmap["BASE"].c_str());
 	m_teleinfo1.HCHC = atoi(XMLmap["HCHC"].c_str());
 	m_teleinfo1.HCHP = atoi(XMLmap["HCHP"].c_str());
@@ -491,11 +492,11 @@ void CEcoDevices::GetMeterRT2Details()
 	m_teleinfo1.ADPS = atoi(XMLmap["ADPS"].c_str());
 
 #ifdef DEBUG_EcoDevices
-	_log.Log(LOG_NORM, "DEBUG: OPTARIF: '%s'", m_teleinfo1.OPTARIF.c_str());
-	_log.Log(LOG_NORM, "DEBUG: PTEC:    '%s'", m_teleinfo1.PTEC.c_str());
-	_log.Log(LOG_NORM, "DEBUG: DEMAIN:  '%s'", m_teleinfo1.DEMAIN.c_str());
+	Log(LOG_NORM, "DEBUG: OPTARIF: '%s'", m_teleinfo1.OPTARIF.c_str());
+	Log(LOG_NORM, "DEBUG: PTEC:    '%s'", m_teleinfo1.PTEC.c_str());
+	Log(LOG_NORM, "DEBUG: DEMAIN:  '%s'", m_teleinfo1.DEMAIN.c_str());
 #endif
-	ProcessTeleinfo(m_status.hostname.c_str(), 1, m_teleinfo1);
+	ProcessTeleinfo(m_status.hostname, 1, m_teleinfo1);
 
 	// 8 internal counters (postes) processing
 	for (i = 0; i < 8; i++)
@@ -505,14 +506,14 @@ void CEcoDevices::GetMeterRT2Details()
 		sprintf(XMLLabel, "/response/info%i/text()", i);
 		value = S_xpath_string(XMLdoc.RootElement(), XMLLabel).c_str();
 		StringSplit(value, ",", splitresults);
-		if (splitresults[0] == "")
+		if (splitresults[0].empty())
 			break;
-		else
-		{
-			fvalue1 = (float)atof(splitresults[0].c_str());
-			if (fvalue1 > 0) SendMeterSensor(m_HwdID, i, 255, fvalue1 / 1000, m_status.hostname + " " + label);
-			fvalue2 = (float)atof(splitresults[1].c_str());
-			if (fvalue2 > 0) SendWaterflowSensor(m_HwdID, (uint8_t)i, 255, fvalue2, m_status.hostname + " " + label);
-		}
+
+		fvalue1 = (float)atof(splitresults[0].c_str());
+		if (fvalue1 > 0)
+			SendMeterSensor(m_HwdID, i, 255, fvalue1 / 1000, m_status.hostname + " " + label);
+		fvalue2 = (float)atof(splitresults[1].c_str());
+		if (fvalue2 > 0)
+			SendWaterflowSensor(m_HwdID, (uint8_t)i, 255, fvalue2, m_status.hostname + " " + label);
 	}
 }
