@@ -38,11 +38,12 @@ enum evoCommands
 	cmdSetpointOverride = 0x2349,
 	cmdDHWState = 0x1F41,
 	cmdDHWTemp = 0x1260,
+        cmdDHWSettings = 0x10A0,//DHW settings sent between controller and DHW sensor can also be requested by the gateway
 	cmdControllerMode = 0x2E04,
 	cmdControllerHeatDemand = 0x0008,//Heat demand sent by the controller for CH / DHW / Boiler  (F9/FA/FC)
 	cmdOpenThermBridge = 0x3220,//OT Bridge Status messages
 	cmdOpenThermSetpoint = 0x22D9,//OT Bridge Control Setpoint
-	cmdActuatorState = 0x3EF0,
+ 	cmdActuatorState = 0x3EF0,
 	cmdActuatorCheck = 0x3B00,
 	cmdBinding = 0x1FC9,
 	cmdExternalSensor = 0x0002,
@@ -56,10 +57,10 @@ enum evoCommands
 };
 
 const char  CEvohomeRadio::m_szNameErr[18] = { 0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F };
-const int CEvohomeRadio::m_evoToDczControllerMode[8] = { 0,5,1,2,3,-1,-1,4 };//are the hidden modes actually valid?
+const int CEvohomeRadio::m_evoToDczControllerMode[8] = { 0,6,1,2,3,4,-1,5 };//are the hidden modes actually valid?
 const int  CEvohomeRadio::m_evoToDczOverrideMode[5] = { zmAuto,-1,zmPerm,-1,zmTmp };//are the hidden modes actually valid?
 const uint8_t CEvohomeRadio::m_dczToEvoZoneMode[3] = { 0,2,4 };
-const uint8_t CEvohomeRadio::m_dczToEvoControllerMode[6] = { 0,2,3,4,7,1 };
+const uint8_t CEvohomeRadio::m_dczToEvoControllerMode[7] = { 0,2,3,4,5,7,1 };
 
 char const CEvohomeMsg::szPacketType[5][8] = { "Unknown","I","RQ","RP","W" };
 
@@ -68,10 +69,9 @@ CEvohomeRadio::CEvohomeRadio(const int ID, const std::string& UserContID)
 	m_HwdID = ID;
 	m_nDevID = 0;
 	m_nMyID = 0;
+	m_nOtbID = 0;
 	m_nBindID = 0;
-	for (int i = 0; i < 2; i++)
-		m_bStartup[i] = true;
-
+	m_bStartup.fill(true);
 	m_nBufPtr = 0;
 	m_nSendFail = 0;
 	m_nZoneCount = 0;
@@ -86,37 +86,36 @@ CEvohomeRadio::CEvohomeRadio(const int ID, const std::string& UserContID)
 		s_strid >> std::hex >> m_UControllerID;
 	}
 
-	RegisterDecoder(cmdZoneTemp, boost::bind(&CEvohomeRadio::DecodeZoneTemp, this, _1));
-	RegisterDecoder(cmdSetPoint, boost::bind(&CEvohomeRadio::DecodeSetpoint, this, _1));
-	RegisterDecoder(cmdSetpointOverride, boost::bind(&CEvohomeRadio::DecodeSetpointOverride, this, _1));
-	RegisterDecoder(cmdDHWState, boost::bind(&CEvohomeRadio::DecodeDHWState, this, _1));
-	RegisterDecoder(cmdDHWTemp, boost::bind(&CEvohomeRadio::DecodeDHWTemp, this, _1));
-	RegisterDecoder(cmdControllerMode, boost::bind(&CEvohomeRadio::DecodeControllerMode, this, _1));
-	RegisterDecoder(cmdSysInfo, boost::bind(&CEvohomeRadio::DecodeSysInfo, this, _1));
-	RegisterDecoder(cmdZoneName, boost::bind(&CEvohomeRadio::DecodeZoneName, this, _1));
-	RegisterDecoder(cmdZoneHeatDemand, boost::bind(&CEvohomeRadio::DecodeHeatDemand, this, _1));
-	RegisterDecoder(cmdOpenThermBridge, boost::bind(&CEvohomeRadio::DecodeOpenThermBridge, this, _1));
-	RegisterDecoder(cmdOpenThermSetpoint, boost::bind(&CEvohomeRadio::DecodeOpenThermSetpoint, this, _1));
-	RegisterDecoder(cmdZoneInfo, boost::bind(&CEvohomeRadio::DecodeZoneInfo, this, _1));
-	RegisterDecoder(cmdControllerHeatDemand, boost::bind(&CEvohomeRadio::DecodeHeatDemand, this, _1));
-	RegisterDecoder(cmdBinding, boost::bind(&CEvohomeRadio::DecodeBinding, this, _1));
-	RegisterDecoder(cmdActuatorState, boost::bind(&CEvohomeRadio::DecodeActuatorState, this, _1));
-	RegisterDecoder(cmdActuatorCheck, boost::bind(&CEvohomeRadio::DecodeActuatorCheck, this, _1));
-	RegisterDecoder(cmdZoneWindow, boost::bind(&CEvohomeRadio::DecodeZoneWindow, this, _1));
-	RegisterDecoder(cmdExternalSensor, boost::bind(&CEvohomeRadio::DecodeExternalSensor, this, _1));
-	RegisterDecoder(cmdDeviceInfo, boost::bind(&CEvohomeRadio::DecodeDeviceInfo, this, _1));
-	RegisterDecoder(cmdBatteryInfo, boost::bind(&CEvohomeRadio::DecodeBatteryInfo, this, _1));
-	RegisterDecoder(cmdSync, boost::bind(&CEvohomeRadio::DecodeSync, this, _1));
+	RegisterDecoder(cmdZoneTemp, [this](auto &&msg) { return DecodeZoneTemp(msg); });
+	RegisterDecoder(cmdSetPoint, [this](auto &&msg) { return DecodeSetpoint(msg); });
+	RegisterDecoder(cmdSetpointOverride, [this](auto &&msg) { return DecodeSetpointOverride(msg); });
+	RegisterDecoder(cmdDHWState, [this](auto &&msg) { return DecodeDHWState(msg); });
+	RegisterDecoder(cmdDHWTemp, [this](auto &&msg) { return DecodeDHWTemp(msg); });
+	RegisterDecoder(cmdDHWSettings, [this](auto &&msg) { return DecodeDHWSettings(msg); });
+	RegisterDecoder(cmdControllerMode, [this](auto &&msg) { return DecodeControllerMode(msg); });
+	RegisterDecoder(cmdSysInfo, [this](auto &&msg) { return DecodeSysInfo(msg); });
+	RegisterDecoder(cmdZoneName, [this](auto &&msg) { return DecodeZoneName(msg); });
+	RegisterDecoder(cmdZoneHeatDemand, [this](auto &&msg) { return DecodeHeatDemand(msg); });
+	RegisterDecoder(cmdOpenThermBridge, [this](auto &&msg) { return DecodeOpenThermBridge(msg); });
+	RegisterDecoder(cmdOpenThermSetpoint, [this](auto &&msg) { return DecodeOpenThermSetpoint(msg); });
+	RegisterDecoder(cmdZoneInfo, [this](auto &&msg) { return DecodeZoneInfo(msg); });
+	RegisterDecoder(cmdControllerHeatDemand, [this](auto &&msg) { return DecodeHeatDemand(msg); });
+	RegisterDecoder(cmdBinding, [this](auto &&msg) { return DecodeBinding(msg); });
+	RegisterDecoder(cmdActuatorState, [this](auto &&msg) { return DecodeActuatorState(msg); });
+	RegisterDecoder(cmdActuatorCheck, [this](auto &&msg) { return DecodeActuatorCheck(msg); });
+	RegisterDecoder(cmdZoneWindow, [this](auto &&msg) { return DecodeZoneWindow(msg); });
+	RegisterDecoder(cmdExternalSensor, [this](auto &&msg) { return DecodeExternalSensor(msg); });
+	RegisterDecoder(cmdDeviceInfo, [this](auto &&msg) { return DecodeDeviceInfo(msg); });
+	RegisterDecoder(cmdBatteryInfo, [this](auto &&msg) { return DecodeBatteryInfo(msg); });
+	RegisterDecoder(cmdSync, [this](auto &&msg) { return DecodeSync(msg); });
 }
 
-
-CEvohomeRadio::~CEvohomeRadio(void)
+CEvohomeRadio::~CEvohomeRadio()
 {
 	m_bIsStarted = false;
 }
 
-
-void CEvohomeRadio::RegisterDecoder(unsigned int cmd, fnc_evohome_decode fndecoder)
+void CEvohomeRadio::RegisterDecoder(unsigned int cmd, const fnc_evohome_decode &fndecoder)
 {
 	m_Decoders.insert(std::pair<int, fnc_evohome_decode >(cmd, fndecoder));
 }
@@ -178,15 +177,19 @@ bool CEvohomeRadio::StartHardware()
 	//we'll put our custom relays in this range
 	result = m_sql.safe_query("SELECT  Unit,Name,DeviceID,nValue,sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (Type==%d) AND (Unit>=64) AND (Unit<96)", m_HwdID, (int)pTypeEvohomeRelay);
 	m_RelayCheck.clear();
-	for (int i = 0; i < static_cast<int>(result.size()); i++)
+	for (auto &i : result)
 	{
-		Log(true, LOG_STATUS, "evohome: Relay: devno=%d demmand=%d", atoi(result[i][0].c_str()), atoi(result[i][4].c_str()));
-		m_RelayCheck.insert(tmap_relay_check_pair(static_cast<uint8_t>(atoi(result[i][0].c_str())), _tRelayCheck(boost::get_system_time() - boost::posix_time::minutes(19), static_cast<uint8_t>(atoi(result[i][4].c_str()))))); //allow 1 minute for startup before trying to restore demand
+		Log(true, LOG_STATUS, "evohome: Relay: devno=%d demmand=%d", atoi(i[0].c_str()), atoi(i[4].c_str()));
+		m_RelayCheck.insert(
+			tmap_relay_check_pair(static_cast<uint8_t>(atoi(i[0].c_str())),
+					      _tRelayCheck(boost::get_system_time() - boost::posix_time::minutes(19),
+							   static_cast<uint8_t>(atoi(i[4].c_str()))))); // allow 1 minute for startup before
+													// trying to restore demand
 	}
 
 	//Start worker thread
 	m_retrycntr = EVOHOME_RETRY_DELAY; //will force reconnect first thing
-	m_thread = std::make_shared<std::thread>(&CEvohomeRadio::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 
@@ -343,6 +346,12 @@ void CEvohomeRadio::RequestDHWTemp()
 }
 
 
+void CEvohomeRadio::RequestDHWSettings()
+{
+        AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetControllerID(), cmdDHWSettings).Add(uint8_t(0)));
+}
+
+
 void CEvohomeRadio::RequestControllerMode()
 {
 	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetControllerID(), cmdControllerMode).Add(uint8_t(0xFF)));
@@ -370,6 +379,7 @@ void CEvohomeRadio::RequestCurrentState()
 	RequestControllerMode();
 	RequestDHWTemp();
 	RequestDHWState();
+        RequestDHWSettings();
 	RequestZoneStartupInfo(0);
 	RequestDeviceInfo(0);
 }
@@ -382,7 +392,8 @@ void CEvohomeRadio::RequestZoneState()
 		RequestSetPointOverride(i);
 	//Trying this linked to DHW heat demand instead...that won't be adequate do it here too!
 	RequestDHWState();
-	SendExternalSensor();
+        RequestDHWSettings();
+ 	SendExternalSensor();
 	SendZoneSensor();
 }
 
@@ -401,6 +412,24 @@ void CEvohomeRadio::RequestDeviceInfo(uint8_t nAddr)
 }
 
 
+void CEvohomeRadio::RequestOpenThermBridge()
+{
+	// Manual requests since the Controller no longer requests this information from the OT Bridge
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdActuatorState).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermSetpoint).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x00)).Add(uint8_t(0)).Add(uint8_t(0)));
+ 	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x05)).Add(uint8_t(0)).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x11)).Add(uint8_t(0)).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x12)).Add(uint8_t(0)).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x13)).Add(uint8_t(0)).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x19)).Add(uint8_t(0)).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x1a)).Add(uint8_t(0)).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x1b)).Add(uint8_t(0)).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x1c)).Add(uint8_t(0)).Add(uint8_t(0)));
+	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktreq, GetOpenThermBridgeID(), cmdOpenThermBridge).Add(uint8_t(0)).Add(uint8_t(0)).Add(uint8_t(0x73)).Add(uint8_t(0)).Add(uint8_t(0))); 
+}
+
+
 void CEvohomeRadio::SendRelayHeatDemand(uint8_t nDevNo, uint8_t nDemand)
 {
 	AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktinf, 0, GetGatewayID(), cmdControllerHeatDemand).Add(nDevNo).Add(nDemand));
@@ -497,7 +526,7 @@ void CEvohomeRadio::SendZoneSensor()
 		{
 			//std::vector<std::string> sd = result[0];
 			std::stringstream s_strid;
-			std::string SensorName = result[0][1].c_str();
+			std::string SensorName = result[0][1];
 			//s_strid << std::hex << sd[0].c_str();
 			s_strid << std::hex << result[0][0].c_str();
 			s_strid >> ID;
@@ -519,7 +548,7 @@ void CEvohomeRadio::SendZoneSensor()
 				tsen.zone = (uint8_t)i;
 				tsen.temperature = static_cast<uint16_t>(dbTemp * 100);
 				RFX_SETID3(ID, tsen.id1, tsen.id2, tsen.id3);
-				sDecodeRXMessage(this, (const unsigned char*)&tsen, "Zone Temp", -1);
+				sDecodeRXMessage(this, (const unsigned char *)&tsen, "Zone Temp", -1, nullptr);
 			}
 		}
 	}
@@ -681,22 +710,28 @@ void CEvohomeRadio::ProcessMsg(const char* rawmsg)
 			{
 				if (msg.id[n].GetIDType() == CEvohomeID::devController)//id type 1 is for controllers
 				{
-					for (uint8_t i = 0; i < 5; i++)
+					for (unsigned int &i : MultiControllerID)
 					{
-						if (MultiControllerID[i] == msg.GetID(n))
+						if (i == msg.GetID(n))
 							break;
-						else if (MultiControllerID[i] == 0)
+						if (i == 0)
 						{
-							MultiControllerID[i] = msg.GetID(n);
-							_log.Log(LOG_STATUS, "evohome: controller detected, ID:0x%x", MultiControllerID[i]);
+							i = msg.GetID(n);
+							_log.Log(LOG_STATUS, "evohome: controller detected, ID:0x%x", i);
 							break;
 						}
-
 					}
-
 				}
 			}
 		}
+		if (msg.id[0].GetIDType() == CEvohomeID::devBridge) //if we get a message from the OT Bridge capture it's ID
+		{
+                        if (!m_nOtbID)
+                        {
+                                m_nOtbID = msg.GetID(0);
+                                _log.Log(LOG_STATUS, "evohome: opentherm bridge detected, ID:0x%x", m_nOtbID);
+                         }		
+		}
 		if (msg.id[0].GetIDType() == CEvohomeID::devGateway) //if we just got an echo of a sent packet we don't need to process it
 		{
 			if (!m_nMyID)//If we haven't got our own id trap it here just in case we need it later on
@@ -774,7 +809,7 @@ int CEvohomeRadio::Bind(uint8_t nDevNo, unsigned char nDevType)//use CEvohomeID:
 
 		return m_nBindID;
 	}
-	else if (nDevType == CEvohomeID::devSensor)//Binding the HGI80 to the evohome controller as an outdoor sensor (there are other sensors)
+	if (nDevType == CEvohomeID::devSensor) // Binding the HGI80 to the evohome controller as an outdoor sensor (there are other sensors)
 	{
 		std::unique_lock<std::mutex> lock(m_mtxBindNotify);
 		m_nBindID = 0;
@@ -790,7 +825,7 @@ int CEvohomeRadio::Bind(uint8_t nDevNo, unsigned char nDevType)//use CEvohomeID:
 		AddSendQueue(CEvohomeMsg(CEvohomeMsg::pktinf, m_nBindID, cmdBinding).Add((uint8_t)0).Add((uint16_t)0xFFFF).Add(CEvohomeID(nGatewayID)));
 		return m_nBindID;
 	}
-	else if (nDevType == CEvohomeID::devZone)//Binding the HGI80 to the evohome controller as a zone temperature sensor
+	if (nDevType == CEvohomeID::devZone) // Binding the HGI80 to the evohome controller as a zone temperature sensor
 	{
 		// Check that the max Device ID includes the zone temperature sensors
 		std::vector<std::vector<std::string> > result;
@@ -867,14 +902,14 @@ bool CEvohomeRadio::DecodeSetpoint(CEvohomeMsg& msg)//0x2309
 		//The exception appears to be for local overrides which may be possible to track by seeing if a change
 		//occurs that does not correspond to the controller setpoint for a given zone
 		if (msg.GetID(0) == GetControllerID())
-			sDecodeRXMessage(this, (const unsigned char*)&tsen, "Setpoint", -1);
+			sDecodeRXMessage(this, (const unsigned char*)&tsen, "Setpoint", -1, m_Name.c_str());
 		else if (AllSensors)
 		{
 			char zstrname[40];
 			sprintf(zstrname, "Zone %d", tsen.zone);
 			tsen.zone += 12; //zone number offset by 12
 			Log(true, LOG_STATUS, "evohome: %s: Setting: %d (0x%x): %d", tag, tsen.zone, msg.GetID(0), tsen.temperature);
-			sDecodeRXMessage(this, (const unsigned char*)&tsen, zstrname, -1);
+			sDecodeRXMessage(this, (const unsigned char *)&tsen, zstrname, -1, nullptr);
 		}
 	}
 	return true;
@@ -941,7 +976,7 @@ bool CEvohomeRadio::DecodeSetpointOverride(CEvohomeMsg& msg)//0x2349
 		Log(true, LOG_STATUS, "evohome: %s: Setting: %d (0x%x): %d (%d=%s)", tag, tsen.zone, msg.GetID(0), tsen.temperature, tsen.mode, GetZoneModeName(tsen.mode));
 	}
 
-	sDecodeRXMessage(this, (const unsigned char*)&tsen, "Setpoint", -1);
+	sDecodeRXMessage(this, (const unsigned char *)&tsen, "Setpoint", -1, nullptr);
 	return true;
 }
 
@@ -993,7 +1028,7 @@ bool CEvohomeRadio::DecodeZoneTemp(CEvohomeMsg& msg)//0x30C9
 		Log(true, LOG_STATUS, "evohome: %s: Zone sensor msg: 0x%x: %d: %d", tag, msg.GetID(0), tsen.zone, tsen.temperature);
 		if (tsen.temperature != 0x7FFF)//afaik this is the error value just ignore it right now as we have no way to report errors...also perhaps could be returned if DHW is not installed?
 		{
-			sDecodeRXMessage(this, (const unsigned char*)&tsen, "Zone Temp", -1);
+			sDecodeRXMessage(this, (const unsigned char *)&tsen, "Zone Temp", -1, nullptr);
 			if (msg.GetID(0) == GetControllerID())
 				bRefresh = SetMaxZoneCount(tsen.zone);//this should increase on startup as we poll all zones so we don't respond to changes here
 		}
@@ -1020,7 +1055,7 @@ bool CEvohomeRadio::DecodeZoneTemp(CEvohomeMsg& msg)//0x30C9
 			{
 				tsen.zone = (uint8_t)atoi(result[0][0].c_str());
 				Log(true, LOG_STATUS, "evohome: %s: Zone sensor msg: 0x%x: %d: %d", tag, msg.GetID(0), tsen.zone, tsen.temperature);
-				sDecodeRXMessage(this, (const unsigned char*)&tsen, "Zone Temp", -1);
+				sDecodeRXMessage(this, (const unsigned char *)&tsen, "Zone Temp", -1, nullptr);
 			}
 			else // If matching relay with same deviceID then create a new Zone Temp sensor with zone number offset by 12
 			{
@@ -1031,7 +1066,7 @@ bool CEvohomeRadio::DecodeZoneTemp(CEvohomeMsg& msg)//0x30C9
 					char zstrname[40];
 					sprintf(zstrname, "Zone %d", atoi(result[0][0].c_str()));
 					Log(true, LOG_STATUS, "evohome: %s: Zone sensor msg: 0x%x: %d: %d", tag, msg.GetID(0), tsen.zone, tsen.temperature);
-					sDecodeRXMessage(this, (const unsigned char*)&tsen, zstrname, -1);
+					sDecodeRXMessage(this, (const unsigned char *)&tsen, zstrname, -1, nullptr);
 				}
 			}
 		}
@@ -1073,9 +1108,10 @@ bool CEvohomeRadio::DecodeDHWState(CEvohomeMsg& msg)//1F41
 	tsen.subtype = sTypeEvohomeWater;
 	RFX_SETID3(msg.GetID(0), tsen.id1, tsen.id2, tsen.id3) //will be id of controller so must use zone number
 
-		tsen.zone = msg.payload[0] + 1;////NA to DHW...controller is 0 so let our zones start from 1...
+	tsen.zone = msg.payload[0] + 1;////NA to DHW...controller is 0 so let our zones start from 1...
 	tsen.updatetype = updSetPoint;//state
-	tsen.temperature = msg.payload[1];//just on or off for DHW
+        // m_DHWSetpoint defaults to 6000 until a value is read and stored
+	tsen.temperature = msg.payload[1] ? m_DHWSetpoint : 0;//no longer just on or off for DHW
 	if (tsen.temperature == 0xFF)// temperature = 255 if DHW not installed
 		return true;
 	int nMode = ConvertMode(m_evoToDczOverrideMode, msg.payload[2]);
@@ -1096,7 +1132,7 @@ bool CEvohomeRadio::DecodeDHWState(CEvohomeMsg& msg)//1F41
 		Log(true, LOG_STATUS, "evohome: %s: Setting: %d: %d (%d=%s)", tag, tsen.zone, tsen.temperature, tsen.mode, GetZoneModeName(tsen.mode));
 	}
 
-	sDecodeRXMessage(this, (const unsigned char*)&tsen, "DHW", -1);
+	sDecodeRXMessage(this, (const unsigned char *)&tsen, "DHW", -1, nullptr);
 	return true;
 }
 
@@ -1143,13 +1179,46 @@ bool CEvohomeRadio::DecodeDHWTemp(CEvohomeMsg& msg)//1260
 		tsen.temperature = msg.payload[i + 1] << 8 | msg.payload[i + 2];
 		Log(true, LOG_STATUS, "evohome: %s: DHW sensor msg: 0x%x: %d: %d", tag, msg.GetID(0), tsen.zone, tsen.temperature);
 		if (tsen.temperature != 0x7FFF)// DHW is not installed, discard value
-			sDecodeRXMessage(this, (const unsigned char*)&tsen, "DHW Temp", -1);
+			sDecodeRXMessage(this, (const unsigned char *)&tsen, "DHW Temp", -1, nullptr);
 	}
 
 	return true;
 }
 
 
+bool CEvohomeRadio::DecodeDHWSettings(CEvohomeMsg& msg)//10a0
+{
+        char tag[] = "DHW_SETTINGS";
+
+        // Filter out messages from other controllers
+        // This also filters out messages sent direct from sensor as can't uniquely identify its DeviceID so added workaround of regularly requesting temp from control$
+        if (msg.GetID(0) != GetControllerID())
+                return true;
+
+        if (msg.payloadsize != 6) {
+                Log(false, LOG_STATUS, "evohome: %s: ERROR: DHW settings msg with an unexpected payload size: %d", tag, msg.payloadsize);
+                return false;
+        }
+
+        //for DHW DevNo is always 0 and not relevant
+        if (msg.payload[0] != 0) {
+                Log(true, LOG_STATUS, "evohome: %s: WARNING: sensor reading with zone != 0: 0x%x - %d", tag, msg.GetID(0), msg.payload[0]);
+		return true;
+        }
+
+	// Store the m_DHWSetpoint for whenever the DHW Setpoint is used
+        m_DHWSetpoint = msg.payload[1] << 8 | msg.payload[2];
+        Log(true, LOG_STATUS, "evohome: %s: DHW Setpoint Stored = %d C", tag, m_DHWSetpoint);
+
+        // The DHW Overrun time is in byte 4
+        Log(true, LOG_STATUS, "evohome: %s: DHW Overrun Time = %d mins", tag, msg.payload[3]);
+        // The DHW Differential is in byte 5 and 6
+        Log(true, LOG_STATUS, "evohome: %s: DHW Differential Temperature = %d C", tag, msg.payload[4] << 8 | msg.payload[5]);
+
+        return true;
+}
+
+
 bool CEvohomeRadio::DecodeControllerMode(CEvohomeMsg& msg)//2E04
 {
 	char tag[] = "CONTROLLER_MODE";
@@ -1184,7 +1253,7 @@ bool CEvohomeRadio::DecodeControllerMode(CEvohomeMsg& msg)//2E04
 	CEvohomeDateTime::DecodeDateTime(tsen, msg.payload, 1);
 	tsen.mode = msg.payload[7];//1 is tmp 0 is perm
 	Log(true, LOG_STATUS, "evohome: %s: Setting: (%d=%s) (%d=%s) %s", tag, tsen.status, GetControllerModeName(tsen.status), tsen.mode, tsen.mode ? "Temporary" : "Permanent", CEvohomeDateTime::GetStrDate(tsen).c_str());
-	sDecodeRXMessage(this, (const unsigned char*)&tsen, "Controller Mode", -1);
+	sDecodeRXMessage(this, (const unsigned char *)&tsen, "Controller Mode", -1, nullptr);
 
 	if (SetControllerMode((uint8_t)nControllerMode))//if only the until time changed we should be ok as the unit will broadcast a new controller mode when the current mode ends
 		RequestZoneState();//This can conflict with our startup polling but will still succeed ok
@@ -1340,7 +1409,7 @@ bool CEvohomeRadio::DecodeZoneWindow(CEvohomeMsg& msg)
 	Log(true, LOG_STATUS, "evohome: %s: %d: Window %d", tag, tsen.zone, nWindow);
 
 	if (msg.GetID(0) == GetControllerID())
-		sDecodeRXMessage(this, (const unsigned char*)&tsen, "Zone Window", -1);
+		sDecodeRXMessage(this, (const unsigned char *)&tsen, "Zone Window", -1, nullptr);
 
 	return true;
 }
@@ -1389,7 +1458,7 @@ void CEvohomeRadio::RXRelay(uint8_t nDevNo, uint8_t nDemand, int nID)
 	tsen.devno = nDevNo;
 	tsen.demand = nDemand;
 	tsen.updatetype = CEvohomeRadio::updDemand;
-	sDecodeRXMessage(this, (const unsigned char*)&tsen, NULL, -1);
+	sDecodeRXMessage(this, (const unsigned char *)&tsen, nullptr, -1, m_Name.c_str());
 }
 
 bool CEvohomeRadio::DecodeHeatDemand(CEvohomeMsg& msg)
@@ -1435,7 +1504,8 @@ bool CEvohomeRadio::DecodeHeatDemand(CEvohomeMsg& msg)
 	{
 		szDevType = "DHW"; //DHW zone valve
 		RequestDHWState();//Trying to link the DHW state refresh to the heat demand...will be broadcast when the controller turns on or off DHW but maybe not if the heat demand doesn't change? (e.g. no heat demand but controller DHW state goes from off to on)
-	}
+	        RequestDHWSettings();
+ 	}
 	else if (nDevNo == 0xf9)//249
 		szDevType = "Heating"; //Central Heating zone valve
 
@@ -1492,7 +1562,7 @@ void CEvohomeRadio::UpdateSwitch(const unsigned char Idx, const bool bOn, const
 	lcmd.LIGHTING2.level = (uint8_t)level;
 	lcmd.LIGHTING2.filler = 0;
 	lcmd.LIGHTING2.rssi = 12;
-	sDecodeRXMessage(this, (const unsigned char*)&lcmd.LIGHTING2, defaultname.c_str(), 255);
+	sDecodeRXMessage(this, (const unsigned char*)&lcmd.LIGHTING2, defaultname.c_str(), 255, m_Name.c_str());
 }
 
 bool CEvohomeRadio::DecodeActuatorCheck(CEvohomeMsg& msg)
@@ -1569,8 +1639,8 @@ bool CEvohomeRadio::DecodeOpenThermBridge(CEvohomeMsg& msg)
 {
 	char tag[] = "OPENTHERM_BRIDGE";
 
-	// Only look for responses from the OT Bridge and Filter out messages from other controllers 
-	if (msg.GetID(1) != GetControllerID())
+	// Only look for responses from the OT Bridge 
+	if (msg.GetID(0) != GetOpenThermBridgeID())
 		return true;
 
 	// All OT messages should have a payload size of 5	
@@ -1580,15 +1650,52 @@ bool CEvohomeRadio::DecodeOpenThermBridge(CEvohomeMsg& msg)
 	}
 	// The OT command response is in byte 4 and 5
 	int nOTResponse = msg.payload[3] << 8 | msg.payload[4];
-	float fOTResponse = static_cast<float>(nOTResponse) / 256.0f;
+	// Check if f8.8 field is negative. Bit 15 will be 1 if negative
+	if (nOTResponse & (1 << 15)) {
+		nOTResponse = - (0x10000 - nOTResponse);
+	}
+	float fOTResponse = static_cast<float>(nOTResponse) / 256.0F;
 
 	// The OT commands are as per the OT Specification
+        // 00 (ID.00) = Status
+        if (msg.payload[2] == 0x00) {
+		// Record all status flags in the same way that the OTGW hardware device currently does
+		// However Evohome seems not to use all of them
+		bool bCH_enabled=(nOTResponse & (1 << 8));
+			UpdateSwitch(101,bCH_enabled,"CH_enabled");
+		bool bDHW_enabled=(nOTResponse & (1 << 9));
+			UpdateSwitch(102,bDHW_enabled,"DHW_enabled");
+		bool bCooling_enable=(nOTResponse & (1 << 10));
+			UpdateSwitch(103,bCooling_enable,"Cooling_enable");
+		bool bOTC_active=(nOTResponse & (1 << 11));
+			UpdateSwitch(104,bOTC_active,"OTC_active");
+		bool bCH2_enabled=(nOTResponse & (1 << 12));
+			UpdateSwitch(105,bCH2_enabled,"CH2_enabled");
+
+		bool bFault_indication=(nOTResponse & (1 << 0));
+			UpdateSwitch(110,bFault_indication,"Fault_indication");
+		bool bCH_active=(nOTResponse & (1 << 1));
+			UpdateSwitch(111,bCH_active,"CH_active");
+		bool bDHW_active=(nOTResponse & (1 << 2));
+			UpdateSwitch(112,bDHW_active,"DHW_active");
+		bool bFlameOn=(nOTResponse & (1 << 3));
+			UpdateSwitch(113,bFlameOn,"FlameOn");
+		bool bCooling_Mode_Active=(nOTResponse & (1 << 4));
+			UpdateSwitch(114,bCooling_Mode_Active,"Cooling_Mode_Active");
+		bool bCH2_Active=(nOTResponse & (1 << 5));
+			UpdateSwitch(115,bCH2_Active,"CH2_Active");
+		bool bDiagnosticEvent=(nOTResponse & (1 << 6));
+			UpdateSwitch(116,bDiagnosticEvent,"DiagnosticEvent");
+
+                Log(true, LOG_STATUS, "evohome: %s: Master Status %02X Slave Status %02X", tag, msg.payload[3], msg.payload[4]);
+                return true;
+        }
 	// 05 (ID.05) = Fault Code
 	if (msg.payload[2] == 0x05) {
 		SendCustomSensor(0, 5, 255, static_cast<float>(msg.payload[3]), "Application fault flags", "");
 		SendCustomSensor(1, 5, 255, static_cast<float>(msg.payload[4]), "OEM fault code", "");
 
-		Log(true, LOG_STATUS, "evohome: %s: Application-specific flags %02X OEM fault code %d", tag, msg.payload[3], msg.payload[4]);
+		Log(true, LOG_STATUS, "evohome: %s: Application-specific flags %02X OEM fault code %02X", tag, msg.payload[3], msg.payload[4]);
 		return true;
 	}
 	// 11 (ID.17) = Relative modulation level
@@ -1629,6 +1736,13 @@ bool CEvohomeRadio::DecodeOpenThermBridge(CEvohomeMsg& msg)
 		Log(true, LOG_STATUS, "evohome: %s: DHW Temperature = %.2f C", tag, fOTResponse);
 		return true;
 	}
+        // 1B (ID.27) = Outside Temperature
+        if (msg.payload[2] == 0x1b) {
+                SendTempSensor(27, 255, fOTResponse, "Outside Temperature");
+
+                Log(true, LOG_STATUS, "evohome: %s: Outside Temperature = %.2f C %02X %02X", tag, fOTResponse, msg.payload[3], msg.payload[4]);
+                return true;
+        }
 	// 1C (ID.28) = Return Water Temperature
 	if (msg.payload[2] == 0x1c) {
 		SendTempSensor(28, 255, fOTResponse, "Return Water Temperature");
@@ -1650,9 +1764,9 @@ bool CEvohomeRadio::DecodeOpenThermSetpoint(CEvohomeMsg& msg)
 {
 	char tag[] = "OPENTHERM_SETPOINT";
 
-	// Only look for responses from the OT Bridge and Filter out messages from other controllers
-	if (msg.GetID(1) != GetControllerID())
-		return true;
+        // Only look for responses from the OT Bridge
+        if (msg.GetID(0) != GetOpenThermBridgeID())
+                return true;
 
 	// All OT messages should have a payload size of 3
 	if (msg.payloadsize != 3) {
@@ -1661,7 +1775,7 @@ bool CEvohomeRadio::DecodeOpenThermSetpoint(CEvohomeMsg& msg)
 	}
 
 	// The OT Control Setpoint is in byte 2 and 3
-	float fOTSetpoint = static_cast<float>(msg.payload[1] << 8 | msg.payload[2]) / 100.0f;
+	float fOTSetpoint = static_cast<float>(msg.payload[1] << 8 | msg.payload[2]) / 100.0F;
 
 	SendTempSensor(1, 255, fOTSetpoint, "Control Setpoint");
 	Log(true, LOG_STATUS, "evohome: %s: Boiler Water Temperature = %.2f C", tag, fOTSetpoint);
@@ -1744,16 +1858,33 @@ bool CEvohomeRadio::DecodeDeviceInfo(CEvohomeMsg& msg)
 		nAlertType = 2;
 	}
 
-	if (nFaultCode == 0x04) { sprintf(sFaultCode, "BATTERY LOW"); }
-	else if (nFaultCode == 0x06) { sprintf(sFaultCode, "COMMS FAULT"); }
+	if (nFaultCode == 0x03) { sprintf(sFaultCode, "MAINS LOW"); }
+	else if (nFaultCode == 0x04)
+	{
+		sprintf(sFaultCode, "BATTERY LOW");
+	}
+	else if (nFaultCode == 0x06)
+	{
+		sprintf(sFaultCode, "COMMS FAULT");
+	}
 	else if (nFaultCode == 0x0a) { sprintf(sFaultCode, "SENSOR ERROR"); }
 	else { sprintf(sFaultCode, "UNKNOWN(%02x)", nFaultCode); }
 
 	if (nDevType == 0x04) { sprintf(sDevType, "ACTUATOR"); }
 	else if (nDevType == 0x01) { sprintf(sDevType, "SENSOR"); }
 	else if (nDevType == 0x05) { sprintf(sDevType, "HOT WATER"); }
-        else if (nDevType == 0x00) { sprintf(sDevType, "CONTROLLER"); }
- 	else { sprintf(sDevType, "UNKNOWN(%02x)", nDevType); }
+	else if (nDevType == 0x06)
+	{
+		sprintf(sDevType, "REMOTE GW");
+	}
+	else if (nDevType == 0x00)
+	{
+		sprintf(sDevType, "CONTROLLER");
+	}
+	else
+	{
+		sprintf(sDevType, "UNKNOWN(%02x)", nDevType);
+	}
 
 	// Log all Fault Logbook entries to the Status log
         Log(false, LOG_STATUS, "evohome: %s: %s %s Device:%06x %s %s", tag, sFaultDateTime, sFaultType, idDev.GetID(), sDevType, sFaultCode);
@@ -1808,14 +1939,14 @@ bool CEvohomeRadio::DecodeBatteryInfo(CEvohomeMsg& msg)
 			tsen.type = pTypeEvohomeZone;
 			tsen.subtype = sTypeEvohomeZone;
 			tsen.zone = nDevNo;
-			sDecodeRXMessage(this, (const unsigned char*)&tsen, NULL, nBattery);
+			sDecodeRXMessage(this, (const unsigned char *)&tsen, nullptr, nBattery, nullptr);
 
 			if (AllSensors)
 			{
 				tsen.type = pTypeEvohomeZone;
 				tsen.subtype = sTypeEvohomeZone;
 				tsen.zone += 12;
-				sDecodeRXMessage(this, (const unsigned char*)&tsen, NULL, nBattery); // Update Zone device battery level
+				sDecodeRXMessage(this, (const unsigned char *)&tsen, nullptr, nBattery, nullptr); // Update Zone device battery level
 			}
 
 			_tEVOHOME3 tsen2;
@@ -1828,7 +1959,7 @@ bool CEvohomeRadio::DecodeBatteryInfo(CEvohomeMsg& msg)
 			tsen2.demand = 0;
 			tsen2.updatetype = CEvohomeRadio::updBattery;
 			tsen2.battery_level = nBattery;
-			sDecodeRXMessage(this, (const unsigned char*)&tsen2, NULL, nBattery);
+			sDecodeRXMessage(this, (const unsigned char *)&tsen2, nullptr, nBattery, nullptr);
 		}
 		else
 		{
@@ -1836,7 +1967,7 @@ bool CEvohomeRadio::DecodeBatteryInfo(CEvohomeMsg& msg)
 			tsen.type = pTypeEvohomeZone;
 			tsen.subtype = sTypeEvohomeZone;
 			tsen.zone = nDevNo;
-			sDecodeRXMessage(this, (const unsigned char*)&tsen, NULL, nBattery);  // Update Relay device battery level
+			sDecodeRXMessage(this, (const unsigned char *)&tsen, nullptr, nBattery, nullptr); // Update Relay device battery level
 		}
 	}
 	else if (msg.id[0].GetIDType() == CEvohomeID::devSensor)
@@ -1847,7 +1978,7 @@ bool CEvohomeRadio::DecodeBatteryInfo(CEvohomeMsg& msg)
 		tsen.subtype = sTypeEvohomeWater;
 		tsen.zone = nDevNo;
 		RFX_SETID3(GetControllerID(), tsen.id1, tsen.id2, tsen.id3);
-		sDecodeRXMessage(this, (const unsigned char*)&tsen, "DHW Temp", nBattery);  // Update DHW Zone sensor
+		sDecodeRXMessage(this, (const unsigned char *)&tsen, "DHW Temp", nBattery, nullptr); // Update DHW Zone sensor
 	}
 	Log(true, LOG_STATUS, "evohome: %s: %s=%d charge=%d(%%) level=%d (%s)", tag, szType.c_str(), nDevNo, nBattery, nLowBat, (nLowBat == 0) ? "Low" : "OK");
 
@@ -1863,18 +1994,17 @@ bool CEvohomeRadio::DecodeSync(CEvohomeMsg& msg) //0x1F09
 		Log(false, LOG_ERROR, "evohome: %s: unexpected payload size: %d", tag, msg.payloadsize);
 		return false;
 	}
+
+	if (msg.payloadsize == 1)
+	{
+		Log(true, LOG_STATUS, "evohome: %s: Type 0x%02x", tag, msg.payload[0]);
+	}
 	else
 	{
-		if (msg.payloadsize == 1)
-		{
-			Log(true, LOG_STATUS, "evohome: %s: Type 0x%02x", tag, msg.payload[0]);
-		}
-		else
-		{
-			Log(true, LOG_STATUS, "evohome: %s: Type 0x%02x (%d)", tag, msg.payload[0], msg.payload[1] << 8 | msg.payload[2]);
-		}
-		return true;
+		Log(true, LOG_STATUS, "evohome: %s: Type 0x%02x (%d)", tag, msg.payload[0], msg.payload[1] << 8 | msg.payload[2]);
 	}
+
+	return true;
 }
 
 void CEvohomeRadio::AddSendQueue(const CEvohomeMsg& msg)
@@ -1941,10 +2071,7 @@ void CEvohomeRadio::Idle_Work()
 
 				if (GetControllerID() == 0xFFFFFF)  //Check whether multiple controllers have been detected
 				{
-					uint8_t MultiControllerCount = 0;
-					for (uint8_t i = 0; i < 5; i++)
-						if (MultiControllerID[i] != 0)
-							MultiControllerCount++;
+					uint8_t MultiControllerCount = sizeof(MultiControllerID) - 1;
 					if (MultiControllerCount > 1) // If multiple controllers detected then stop and user required to set controller ID on hardware settings page
 					{
 						_log.Log(LOG_ERROR, "evohome serial: multiple controllers detected!  Please set controller ID in hardware settings.");
@@ -1967,7 +2094,9 @@ void CEvohomeRadio::Idle_Work()
 				for (uint8_t i = 0; i < nZoneCount; i++)
 					RequestZoneTemp(i);
 				RequestDHWTemp();  // Request DHW temp from controller as workaround for being unable to identify DeviceID
-			}
+ 			        RequestDHWSettings();
+				RequestOpenThermBridge();  //Request OpenTherm information as the controller no longer requests it
+ 			}
 			if (AllSensors == false) // Check whether individual zone sensors has been activated
 			{
 				std::vector<std::vector<std::string> > result;
@@ -2017,7 +2146,7 @@ namespace http {
 			std::string type = request::findValue(&req, "devtype");
 			int HwdID = atoi(idx.c_str());
 			CDomoticzHardwareBase* pHardware = m_mainworker.GetHardware(HwdID);
-			if (pHardware == NULL)
+			if (pHardware == nullptr)
 				return;
 			if (pHardware->HwdType != HTYPE_EVOHOME_SERIAL && pHardware->HwdType != HTYPE_EVOHOME_TCP)
 				return;
@@ -2134,5 +2263,5 @@ namespace http {
 			root["title"] = "BindEvohome";
 			root["Used"] = false;
 		}
-	}
-}
+	} // namespace server
+} // namespace http
