@@ -76,13 +76,11 @@ CEvohomeWeb::CEvohomeWeb(const int ID, const std::string &Username, const std::s
 	m_wdayoff = 6; // saturday
 }
 
-
-CEvohomeWeb::~CEvohomeWeb(void)
+CEvohomeWeb::~CEvohomeWeb()
 {
 	m_bIsStarted = false;
 }
 
-
 void CEvohomeWeb::Init()
 {
 	m_loggedon = false;
@@ -124,7 +122,7 @@ bool CEvohomeWeb::StartSession()
 		return false;
 	}
 
-	m_sessiontimer = mytime(NULL) + 3599; // Honeywell will invalidate our session ID after an hour
+	m_sessiontimer = mytime(nullptr) + 3599; // Honeywell will invalidate our session ID after an hour
 	m_loggedon = true;
 	m_logonfailures = 0;
 
@@ -136,7 +134,7 @@ bool CEvohomeWeb::StartSession()
 		_log.Log(LOG_ERROR, "(%s) failed to retrieve installation info from server", m_Name.c_str());
 		return false;
 	}
-	m_tcs = NULL;
+	m_tcs = nullptr;
 	if (
 		(m_locations.size() > m_locationId) &&
 		(m_locations[m_locationId].gateways.size() > m_gatewayId) &&
@@ -160,8 +158,8 @@ bool CEvohomeWeb::StartSession()
 		{
 			std::vector<std::string> splitresults;
 			StringSplit(result[0][0], ";", splitresults);
-			if (splitresults.size()>0)
-				m_awaysetpoint = strtod(splitresults[0].c_str(), NULL);
+			if (!splitresults.empty())
+				m_awaysetpoint = strtod(splitresults[0].c_str(), nullptr);
 			if (splitresults.size()>1)
 				m_wdayoff = atoi(splitresults[1].c_str()) % 7;
 		}
@@ -181,7 +179,7 @@ bool CEvohomeWeb::StartHardware()
 	if (m_username.empty() || m_password.empty())
 		return false;
 	Init();
-	m_thread = std::make_shared<std::thread>(&CEvohomeWeb::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	if (!m_thread)
 		return false;
@@ -215,7 +213,7 @@ void CEvohomeWeb::Do_Work()
 		sec_counter++;
 		m_lastconnect++;
 		if (sec_counter % 10 == 0)
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 
 		if ((sec_counter % m_refreshrate == 0) && (pollcounter++ > m_logonfailures) && (m_lastconnect >= MINPOLINTERVAL))
 		{
@@ -285,8 +283,8 @@ bool CEvohomeWeb::GetStatus()
 		get_v1_temps();
 
 	// cycle all zones for status
-	for (std::vector<zone>::size_type i = 0; i < m_tcs->zones.size(); ++i)
-		DecodeZone(&m_tcs->zones[i]);
+	for (auto &i : m_tcs->zones)
+		DecodeZone(&i);
 
 	// hot water status
 	if (has_dhw(m_tcs))
@@ -306,14 +304,14 @@ bool CEvohomeWeb::SetSystemMode(uint8_t sysmode)
 		if (sznewmode == "HeatingOff")
 		{
 			// cycle my zones to reflect the HeatingOff mode
-			for (std::vector<zone>::size_type i = 0; i < m_tcs->zones.size(); ++i)
+			for (auto &i : m_tcs->zones)
 			{
-				zone* hz = &m_tcs->zones[i];
+				zone *hz = &i;
 				std::string szId, sztemperature;
 				szId = (*hz->installationInfo)["zoneId"].asString();
 				if ((m_showhdtemps) && !hz->hdtemp.empty())
 					sztemperature = hz->hdtemp;
-				else if (hz->status != NULL)
+				else if (hz->status != nullptr)
 					sztemperature = (*hz->status)["temperatureStatus"]["temperature"].asString();
 				else
 				{
@@ -330,11 +328,11 @@ bool CEvohomeWeb::SetSystemMode(uint8_t sysmode)
 		}
 
 		// cycle my zones to restore scheduled temps
-		for (std::vector<zone>::size_type i = 0; i < m_tcs->zones.size(); ++i)
+		for (auto &i : m_tcs->zones)
 		{
-			zone* hz = &m_tcs->zones[i];
-			std::string zonemode = "";
-			if (hz->status == NULL) // don't touch invalid zone - it should already show as 'Offline'
+			zone *hz = &i;
+			std::string zonemode;
+			if (hz->status == nullptr) // don't touch invalid zone - it should already show as 'Offline'
 				continue;
 			if (hz->status->isMember("heatSetpointStatus"))
 				zonemode = (*hz->status)["heatSetpointStatus"]["setpointMode"].asString();
@@ -342,7 +340,7 @@ bool CEvohomeWeb::SetSystemMode(uint8_t sysmode)
 				continue;
 
 			std::string sztemperature, szsetpoint;
-			std::string szuntil = "";
+			std::string szuntil;
 			double setpoint = 0;
 
 			/*  there is no strict definition for modes Away, DayOff and Custom so we'll have to wait
@@ -357,7 +355,7 @@ bool CEvohomeWeb::SetSystemMode(uint8_t sysmode)
 				if ((!hz->schedule.isNull()) || get_zone_schedule(hz->zoneId))
 				{
 					szuntil = local_to_utc(get_next_switchpoint_ex(hz->schedule, szsetpoint));
-					setpoint = strtod(szsetpoint.c_str(), NULL);
+					setpoint = strtod(szsetpoint.c_str(), nullptr);
 				}
 
 				// Eco lowers the setpoint of all zones by 3 degrees, but resets a zone mode to Normal setting
@@ -368,7 +366,7 @@ bool CEvohomeWeb::SetSystemMode(uint8_t sysmode)
 
 			if ((m_showhdtemps) && !hz->hdtemp.empty())
 				sztemperature = hz->hdtemp;
-			else if (hz->status != NULL)
+			else if (hz->status != nullptr)
 				sztemperature = (*hz->status)["temperatureStatus"]["temperature"].asString();
 			else
 			{
@@ -403,7 +401,7 @@ bool CEvohomeWeb::SetSetpoint(const char *pdata)
 	std::string zoneId(std::to_string((int)RFX_GETID3(pEvo->id1, pEvo->id2, pEvo->id3)));
 
 	zone* hz = get_zone_by_ID(zoneId);
-	if (hz == NULL) // zone number not known by installation (manually added?)
+	if (hz == nullptr) // zone number not known by installation (manually added?)
 	{
 		_log.Log(LOG_ERROR, "(%s) attempt to change setpoint on unknown zone", m_Name.c_str());
 		return false;
@@ -415,11 +413,11 @@ bool CEvohomeWeb::SetSetpoint(const char *pdata)
 			return false;
 
 		std::string szsetpoint;
-		std::string szuntil = "";
+		std::string szuntil;
 		if ((!hz->schedule.isNull()) || get_zone_schedule(hz->zoneId))
 		{
 			szuntil = local_to_utc(get_next_switchpoint_ex(hz->schedule, szsetpoint));
-			pEvo->temperature = (int16_t)(strtod(szsetpoint.c_str(), NULL) * 100);
+			pEvo->temperature = (int16_t)(strtod(szsetpoint.c_str(), nullptr) * 100);
 		}
 
 		if ((m_showschedule) && (!szuntil.empty()))
@@ -447,6 +445,22 @@ bool CEvohomeWeb::SetSetpoint(const char *pdata)
 	if ((pEvo->mode) == 2) // temporary override
 	{
 		std::string szISODate(CEvohomeDateTime::GetISODate(pEvo));
+		if((!pEvo->year) && !pEvo->hrs)
+		{
+			std::string szsetpoint_tmp;
+			if ((!hz->schedule.isNull()) || get_zone_schedule(zoneId))
+			{
+				szISODate = local_to_utc(get_next_switchpoint_ex(hz->schedule, szsetpoint_tmp));
+				if (!szISODate.empty())
+				{
+					pEvo->year = (uint16_t)(atoi(szISODate.substr(0, 4).c_str()));
+					pEvo->month = (uint8_t)(atoi(szISODate.substr(5, 2).c_str()));
+					pEvo->day = (uint8_t)(atoi(szISODate.substr(8, 2).c_str()));
+					pEvo->hrs = (uint8_t)(atoi(szISODate.substr(11, 2).c_str()));
+					pEvo->mins = (uint8_t)(atoi(szISODate.substr(14, 2).c_str()));
+				}
+			}
+		}
 		return set_temperature(zoneId, s_setpoint.str(), szISODate);
 	}
 	return false;
@@ -486,11 +500,11 @@ bool CEvohomeWeb::SetDHWState(const char *pdata)
 
 void CEvohomeWeb::DecodeControllerMode(temperatureControlSystem* tcs)
 {
-	unsigned long ID = (unsigned long)(strtod(tcs->systemId.c_str(), NULL));
+	unsigned long ID = (unsigned long)(strtod(tcs->systemId.c_str(), nullptr));
 	std::string szsystemMode, szmodelType;
 	uint8_t sysmode = 0;
 
-	if (tcs->status == NULL)
+	if (tcs->status == nullptr)
 		szsystemMode = "Unknown";
 	else
 		szsystemMode = (*tcs->status)["systemModeStatus"]["mode"].asString();
@@ -505,7 +519,7 @@ void CEvohomeWeb::DecodeControllerMode(temperatureControlSystem* tcs)
 	RFX_SETID3(ID, tsen.id1, tsen.id2, tsen.id3);
 	tsen.mode = 0; // web API does not support temp override of controller mode
 	tsen.status = sysmode;
-	sDecodeRXMessage(this, (const unsigned char *)&tsen, "Controller mode", -1);
+	sDecodeRXMessage(this, (const unsigned char *)&tsen, "Controller mode", -1, nullptr);
 
 	if (GetControllerName().empty() || m_updatedev)
 	{
@@ -525,7 +539,7 @@ void CEvohomeWeb::DecodeControllerMode(temperatureControlSystem* tcs)
 		if (!result.empty() && ((result[0][2] != devname) || (!result[0][3].empty())))
 		{
 			// also change lastupdate time to allow the web frontend to pick up the change
-			time_t now = mytime(NULL);
+			time_t now = mytime(nullptr);
 			struct tm ltime;
 			localtime_r(&now, &ltime);
 			// also wipe StrParam1 - we do not also want to call the old (python) script when changing system mode
@@ -541,11 +555,11 @@ void CEvohomeWeb::DecodeZone(zone* hz)
 	// only for mainworker to reassemble it.
 
 	std::string szId, sztemperature, szsetpoint, szmode;
-	std::string szuntil= "";
+	std::string szuntil;
 	std::stringstream ssUpdateStat;
 
 	szId = (*hz->installationInfo)["zoneId"].asString();
-	if (hz->status == NULL)
+	if (hz->status == nullptr)
 	{
 		sztemperature = "-";
 		szsetpoint = "-";
@@ -567,13 +581,13 @@ void CEvohomeWeb::DecodeZone(zone* hz)
 
 	unsigned long evoID = atol(szId.c_str());
 	std::string szsysmode;
-	if (m_tcs->status == NULL)
+	if (m_tcs->status == nullptr)
 		szsysmode = "Unknown";
 	else
 		szsysmode = (*m_tcs->status)["systemModeStatus"]["mode"].asString();
 	if ((szsysmode == "Away") && (szmode == "FollowSchedule"))
 	{
-		double new_awaysetpoint = strtod(szsetpoint.c_str(), NULL);
+		double new_awaysetpoint = strtod(szsetpoint.c_str(), nullptr);
 		if (m_awaysetpoint != new_awaysetpoint)
 		{
 			m_awaysetpoint = new_awaysetpoint;
@@ -649,18 +663,20 @@ void CEvohomeWeb::DecodeZone(zone* hz)
 	}
 
 	// Notify MQTT and various push mechanisms
-	m_mainworker.sOnDeviceReceived(this->m_HwdID, DevRowIdx, (*hz->installationInfo)["name"].asString(), NULL);
+	m_mainworker.sOnDeviceReceived(this->m_HwdID, DevRowIdx, (*hz->installationInfo)["name"].asString(), nullptr);
 }
 
 
 void CEvohomeWeb::DecodeDHWState(temperatureControlSystem* tcs)
 {
 	// Hot Water is essentially just another zone
-	if ((tcs->status == NULL) || (!tcs->status->isMember("dhw") || !(*tcs->status)["dhw"].isMember("temperatureStatus") || !(*tcs->status)["dhw"].isMember("stateStatus")))
+	if ((tcs->status == nullptr)
+	    || (!tcs->status->isMember("dhw") || !(*tcs->status)["dhw"].isMember("temperatureStatus")
+		|| !(*tcs->status)["dhw"].isMember("stateStatus")))
 		return;
 
 	std::string szId, szmode;
-	std::string szuntil = "";
+	std::string szuntil;
 	std::stringstream ssUpdateStat;
 
 	szId = (*tcs->status)["dhw"]["dhwId"].asString();
@@ -717,7 +733,7 @@ void CEvohomeWeb::DecodeDHWState(temperatureControlSystem* tcs)
 	uint64_t DevRowIdx = m_sql.UpdateValue(this->m_HwdID, szId.c_str(), 1, pTypeEvohomeWater, sTypeEvohomeWater, 10, 255, 50, ssUpdateStat.str().c_str(), sdevname);
 
 	// Notify MQTT and various push mechanisms
-	m_mainworker.sOnDeviceReceived(this->m_HwdID, DevRowIdx, "Hot Water", NULL);
+	m_mainworker.sOnDeviceReceived(this->m_HwdID, DevRowIdx, "Hot Water", nullptr);
 }
 
 
@@ -740,7 +756,7 @@ uint8_t CEvohomeWeb::GetUnit_by_ID(unsigned long evoID)
 		{
 			int unit = atoi(result[row][0].c_str());
 			m_zones[unit] = atol(result[row][1].c_str());
-			if (m_zones[unit] == (unsigned long)(unit + 92000)) // mark manually added, unlinked zone as free
+			if (m_zones[unit] == uint64_t(unit) + 92000) // mark manually added, unlinked zone as free
 				m_zones[unit] = 0;
 		}
 		m_zones[0] = 1;
@@ -791,7 +807,7 @@ std::string CEvohomeWeb::local_to_utc(const std::string &local_time)
 	if (m_tzoffset == -1)
 	{
 		// calculate timezone offset once
-		time_t now = mytime(NULL);
+		time_t now = mytime(nullptr);
 		struct tm utime;
 		gmtime_r(&now, &utime);
 		utime.tm_isdst = -1;
@@ -881,7 +897,7 @@ bool CEvohomeWeb::login(const std::string &user, const std::string &password)
 	}
 
 	Json::Value j_login;
-	if (!ParseJSon(sz_response.c_str(), j_login))
+	if (!ParseJSon(sz_response, j_login))
 	{
 		_log.Log(LOG_ERROR, "(%s) failed parsing response from login to portal", m_Name.c_str());
 		return false;
@@ -906,7 +922,7 @@ bool CEvohomeWeb::login(const std::string &user, const std::string &password)
 
 	m_v2refresh_token = j_login["refresh_token"].asString();
 	int v2token_expiration_time = atoi(j_login["expires_in"].asString().c_str());
-	m_sessiontimer = mytime(NULL) + v2token_expiration_time; // Honeywell will invalidate our session ID after an hour
+	m_sessiontimer = mytime(nullptr) + v2token_expiration_time; // Honeywell will invalidate our session ID after an hour
 
 	std::stringstream atoken;
 	atoken << "Authorization: bearer " << j_login["access_token"].asString();
@@ -958,7 +974,7 @@ bool CEvohomeWeb::renew_login()
 	}
 
 	Json::Value j_login;
-	if (!ParseJSon(sz_response.c_str(), j_login))
+	if (!ParseJSon(sz_response, j_login))
 	{
 		_log.Log(LOG_ERROR, "(%s) failed parsing response from renewing login", m_Name.c_str());
 		return false;
@@ -986,7 +1002,7 @@ bool CEvohomeWeb::renew_login()
 
 	m_v2refresh_token = j_login["refresh_token"].asString();
 	int v2token_expiration_time = atoi(j_login["expires_in"].asString().c_str());
-	m_sessiontimer = mytime(NULL) + v2token_expiration_time; // Honeywell will invalidate our session ID after an hour
+	m_sessiontimer = mytime(nullptr) + v2token_expiration_time; // Honeywell will invalidate our session ID after an hour
 
 	std::stringstream atoken;
 	atoken << "Authorization: bearer " << j_login["access_token"].asString();
@@ -1018,7 +1034,7 @@ bool CEvohomeWeb::user_account()
 	}
 
 	Json::Value j_account;
-	if (!ParseJSon(sz_response.c_str(), j_account))
+	if (!ParseJSon(sz_response, j_account))
 	{
 		_log.Log(LOG_ERROR, "(%s) failed parsing response from retrieve user account info", m_Name.c_str());
 		return false;
@@ -1215,7 +1231,7 @@ bool CEvohomeWeb::full_installation()
 
 bool CEvohomeWeb::get_status(const std::string &locationId)
 {
-	if ((m_locations.size() == 0) && !full_installation())
+	if ((m_locations.empty()) && !full_installation())
 		return false;
 
 	for (size_t i = 0; i < m_locations.size(); i++)
@@ -1227,7 +1243,7 @@ bool CEvohomeWeb::get_status(const std::string &locationId)
 }
 bool CEvohomeWeb::get_status(int location)
 {
-	if ((m_locations.size() == 0) && !full_installation())
+	if ((m_locations.empty()) && !full_installation())
 		return false;
 	if (m_locations[location].locationId.empty())
 		return false;
@@ -1333,29 +1349,29 @@ bool CEvohomeWeb::get_status(int location)
 
 CEvohomeWeb::zone* CEvohomeWeb::get_zone_by_ID(const std::string &zoneId)
 {
-	if ((m_locations.size() == 0) && !full_installation())
-		return NULL;
+	if ((m_locations.empty()) && !full_installation())
+		return nullptr;
 
-	for (size_t l = 0; l < m_locations.size(); l++)
+	for (auto &m_location : m_locations)
 	{
-		for (size_t g = 0; g < m_locations[l].gateways.size(); g++)
+		for (auto &gateway : m_location.gateways)
 		{
-			for (size_t t = 0; t < m_locations[l].gateways[g].temperatureControlSystems.size(); t++)
+			for (auto &temperatureControlSystem : gateway.temperatureControlSystems)
 			{
-				for (size_t z = 0; z < m_locations[l].gateways[g].temperatureControlSystems[t].zones.size(); z++)
+				for (auto &zone : temperatureControlSystem.zones)
 				{
-					if (m_locations[l].gateways[g].temperatureControlSystems[t].zones[z].zoneId == zoneId)
-						return &m_locations[l].gateways[g].temperatureControlSystems[t].zones[z];
+					if (zone.zoneId == zoneId)
+						return &zone;
 				}
-				if (m_locations[l].gateways[g].temperatureControlSystems[t].dhw.size() > 0)
+				if (!temperatureControlSystem.dhw.empty())
 				{
-					if (m_locations[l].gateways[g].temperatureControlSystems[t].dhw[0].zoneId == zoneId)
-						return &m_locations[l].gateways[g].temperatureControlSystems[t].dhw[0];
+					if (temperatureControlSystem.dhw[0].zoneId == zoneId)
+						return &temperatureControlSystem.dhw[0];
 				}
 			}
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
 
@@ -1387,7 +1403,7 @@ bool CEvohomeWeb::get_zone_schedule(const std::string &zoneId, const std::string
 		return false;
 
 	zone* hz = get_zone_by_ID(zoneId);
-	if (hz == NULL)
+	if (hz == nullptr)
 		return false;
 	bool ret = ParseJSon(sz_response, hz->schedule);
 	if (ret)
@@ -1423,7 +1439,7 @@ std::string CEvohomeWeb::get_next_switchpoint_ex(Json::Value &schedule, std::str
 		return "";
 
 	struct tm ltime;
-	time_t now = mytime(NULL);
+	time_t now = mytime(nullptr);
 	localtime_r(&now, &ltime);
 	int year = ltime.tm_year;
 	int month = ltime.tm_mon;
@@ -1439,7 +1455,7 @@ std::string CEvohomeWeb::get_next_switchpoint_ex(Json::Value &schedule, std::str
 	}
 
 	// Hack: DayOff needs to reference a specific weekday rather than current
-	if (m_tcs->status != NULL)
+	if (m_tcs->status != nullptr)
 	{
 		std::string szsystemMode = (*m_tcs->status)["systemModeStatus"]["mode"].asString();
 		if (szsystemMode == "DayOff")
@@ -1567,7 +1583,7 @@ bool CEvohomeWeb::set_system_mode(const std::string &systemId, int mode)
 
 	std::string sz_putdata = "{\"SystemMode\":";
 	sz_putdata.append(std::to_string(mode));
-	sz_putdata.append(",\"TimeUntil\":null,\"Permanent\":true}");
+	sz_putdata.append(R"(,"TimeUntil":null,"Permanent":true})");
 
 	std::string sz_response = put_receive_data(sz_url, sz_putdata, m_SessionHeaders);
 	if (!sz_response.find("\"id\""))
@@ -1581,7 +1597,7 @@ bool CEvohomeWeb::set_system_mode(const std::string &systemId, int mode)
 		}
 
 		Json::Value j_response;
-		if (ParseJSon(sz_response.c_str(), j_response) && (j_response.isMember("message")))
+		if (ParseJSon(sz_response, j_response) && (j_response.isMember("message")))
 		{
 			std::string szError = j_response["message"].asString();
 			_log.Log(LOG_ERROR, "(%s) set system mode failed with message: %s", m_Name.c_str(), szError.c_str());
@@ -1603,8 +1619,8 @@ bool CEvohomeWeb::set_temperature(const std::string &zoneId, const std::string &
 
 	std::string sz_putdata = "{\"HeatSetpointValue\":";
 	sz_putdata.append(temperature);
-	if (time_until == "")
-		sz_putdata.append(",\"SetpointMode\":1,\"TimeUntil\":null}");
+	if (time_until.empty())
+		sz_putdata.append(R"(,"SetpointMode":1,"TimeUntil":null})");
 	else
 	{
 		if (!verify_datetime(time_until))
@@ -1612,7 +1628,7 @@ bool CEvohomeWeb::set_temperature(const std::string &zoneId, const std::string &
 			_log.Log(LOG_ERROR, "(%s) ignored zone temperature override because of invalid 'time_until' value", m_Name.c_str());
 			return false;
 		}
-		sz_putdata.append(",\"SetpointMode\":2,\"TimeUntil\":\"");
+		sz_putdata.append(R"(,"SetpointMode":2,"TimeUntil":")");
 		sz_putdata.append(time_until.substr(0, 10));
 		sz_putdata.append("T");
 		sz_putdata.append(time_until.substr(11, 8));
@@ -1632,7 +1648,7 @@ bool CEvohomeWeb::set_temperature(const std::string &zoneId, const std::string &
 		}
 
 		Json::Value j_response;
-		if (ParseJSon(sz_response.c_str(), j_response) && (j_response.isMember("message")))
+		if (ParseJSon(sz_response, j_response) && (j_response.isMember("message")))
 		{
 			std::string szError = j_response["message"].asString();
 			_log.Log(LOG_ERROR, "(%s) set zone temperature override failed with message: %s", m_Name.c_str(), szError.c_str());
@@ -1652,7 +1668,7 @@ bool CEvohomeWeb::cancel_temperature_override(const std::string &zoneId)
 	sz_url.append(zoneId);
 	sz_url.append("/heatSetpoint");
 
-	std::string sz_putdata = "{\"HeatSetpointValue\":0.0,\"SetpointMode\":0,\"TimeUntil\":null}";
+	std::string sz_putdata = R"({"HeatSetpointValue":0.0,"SetpointMode":0,"TimeUntil":null})";
 
 	std::string sz_response = put_receive_data(sz_url, sz_putdata, m_SessionHeaders);
 
@@ -1667,7 +1683,7 @@ bool CEvohomeWeb::cancel_temperature_override(const std::string &zoneId)
 		}
 
 		Json::Value j_response;
-		if (ParseJSon(sz_response.c_str(), j_response) && (j_response.isMember("message")))
+		if (ParseJSon(sz_response, j_response) && (j_response.isMember("message")))
 		{
 			std::string szError = j_response["message"].asString();
 			_log.Log(LOG_ERROR, "(%s) cancel zone temperature override failed with message: %s", m_Name.c_str(), szError.c_str());
@@ -1695,15 +1711,15 @@ bool CEvohomeWeb::set_dhw_mode(const std::string &dhwId, const std::string &mode
 
 	std::string sz_putdata = "{\"State\":";
 	if (mode == "auto")
-		sz_putdata.append("0,\"Mode\":0,\"UntilTime\":null}");
+		sz_putdata.append(R"(0,"Mode":0,"UntilTime":null})");
 	else
 	{
 		if (mode == "on")
 			sz_putdata.append("1");
 		else
 			sz_putdata.append("0");
-		if (time_until == "")
-			sz_putdata.append(",\"Mode\":1,\"UntilTime\":null}");
+		if (time_until.empty())
+			sz_putdata.append(R"(,"Mode":1,"UntilTime":null})");
 		else
 		{
 			if (!verify_datetime(time_until))
@@ -1711,7 +1727,7 @@ bool CEvohomeWeb::set_dhw_mode(const std::string &dhwId, const std::string &mode
 				_log.Log(LOG_ERROR, "(%s) ignored hot water override because of invalid 'time_until' value", m_Name.c_str());
 				return false;
 			}
-			sz_putdata.append(",\"Mode\":2,\"UntilTime\":\"");
+			sz_putdata.append(R"(,"Mode":2,"UntilTime":")");
 			sz_putdata.append(time_until.substr(0, 10));
 			sz_putdata.append("T");
 			sz_putdata.append(time_until.substr(11, 8));
@@ -1732,7 +1748,7 @@ bool CEvohomeWeb::set_dhw_mode(const std::string &dhwId, const std::string &mode
 		}
 
 		Json::Value j_response;
-		if (ParseJSon(sz_response.c_str(), j_response) && (j_response.isMember("message")))
+		if (ParseJSon(sz_response, j_response) && (j_response.isMember("message")))
 		{
 			std::string szError = j_response["message"].asString();
 			_log.Log(LOG_ERROR, "(%s) set hot water override failed with message: %s", m_Name.c_str(), szError.c_str());
@@ -1777,7 +1793,7 @@ bool CEvohomeWeb::v1_login(const std::string &user, const std::string &password)
 	}
 
 	Json::Value j_login;
-	if (!ParseJSon(sz_response.c_str(), j_login))
+	if (!ParseJSon(sz_response, j_login))
 	{
 		_log.Log(LOG_ERROR, "(%s) cannot parse return data from v1 login", m_Name.c_str());
 		return false;
@@ -1874,7 +1890,7 @@ void CEvohomeWeb::get_v1_temps()
 	}
 
 	Json::Value *j_error;
-	if (j_fi.isMember("locations") && (j_fi["locations"].size() > 0))
+	if (j_fi.isMember("locations") && (!j_fi["locations"].empty()))
 		j_error = &j_fi["locations"][0];
 	else
 		j_error = &j_fi;
@@ -1916,7 +1932,7 @@ void CEvohomeWeb::get_v1_temps()
 			std::string zoneId = (*j_dev)["deviceID"].asString();
 
 			zone *v2zone = get_zone_by_ID(zoneId);
-			if (v2zone != NULL)
+			if (v2zone != nullptr)
 			{
 				double v1temp = (*j_dev)["thermostat"]["indoorTemperature"].asDouble();
 				if (v1temp > 127) // allow rounding error
@@ -1940,7 +1956,7 @@ void CEvohomeWeb::get_v1_temps()
  *									*
  ************************************************************************/
 
-std::string CEvohomeWeb::send_receive_data(std::string url, std::vector<std::string> &headers)
+std::string CEvohomeWeb::send_receive_data(const std::string &url, std::vector<std::string> &headers)
 {
 	std::vector<unsigned char> vHTTPResponse;
 	std::vector<std::string> vHeaderData;
@@ -1950,8 +1966,7 @@ std::string CEvohomeWeb::send_receive_data(std::string url, std::vector<std::str
 	return process_response(vHTTPResponse, vHeaderData, httpOK);
 }
 
-
-std::string CEvohomeWeb::send_receive_data(std::string url, std::string postdata, std::vector<std::string> &headers)
+std::string CEvohomeWeb::send_receive_data(const std::string &url, const std::string &postdata, std::vector<std::string> &headers)
 {
 	std::vector<unsigned char> vHTTPResponse;
 	std::vector<std::string> vHeaderData;
@@ -1961,8 +1976,7 @@ std::string CEvohomeWeb::send_receive_data(std::string url, std::string postdata
 	return process_response(vHTTPResponse, vHeaderData, httpOK);
 }
 
-
-std::string CEvohomeWeb::put_receive_data(std::string url, std::string putdata, std::vector<std::string> &headers)
+std::string CEvohomeWeb::put_receive_data(const std::string &url, const std::string &putdata, std::vector<std::string> &headers)
 {
 	std::vector<unsigned char> vHTTPResponse;
 	std::vector<std::string> vHeaderData;
@@ -1981,10 +1995,10 @@ std::string CEvohomeWeb::process_response(std::vector<unsigned char> vHTTPRespon
 
 	sz_response.insert(sz_response.begin(), vHTTPResponse.begin(), vHTTPResponse.end());
 
-	if (vHeaderData.size() > 0)
+	if (!vHeaderData.empty())
 	{
 
-		size_t pos = vHeaderData[0].find(" ");
+		size_t pos = vHeaderData[0].find(' ');
 		if (pos != std::string::npos)
 		{
 			pos++;
@@ -2015,18 +2029,18 @@ std::string CEvohomeWeb::process_response(std::vector<unsigned char> vHTTPRespon
 		if (!httpOK)
 		{
 			 // sz_retcode contains a Curl status code
-			sz_response = "{\"code\":\"";
-			sz_response.append(sz_retcode);
-			sz_response.append("\",\"message\":\"");
-			if (!sz_rettext.empty())
-				sz_response.append(sz_rettext);
-			else
-			{
-				sz_response.append("HTTP client error ");
-				sz_response.append(sz_retcode);
-			}
-                        sz_response.append("\"}");
-			return sz_response;
+			 sz_response = R"({"code":")";
+			 sz_response.append(sz_retcode);
+			 sz_response.append(R"(","message":")");
+			 if (!sz_rettext.empty())
+				 sz_response.append(sz_rettext);
+			 else
+			 {
+				 sz_response.append("HTTP client error ");
+				 sz_response.append(sz_retcode);
+			 }
+			 sz_response.append("\"}");
+			 return sz_response;
 		}
 
 		if ((sz_retcode != "200") && (!sz_response.empty()))
@@ -2034,10 +2048,10 @@ std::string CEvohomeWeb::process_response(std::vector<unsigned char> vHTTPRespon
 			if ((sz_response[0] == '[') || (sz_response[0] == '{'))
 			{
 				// append code to the json response so it will take preference over any existing (textual) message code
-				size_t pos = sz_response.find_last_of("}");
+				size_t pos = sz_response.find_last_of('}');
 				if (pos != std::string::npos)
 				{
-					sz_response.insert(pos, ",\"code\":\"\"");
+					sz_response.insert(pos, R"(,"code":"")");
 					sz_response.insert(pos+9, sz_retcode);
 					return sz_response;
 				}
@@ -2048,11 +2062,11 @@ std::string CEvohomeWeb::process_response(std::vector<unsigned char> vHTTPRespon
 	if (sz_response.empty())
 	{
 		if (sz_retcode.empty())
-			return "{\"code\":\"-1\",\"message\":\"Evohome portal did not return any data or status\"}";
+			return R"({"code":"-1","message":"Evohome portal did not return any data or status"})";
 
-		sz_response = "{\"code\":\"";
+		sz_response = R"({"code":")";
 		sz_response.append(sz_retcode);
-		sz_response.append("\",\"message\":\"");
+		sz_response.append(R"(","message":")");
 		if (!sz_rettext.empty())
 			sz_response.append(sz_rettext);
 		else
@@ -2071,12 +2085,12 @@ std::string CEvohomeWeb::process_response(std::vector<unsigned char> vHTTPRespon
 	if (sz_response.find("<title>") != std::string::npos) // received an HTML page
 	{
 		std::stringstream ss_error;
-		ss_error << "{\"code\":\"";
+		ss_error << R"({"code":")";
 		if (!sz_retcode.empty())
 			ss_error << sz_retcode;
 		else
 			ss_error << "-1";
-		ss_error << "\",\"message\":\"";
+		ss_error << R"(","message":")";
 		int i = sz_response.find("<title>");
 		char* html = &sz_response[i];
 		i = 7;
@@ -2094,12 +2108,12 @@ std::string CEvohomeWeb::process_response(std::vector<unsigned char> vHTTPRespon
 	if (sz_response.find("<html>") != std::string::npos) // received an HTML page without a title
 	{
 		std::stringstream ss_error;
-		ss_error << "{\"code\":\"";
+		ss_error << R"({"code":")";
 		if (!sz_retcode.empty())
 			ss_error << sz_retcode;
 		else
 			ss_error << "-1";
-		ss_error << "\",\"message\":\"";
+		ss_error << R"(","message":")";
 		size_t i = 0;
 		char* html = &sz_response[0];
 		char c;
@@ -2124,6 +2138,6 @@ std::string CEvohomeWeb::process_response(std::vector<unsigned char> vHTTPRespon
 		ss_error << "\"}";
 		return ss_error.str();
 	}
-	return "{\"code\":\"-1\",\"message\":\"unhandled response\"}";
+	return R"({"code":"-1","message":"unhandled response"})";
 }
 
