@@ -4,26 +4,30 @@
 
 class CICYThermostat : public CDomoticzHardwareBase
 {
-	enum _eICYCompanyMode {
-		CMODE_UNKNOWN=0,
+	enum _eICYCompanyMode
+	{
+		CMODE_UNKNOWN = 0,
 		CMODE_PORTAL,
 		CMODE_ENI,
 		CMODE_SEC,
 	};
-public:
-	CICYThermostat(const int ID, const std::string &Username, const std::string &Password);
-	~CICYThermostat(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-	void SetSetpoint(const int idx, const float temp);
-private:
+
+      public:
+	CICYThermostat(int ID, const std::string &Username, const std::string &Password);
+	~CICYThermostat() override = default;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+	void SetSetpoint(int idx, float temp);
+
+      private:
 	void Init();
 	bool StartHardware() override;
 	bool StopHardware() override;
 	void Do_Work();
 	void GetMeterDetails();
-	void SendSetPointSensor(const unsigned char Idx, const float Temp, const std::string &defaultname);
+	void SendSetPointSensor(unsigned char Idx, float Temp, const std::string &defaultname);
 	bool GetSerialAndToken();
-private:
+
+      private:
 	std::string m_UserName;
 	std::string m_Password;
 	std::string m_SerialNumber;
@@ -31,4 +35,3 @@ private:
 	std::shared_ptr<std::thread> m_thread;
 	_eICYCompanyMode m_companymode;
 };
-
