@@ -39,10 +39,6 @@ m_szIPAddress(IPAddress)
 	Init();
 }
 
-CInComfort::~CInComfort(void)
-{
-}
-
 void CInComfort::Init()
 {
 }
@@ -53,7 +49,7 @@ bool CInComfort::StartHardware()
 
 	Init();
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CInComfort::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -77,7 +73,7 @@ bool CInComfort::StopHardware()
 void CInComfort::Do_Work()
 {
 	int sec_counter = 0;
-	_log.Log(LOG_STATUS, "InComfort: Worker started...");
+	Log(LOG_STATUS, "Worker started...");
 	while (!IsStopRequested(1000))
 	{
 		sec_counter++;
@@ -89,7 +85,7 @@ void CInComfort::Do_Work()
 			GetHeaterDetails();
 		}
 	}
-	_log.Log(LOG_STATUS, "InComfort: Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 bool CInComfort::WriteToHardware(const char * /*pdata*/, const unsigned char /*length*/)
@@ -100,27 +96,27 @@ bool CInComfort::WriteToHardware(const char * /*pdata*/, const unsigned char /*l
 
 void CInComfort::SetSetpoint(const int /*idx*/, const float temp)
 {
-	_log.Log(LOG_NORM, "InComfort: Setpoint of sensor with idx idx changed to temp");
+	Log(LOG_NORM, "Setpoint of sensor with idx idx changed to temp");
 	std::string jsonData = SetRoom1SetTemperature(temp);
 	if (jsonData.length() > 0)
 		ParseAndUpdateDevices(jsonData);
 }
 
-std::string CInComfort::GetHTTPData(std::string sURL)
+std::string CInComfort::GetHTTPData(const std::string &sURL)
 {
 	// Get Data
 	std::vector<std::string> ExtraHeaders;
 	std::string sResult;
 	if (!HTTPClient::GET(sURL, ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_ERROR, "InComfort: Error getting current state!");
+		Log(LOG_ERROR, "Error getting current state!");
 	}
 	return sResult;
 }
 
 std::string CInComfort::SetRoom1SetTemperature(float tempSetpoint)
 {
-	float setpointToSet = (tempSetpoint - 5.0f) * 10.0f;
+	float setpointToSet = (tempSetpoint - 5.0F) * 10.0F;
 
 	std::stringstream sstr;
 	sstr << "http://" << m_szIPAddress << ":" << m_usIPPort << "/data.json?heater=0&setpoint=" << setpointToSet << "&thermostat=0";
@@ -140,7 +136,7 @@ void CInComfort::GetHeaterDetails()
 	std::string sResult = GetHTTPData(sstr.str());
 	if (sResult.empty())
 	{
-		_log.Log(LOG_ERROR, "InComfort: Error getting current state!");
+		Log(LOG_ERROR, "Error getting current state!");
 		return;
 	}
 	ParseAndUpdateDevices(sResult);
@@ -150,35 +146,35 @@ void CInComfort::SetProgramState(const int /*newState*/)
 {
 }
 
-void CInComfort::ParseAndUpdateDevices(std::string jsonData)
+void CInComfort::ParseAndUpdateDevices(const std::string &jsonData)
 {
 	Json::Value root;
 	bool bRet = ParseJSon(jsonData, root);
 	if ((!bRet) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "InComfort: Invalid data received. Data is not json formatted.");
+		Log(LOG_ERROR, "Invalid data received. Data is not json formatted.");
 		return;
 	}
 	if (root["nodenr"].empty() == true)
 	{
-		_log.Log(LOG_ERROR, "InComfort: Invalid data received. Nodenr not found.");
+		Log(LOG_ERROR, "Invalid data received. Nodenr not found.");
 		return;
 	}
 
-	float room1Temperature = (root["room_temp_1_lsb"].asInt() + root["room_temp_1_msb"].asInt() * 256) / 100.0f;
-	float room1SetTemperature = (root["room_temp_set_1_lsb"].asInt() + root["room_temp_set_1_msb"].asInt() * 256) / 100.0f;
-	float room1OverrideTemperature = (root["room_set_ovr_1_lsb"].asInt() + root["room_set_ovr_1_msb"].asInt() * 256) / 100.0f;
-	float room2Temperature = (root["room_temp_2_lsb"].asInt() + root["room_temp_2_msb"].asInt() * 256) / 100.0f;
-	float room2SetTemperature = (root["room_temp_set_2_lsb"].asInt() + root["room_temp_set_2_msb"].asInt() * 256) / 100.0f;
-	float room2OverrideTemperature = (root["room_set_ovr_2_lsb"].asInt() + root["room_set_ovr_2_msb"].asInt() * 256) / 100.0f;
+	float room1Temperature = (root["room_temp_1_lsb"].asInt() + root["room_temp_1_msb"].asInt() * 256) / 100.0F;
+	float room1SetTemperature = (root["room_temp_set_1_lsb"].asInt() + root["room_temp_set_1_msb"].asInt() * 256) / 100.0F;
+	float room1OverrideTemperature = (root["room_set_ovr_1_lsb"].asInt() + root["room_set_ovr_1_msb"].asInt() * 256) / 100.0F;
+	float room2Temperature = (root["room_temp_2_lsb"].asInt() + root["room_temp_2_msb"].asInt() * 256) / 100.0F;
+	float room2SetTemperature = (root["room_temp_set_2_lsb"].asInt() + root["room_temp_set_2_msb"].asInt() * 256) / 100.0F;
+	float room2OverrideTemperature = (root["room_set_ovr_2_lsb"].asInt() + root["room_set_ovr_2_msb"].asInt() * 256) / 100.0F;
 
 	int statusDisplayCode = root["displ_code"].asInt();
 	//int rssi = root["rf_message_rssi"].asInt();
 	//int rfStatusCounter = root["rfstatus_cntr"].asInt();
 
-	float centralHeatingTemperature = (root["ch_temp_lsb"].asInt() + root["ch_temp_msb"].asInt() * 256) / 100.0f;
-	float centralHeatingPressure = (root["ch_pressure_lsb"].asInt() + root["ch_pressure_msb"].asInt() * 256) / 100.0f;
-	float tapWaterTemperature = (root["tap_temp_lsb"].asInt() + root["tap_temp_msb"].asInt() * 256) / 100.0f;
+	float centralHeatingTemperature = (root["ch_temp_lsb"].asInt() + root["ch_temp_msb"].asInt() * 256) / 100.0F;
+	float centralHeatingPressure = (root["ch_pressure_lsb"].asInt() + root["ch_pressure_msb"].asInt() * 256) / 100.0F;
+	float tapWaterTemperature = (root["tap_temp_lsb"].asInt() + root["tap_temp_msb"].asInt() * 256) / 100.0F;
 
 	int io = root["IO"].asInt();
 	bool lockout = (io & 0x01) > 0;
@@ -213,7 +209,7 @@ void CInComfort::ParseAndUpdateDevices(std::string jsonData)
 
 	// Compare the time of the last update to the current time.
 	// For items changing frequently, update the value every 5 minutes, for all others update every 15 minutes
-	time_t currentTime = mytime(NULL);
+	time_t currentTime = mytime(nullptr);
 	bool updateFrequentChangingValues = (currentTime - m_LastUpdateFrequentChangingValues) >= 300;
 	if (updateFrequentChangingValues)
 		m_LastUpdateFrequentChangingValues = currentTime;
@@ -280,8 +276,8 @@ void CInComfort::ParseAndUpdateDevices(std::string jsonData)
 		bool pumpActive = (io & 0x02) > 0;
 		bool tapFunctionActive = (io & 0x04) > 0;
 		bool burnerActive = (io & 0x08) > 0;
-		SendSwitch(8, 1, 255, pumpActive, 0, "Pump Active");
-		SendSwitch(8, 2, 255, tapFunctionActive, 0, "Tap Function Active");
-		SendSwitch(8, 3, 255, burnerActive, 0, "Burner Active");
+		SendSwitch(8, 1, 255, pumpActive, 0, "Pump Active", m_Name);
+		SendSwitch(8, 2, 255, tapFunctionActive, 0, "Tap Function Active", m_Name);
+		SendSwitch(8, 3, 255, burnerActive, 0, "Burner Active", m_Name);
 	}
 }
