@@ -5,10 +5,11 @@
 
 class KMTronic433 : public AsyncSerial, public KMTronicBase
 {
-public:
-	KMTronic433(const int ID, const std::string& devname);
-	~KMTronic433();
-private:
+      public:
+	KMTronic433(int ID, const std::string &devname);
+	~KMTronic433() override = default;
+
+      private:
 	bool StartHardware() override;
 	bool StopHardware() override;
 
@@ -22,9 +23,8 @@ private:
 	bool OpenSerialDevice();
 
 	/**
-	* Read callback, stores data in the buffer
-	*/
+	 * Read callback, stores data in the buffer
+	 */
 	void readCallback(const char *data, size_t len);
-	bool WriteInt(const unsigned char *data, const size_t len, const bool bWaitForReturn) override;
+	bool WriteInt(const unsigned char *data, size_t len, bool bWaitForReturn) override;
 };
-
