@@ -9,16 +9,14 @@
 #include "../main/WebServer.h"
 #include "../main/mainworker.h"
 #include "hardwaretypes.h"
+#include <ctime>
 #include <string>
 #include <sstream>
 #include <algorithm>
 #include <iostream>
-#include <boost/bind.hpp>
 #include "../webserver/cWebem.h"
 #include <json/json.h>
 
-#include <ctime>
-
 #define round(a) ( int ) ( a + .5 )
 #define MAX_PAYLOAD_LENGTH 25 //https://www.mysensors.org/download/serial_api_20
 
@@ -237,8 +235,8 @@ std::string MySensorsBase::GetMySensorsPresentationTypeStr(const enum _ePresenta
 	return "Unknown!";
 }
 
-MySensorsBase::MySensorsBase(void) :
-	m_GatewayVersion("?")
+MySensorsBase::MySensorsBase()
+	: m_GatewayVersion("?")
 {
 	m_bAckReceived = false;
 	m_AckNodeID = -1;
@@ -246,10 +244,6 @@ MySensorsBase::MySensorsBase(void) :
 	m_AckSetType = V_UNKNOWN;
 }
 
-MySensorsBase::~MySensorsBase(void)
-{
-}
-
 void MySensorsBase::LoadDevicesFromDatabase()
 {
 	m_nodes.clear();
@@ -258,10 +252,8 @@ void MySensorsBase::LoadDevicesFromDatabase()
 	result = m_sql.safe_query("SELECT ID, Name, SketchName, SketchVersion FROM MySensors WHERE (HardwareID=%d) ORDER BY ID ASC", m_HwdID);
 	if (!result.empty())
 	{
-		for (const auto & itt : result)
+		for (const auto &sd : result)
 		{
-			std::vector<std::string> sd = itt;
-
 			int ID = atoi(sd[0].c_str());
 			std::string Name = sd[1];
 			std::string SkectName = sd[2];
@@ -278,18 +270,14 @@ void MySensorsBase::LoadDevicesFromDatabase()
 			if (!result2.empty())
 			{
 				int gID = 1;
-				for (const auto & itt2 : result2)
+				for (const auto &sd2 : result2)
 				{
-					std::vector<std::string> sd2 = itt2;
 					_tMySensorChild mSensor;
 					mSensor.nodeID = ID;
 					mSensor.childID = atoi(sd2[0].c_str());
 					mSensor.presType = (_ePresentationType)atoi(sd2[1].c_str());
-					for (const auto & itt3 : mNode.m_childs)
-					{
-						if ((itt3.presType == mSensor.presType) && (itt3.groupID == gID))
-							gID++;
-					}
+					gID += std::count_if(mNode.m_childs.begin(), mNode.m_childs.end(),
+							     [&](const _tMySensorChild &child) { return (child.presType == mSensor.presType) && (child.groupID == gID); });
 					mSensor.groupID = gID;
 					mSensor.childName = sd2[2];
 					mSensor.useAck = atoi(sd2[3].c_str()) != 0;
@@ -321,9 +309,9 @@ int MySensorsBase::FindNextNodeID()
 {
 	unsigned char _UsedValues[256];
 	memset(_UsedValues, 0, sizeof(_UsedValues));
-	for (const auto & itt : m_nodes)
+	for (const auto &node : m_nodes)
 	{
-		int ID = itt.first;
+		int ID = node.first;
 		if (ID < 255)
 		{
 			_UsedValues[ID] = 1;
@@ -339,9 +327,8 @@ int MySensorsBase::FindNextNodeID()
 
 MySensorsBase::_tMySensorNode* MySensorsBase::FindNode(const uint8_t nodeID)
 {
-	std::map<int, _tMySensorNode>::iterator itt;
-	itt = m_nodes.find(nodeID);
-	return (itt == m_nodes.end()) ? NULL : &itt->second;
+	auto itt = m_nodes.find(nodeID);
+	return (itt == m_nodes.end()) ? nullptr : &itt->second;
 }
 
 MySensorsBase::_tMySensorNode* MySensorsBase::InsertNode(const int nodeID)
@@ -366,7 +353,7 @@ void MySensorsBase::UpdateNode(const int nodeID, const std::string &name)
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "MySensors: Update command received for unknown node_id: %d", nodeID);
+		Log(LOG_ERROR, "Update command received for unknown node_id: %d", nodeID);
 	}
 }
 
@@ -395,62 +382,60 @@ void MySensorsBase::UpdateChild(const int nodeID, const int childID, const bool
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "MySensors: Update command received for unknown node_id: %d, child_id: %d", nodeID, childID);
+		Log(LOG_ERROR, "Update command received for unknown node_id: %d, child_id: %d", nodeID, childID);
 	}
 }
 
 //Find any sensor with presentation type
 MySensorsBase::_tMySensorChild* MySensorsBase::FindSensorWithPresentationType(const int nodeID, const _ePresentationType presType)
 {
-	std::map<int, _tMySensorNode>::iterator ittNode;
-	ittNode = m_nodes.find(nodeID);
+	auto ittNode = m_nodes.find(nodeID);
 	if (ittNode == m_nodes.end())
-		return NULL;
+		return nullptr;
 	_tMySensorNode *pNode = &ittNode->second;
-	for (auto & itt : pNode->m_childs)
+	for (auto &child : pNode->m_childs)
 	{
-		if (itt.presType == presType)
-			return &itt;
+		if (child.presType == presType)
+			return &child;
 	}
-	return NULL;
+	return nullptr;
 }
 
 //Find any sensor with value type
 MySensorsBase::_tMySensorChild* MySensorsBase::FindChildWithValueType(const int nodeID, const _eSetType valType, const int groupID)
 {
-	std::map<int, _tMySensorNode>::iterator ittNode;
-	ittNode = m_nodes.find(nodeID);
+	auto ittNode = m_nodes.find(nodeID);
 	if (ittNode == m_nodes.end())
-		return NULL;
+		return nullptr;
 	_tMySensorNode *pNode = &ittNode->second;
-	for (auto & itt : pNode->m_childs)
+	for (auto &child : pNode->m_childs)
 	{
-		if ((itt.groupID == groupID) || (groupID == 0))
+		if ((child.groupID == groupID) || (groupID == 0))
 		{
-			for (const auto & itt2 : itt.values)
+			for (const auto &itt2 : child.values)
 			{
 				if (itt2.first == valType)
 				{
 					if (!itt2.second.bValidValue)
-						return NULL;
-					return &itt;
+						return nullptr;
+					return &child;
 				}
 			}
 		}
 	}
-	return NULL;
+	return nullptr;
 }
 
 void MySensorsBase::UpdateNodeBatteryLevel(const int nodeID, const int Level)
 {
-	std::map<int, _tMySensorNode>::iterator ittNode = m_nodes.find(nodeID);
+	auto ittNode = m_nodes.find(nodeID);
 	if (ittNode == m_nodes.end())
 		return; //Not found
 	_tMySensorNode *pNode = &ittNode->second;
-	for (auto & itt : pNode->m_childs)
+	for (auto &child : pNode->m_childs)
 	{
-		itt.hasBattery = true;
-		itt.batValue = Level;
+		child.hasBattery = true;
+		child.batValue = Level;
 
 		//Uncomment the below to for a sensor update
 /*
@@ -469,7 +454,7 @@ void MySensorsBase::UpdateNodeBatteryLevel(const int nodeID, const int Level)
 void MySensorsBase::UpdateNodeHeartbeat(const uint8_t nodeID)
 {
 
-	std::map<int, _tMySensorNode>::iterator ittNode = m_nodes.find(nodeID);
+	auto ittNode = m_nodes.find(nodeID);
 	if (ittNode == m_nodes.end())
 		return; //Not found
 
@@ -477,9 +462,9 @@ void MySensorsBase::UpdateNodeHeartbeat(const uint8_t nodeID)
 	mytime(&m_LastHeartbeatReceive);
 	_tMySensorNode *pNode = &ittNode->second;
 
-	for (auto & itt : pNode->m_childs)
+	for (const auto &child : pNode->m_childs)
 	{
-		for (const auto & itt2 : itt.values)
+		for (const auto &itt2 : child.values)
 		{
 			if (itt2.second.bValidValue)
 			{
@@ -491,29 +476,28 @@ void MySensorsBase::UpdateNodeHeartbeat(const uint8_t nodeID)
 				case V_LOCK_STATUS:
 				case V_STATUS:
 				case V_PERCENTAGE:
-					UpdateSwitchLastUpdate(nodeID, itt.childID);
+					UpdateSwitchLastUpdate(nodeID, child.childID);
 					break;
 				case V_SCENE_ON:
 				case V_SCENE_OFF:
-					if (itt.GetValue(vType, intValue))
-						UpdateSwitchLastUpdate(nodeID, itt.childID + intValue);
+					if (child.GetValue(vType, intValue))
+						UpdateSwitchLastUpdate(nodeID, child.childID + intValue);
 					break;
 				case V_UP:
 				case V_DOWN:
 				case V_STOP:
-					if (itt.GetValue(vType, intValue))
-						UpdateBlindSensorLastUpdate(nodeID, itt.childID);
+					if (child.GetValue(vType, intValue))
+						UpdateBlindSensorLastUpdate(nodeID, child.childID);
 					break;
 				case V_RGB:
 				case V_RGBW:
-					if (itt.GetValue(vType, intValue))
-						UpdateRGBWSwitchLastUpdate(nodeID, itt.childID);
+					if (child.GetValue(vType, intValue))
+						UpdateRGBWSwitchLastUpdate(nodeID, child.childID);
 					break;
 				}
 			}
 		}
 	}
-
 }
 
 void MySensorsBase::MakeAndSendWindSensor(const int nodeID, const std::string &sname)
@@ -560,7 +544,7 @@ void MySensorsBase::MakeAndSendWindSensor(const int nodeID, const std::string &s
 		fChill = fTemp;
 		if ((fTemp < 10.0) && (fWind >= 1.4))
 		{
-			fChill = 13.12f + 0.6215f*fTemp - 11.37f*pow(fWind*3.6f, 0.16f) + 0.3965f*fTemp*pow(fWind*3.6f, 0.16f);
+			fChill = 13.12F + 0.6215F * fTemp - 11.37F * std::pow(fWind * 3.6F, 0.16F) + 0.3965F * fTemp * std::pow(fWind * 3.6F, 0.16F);
 		}
 	}
 	int cNode = (nodeID << 8) | ChildID;
@@ -837,18 +821,19 @@ void MySensorsBase::SendSensor2Domoticz(_tMySensorNode *pNode, _tMySensorChild *
 	case V_RGB:
 		//RRGGBB
 		if (pChild->GetValue(vType, intValue))
-			SendRGBWSwitch(pChild->nodeID, (uint8_t)pChild->childID, pChild->batValue, intValue, false, (!pChild->childName.empty()) ? pChild->childName : "RGB Light");
+			SendRGBWSwitch(pChild->nodeID, (uint8_t)pChild->childID, pChild->batValue, intValue, false, (!pChild->childName.empty()) ? pChild->childName : "RGB Light", m_Name);
 		break;
 	case V_RGBW:
 		//RRGGBBWW
 		if (pChild->GetValue(vType, intValue))
-			SendRGBWSwitch(pChild->nodeID, (uint8_t)pChild->childID, pChild->batValue, intValue, true, (!pChild->childName.empty()) ? pChild->childName : "RGBW Light");
+			SendRGBWSwitch(pChild->nodeID, (uint8_t)pChild->childID, pChild->batValue, intValue, true, (!pChild->childName.empty()) ? pChild->childName : "RGBW Light", m_Name);
 		break;
 	case V_UP:
 	case V_DOWN:
 	case V_STOP:
 		if (pChild->GetValue(vType, intValue))
-			SendBlindSensor((uint8_t)pChild->nodeID, (uint8_t)pChild->childID, pChild->batValue, (uint8_t)intValue, (!pChild->childName.empty()) ? pChild->childName : "Blinds/Window");
+			SendBlindSensor((uint8_t)pChild->nodeID, (uint8_t)pChild->childID, pChild->batValue, (uint8_t)intValue, (!pChild->childName.empty()) ? pChild->childName : "Blinds/Window",
+					m_Name);
 		break;
 	case V_LIGHT_LEVEL:
 		if (pChild->GetValue(vType, floatValue))
@@ -1027,7 +1012,7 @@ void MySensorsBase::SendSensor2Domoticz(_tMySensorNode *pNode, _tMySensorChild *
 			gswitch.battery_level = (uint8_t)pChild->batValue;
 			gswitch.rssi = 12;
 			gswitch.seqnbr = 0;
-			sDecodeRXMessage(this, (const unsigned char *)&gswitch, (!pChild->childName.empty()) ? pChild->childName.c_str() : "IR Command", pChild->batValue);
+			sDecodeRXMessage(this, (const unsigned char *)&gswitch, (!pChild->childName.empty()) ? pChild->childName.c_str() : "IR Command", pChild->batValue, m_Name.c_str());
 		}
 		break;
 	case V_PH:
@@ -1086,7 +1071,7 @@ void MySensorsBase::UpdateSwitchLastUpdate(const unsigned char NodeID, const int
 	result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit==%d) AND (Type==%d) AND (Subtype==%d)", m_HwdID, szIdx, ChildID, int(pTypeGeneralSwitch), int(sSwitchTypeAC));
 	if (result.empty())
 		return; //not found!
-	time_t now = time(0);
+	time_t now = time(nullptr);
 	struct tm ltime;
 	localtime_r(&now, &ltime);
 
@@ -1104,7 +1089,7 @@ void MySensorsBase::UpdateBlindSensorLastUpdate(const int NodeID, const int Chil
 	result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit==%d)", m_HwdID, szIdx, ChildID);
 	if (result.empty())
 		return;
-	time_t now = time(0);
+	time_t now = time(nullptr);
 	struct tm ltime;
 	localtime_r(&now, &ltime);
 
@@ -1125,7 +1110,7 @@ void MySensorsBase::UpdateRGBWSwitchLastUpdate(const int NodeID, const int Child
 	result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit==%d)", m_HwdID, szIdx, ChildID);
 	if (result.empty())
 		return;
-	time_t now = time(0);
+	time_t now = time(nullptr);
 	struct tm ltime;
 	localtime_r(&now, &ltime);
 
@@ -1185,7 +1170,7 @@ void MySensorsBase::UpdateSwitch(const _eSetType vType, const unsigned char Idx,
 	gswitch.battery_level = (uint8_t)BatLevel;
 	gswitch.rssi = 12;
 	gswitch.seqnbr = 0;
-	sDecodeRXMessage(this, (const unsigned char *)&gswitch, defaultname.c_str(), BatLevel);
+	sDecodeRXMessage(this, (const unsigned char *)&gswitch, defaultname.c_str(), BatLevel, m_Name.c_str());
 
 
 }
@@ -1226,7 +1211,7 @@ bool MySensorsBase::GetSwitchValue(const int Idx, const int SubUnit, const int s
 		sSwitchValue = (nvalue == light2_sOn) ? "1" : "0";
 		return true;
 	}
-	else if ((sub_type == V_RGB) || (sub_type == V_RGBW))
+	if ((sub_type == V_RGB) || (sub_type == V_RGBW))
 	{
 		sSwitchValue = (nvalue == Color_LedOn) ? "1" : "0";
 		return true;
@@ -1245,7 +1230,7 @@ bool MySensorsBase::SendNodeSetCommand(const int NodeID, const int ChildID, cons
 	//Check if Node is asleep, and if so, add the command to it's message queue
 	std::lock_guard<std::mutex> l(m_node_sleep_mutex);
 	bool bIsAsleep = false;
-	std::map<int, bool>::iterator itt = m_node_sleep_states.find(NodeID);
+	auto itt = m_node_sleep_states.find(NodeID);
 	if (itt != m_node_sleep_states.end())
 	{
 		bIsAsleep = (itt->second == true);
@@ -1284,7 +1269,7 @@ bool MySensorsBase::SendNodeSetCommandImpl(const int NodeID, const int ChildID,
 	while ((!m_bAckReceived) && (repeat < repeats))
 	{
 		if (repeat != 0)
-			_log.Log(LOG_ERROR, "MySensors: Repeating previous command (%d/%d)", repeat + 1, repeats);
+			Log(LOG_ERROR, "Repeating previous command (%d/%d)", repeat + 1, repeats);
 		SendCommandInt(NodeID, ChildID, messageType, bUseAck, SubType, Payload);
 		if (!bUseAck)
 			return true;
@@ -1302,7 +1287,7 @@ bool MySensorsBase::SendNodeSetCommandImpl(const int NodeID, const int ChildID,
 	}
 	if (m_bAckReceived)
 		return true;
-	_log.Log(LOG_ERROR, "MySensors: Command not received by Node !! (node_id: %d, child_id: %d)", NodeID, ChildID);
+	Log(LOG_ERROR, "Command not received by Node !! (node_id: %d, child_id: %d)", NodeID, ChildID);
 	return m_bAckReceived;
 }
 
@@ -1338,7 +1323,7 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 			_tMySensorChild *pChild = pNode->FindChild(child_sensor_id);
 			if (!pChild)
 			{
-				_log.Log(LOG_ERROR, "MySensors: Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
+				Log(LOG_ERROR, "Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
 				return false;
 			}
 
@@ -1360,28 +1345,25 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 					//Door lock/contact
 					return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_LOCK_STATUS, lState, pChild->useAck, pChild->ackTimeout);
 				}
-				else if (pChild->presType == S_SCENE_CONTROLLER)
+				if (pChild->presType == S_SCENE_CONTROLLER)
 				{
 					//Scene Controller
 					return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, (light_command == light2_sOn) ? V_SCENE_ON : V_SCENE_OFF, lState, pChild->useAck, pChild->ackTimeout);
 				}
-				else
-				{
-					//normal
-					return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_STATUS, lState, pChild->useAck, pChild->ackTimeout);
-				}
+				// normal
+				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_STATUS, lState, pChild->useAck, pChild->ackTimeout);
 			}
-			else if (light_command == light2_sSetLevel)
+			if (light_command == light2_sSetLevel)
 			{
-				float fvalue = (100.0f / 15.0f)*float(pCmd->LIGHTING2.level);
-				if (fvalue > 100.0f)
-					fvalue = 100.0f; //99 is fully on
+				float fvalue = (100.0F / 15.0F) * float(pCmd->LIGHTING2.level);
+				if (fvalue > 100.0F)
+					fvalue = 100.0F; // 99 is fully on
 				int svalue = round(fvalue);
 				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_PERCENTAGE, std::to_string(svalue), pChild->useAck, pChild->ackTimeout);
 			}
 		}
 		else {
-			_log.Log(LOG_ERROR, "MySensors: Light command received for unknown node_id: %d", node_id);
+			Log(LOG_ERROR, "Light command received for unknown node_id: %d", node_id);
 			return false;
 		}
 	}
@@ -1399,7 +1381,7 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 				_tMySensorChild *pChild = pNode->FindChild(child_sensor_id);
 				if (!pChild)
 				{
-					_log.Log(LOG_ERROR, "MySensors: Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
+					Log(LOG_ERROR, "Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
 					return false;
 				}
 
@@ -1428,24 +1410,21 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 						//Door lock/contact
 						return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_LOCK_STATUS, lState, pChild->useAck, pChild->ackTimeout);
 					}
-					else if (pChild->presType == S_SCENE_CONTROLLER)
+					if (pChild->presType == S_SCENE_CONTROLLER)
 					{
 						//Scene Controller
 						return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, (cmnd == gswitch_sOn) ? V_SCENE_ON : V_SCENE_OFF, lState, pChild->useAck, pChild->ackTimeout);
 					}
-					else
-					{
-						//normal
-						return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_STATUS, lState, pChild->useAck, pChild->ackTimeout);
-					}
+					// normal
+					return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_STATUS, lState, pChild->useAck, pChild->ackTimeout);
 				}
-				else if (cmnd == gswitch_sSetLevel)
+				if (cmnd == gswitch_sSetLevel)
 				{
 					return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_PERCENTAGE, std::to_string(level), pChild->useAck, pChild->ackTimeout);
 				}
 			}
 			else {
-				_log.Log(LOG_ERROR, "MySensors: Light command received for unknown node_id: %d", node_id);
+				Log(LOG_ERROR, "Light command received for unknown node_id: %d", node_id);
 				return false;
 			}
 		}
@@ -1464,7 +1443,7 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 				}
 			}
 			else {
-				_log.Log(LOG_ERROR, "MySensors: Blinds/Window command received for unknown node_id: %d", node_id);
+				Log(LOG_ERROR, "Blinds/Window command received for unknown node_id: %d", node_id);
 				return false;
 			}
 		}
@@ -1486,11 +1465,11 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 			_tMySensorChild *pChild = pNode->FindChild(child_sensor_id);
 			if (!pChild)
 			{
-				_log.Log(LOG_ERROR, "MySensors: Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
+				Log(LOG_ERROR, "Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
 				return false;
 			}
 
-			bool bIsRGBW = (pNode->FindChildWithPresentationType(child_sensor_id, S_RGBW_LIGHT) != NULL);
+			bool bIsRGBW = (pNode->FindChildWithPresentationType(child_sensor_id, S_RGBW_LIGHT) != nullptr);
 			if (pLed->command == Color_SetColor)
 			{
 				std::stringstream sstr;
@@ -1519,16 +1498,16 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 						<< std::setw(2) << std::uppercase << std::hex << std::setfill('0') << std::hex << b;
 				}
 				else {
-					_log.Log(LOG_STATUS, "MySensors: SetRGBColour - Color mode %d is unhandled, if you have a suggestion for what it should do, please post on the Domoticz forum", pLed->color.mode);
+					Log(LOG_STATUS, "SetRGBColour - Color mode %d is unhandled, if you have a suggestion for what it should do, please post on the Domoticz forum", pLed->color.mode);
 					return false;
 				}
 				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, (bIsRGBW == true) ? V_RGBW : V_RGB, sstr.str(), pChild->useAck, pChild->ackTimeout);
 			}
-			else if (pLed->command == Color_SetColorToWhite)
+			if (pLed->command == Color_SetColorToWhite)
 			{
 				std::stringstream sstr;
 				int Brightness = 100;
-				int wWhite = round((255.0f / 100.0f)*float(Brightness));
+				int wWhite = round((255.0F / 100.0F) * float(Brightness));
 				if (!bIsRGBW)
 				{
 					sstr << std::setw(2) << std::uppercase << std::hex << std::setfill('0') << std::hex << wWhite
@@ -1542,21 +1521,21 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 				}
 				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, (bIsRGBW == true) ? V_RGBW : V_RGB, sstr.str(), pChild->useAck, pChild->ackTimeout);
 			}
-			else if (pLed->command == Color_SetBrightnessLevel)
+			if (pLed->command == Color_SetBrightnessLevel)
 			{
 				int svalue = pLed->value;
 				if (svalue > 100)
 					svalue = 100;
 				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_PERCENTAGE, std::to_string(svalue), pChild->useAck, pChild->ackTimeout);
 			}
-			else if ((pLed->command == Color_LedOff) || (pLed->command == Color_LedOn))
+			if ((pLed->command == Color_LedOff) || (pLed->command == Color_LedOn))
 			{
 				std::string lState = (pLed->command == Color_LedOn) ? "1" : "0";
 				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_STATUS, lState, pChild->useAck, pChild->ackTimeout);
 			}
 		}
 		else {
-			_log.Log(LOG_ERROR, "MySensors: Light command received for unknown node_id: %d", node_id);
+			Log(LOG_ERROR, "Light command received for unknown node_id: %d", node_id);
 			return false;
 		}
 	}
@@ -1571,7 +1550,7 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 			_tMySensorChild *pChild = pNode->FindChild(child_sensor_id);
 			if (!pChild)
 			{
-				_log.Log(LOG_ERROR, "MySensors: Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
+				Log(LOG_ERROR, "Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
 				return false;
 			}
 
@@ -1579,17 +1558,17 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 			{
 				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_UP, "", pChild->useAck, pChild->ackTimeout);
 			}
-			else if (pCmd->BLINDS1.cmnd == blinds_sClose)
+			if (pCmd->BLINDS1.cmnd == blinds_sClose)
 			{
 				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_DOWN, "", pChild->useAck, pChild->ackTimeout);
 			}
-			else if (pCmd->BLINDS1.cmnd == blinds_sStop)
+			if (pCmd->BLINDS1.cmnd == blinds_sStop)
 			{
 				return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, V_STOP, "", pChild->useAck, pChild->ackTimeout);
 			}
 		}
 		else {
-			_log.Log(LOG_ERROR, "MySensors: Blinds/Window command received for unknown node_id: %d", node_id);
+			Log(LOG_ERROR, "Blinds/Window command received for unknown node_id: %d", node_id);
 			return false;
 		}
 	}
@@ -1607,7 +1586,7 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 			_tMySensorChild *pChild = pNode->FindChild(child_sensor_id);
 			if (!pChild)
 			{
-				_log.Log(LOG_ERROR, "MySensors: Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
+				Log(LOG_ERROR, "Light command received for unknown node_id: %d, child_id: %d", node_id, child_sensor_id);
 				return false;
 			}
 
@@ -1615,14 +1594,12 @@ bool MySensorsBase::WriteToHardware(const char *pdata, const unsigned char /*len
 			sprintf(szTmp, "%.1f", pMeter->temp);
 			return SendNodeSetCommand(node_id, child_sensor_id, MT_Set, vtype_id, szTmp, pChild->useAck, pChild->ackTimeout);
 		}
-		else {
-			_log.Log(LOG_ERROR, "MySensors: Blinds/Window command received for unknown node_id: %d", node_id);
-			return false;
-		}
+		Log(LOG_ERROR, "Blinds/Window command received for unknown node_id: %d", node_id);
+		return false;
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "MySensors: Unknown action received");
+		Log(LOG_ERROR, "Unknown action received");
 		return false;
 	}
 	return true;
@@ -1692,7 +1669,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 	if (sLine.size() < 2)
 		return;
 
-	//_log.Log(LOG_STATUS, sLine.c_str());
+	//Log(LOG_STATUS, sLine.c_str());
 
 	std::vector<std::string> results;
 	StringSplit(sLine, ";", results);
@@ -1704,7 +1681,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 	_eMessageType message_type = (_eMessageType)atoi(results[2].c_str());
 	int ack = atoi(results[3].c_str());
 	int sub_type = atoi(results[4].c_str());
-	std::string payload = "";
+	std::string payload;
 	if (results.size() >= 6)
 	{
 		for (size_t ip = 0; ip < results.size() - 5; ip++)
@@ -1713,7 +1690,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 		}
 	}
 #ifdef _DEBUG
-	_log.Log(LOG_NORM, "MySensors: NodeID: %d, ChildID: %d, MessageType: %d, Ack: %d, SubType: %d, Payload: %s", node_id, child_sensor_id, message_type, ack, sub_type, payload.c_str());
+	Log(LOG_NORM, "NodeID: %d, ChildID: %d, MessageType: %d, Ack: %d, SubType: %d, Payload: %s", node_id, child_sensor_id, message_type, ack, sub_type, payload.c_str());
 #endif
 
 	if (message_type == MT_Internal)
@@ -1726,10 +1703,10 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			{
 				//Store gateway version
 				m_GatewayVersion = payload;
-				_log.Log(LOG_NORM, "MySensors: Gateway Version: %s", payload.c_str());
+				Log(LOG_NORM, "Gateway Version: %s", payload.c_str());
 			}
 			else {
-				_log.Log(LOG_NORM, "MySensors: VERSION from NodeID: %d, ChildID: %d, Payload: %s", node_id, child_sensor_id, payload.c_str());
+				Log(LOG_NORM, "VERSION from NodeID: %d, ChildID: %d, Payload: %s", node_id, child_sensor_id, payload.c_str());
 			}
 		}
 		break;
@@ -1747,7 +1724,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			SendNodeCommand(node_id, child_sensor_id, message_type, I_CONFIG, "M");
 			break;
 		case I_SKETCH_NAME:
-			_log.Log(LOG_STATUS, "MySensors: Node: %d, Sketch Name: %s", node_id, payload.c_str());
+			Log(LOG_STATUS, "Node: %d, Sketch Name: %s", node_id, payload.c_str());
 			if (_tMySensorNode *pNode = FindNode(node_id))
 			{
 				DatabaseUpdateSketchName(node_id, payload);
@@ -1760,7 +1737,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			}
 			break;
 		case I_SKETCH_VERSION:
-			_log.Log(LOG_STATUS, "MySensors: Node: %d, Sketch Version: %s", node_id, payload.c_str());
+			Log(LOG_STATUS, "Node: %d, Sketch Version: %s", node_id, payload.c_str());
 			if (_tMySensorNode *pNode = FindNode(node_id))
 			{
 				DatabaseUpdateSketchVersion(node_id, payload);
@@ -1776,10 +1753,10 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			UpdateNodeBatteryLevel(node_id, atoi(payload.c_str()));
 			break;
 		case I_LOG_MESSAGE:
-			//_log.Log(LOG_NORM, "MySensors: 'Log': %s", payload.c_str());
+			//Log(LOG_NORM, "'Log': %s", payload.c_str());
 			break;
 		case I_GATEWAY_READY:
-			_log.Log(LOG_NORM, "MySensors: Gateway Ready...");
+			Log(LOG_NORM, "Gateway Ready...");
 			//Request Gateway Version
 			SendCommandInt(0, 0, MT_Internal, false, I_VERSION, "Get Version");
 			break;
@@ -1821,7 +1798,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			while (1 == 0);
 			break;
 		case I_INCLUSION_MODE:
-			_log.Log(LOG_NORM, "MySensors: Inclusion mode=%s", payload.c_str());
+			Log(LOG_NORM, "Inclusion mode=%s", payload.c_str());
 			m_sql.m_bAcceptNewHardware = atoi(payload.c_str()) ? true : false;
 			break;
 		case I_PRE_SLEEP_NOTIFICATION:
@@ -1830,7 +1807,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			if (node_id != 255)
 			{
 				std::lock_guard<std::mutex> l(m_node_sleep_mutex);
-				std::map<int, std::vector<_tMySensorSmartSleepQueueItem> >::const_iterator itt = m_node_sleep_queue.find(node_id);
+				auto itt = m_node_sleep_queue.find(node_id);
 				if (itt != m_node_sleep_queue.end())
 				{
 					//Send queues messages
@@ -1868,16 +1845,16 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 		_eSetType vType = (_eSetType)sub_type;
 
 		_tMySensorNode *pNode = FindNode(node_id);
-		if (pNode == NULL)
+		if (pNode == nullptr)
 		{
 			pNode = InsertNode(node_id);
-			if (pNode == NULL)
+			if (pNode == nullptr)
 				return;
 		}
-		pNode->lastreceived = mytime(NULL);
+		pNode->lastreceived = mytime(nullptr);
 
 		_tMySensorChild *pChild = pNode->FindChild(child_sensor_id);
-		if (pChild == NULL)
+		if (pChild == nullptr)
 		{
 			//Unknown sensor, add it to the system
 			_tMySensorChild mSensor;
@@ -1890,7 +1867,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			}
 			pNode->m_childs.push_back(mSensor);
 			pChild = pNode->FindChild(child_sensor_id);
-			if (pChild == NULL)
+			if (pChild == nullptr)
 				return;
 		}
 		pChild->lastreceived = pNode->lastreceived;
@@ -2078,7 +2055,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			bHaveValue = true;
 			break;
 		case V_IR_RECEIVE:
-			pChild->SetValue(vType, atoi(payload.c_str()));
+			pChild->SetValue(vType, (int)std::stoul(payload.c_str()));
 			bHaveValue = true;
 			break;
 		case V_IR_SEND:
@@ -2116,11 +2093,11 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 		default:
 			if (sub_type > V_CURRENT)
 			{
-				_log.Log(LOG_ERROR, "MySensors: Unknown/Invalid sensor type (%d)", sub_type);
+				Log(LOG_ERROR, "Unknown/Invalid sensor type (%d)", sub_type);
 			}
 			else
 			{
-				_log.Log(LOG_ERROR, "MySensors: Unhandled sensor (sub-type=%d), please report with log!", sub_type);
+				Log(LOG_ERROR, "Unhandled sensor (sub-type=%d), please report with log!", sub_type);
 			}
 			break;
 		}
@@ -2198,15 +2175,15 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			break;
 		}
 		_tMySensorNode *pNode = FindNode(node_id);
-		if (pNode == NULL)
+		if (pNode == nullptr)
 		{
 			pNode = InsertNode(node_id);
-			if (pNode == NULL)
+			if (pNode == nullptr)
 				return;
 		}
-		pNode->lastreceived = mytime(NULL);
+		pNode->lastreceived = mytime(nullptr);
 		_tMySensorChild *pSensor = pNode->FindChild(child_sensor_id);
-		if (pSensor == NULL)
+		if (pSensor == nullptr)
 		{
 			//Unknown sensor, add it to the system
 			_tMySensorChild mSensor;
@@ -2214,14 +2191,14 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			mSensor.childID = child_sensor_id;
 			pNode->m_childs.push_back(mSensor);
 			pSensor = pNode->FindChild(child_sensor_id);
-			if (pSensor == NULL)
+			if (pSensor == nullptr)
 				return;
 		}
 		bool bDiffPresentation = (
 			(pSensor->presType != pType) ||
 			(pSensor->childName != payload)
 			);
-		pSensor->lastreceived = mytime(NULL);
+		pSensor->lastreceived = mytime(nullptr);
 		pSensor->presType = pType;
 		pSensor->childName = payload;
 
@@ -2245,9 +2222,9 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 				else if (vType == V_TRIPPED)
 					UpdateSwitch(vType, node_id, child_sensor_id, false, 100, (!pSensor->childName.empty()) ? pSensor->childName : "Security Sensor", pSensor->batValue);
 				else if (vType == V_RGBW)
-					SendRGBWSwitch(node_id, child_sensor_id, pSensor->batValue, 0, true, (!pSensor->childName.empty()) ? pSensor->childName : "RGBW Light");
+					SendRGBWSwitch(node_id, child_sensor_id, pSensor->batValue, 0, true, (!pSensor->childName.empty()) ? pSensor->childName : "RGBW Light", m_Name);
 				else if (vType == V_RGB)
-					SendRGBWSwitch(node_id, child_sensor_id, pSensor->batValue, 0, false, (!pSensor->childName.empty()) ? pSensor->childName : "RGB Light");
+					SendRGBWSwitch(node_id, child_sensor_id, pSensor->batValue, 0, false, (!pSensor->childName.empty()) ? pSensor->childName : "RGB Light", m_Name);
 			}
 		}
 		else if (vType == V_UP)
@@ -2255,7 +2232,7 @@ void MySensorsBase::ParseLine(const std::string &sLine)
 			int blind_value;
 			if (!GetBlindsValue(node_id, child_sensor_id, blind_value))
 			{
-				SendBlindSensor(node_id, child_sensor_id, pSensor->batValue, blinds_sOpen, (!pSensor->childName.empty()) ? pSensor->childName : "Blinds/Window");
+				SendBlindSensor(node_id, child_sensor_id, pSensor->batValue, blinds_sOpen, (!pSensor->childName.empty()) ? pSensor->childName : "Blinds/Window", m_Name);
 			}
 		}
 		else if (vType == V_TEXT)
@@ -2326,12 +2303,12 @@ void MySensorsBase::SendTextSensorValue(const int nodeID, const int childID, con
 		}
 		else
 		{
-			_log.Log(LOG_ERROR, "MySensors: Text update received for unknown node_id: %d, child_id: %d", nodeID, childID);
+			Log(LOG_ERROR, "Text update received for unknown node_id: %d, child_id: %d", nodeID, childID);
 		}
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "MySensors: Text update received for unknown node_id: %d, child_id: %d", nodeID, childID);
+		Log(LOG_ERROR, "Text update received for unknown node_id: %d, child_id: %d", nodeID, childID);
 	}
 
 }
@@ -2339,9 +2316,9 @@ void MySensorsBase::SendTextSensorValue(const int nodeID, const int childID, con
 bool MySensorsBase::StartSendQueue()
 {
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&MySensorsBase::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadName(m_thread->native_handle(), "MySensorsBase");
-	return (m_thread != NULL);
+	return (m_thread != nullptr);
 }
 
 void MySensorsBase::StopSendQueue()
@@ -2371,7 +2348,7 @@ void MySensorsBase::Do_Work()
 			return;
 		}
 #ifdef _DEBUG
-		_log.Log(LOG_STATUS, "MySensors: going to send: %s", toSend.c_str());
+		Log(LOG_STATUS, "going to send: %s", toSend.c_str());
 #endif
 		WriteInt(toSend);
 	}
@@ -2388,11 +2365,11 @@ namespace http {
 				return; //Only admin user allowed
 			}
 			std::string hwid = request::findValue(&req, "idx");
-			if (hwid == "")
+			if (hwid.empty())
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pHardware == NULL)
+			if (pHardware == nullptr)
 				return;
 			if (
 				(pHardware->HwdType != HTYPE_MySensorsUSB) &&
@@ -2412,10 +2389,8 @@ namespace http {
 			if (!result.empty())
 			{
 				int ii = 0;
-				for (const auto & itt : result)
+				for (const auto &sd : result)
 				{
-					std::vector<std::string> sd = itt;
-
 					int NodeID = atoi(sd[0].c_str());
 
 					root["result"][ii]["idx"] = NodeID;
@@ -2425,7 +2400,7 @@ namespace http {
 
 					MySensorsBase::_tMySensorNode* pNode = pMySensorsHardware->FindNode(NodeID);
 
-					if (pNode != NULL)
+					if (pNode != nullptr)
 					{
 						if (pNode->lastreceived != 0)
 						{
@@ -2463,14 +2438,11 @@ namespace http {
 			}
 			std::string hwid = request::findValue(&req, "idx");
 			std::string nodeid = request::findValue(&req, "nodeid");
-			if (
-				(hwid == "") ||
-				(nodeid == "")
-				)
+			if ((hwid.empty()) || (nodeid.empty()))
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pHardware == NULL)
+			if (pHardware == nullptr)
 				return;
 			if (
 				(pHardware->HwdType != HTYPE_MySensorsUSB) &&
@@ -2487,9 +2459,8 @@ namespace http {
 			std::vector<std::vector<std::string> > result;
 			result = m_sql.safe_query("SELECT ChildID, [Type], Name, UseAck, AckTimeout FROM MySensorsChilds WHERE (HardwareID=%d) AND (NodeID == %d) ORDER BY ChildID ASC", iHardwareID, NodeID);
 			int ii = 0;
-			for (const auto & itt2 : result)
+			for (const auto &sd2 : result)
 			{
-				std::vector<std::string> sd2 = itt2;
 				int ChildID = atoi(sd2[0].c_str());
 				root["result"][ii]["child_id"] = ChildID;
 				root["result"][ii]["type"] = MySensorsBase::GetMySensorsPresentationTypeStr((MySensorsBase::_ePresentationType)atoi(sd2[1].c_str()));
@@ -2497,11 +2468,11 @@ namespace http {
 				root["result"][ii]["use_ack"] = (sd2[3] != "0") ? "true" : "false";
 				root["result"][ii]["ack_timeout"] = atoi(sd2[4].c_str());
 				std::string szDate = "-";
-				std::string szValues = "";
-				if (pNode != NULL)
+				std::string szValues;
+				if (pNode != nullptr)
 				{
 					MySensorsBase::_tMySensorChild*  pChild = pNode->FindChild(ChildID);
-					if (pChild != NULL)
+					if (pChild != nullptr)
 					{
 						std::vector<MySensorsBase::_eSetType> ctypes = pChild->GetChildValueTypes();
 						std::vector<std::string> cvalues = pChild->GetChildValues();
@@ -2545,15 +2516,11 @@ namespace http {
 			std::string hwid = request::findValue(&req, "idx");
 			std::string nodeid = request::findValue(&req, "nodeid");
 			std::string name = HTMLSanitizer::Sanitize(request::findValue(&req, "name"));
-			if (
-				(hwid == "") ||
-				(nodeid == "") ||
-				(name == "")
-				)
+			if ((hwid.empty()) || (nodeid.empty()) || (name.empty()))
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pBaseHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			if (
 				(pBaseHardware->HwdType != HTYPE_MySensorsUSB) &&
@@ -2577,14 +2544,11 @@ namespace http {
 
 			std::string hwid = request::findValue(&req, "idx");
 			std::string nodeid = request::findValue(&req, "nodeid");
-			if (
-				(hwid == "") ||
-				(nodeid == "")
-				)
+			if ((hwid.empty()) || (nodeid.empty()))
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pBaseHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			if (
 				(pBaseHardware->HwdType != HTYPE_MySensorsUSB) &&
@@ -2609,15 +2573,11 @@ namespace http {
 			std::string hwid = request::findValue(&req, "idx");
 			std::string nodeid = request::findValue(&req, "nodeid");
 			std::string childid = request::findValue(&req, "childid");
-			if (
-				(hwid == "") ||
-				(nodeid == "") ||
-				(childid == "")
-				)
+			if ((hwid.empty()) || (nodeid.empty()) || (childid.empty()))
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pBaseHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			if (
 				(pBaseHardware->HwdType != HTYPE_MySensorsUSB) &&
@@ -2655,7 +2615,7 @@ namespace http {
 				return;
 			int iHardwareID = atoi(hwid.c_str());
 			CDomoticzHardwareBase *pBaseHardware = m_mainworker.GetHardware(iHardwareID);
-			if (pBaseHardware == NULL)
+			if (pBaseHardware == nullptr)
 				return;
 			if (
 				(pBaseHardware->HwdType != HTYPE_MySensorsUSB) &&
@@ -2674,5 +2634,5 @@ namespace http {
 				iAckTimeout = 100;
 			pMySensorsHardware->UpdateChild(NodeID, ChildID, bUseAck, iAckTimeout);
 		}
-	}
-}
+	} // namespace server
+} // namespace http
