@@ -5,10 +5,11 @@
 
 class MySensorsSerial : public AsyncSerial, public MySensorsBase
 {
-public:
-	MySensorsSerial(const int ID, const std::string& devname, const int Mode1);
-	~MySensorsSerial();
-private:
+      public:
+	MySensorsSerial(int ID, const std::string &devname, int Mode1);
+	~MySensorsSerial() override = default;
+
+      private:
 	bool StartHardware() override;
 	bool StopHardware() override;
 
@@ -24,4 +25,3 @@ private:
 	void readCallback(const char *data, size_t len);
 	void WriteInt(const std::string &sendStr) override;
 };
-
