@@ -8,18 +8,14 @@
 
 #define RETRY_DELAY 30
 
-MySensorsTCP::MySensorsTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort) :
-	m_szIPAddress(IPAddress),
-	m_usIPPort(usIPPort),
-	m_retrycntr(RETRY_DELAY)
+MySensorsTCP::MySensorsTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort)
+	: m_retrycntr(RETRY_DELAY)
+	, m_szIPAddress(IPAddress)
+	, m_usIPPort(usIPPort)
 {
 	m_HwdID = ID;
 }
 
-MySensorsTCP::~MySensorsTCP(void)
-{
-}
-
 bool MySensorsTCP::StartHardware()
 {
 	RequestStart();
@@ -33,7 +29,7 @@ bool MySensorsTCP::StartHardware()
 	m_bIsStarted = true;
 
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&MySensorsTCP::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	StartSendQueue();
 	return (m_thread != nullptr);
@@ -54,7 +50,7 @@ bool MySensorsTCP::StopHardware()
 
 void MySensorsTCP::OnConnect()
 {
-	_log.Log(LOG_STATUS, "MySensors: connected to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+	Log(LOG_STATUS, "connected to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	m_bIsStarted = true;
 	m_LineReceived.clear();
 
@@ -67,20 +63,20 @@ void MySensorsTCP::OnConnect()
 
 void MySensorsTCP::OnDisconnect()
 {
-	_log.Log(LOG_STATUS, "MySensors: disconnected");
+	Log(LOG_STATUS, "disconnected");
 }
 
 void MySensorsTCP::Do_Work()
 {
 	int sec_counter = 0;
-	_log.Log(LOG_STATUS, "MySensors: trying to connect to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+	Log(LOG_STATUS, "trying to connect to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	connect(m_szIPAddress, m_usIPPort);
 	while (!IsStopRequested(1000))
 	{
 		sec_counter++;
 
 		if (sec_counter % 12 == 0) {
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (isConnected())
@@ -95,7 +91,7 @@ void MySensorsTCP::Do_Work()
 	}
 	terminate();
 
-	_log.Log(LOG_STATUS, "MySensors: TCP/IP Worker stopped...");
+	Log(LOG_STATUS, "TCP/IP Worker stopped...");
 }
 
 void MySensorsTCP::OnData(const unsigned char *pData, size_t length)
@@ -113,17 +109,17 @@ void MySensorsTCP::OnError(const boost::system::error_code& error)
 		(error == boost::asio::error::timed_out)
 		)
 	{
-		_log.Log(LOG_ERROR, "MySensors: Can not connect to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
+		Log(LOG_ERROR, "Can not connect to: %s:%d", m_szIPAddress.c_str(), m_usIPPort);
 	}
 	else if (
 		(error == boost::asio::error::eof) ||
 		(error == boost::asio::error::connection_reset)
 		)
 	{
-		_log.Log(LOG_STATUS, "MySensors: Connection reset!");
+		Log(LOG_STATUS, "Connection reset!");
 	}
 	else
-		_log.Log(LOG_ERROR, "MySensors: %s", error.message().c_str());
+		Log(LOG_ERROR, "%s", error.message().c_str());
 }
 
 void MySensorsTCP::WriteInt(const std::string &sendStr)
