@@ -121,10 +121,6 @@ m_szIPAddress(IPAddress)
 	Init();
 }
 
-CNefitEasy::~CNefitEasy(void)
-{
-}
-
 void CNefitEasy::Init()
 {
 	m_lastgasusage = 0;
@@ -137,7 +133,7 @@ bool CNefitEasy::StartHardware()
 
 	Init();
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CNefitEasy::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted=true;
 	sOnConnected(this);
@@ -170,13 +166,13 @@ void CNefitEasy::Do_Work()
 	int fast_pollint = NEFIT_FAST_POLL_INTERVAL;
 	int slow_pollint = NEFIT_SLOW_INTERVAL;
 
-	_log.Log(LOG_STATUS, "NefitEasy: Worker started...");
+	Log(LOG_STATUS, "Worker started...");
 
 	while (!IsStopRequested(1000))
 	{
 		sec_counter++;
 		if (sec_counter % 12 == 0) {
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 		if ((sec_counter % fast_pollint == 0) || (bFirstTime))
 		{
@@ -191,7 +187,7 @@ void CNefitEasy::Do_Work()
 			}
 			catch (...)
 			{
-				_log.Log(LOG_ERROR, "NefitEasy: Error getting/processing status result...");
+				Log(LOG_ERROR, "Error getting/processing status result...");
 			}
 		}
 		if ((sec_counter % slow_pollint == 0) || (bFirstTime))
@@ -205,7 +201,7 @@ void CNefitEasy::Do_Work()
 			}
 			catch (...)
 			{
-				_log.Log(LOG_ERROR, "NefitEasy: Error getting/processing pressure result...");
+				Log(LOG_ERROR, "Error getting/processing pressure result...");
 			}
 		}
 		if (sec_counter % NEFIT_GAS_INTERVAL == 0)
@@ -216,12 +212,12 @@ void CNefitEasy::Do_Work()
 			}
 			catch (...)
 			{
-				_log.Log(LOG_ERROR, "NefitEasy: Error getting/processing gas result...");
+				Log(LOG_ERROR, "Error getting/processing gas result...");
 			}
 		}
 		bFirstTime = false;
 	}
-	_log.Log(LOG_STATUS, "NefitEasy: Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 bool CNefitEasy::WriteToHardware(const char *pdata, const unsigned char /*length*/)
@@ -238,7 +234,7 @@ bool CNefitEasy::WriteToHardware(const char *pdata, const unsigned char /*length
 			SetUserMode(bIsOn);
 			return true;
 		}
-		else if (node_id == 2)
+		if (node_id == 2)
 		{
 			//Hot Water Switch
 			SetHotWaterMode(bIsOn);
@@ -265,14 +261,14 @@ void CNefitEasy::SetUserMode(bool bSetUserModeClock)
 		szURL << "http://" << m_szIPAddress << ":" << m_usIPPort << NEFITEASY_HTTP_BRIDGE << NEFITEASY_SET_USER_MODE;
 		if (!HTTPClient::POST(szURL.str(), root.toStyledString(), ExtraHeaders, sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error setting User Mode!");
+			Log(LOG_ERROR, "Error setting User Mode!");
 			return;
 		}
 		GetStatusDetails();
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error setting User Mode!");
+		Log(LOG_ERROR, "Error setting User Mode!");
 		return;
 	}
 }
@@ -295,20 +291,20 @@ void CNefitEasy::SetHotWaterMode(bool bTurnOn)
 		szURL << "http://" << m_szIPAddress << ":" << m_usIPPort << NEFITEASY_HTTP_BRIDGE << NEFITEASY_SET_HOT_WATER_CLOCK_MODE;
 		if (!HTTPClient::POST(szURL.str(), root.toStyledString(), ExtraHeaders, sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error setting User Mode!");
+			Log(LOG_ERROR, "Error setting User Mode!");
 			return;
 		}
 		szURL << "http://" << m_szIPAddress << ":" << m_usIPPort << NEFITEASY_HTTP_BRIDGE << NEFITEASY_SET_HOT_WATER_MANUAL_MODE;
 		if (!HTTPClient::POST(szURL.str(), root.toStyledString(), ExtraHeaders, sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error setting User Mode!");
+			Log(LOG_ERROR, "Error setting User Mode!");
 			return;
 		}
 		GetStatusDetails();
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error setting User Mode!");
+		Log(LOG_ERROR, "Error setting User Mode!");
 		return;
 	}
 }
@@ -327,13 +323,13 @@ bool CNefitEasy::GetStatusDetails()
 	{
 		if (!HTTPClient::GET(szURL.str(), sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+			Log(LOG_ERROR, "Error getting http data!");
 			return false;
 		}
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+		Log(LOG_ERROR, "Error getting http data!");
 		return false;
 	}
 #endif
@@ -348,26 +344,26 @@ bool CNefitEasy::GetStatusDetails()
 	if ((!ret) || (!root.isObject()))
 	{
 		if (sResult.find("Error: REQUEST_TIMEOUT") != std::string::npos)
-			_log.Log(LOG_ERROR, "NefitEasy: Request Timeout !");
+			Log(LOG_ERROR, "Request Timeout !");
 		else
-			_log.Log(LOG_ERROR, "NefitEasy: Invalid data received (main)!");
+			Log(LOG_ERROR, "Invalid data received (main)!");
 		return false;
 	}
 	if(!CheckId(NEFITEASY_STATUS_URL, root))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid response received (main)");
+		Log(LOG_ERROR, "Invalid response received (main)");
 		return false;
 	}
 
 	if (root["value"].empty())
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received (main)");
+		Log(LOG_ERROR, "Invalid data received (main)");
 		return false;
 	}
 	root2 = root["value"];
 	if (root2["TOT"].empty())
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received (main)");
+		Log(LOG_ERROR, "Invalid data received (main)");
 		return false;
 	}
 	/*
@@ -425,7 +421,7 @@ bool CNefitEasy::GetStatusDetails()
 		tmpstr = root2["BAI"].asString();
 		if (tmpstr != "null")
 		{
-			std::string bstatus = "";
+			std::string bstatus;
 			if (tmpstr == "CH")
 				bstatus = "central heating";
 			else if (tmpstr == "HW")
@@ -446,13 +442,13 @@ bool CNefitEasy::GetStatusDetails()
 	{
 		tmpstr = root2["UMD"].asString();
 		m_bClockMode = (tmpstr == "clock");
-		SendSwitch(1, 1, -1, m_bClockMode, 0, "Clock Mode");
+		SendSwitch(1, 1, -1, m_bClockMode, 0, "Clock Mode", m_Name);
 	}
 	if (!root2["DHW"].empty())
 	{
 		tmpstr = root2["DHW"].asString();
 		bool bIsOn = (tmpstr != "off");
-		SendSwitch(2, 1, -1, bIsOn, 0, "Hot Water");
+		SendSwitch(2, 1, -1, bIsOn, 0, "Hot Water", m_Name);
 	}
 
 	return true;
@@ -474,13 +470,13 @@ bool CNefitEasy::GetOutdoorTemp()
 	{
 		if (!HTTPClient::GET(szURL2.str(), sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+			Log(LOG_ERROR, "Error getting http data!");
 			return false;
 		}
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+		Log(LOG_ERROR, "Error getting http data!");
 		return false;
 	}
 #endif
@@ -491,17 +487,17 @@ bool CNefitEasy::GetOutdoorTemp()
 	ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received! (ODT)");
+		Log(LOG_ERROR, "Invalid data received! (ODT)");
 		return false;
 	}
 	if(!CheckId(NEFITEASY_OUTDOORTEMP_URL, root))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid response received! (ODT)");
+		Log(LOG_ERROR, "Invalid response received! (ODT)");
 		return false;
 	}
 	if (root["value"].empty() == true)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received (ODT)");
+		Log(LOG_ERROR, "Invalid data received (ODT)");
 		return false;
 	}
 
@@ -526,13 +522,13 @@ bool CNefitEasy::GetFlowTemp()
 	{
 		if (!HTTPClient::GET(szURL2.str(), sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+			Log(LOG_ERROR, "Error getting http data!");
 			return false;
 		}
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+		Log(LOG_ERROR, "Error getting http data!");
 		return false;
 	}
 #endif
@@ -543,17 +539,17 @@ bool CNefitEasy::GetFlowTemp()
 	ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received! (FT)");
+		Log(LOG_ERROR, "Invalid data received! (FT)");
 		return false;
 	}
 	if(!CheckId(NEFITEASY_FLOWTEMP_URL, root))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid response received (FT)");
+		Log(LOG_ERROR, "Invalid response received (FT)");
 		return false;
 	}
 	if (root["value"].empty() == true)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received (FT)");
+		Log(LOG_ERROR, "Invalid data received (FT)");
 		return false;
 	}
 
@@ -578,13 +574,13 @@ bool CNefitEasy::GetPressure()
 	{
 		if (!HTTPClient::GET(szURL.str(), sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+			Log(LOG_ERROR, "Error getting http data!");
 			return false;
 		}
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+		Log(LOG_ERROR, "Error getting http data!");
 		return false;
 	}
 #endif
@@ -595,17 +591,17 @@ bool CNefitEasy::GetPressure()
 	ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received! (Press)");
+		Log(LOG_ERROR, "Invalid data received! (Press)");
 		return false;
 	}
 	if(!CheckId(NEFITEASY_PRESSURE_URL, root))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid response received! (Press)");
+		Log(LOG_ERROR, "Invalid response received! (Press)");
 		return false;
 	}
 	if (root["value"].empty())
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received (Press)");
+		Log(LOG_ERROR, "Invalid data received (Press)");
 		return false;
 	}
 	float pressure = root["value"].asFloat();
@@ -628,13 +624,13 @@ bool CNefitEasy::GetDisplayCode()
 	{
 		if (!HTTPClient::GET(szURL3.str(), sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+			Log(LOG_ERROR, "Error getting http data!");
 			return false;
 		}
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+		Log(LOG_ERROR, "Error getting http data!");
 		return false;
 	}
 #endif
@@ -645,17 +641,17 @@ bool CNefitEasy::GetDisplayCode()
 	ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received! (DP)");
+		Log(LOG_ERROR, "Invalid data received! (DP)");
 		return false;
 	}
 	if(!CheckId(NEFITEASY_DISPLAYCODE_URL, root))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid response received! (DP)");
+		Log(LOG_ERROR, "Invalid response received! (DP)");
 		return false;
 	}
 	if (root["value"].empty() == true)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received (DP)");
+		Log(LOG_ERROR, "Invalid data received (DP)");
 		return false;
 	}
 
@@ -728,13 +724,13 @@ bool CNefitEasy::GetGasUsage()
 	{
 		if (!HTTPClient::GET(szURL.str(), sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+			Log(LOG_ERROR, "Error getting http data!");
 			return false;
 		}
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error getting http data!");
+		Log(LOG_ERROR, "Error getting http data!");
 		return false;
 	}
 #endif
@@ -745,29 +741,29 @@ bool CNefitEasy::GetGasUsage()
 	ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received! (Gas)");
+		Log(LOG_ERROR, "Invalid data received! (Gas)");
 		return false;
 	}
 	if(!CheckId(NEFITEASY_GAS_URL, root))
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid response received! (Gas)");
+		Log(LOG_ERROR, "Invalid response received! (Gas)");
 		return false;
 	}
 	if (root["value"].empty())
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Invalid data received (Gas)");
+		Log(LOG_ERROR, "Invalid data received (Gas)");
 		return false;
 	}
 	float yeargas = root["value"].asFloat();
 	//convert from kWh to m3
-	yeargas *= (0.12307692f*1000.0f);
+	yeargas *= (0.12307692F * 1000.0F);
 	uint32_t gusage = (uint32_t)yeargas;
 	if (gusage < m_lastgasusage)
 	{
 
 	}
 	m_p1gas.gasusage = gusage;
-	sDecodeRXMessage(this, (const unsigned char *)&m_p1gas, "Gas", 255);
+	sDecodeRXMessage(this, (const unsigned char *)&m_p1gas, "Gas", 255, nullptr);
 	return true;
 }
 
@@ -787,7 +783,7 @@ void CNefitEasy::SetSetpoint(const int /*idx*/, const float temp)
 		szURL << "http://" << m_szIPAddress << ":" << m_usIPPort << NEFITEASY_HTTP_BRIDGE << NEFITEASY_SET_TEMP_ROOM;
 		if (!HTTPClient::POST(szURL.str(), root.toStyledString(), ExtraHeaders, sResult))
 		{
-			_log.Log(LOG_ERROR, "NefitEasy: Error setting setpoint!");
+			Log(LOG_ERROR, "Error setting setpoint!");
 			return;
 		}
 		szURL.clear();
@@ -799,7 +795,7 @@ void CNefitEasy::SetSetpoint(const int /*idx*/, const float temp)
 			szURL << "http://" << m_szIPAddress << ":" << m_usIPPort << NEFITEASY_HTTP_BRIDGE << NEFITEASY_SET_TEMP_OVERRIDE;
 			if (!HTTPClient::POST(szURL.str(), root2.toStyledString(), ExtraHeaders, sResult))
 			{
-				_log.Log(LOG_ERROR, "NefitEasy: Error setting setpoint!");
+				Log(LOG_ERROR, "Error setting setpoint!");
 				return;
 			}
 			szURL.clear();
@@ -807,7 +803,7 @@ void CNefitEasy::SetSetpoint(const int /*idx*/, const float temp)
 			szURL << "http://" << m_szIPAddress << ":" << m_usIPPort << NEFITEASY_HTTP_BRIDGE << NEFITEASY_SET_TEMP_OVERRIDE_TEMP;
 			if (!HTTPClient::POST(szURL.str(), root.toStyledString(), ExtraHeaders, sResult))
 			{
-				_log.Log(LOG_ERROR, "NefitEasy: Error setting setpoint!");
+				Log(LOG_ERROR, "Error setting setpoint!");
 				return;
 			}
 		}
@@ -818,14 +814,14 @@ void CNefitEasy::SetSetpoint(const int /*idx*/, const float temp)
 			szURL << "http://" << m_szIPAddress << ":" << m_usIPPort << NEFITEASY_HTTP_BRIDGE << NEFITEASY_SET_TEMP_OVERRIDE;
 			if (!HTTPClient::POST(szURL.str(), root2.toStyledString(), ExtraHeaders, sResult))
 			{
-				_log.Log(LOG_ERROR, "NefitEasy: Error setting setpoint!");
+				Log(LOG_ERROR, "Error setting setpoint!");
 				return;
 			}
 		}
 	}
 	catch (...)
 	{
-		_log.Log(LOG_ERROR, "NefitEasy: Error setting Setpoint!");
+		Log(LOG_ERROR, "Error setting Setpoint!");
 		return;
 	}
 	GetStatusDetails();
