@@ -16,14 +16,14 @@
 #include "../main/json_helper.h"
 #include "../webserver/Base64.h"
 
-
-#define round(a) ( int ) ( a + .5 )
+#define round(a) (int)(a + .5)
 
 // Base URL of API including trailing slash
 const std::string NEST_OAUTHAPI_BASE = "https://developer-api.nest.com/";
 const std::string NEST_OAUTHAPI_OAUTH_ACCESSTOKENURL = "https://api.home.nest.com/oauth2/access_token";
 
-CNestOAuthAPI::CNestOAuthAPI(const int ID, const std::string &apikey, const std::string &extradata) : m_OAuthApiAccessToken(apikey)
+CNestOAuthAPI::CNestOAuthAPI(const int ID, const std::string &apikey, const std::string &extradata)
+	: m_OAuthApiAccessToken(apikey)
 {
 	m_HwdID = ID;
 
@@ -40,10 +40,6 @@ CNestOAuthAPI::CNestOAuthAPI(const int ID, const std::string &apikey, const std:
 	Init();
 }
 
-CNestOAuthAPI::~CNestOAuthAPI(void)
-{
-}
-
 void CNestOAuthAPI::Init()
 {
 	m_bDoLogin = true;
@@ -54,10 +50,10 @@ bool CNestOAuthAPI::StartHardware()
 	RequestStart();
 
 	Init();
-	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CNestOAuthAPI::Do_Work, this);
+	// Start worker thread
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
-	m_bIsStarted=true;
+	m_bIsStarted = true;
 	sOnConnected(this);
 	return (m_thread != nullptr);
 }
@@ -70,22 +66,22 @@ bool CNestOAuthAPI::StopHardware()
 		m_thread->join();
 		m_thread.reset();
 	}
-    m_bIsStarted=false;
-    return true;
+	m_bIsStarted = false;
+	return true;
 }
 
 #define NEST_POLL_INTERVAL 60
 
 void CNestOAuthAPI::Do_Work()
 {
-	_log.Log(LOG_STATUS,"NestOAuthAPI: Worker started...");
-	int sec_counter = NEST_POLL_INTERVAL-5;
+	Log(LOG_STATUS, "Worker started...");
+	int sec_counter = NEST_POLL_INTERVAL - 5;
 	while (!IsStopRequested(1000))
 	{
 		sec_counter++;
 		if (sec_counter % 12 == 0)
 		{
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (sec_counter % NEST_POLL_INTERVAL == 0)
@@ -94,22 +90,21 @@ void CNestOAuthAPI::Do_Work()
 		}
 	}
 	Logout();
-	_log.Log(LOG_STATUS,"NestOAuthAPI: Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 void CNestOAuthAPI::SendSetPointSensor(const unsigned char Idx, const float Temp, const std::string &defaultname)
 {
 	_tThermostat thermos;
-	thermos.subtype=sTypeThermSetpoint;
-	thermos.id1=0;
-	thermos.id2=0;
-	thermos.id3=0;
-	thermos.id4=Idx;
-	thermos.dunit=0;
+	thermos.subtype = sTypeThermSetpoint;
+	thermos.id1 = 0;
+	thermos.id2 = 0;
+	thermos.id3 = 0;
+	thermos.id4 = Idx;
+	thermos.dunit = 0;
+	thermos.temp = Temp;
 
-	thermos.temp=Temp;
-
-	sDecodeRXMessage(this, (const unsigned char *)&thermos, defaultname.c_str(), 255);
+	sDecodeRXMessage(this, (const unsigned char *)&thermos, defaultname.c_str(), 255, nullptr);
 }
 
 // Creates and updates switch used to log Heating and/or Cooling.
@@ -117,12 +112,11 @@ void CNestOAuthAPI::UpdateSwitch(const unsigned char Idx, const bool bOn, const
 {
 	char szIdx[10];
 	sprintf(szIdx, "%X%02X%02X%02X", 0, 0, 0, Idx);
-	std::vector<std::vector<std::string> > result;
-	result = m_sql.safe_query("SELECT Name,nValue,sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (Type==%d) AND (SubType==%d) AND (DeviceID=='%q')",
-		m_HwdID, pTypeLighting2, sTypeAC, szIdx);
+	std::vector<std::vector<std::string>> result;
+	result = m_sql.safe_query("SELECT Name,nValue,sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (Type==%d) AND (SubType==%d) AND (DeviceID=='%q')", m_HwdID, pTypeLighting2, sTypeAC, szIdx);
 	if (!result.empty())
 	{
-		//check if we have a change, if not do not update it
+		// check if we have a change, if not do not update it
 		int nvalue = atoi(result[0][1].c_str());
 		if ((!bOn) && (nvalue == 0))
 			return;
@@ -130,7 +124,7 @@ void CNestOAuthAPI::UpdateSwitch(const unsigned char Idx, const bool bOn, const
 			return;
 	}
 
-	//Send as Lighting 2
+	// Send as Lighting 2
 	tRBUF lcmd;
 	memset(&lcmd, 0, sizeof(RBUF));
 	lcmd.LIGHTING2.packetlength = sizeof(lcmd.LIGHTING2) - 1;
@@ -155,25 +149,27 @@ void CNestOAuthAPI::UpdateSwitch(const unsigned char Idx, const bool bOn, const
 	lcmd.LIGHTING2.level = (BYTE)level;
 	lcmd.LIGHTING2.filler = 0;
 	lcmd.LIGHTING2.rssi = 12;
-	sDecodeRXMessage(this, (const unsigned char *)&lcmd.LIGHTING2, defaultname.c_str(), 255);
+	sDecodeRXMessage(this, (const unsigned char *)&lcmd.LIGHTING2, defaultname.c_str(), 255, m_Name.c_str());
 }
 
-bool CNestOAuthAPI::ValidateNestApiAccessToken(const std::string & /*accesstoken*/) {
+bool CNestOAuthAPI::ValidateNestApiAccessToken(const std::string & /*accesstoken*/)
+{
 	std::string sResult;
 
 	// Let's get a list of structures to see if the supplied Access Token works
 	std::string sURL = NEST_OAUTHAPI_BASE + "structures.json?auth=" + m_OAuthApiAccessToken;
-	_log.Log(LOG_NORM, "NestOAuthAPI: Trying to access API on " + sURL);
+	Log(LOG_NORM, "Trying to access API on " + sURL);
 	std::vector<std::string> ExtraHeaders;
 	std::vector<std::string> vHeaderData;
 
-	if ((!HTTPClient::GET(sURL, ExtraHeaders, sResult, vHeaderData, false))||(sResult.empty()))
+	if ((!HTTPClient::GET(sURL, ExtraHeaders, sResult, vHeaderData, false)) || (sResult.empty()))
 	{
 		std::string sErrorMsg = "Got empty response body while getting structures.";
-		if (!vHeaderData.empty()) {
+		if (!vHeaderData.empty())
+		{
 			sErrorMsg += " Response code: " + vHeaderData[0];
 		}
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Error while performing login: %s", sErrorMsg.c_str());
+		Log(LOG_ERROR, "Error while performing login: %s", sErrorMsg.c_str());
 		return false;
 	}
 
@@ -181,12 +177,12 @@ bool CNestOAuthAPI::ValidateNestApiAccessToken(const std::string & /*accesstoken
 	bool bRet = ParseJSon(sResult, root);
 	if ((!bRet) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Failed to parse received JSON data.");
+		Log(LOG_ERROR, "Failed to parse received JSON data.");
 		return false;
 	}
 	if (root.empty())
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: JSON data parsed but resulted in no nodes.");
+		Log(LOG_ERROR, "JSON data parsed but resulted in no nodes.");
 		return false;
 	}
 
@@ -195,12 +191,12 @@ bool CNestOAuthAPI::ValidateNestApiAccessToken(const std::string & /*accesstoken
 
 	if (oFirstElement["name"].empty())
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Did not get name for first structure!");
+		Log(LOG_ERROR, "Did not get name for first structure!");
 		return false;
 	}
-	// _log.Log(LOG_NORM, ("NestOAuthAPI: Got first structure name: "+oFirstElement["name"].asString()).c_str());
+	// Log(LOG_NORM, ("Got first structure name: "+oFirstElement["name"].asString()).c_str());
 
-	_log.Log(LOG_NORM, "NestOAuthAPI: Access token appears to be valid.");
+	Log(LOG_NORM, "Access token appears to be valid.");
 	return true;
 }
 
@@ -209,42 +205,46 @@ bool CNestOAuthAPI::Login()
 	// If we don't have an access token available
 	if (m_OAuthApiAccessToken.empty())
 	{
-		_log.Log(LOG_NORM, "NestOAuthAPI: No API key available.");
+		Log(LOG_NORM, "No API key available.");
 		// Check if we do have a productid, secret and pin code
-		if (!m_ProductId.empty() && !m_ProductSecret.empty() && !m_PinCode.empty()) {
-			_log.Log(LOG_NORM, "NestOAuthAPI: Access token missing. Will request an API key based on Product Id, Product Secret and PIN code.");
+		if (!m_ProductId.empty() && !m_ProductSecret.empty() && !m_PinCode.empty())
+		{
+			Log(LOG_NORM, "Access token missing. Will request an API key based on Product Id, Product Secret and PIN code.");
 
-			std::string sTmpToken = "";
+			std::string sTmpToken;
 			try
 			{
 				// Request the token using the information that we already have.
 				sTmpToken = FetchNestApiAccessToken(m_ProductId, m_ProductSecret, m_PinCode);
 
-				if (!sTmpToken.empty()) {
-					_log.Log(LOG_NORM, "NestOAuthAPI: Received an access token to use for future requests: " + sTmpToken);
+				if (!sTmpToken.empty())
+				{
+					Log(LOG_NORM, "Received an access token to use for future requests: " + sTmpToken);
 
 					// Store the access token in the database and set the application to use it.
 					SetOAuthAccessToken(m_HwdID, sTmpToken);
 				}
-				else {
+				else
+				{
 					throw std::runtime_error("Received access token does not appear to be valid.");
 				}
 			}
-			catch (std::exception& e)
+			catch (std::exception &e)
 			{
 				// Apparently something went wrong fetching the access token.
 				std::string what = e.what();
-				_log.Log(LOG_ERROR, "NestOAuthAPI: Error retrieving access token: " + what);
+				Log(LOG_ERROR, "Error retrieving access token: " + what);
 				return false;
 			}
 		}
-		else _log.Log(LOG_NORM, "NestOAuthAPI: Access token missing. Will not attempt to request one using Product Id, Product Secret and PIN code since at least one of these is empty.");
+		else
+			Log(LOG_NORM, "Access token missing. Will not attempt to request one using Product Id, Product Secret and PIN code since at least one of these is empty.");
 	}
 
 	// Check if we still don't have an access token available
 	if (m_OAuthApiAccessToken.empty())
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Cannot login: access token was not supplied and failed to fetch one.");
+		Log(LOG_ERROR, "Cannot login: access token was not supplied and failed to fetch one.");
 		Logout();
 
 		// Clear the retrieved tokens and secrets so we won't be
@@ -258,20 +258,19 @@ bool CNestOAuthAPI::Login()
 
 	if (ValidateNestApiAccessToken(m_OAuthApiAccessToken))
 	{
-		_log.Log(LOG_NORM, "NestOAuthAPI: Login success. Token successfully validated.");
+		Log(LOG_NORM, "Login success. Token successfully validated.");
 		m_bDoLogin = false;
 		return true;
 	}
-	else {
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Login failed: token did not validate.");
-		return false;
-	}
+
+	Log(LOG_ERROR, "Login failed: token did not validate.");
+	return false;
 }
 
 void CNestOAuthAPI::Logout()
 {
 	if (m_bDoLogin)
-		return; //we are not logged in
+		return; // we are not logged in
 	m_bDoLogin = true;
 }
 
@@ -282,7 +281,7 @@ bool CNestOAuthAPI::WriteToHardware(const char *pdata, const unsigned char /*len
 
 	const tRBUF *pCmd = reinterpret_cast<const tRBUF *>(pdata);
 	if (pCmd->LIGHTING2.packettype != pTypeLighting2)
-		return false; //later add RGB support, if someone can provide access
+		return false; // later add RGB support, if someone can provide access
 
 	int node_id = pCmd->LIGHTING2.id4;
 
@@ -290,7 +289,7 @@ bool CNestOAuthAPI::WriteToHardware(const char *pdata, const unsigned char /*len
 
 	if ((node_id - 3) % 3 == 0)
 	{
-		//Away
+		// Away
 		return SetAway((const unsigned char)node_id, bIsOn);
 	}
 
@@ -308,7 +307,7 @@ void CNestOAuthAPI::UpdateSmokeSensor(const unsigned char Idx, const bool bOn, c
 	bool bDeviceExists = true;
 	char szIdx[10];
 	sprintf(szIdx, "%X%02X%02X%02X", 0, 0, Idx, 0);
-	std::vector<std::vector<std::string> > result;
+	std::vector<std::vector<std::string>> result;
 	result = m_sql.safe_query("SELECT Name,nValue,sValue FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q')", m_HwdID, szIdx);
 	if (result.empty())
 	{
@@ -316,7 +315,7 @@ void CNestOAuthAPI::UpdateSmokeSensor(const unsigned char Idx, const bool bOn, c
 	}
 	else
 	{
-		//check if we have a change, if not only update the LastUpdate field
+		// check if we have a change, if not only update the LastUpdate field
 		bool bNoChange = false;
 		int nvalue = atoi(result[0][1].c_str());
 		if ((!bOn) && (nvalue == 0))
@@ -325,20 +324,19 @@ void CNestOAuthAPI::UpdateSmokeSensor(const unsigned char Idx, const bool bOn, c
 			bNoChange = true;
 		if (bNoChange)
 		{
-			time_t now = time(0);
+			time_t now = time(nullptr);
 			struct tm ltime;
 			localtime_r(&now, &ltime);
 
 			char szLastUpdate[40];
 			sprintf(szLastUpdate, "%04d-%02d-%02d %02d:%02d:%02d", ltime.tm_year + 1900, ltime.tm_mon + 1, ltime.tm_mday, ltime.tm_hour, ltime.tm_min, ltime.tm_sec);
 
-			m_sql.safe_query("UPDATE DeviceStatus SET LastUpdate='%q' WHERE(HardwareID == %d) AND (DeviceID == '%q')",
-				szLastUpdate, m_HwdID, szIdx);
+			m_sql.safe_query("UPDATE DeviceStatus SET LastUpdate='%q' WHERE(HardwareID == %d) AND (DeviceID == '%q')", szLastUpdate, m_HwdID, szIdx);
 			return;
 		}
 	}
 
-	//Send as Lighting 2
+	// Send as Lighting 2
 	tRBUF lcmd;
 	memset(&lcmd, 0, sizeof(RBUF));
 	lcmd.LIGHTING2.packetlength = sizeof(lcmd.LIGHTING2) - 1;
@@ -366,8 +364,8 @@ void CNestOAuthAPI::UpdateSmokeSensor(const unsigned char Idx, const bool bOn, c
 
 	if (!bDeviceExists)
 	{
-		m_mainworker.PushAndWaitRxMessage(this, (const unsigned char *)&lcmd.LIGHTING2, defaultname.c_str(), 255);
-		//Assign default name for device
+		m_mainworker.PushAndWaitRxMessage(this, (const unsigned char *)&lcmd.LIGHTING2, defaultname.c_str(), 255, m_Name.c_str());
+		// Assign default name for device
 		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q' WHERE (HardwareID==%d) AND (DeviceID=='%q')", defaultname.c_str(), m_HwdID, szIdx);
 		result = m_sql.safe_query("SELECT ID FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q')", m_HwdID, szIdx);
 		if (!result.empty())
@@ -376,7 +374,7 @@ void CNestOAuthAPI::UpdateSmokeSensor(const unsigned char Idx, const bool bOn, c
 		}
 	}
 	else
-		sDecodeRXMessage(this, (const unsigned char *)&lcmd.LIGHTING2, defaultname.c_str(), 255);
+		sDecodeRXMessage(this, (const unsigned char *)&lcmd.LIGHTING2, defaultname.c_str(), 255, m_Name.c_str());
 }
 
 void CNestOAuthAPI::GetMeterDetails()
@@ -385,7 +383,7 @@ void CNestOAuthAPI::GetMeterDetails()
 	if (m_bDoLogin)
 	{
 		if (!Login())
-		return;
+			return;
 	}
 
 	Json::Value deviceRoot;
@@ -400,7 +398,7 @@ void CNestOAuthAPI::GetMeterDetails()
 
 	if (!HTTPClient::GET(sURL, ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Error getting structures!");
+		Log(LOG_ERROR, "Error getting structures!");
 		m_bDoLogin = true;
 		return;
 	}
@@ -408,17 +406,16 @@ void CNestOAuthAPI::GetMeterDetails()
 	bRet = ParseJSon(sResult, structureRoot);
 	if ((!bRet) || (!structureRoot.isObject()))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Invalid structures data received!");
+		Log(LOG_ERROR, "Invalid structures data received!");
 		m_bDoLogin = true;
 		return;
 	}
 
-
-	//Get Data for devices
+	// Get Data for devices
 	sURL = NEST_OAUTHAPI_BASE + "devices.json?auth=" + m_OAuthApiAccessToken;
 	if (!HTTPClient::GET(sURL, ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Error getting devices!");
+		Log(LOG_ERROR, "Error getting devices!");
 		m_bDoLogin = true;
 		return;
 	}
@@ -426,7 +423,7 @@ void CNestOAuthAPI::GetMeterDetails()
 	bRet = ParseJSon(sResult, deviceRoot);
 	if ((!bRet) || (!deviceRoot.isObject()))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Invalid devices data received!");
+		Log(LOG_ERROR, "Invalid devices data received!");
 		m_bDoLogin = true;
 		return;
 	}
@@ -435,38 +432,37 @@ void CNestOAuthAPI::GetMeterDetails()
 
 	if ((!bHaveThermostats) && (!bHaveSmokeDetects))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: request not successful 1 (no thermostat or protect was received), restarting..!");
+		Log(LOG_ERROR, "request not successful 1 (no thermostat or protect was received), restarting..!");
 		m_bDoLogin = true;
 		return;
 	}
 
-	//Protect
+	// Protect
 	if (bHaveSmokeDetects)
 	{
 		if (deviceRoot["smoke_co_alarms"].empty())
 		{
-			_log.Log(LOG_ERROR, "NestOAuthAPI: smoke detectors request not successful, restarting..!");
+			Log(LOG_ERROR, "smoke detectors request not successful, restarting..!");
 			m_bDoLogin = true;
 			return;
 		}
 		Json::Value::Members members = deviceRoot["smoke_co_alarms"].getMemberNames();
 		if (members.empty())
 		{
-			_log.Log(LOG_ERROR, "NestOAuthAPI: smoke detectors request not successful, restarting..!");
+			Log(LOG_ERROR, "smoke detectors request not successful, restarting..!");
 			m_bDoLogin = true;
 			return;
 		}
 		int SwitchIndex = 1;
-		for (Json::Value::iterator itDevice = deviceRoot["smoke_co_alarms"].begin(); itDevice != deviceRoot["smoke_co_alarms"].end(); ++itDevice)
+		for (auto device : deviceRoot["smoke_co_alarms"])
 		{
-			Json::Value device = *itDevice;
-			//std::string devstring = itDevice.key().asString();
+			// std::string devstring = itDevice.key().asString();
 			std::string devWhereName = device["where_name"].asString();
 
 			if (devWhereName.empty())
 				continue;
 
-			std::string devName = devWhereName;
+			const std::string &devName = devWhereName;
 
 			// Default value is true, let's assume the worst.
 			bool bSmokeAlarm = true;
@@ -495,13 +491,13 @@ void CNestOAuthAPI::GetMeterDetails()
 			}
 
 			UpdateSmokeSensor((const unsigned char)SwitchIndex, bSmokeAlarm, devName + " Smoke Alarm");
-			UpdateSmokeSensor((const unsigned char)(SwitchIndex+1), bCOAlarm, devName + " CO Alarm");
+			UpdateSmokeSensor((const unsigned char)(SwitchIndex + 1), bCOAlarm, devName + " CO Alarm");
 
 			SwitchIndex = SwitchIndex + 2;
 		}
 	}
 
-	//Thermostat
+	// Thermostat
 	if (!bHaveThermostats)
 		return;
 	if (deviceRoot["thermostats"].empty())
@@ -510,18 +506,18 @@ void CNestOAuthAPI::GetMeterDetails()
 		if (bHaveSmokeDetects)
 			return;
 
-		_log.Log(LOG_ERROR, "NestOAuthAPI: request not successful 2 (no thermostat or protect was received), restarting..!");
+		Log(LOG_ERROR, "request not successful 2 (no thermostat or protect was received), restarting..!");
 		m_bDoLogin = true;
 		return;
 	}
 
 	size_t iThermostat = 0;
 	size_t iStructure = 0;
-	for (Json::Value::iterator ittStructure = structureRoot.begin(); ittStructure != structureRoot.end(); ++ittStructure)
+	for (auto nstructure : structureRoot)
 	{
 		// Get general structure information
-		Json::Value nstructure = *ittStructure;
-		if (!nstructure.isObject()) continue;
+		if (!nstructure.isObject())
+			continue;
 
 		// Store the structure information in a map.
 		_tNestStructure nstruct;
@@ -533,21 +529,21 @@ void CNestOAuthAPI::GetMeterDetails()
 		if (!nstructure["away"].empty())
 		{
 			bool bIsAway = (nstructure["away"].asString() == "away" || nstructure["away"].asString() == "auto-away");
-			SendSwitch((iStructure * 3) + 3, 1, 255, bIsAway, 0, nstruct.Name + " Away");
+			SendSwitch((iStructure * 3) + 3, 1, 255, bIsAway, 0, nstruct.Name + " Away", m_Name);
 		}
 
 		// Find out which thermostats are available under this structure
-		for (Json::Value::iterator ittDevice = nstructure["thermostats"].begin(); ittDevice != nstructure["thermostats"].end(); ++ittDevice)
+		for (auto &ittDevice : nstructure["thermostats"])
 		{
-			std::string devID = (*ittDevice).asString();
+			std::string devID = ittDevice.asString();
 
-			// _log.Log(LOG_NORM, ("Nest: Found Thermostat " + devID + " in structure " + StructureName).c_str());
+			// Log(LOG_NORM, ("Nest: Found Thermostat " + devID + " in structure " + StructureName).c_str());
 
 			// Get some more information for this thermostat
 			Json::Value ndevice = deviceRoot["thermostats"][devID];
 			if (!ndevice.isObject())
 			{
-				_log.Log(LOG_ERROR, "NestOAuthAPI: Structure referenced thermostat %s but it was not found.", devID.c_str());
+				Log(LOG_ERROR, "Structure referenced thermostat %s but it was not found.", devID.c_str());
 				continue;
 			}
 
@@ -574,16 +570,16 @@ void CNestOAuthAPI::GetMeterDetails()
 			std::string sHvacMode = ndevice["hvac_mode"].asString();
 			std::string sHvacState = ndevice["hvac_state"].asString();
 
-			//Setpoint
-			if (!ndevice["target_temperature_"+temperatureScale].empty())
+			// Setpoint
+			if (!ndevice["target_temperature_" + temperatureScale].empty())
 			{
-				float currentSetpoint = ndevice["target_temperature_"+temperatureScale].asFloat();
+				float currentSetpoint = ndevice["target_temperature_" + temperatureScale].asFloat();
 				SendSetPointSensor((const unsigned char)(iThermostat * 3) + 1, currentSetpoint, Name + " Setpoint");
 			}
-			//Room Temperature/Humidity
-			if (!ndevice["ambient_temperature_"+temperatureScale].empty())
+			// Room Temperature/Humidity
+			if (!ndevice["ambient_temperature_" + temperatureScale].empty())
 			{
-				float currentTemp = ndevice["ambient_temperature_"+temperatureScale].asFloat();
+				float currentTemp = ndevice["ambient_temperature_" + temperatureScale].asFloat();
 				int Humidity = ndevice["humidity"].asInt();
 				SendTempHumSensor((iThermostat * 3) + 2, 255, currentTemp, Humidity, Name + " TempHum");
 			}
@@ -608,7 +604,7 @@ void CNestOAuthAPI::GetMeterDetails()
 			bool bManualEcomodeEnabled = (!sHvacMode.empty() && sHvacMode == "off");
 
 			// UpdateSwitch(115 + (iThermostat * 3), bManualEcomodeEnabled, Name + " Manual Eco Mode");
-			SendSwitch((iThermostat * 3) + 4, 1, 255, bManualEcomodeEnabled, 0, Name + " Manual Eco Mode");
+			SendSwitch((iThermostat * 3) + 4, 1, 255, bManualEcomodeEnabled, 0, Name + " Manual Eco Mode", m_Name);
 
 			iThermostat++;
 		}
@@ -633,7 +629,7 @@ void CNestOAuthAPI::SetSetpoint(const int idx, const float temp)
 
 	if (m_thermostats[iThermostat].Serial.empty())
 	{
-		_log.Log(LOG_NORM, "NestOAuthAPI: Thermostat has not been initialized yet. Try again later.");
+		Log(LOG_NORM, "Thermostat has not been initialized yet. Try again later.");
 		return;
 	}
 
@@ -642,7 +638,7 @@ void CNestOAuthAPI::SetSetpoint(const int idx, const float temp)
 	ExtraHeaders.push_back("Content-Type:application/json");
 	float tempDest = temp;
 
-	//unsigned char tSign = m_sql.m_tempsign[0];
+	// unsigned char tSign = m_sql.m_tempsign[0];
 
 	// Find out if we're using C or F.
 	std::string temperatureScale(1, m_sql.m_tempsign[0]);
@@ -656,7 +652,7 @@ void CNestOAuthAPI::SetSetpoint(const int idx, const float temp)
 	std::string sURL = NEST_OAUTHAPI_BASE + "devices/thermostats/" + m_thermostats[iThermostat].Serial;
 	if (!HTTPClient::PUT(sURL, root.toStyledString(), ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Error setting setpoint!");
+		Log(LOG_ERROR, "Error setting setpoint!");
 		m_bDoLogin = true;
 		return;
 	}
@@ -670,7 +666,8 @@ bool CNestOAuthAPI::SetManualEcoMode(const unsigned char node_id, const bool bIs
 	size_t iThermostat = (node_id - 4) / 3;
 
 	// Check if we even got that many thermostats.
-	if (iThermostat > m_thermostats.size()) return false;
+	if (iThermostat > m_thermostats.size())
+		return false;
 
 	// Grab a reference to that thermostat.
 	_tNestThemostat thermostat = m_thermostats[iThermostat];
@@ -679,13 +676,13 @@ bool CNestOAuthAPI::SetManualEcoMode(const unsigned char node_id, const bool bIs
 	{
 		if (thermostat.Serial.empty())
 		{
-			_log.Log(LOG_ERROR, "NestOAuthAPI: Thermostat " + std::to_string(iThermostat) + " has not been initialized yet. Try again later.");
+			Log(LOG_ERROR, "Thermostat " + std::to_string(iThermostat) + " has not been initialized yet. Try again later.");
 			return false;
 		}
 	}
-	catch (std::exception& e)
+	catch (std::exception &e)
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Failed to get thermostat serial (for now). Trying again later..(%s)",e.what());
+		Log(LOG_ERROR, "Failed to get thermostat serial (for now). Trying again later..(%s)", e.what());
 		return false;
 	}
 
@@ -694,9 +691,12 @@ bool CNestOAuthAPI::SetManualEcoMode(const unsigned char node_id, const bool bIs
 	// If it can heat-cool, then do that, else set to whatever thing it can do.
 	Json::Value root;
 	std::string sNewHvacMode;
-	if (thermostat.CanCool && thermostat.CanHeat) sNewHvacMode = "heat-cool";
-	else if (thermostat.CanCool) sNewHvacMode = "cool";
-	else if (thermostat.CanHeat) sNewHvacMode = "heat";
+	if (thermostat.CanCool && thermostat.CanHeat)
+		sNewHvacMode = "heat-cool";
+	else if (thermostat.CanCool)
+		sNewHvacMode = "cool";
+	else if (thermostat.CanHeat)
+		sNewHvacMode = "heat";
 	root["hvac_mode"] = (bIsOn ? "off" : sNewHvacMode);
 
 	std::string sResult;
@@ -704,7 +704,7 @@ bool CNestOAuthAPI::SetManualEcoMode(const unsigned char node_id, const bool bIs
 
 	if (!PushToNestApi("PUT", sURL, root, sResult))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Error setting manual eco mode!");
+		Log(LOG_ERROR, "Error setting manual eco mode!");
 		// Failure, request a fresh login.
 		m_bDoLogin = true;
 		return false;
@@ -716,7 +716,7 @@ bool CNestOAuthAPI::PushToNestApi(const std::string & /*sMethod*/, const std::st
 {
 	if (m_OAuthApiAccessToken.empty())
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Failed to push information to Nest Api: No access token supplied.");
+		Log(LOG_ERROR, "Failed to push information to Nest Api: No access token supplied.");
 		return false;
 	}
 
@@ -735,7 +735,7 @@ bool CNestOAuthAPI::PushToNestApi(const std::string & /*sMethod*/, const std::st
 
 	if (!HTTPClient::PUT(sUrl, sPostData, ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Error pushing information to Nest Api.");
+		Log(LOG_ERROR, "Error pushing information to Nest Api.");
 		return false;
 	}
 	return true;
@@ -749,7 +749,7 @@ bool CNestOAuthAPI::SetAway(const unsigned char Idx, const bool bIsAway)
 
 	if (m_structures[iStructure].StructureId.empty())
 	{
-		_log.Log(LOG_NORM, "NestOAuthAPI: Structure "+std::to_string(iStructure)+" has not been initialized yet. Try again later.");
+		Log(LOG_NORM, "Structure " + std::to_string(iStructure) + " has not been initialized yet. Try again later.");
 		return false;
 	}
 
@@ -761,7 +761,7 @@ bool CNestOAuthAPI::SetAway(const unsigned char Idx, const bool bIsAway)
 	std::string sURL = NEST_OAUTHAPI_BASE + "structures" + "/" + m_structures[iStructure].StructureId;
 	if (!PushToNestApi("PUT", sURL, root, sResult))
 	{
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Error setting away mode!");
+		Log(LOG_ERROR, "Error setting away mode!");
 		m_bDoLogin = true;
 		return false;
 	}
@@ -780,20 +780,23 @@ void CNestOAuthAPI::SetProgramState(const int /*newState*/)
 	}
 }
 
-std::string CNestOAuthAPI::FetchNestApiAccessToken(const std::string &productid, const std::string &secret, const std::string &pincode) {
+std::string CNestOAuthAPI::FetchNestApiAccessToken(const std::string &productid, const std::string &secret, const std::string &pincode)
+{
 	// Check if there isn't already an access token
-	if (!m_OAuthApiAccessToken.empty()) {
-		_log.Log(LOG_ERROR, "NestOAuthAPI: There is already an API access token configured for this hardware ID: no need to fetch a new token.");
+	if (!m_OAuthApiAccessToken.empty())
+	{
+		Log(LOG_ERROR, "There is already an API access token configured for this hardware ID: no need to fetch a new token.");
 		return "";
 	}
 
 	// Check if we have a productid, secret and pin code
-	if (productid.empty() || secret.empty() || pincode.empty()) {
-		_log.Log(LOG_ERROR, "NestOAuthAPI: No access token supplied and no ProductId, Secret or PIN to obtain one either.");
+	if (productid.empty() || secret.empty() || pincode.empty())
+	{
+		Log(LOG_ERROR, "No access token supplied and no ProductId, Secret or PIN to obtain one either.");
 		return "";
 	}
 
-	_log.Log(LOG_NORM, "NestOAuthAPI: Preparing URL");
+	Log(LOG_NORM, "Preparing URL");
 
 	std::vector<std::string> ExtraHeaders;
 	std::string sResult;
@@ -812,23 +815,24 @@ std::string CNestOAuthAPI::FetchNestApiAccessToken(const std::string &productid,
 	s << "code=" << sPincode << "&client_id=" << sProductid << "&client_secret=" << sSecret << "&grant_type=authorization_code";
 	std::string sPostData = s.str();
 
-	_log.Debug(DEBUG_HARDWARE, "NestOAuthAPI: postdata= " + sPostData);
-	_log.Log(LOG_NORM, "NestOAuthAPI: Doing POST request to URL: " + NEST_OAUTHAPI_OAUTH_ACCESSTOKENURL);
+	Debug(DEBUG_HARDWARE, "postdata= " + sPostData);
+	Log(LOG_NORM, "Doing POST request to URL: " + NEST_OAUTHAPI_OAUTH_ACCESSTOKENURL);
 
 	try
 	{
-		_log.Log(LOG_NORM, "NestOAuthAPI: Will now attempt to fetch access token.");
+		Log(LOG_NORM, "Will now attempt to fetch access token.");
 
 		std::vector<std::string> vResponseHeaders;
 		if (!HTTPClient::POST(NEST_OAUTHAPI_OAUTH_ACCESSTOKENURL, sPostData, ExtraHeaders, sResult, vResponseHeaders, true, false))
 		{
 			std::string sErrorMsg = "Failed to fetch token from API. ";
-			if (!vResponseHeaders.empty()) {
+			if (!vResponseHeaders.empty())
+			{
 				sErrorMsg += "Response code: " + vResponseHeaders[0];
 			}
 			throw std::runtime_error(sErrorMsg.c_str());
 		}
-		_log.Log(LOG_NORM, "NestOAuthAPI: POST request completed. Result: " + sResult);
+		Log(LOG_NORM, "POST request completed. Result: " + sResult);
 
 		if (sResult.empty())
 		{
@@ -837,34 +841,37 @@ std::string CNestOAuthAPI::FetchNestApiAccessToken(const std::string &productid,
 
 		try
 		{
-			_log.Log(LOG_NORM, "NestOAuthAPI: Will now parse result to JSON");
+			Log(LOG_NORM, "Will now parse result to JSON");
 			Json::Value root;
 			bool bRet = ParseJSon(sResult, root);
-			_log.Log(LOG_NORM, "NestOAuthAPI: JSON data parse call returned.");
+			Log(LOG_NORM, "JSON data parse call returned.");
 
-			if ((!bRet) || (!root.isObject())) throw std::runtime_error("Failed to parse JSON data.");
-			_log.Log(LOG_NORM, "NestOAuthAPI: Parsing of JSON data apparently successful");
+			if ((!bRet) || (!root.isObject()))
+				throw std::runtime_error("Failed to parse JSON data.");
+			Log(LOG_NORM, "Parsing of JSON data apparently successful");
 
-			if (root.empty()) throw std::runtime_error("Parsed JSON data contains no elements.");
-			_log.Log(LOG_NORM, "NestOAuthAPI: parsed JSON data contains more than 0 elements");
+			if (root.empty())
+				throw std::runtime_error("Parsed JSON data contains no elements.");
+			Log(LOG_NORM, "parsed JSON data contains more than 0 elements");
 
-			_log.Log(LOG_NORM, "NestOAuthAPI: Fetching access_token from JSON object");
+			Log(LOG_NORM, "Fetching access_token from JSON object");
 			sReceivedAccessToken = root["access_token"].asString();
 
-			if (sReceivedAccessToken.empty()) throw std::runtime_error("Received an empty access token from parsed JSON data.");
-			_log.Log(LOG_NORM, ("NestOAuthAPI: Returning fetched access token: " + sReceivedAccessToken));
+			if (sReceivedAccessToken.empty())
+				throw std::runtime_error("Received an empty access token from parsed JSON data.");
+			Log(LOG_NORM, ("Returning fetched access token: " + sReceivedAccessToken));
 			return sReceivedAccessToken;
 		}
 		catch (std::exception &e)
 		{
 			std::string what = e.what();
-			throw "Error parsing received JSON data: "+what;
+			throw "Error parsing received JSON data: " + what;
 		}
 	}
 	catch (std::exception &e)
 	{
 		std::string what = e.what();
-		_log.Log(LOG_ERROR, "NestOAuthAPI: Error getting access token: "+ what);
+		Log(LOG_ERROR, "Error getting access token: " + what);
 		return "";
 	}
 }
@@ -874,7 +881,7 @@ bool CNestOAuthAPI::SetOAuthAccessToken(const unsigned int ID, std::string &newT
 	// Set the application to use the new token.
 	m_OAuthApiAccessToken = newToken;
 
-	_log.Log(LOG_NORM, "NestOAuthAPI: Storing received access token " + newToken + " and clearing token request information.");
+	Log(LOG_NORM, "Storing received access token " + newToken + " and clearing token request information.");
 
 	// This can probably be done in a better way. For now let's just assume things will succeed.
 	m_sql.safe_query("UPDATE Hardware SET Username='%q', Extra='' WHERE (ID==%d)", newToken.c_str(), ID);
