@@ -54,13 +54,13 @@ struct _tNetatmoDevice
 	//Json::Value Modules;
 };
 
-CNetatmo::CNetatmo(const int ID, const std::string& username, const std::string& password) :
-	m_username(CURLEncode::URLEncode(username)),
-	m_password(CURLEncode::URLEncode(password)),
-	m_clientId("5588029e485a88af28f4a3c4"),
-	m_clientSecret("6vIpQVjNsL2A74Bd8tINscklLw2LKv7NhE9uW2")
+CNetatmo::CNetatmo(const int ID, const std::string &username, const std::string &password)
+	: m_clientId("5588029e485a88af28f4a3c4")
+	, m_clientSecret("6vIpQVjNsL2A74Bd8tINscklLw2LKv7NhE9uW2")
+	, m_username(CURLEncode::URLEncode(username))
+	, m_password(CURLEncode::URLEncode(password))
 {
-	m_nextRefreshTs = mytime(NULL);
+	m_nextRefreshTs = mytime(nullptr);
 	m_isLogged = false;
 	m_NetatmoType = NETYPE_WEATHER_STATION;
 
@@ -72,14 +72,10 @@ CNetatmo::CNetatmo(const int ID, const std::string& username, const std::string&
 	m_bPollWeatherData = true;
 	m_bFirstTimeThermostat = true;
 	m_bFirstTimeWeatherData = true;
-	m_tSetpointUpdateTime = time(NULL);
+	m_tSetpointUpdateTime = time(nullptr);
 	Init();
 }
 
-CNetatmo::~CNetatmo(void)
-{
-}
-
 void CNetatmo::Init()
 {
 	m_RainOffset.clear();
@@ -106,7 +102,7 @@ bool CNetatmo::StartHardware()
 
 	Init();
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CNetatmo::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -130,12 +126,12 @@ void CNetatmo::Do_Work()
 	int sec_counter = 600 - 5;
 	bool bFirstTimeWS = true;
 	bool bFirstTimeTH = true;
-	_log.Log(LOG_STATUS, "Netatmo: Worker started...");
+	Log(LOG_STATUS, "Worker started...");
 	while (!IsStopRequested(1000))
 	{
 		sec_counter++;
 		if (sec_counter % 12 == 0) {
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 		}
 
 		if (!m_isLogged)
@@ -168,7 +164,7 @@ void CNetatmo::Do_Work()
 					}
 					if (m_bForceSetpointUpdate)
 					{
-						time_t atime = time(NULL);
+						time_t atime = time(nullptr);
 						if (atime >= m_tSetpointUpdateTime)
 						{
 							m_bForceSetpointUpdate = false;
@@ -180,7 +176,7 @@ void CNetatmo::Do_Work()
 			}
 		}
 	}
-	_log.Log(LOG_STATUS, "Netatmo: Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 bool CNetatmo::Login()
@@ -216,7 +212,7 @@ bool CNetatmo::Login()
 	bool ret = HTTPClient::POST(httpUrl, httpData, ExtraHeaders, sResult);
 	if (!ret)
 	{
-		_log.Log(LOG_ERROR, "Netatmo: Error connecting to Server...");
+		Log(LOG_ERROR, "Error connecting to Server...");
 		return false;
 	}
 
@@ -224,23 +220,23 @@ bool CNetatmo::Login()
 	ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "Netatmo: Invalid/no data received...");
+		Log(LOG_ERROR, "Invalid/no data received...");
 		return false;
 	}
 
 	if (root["access_token"].empty() || root["expires_in"].empty() || root["refresh_token"].empty())
 	{
-		_log.Log(LOG_ERROR, "Netatmo: No access granted, check username/password...");
+		Log(LOG_ERROR, "No access granted, check username/password...");
 		return false;
 	}
 
 	//Initial Access Token
 	m_accessToken = root["access_token"].asString();
 	m_refreshToken = root["refresh_token"].asString();
-	//_log.Log(LOG_STATUS, "Access token: %s", m_accessToken.c_str());
-	//_log.Log(LOG_STATUS, "RefreshToken: %s", m_refreshToken.c_str());
+	//Log(LOG_STATUS, "Access token: %s", m_accessToken.c_str());
+	//Log(LOG_STATUS, "RefreshToken: %s", m_refreshToken.c_str());
 	int expires = root["expires_in"].asInt();
-	m_nextRefreshTs = mytime(NULL) + expires;
+	m_nextRefreshTs = mytime(nullptr) + expires;
 	StoreRefreshToken();
 	m_isLogged = true;
 	return true;
@@ -256,7 +252,7 @@ bool CNetatmo::RefreshToken(const bool bForce)
 	{
 		if (!m_isLogged)
 			return false;
-		if ((mytime(NULL) - 15) < m_nextRefreshTs)
+		if ((mytime(nullptr) - 15) < m_nextRefreshTs)
 			return true; //no need to refresh the token yet
 	}
 
@@ -278,7 +274,7 @@ bool CNetatmo::RefreshToken(const bool bForce)
 	bool ret = HTTPClient::POST(httpUrl, httpData, ExtraHeaders, sResult);
 	if (!ret)
 	{
-		_log.Log(LOG_ERROR, "Netatmo: Error connecting to Server...");
+		Log(LOG_ERROR, "Error connecting to Server...");
 		return false;
 	}
 
@@ -286,7 +282,7 @@ bool CNetatmo::RefreshToken(const bool bForce)
 	ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "Netatmo: Invalid/no data received...");
+		Log(LOG_ERROR, "Invalid/no data received...");
 		//Force login next time
 		m_isLogged = false;
 		return false;
@@ -295,7 +291,7 @@ bool CNetatmo::RefreshToken(const bool bForce)
 	if (root["access_token"].empty() || root["expires_in"].empty() || root["refresh_token"].empty())
 	{
 		//Force login next time
-		_log.Log(LOG_ERROR, "Netatmo: No access granted, forcing login again...");
+		Log(LOG_ERROR, "No access granted, forcing login again...");
 		m_isLogged = false;
 		return false;
 	}
@@ -303,7 +299,7 @@ bool CNetatmo::RefreshToken(const bool bForce)
 	m_accessToken = root["access_token"].asString();
 	m_refreshToken = root["refresh_token"].asString();
 	int expires = root["expires_in"].asInt();
-	m_nextRefreshTs = mytime(NULL) + expires;
+	m_nextRefreshTs = mytime(nullptr) + expires;
 	//StoreRefreshToken();
 	return true;
 }
@@ -344,7 +340,7 @@ int CNetatmo::GetBatteryLevel(const std::string &ModuleType, int battery_percent
 
 		//range = 1000
 		batValue = 3200 - battery_percent;
-		batValue = 100 - int((100.0f / 1000.0f)*float(batValue));
+		batValue = 100 - int((100.0F / 1000.0F) * float(batValue));
 	}
 	else if (ModuleType == "NATherm1")
 	{
@@ -355,7 +351,7 @@ int CNetatmo::GetBatteryLevel(const std::string &ModuleType, int battery_percent
 
 		//range = 1100
 		batValue = 4100 - battery_percent;
-		batValue = 100 - int((100.0f / 1100.0f)*float(batValue));
+		batValue = 100 - int((100.0F / 1100.0F) * float(batValue));
 	}
 
 	return batValue;
@@ -390,7 +386,7 @@ bool CNetatmo::ParseDashboard(const Json::Value &root, const int DevIdx, const i
 	if (ModuleType != "NATherm1")
 	{
 		std::time_t tNetatmoLastUpdate = 0;
-		std::time_t tNow = time(NULL);
+		std::time_t tNow = time(nullptr);
 
 		// initialize the relevant device flag
 		if ( m_bNetatmoRefreshed.find(ID) == m_bNetatmoRefreshed.end() )
@@ -402,20 +398,20 @@ bool CNetatmo::ParseDashboard(const Json::Value &root, const int DevIdx, const i
 		{
 			tNetatmoLastUpdate = root["time_utc"].asUInt();
 		}
-		_log.Debug(DEBUG_HARDWARE, "Netatmo: Module [%s] last update = %s", name.c_str(), ctime(&tNetatmoLastUpdate));
+		Debug(DEBUG_HARDWARE, "Module [%s] last update = %s", name.c_str(), ctime(&tNetatmoLastUpdate));
 		// check if Netatmo data was updated in the past 10 mins (+1 min for sync time lags)... if not means sensors failed to send to cloud
 		if (tNetatmoLastUpdate > (tNow - 660))
 		{
 			if (!m_bNetatmoRefreshed[ID])
 			{
-				_log.Log(LOG_STATUS, "Netatmo: cloud data for module [%s] is now updated again", name.c_str());
+				Log(LOG_STATUS, "cloud data for module [%s] is now updated again", name.c_str());
 				m_bNetatmoRefreshed[ID] = true;
 			}
 		}
 		else
 		{
 			if (m_bNetatmoRefreshed[ID])
-				_log.Log(LOG_ERROR, "Netatmo: cloud data for module [%s] no longer updated (module possibly disconnected)", name.c_str());
+				Log(LOG_ERROR, "cloud data for module [%s] no longer updated (module possibly disconnected)", name.c_str());
 			m_bNetatmoRefreshed[ID] = false;
 			return false;
 		}
@@ -484,8 +480,8 @@ bool CNetatmo::ParseDashboard(const Json::Value &root, const int DevIdx, const i
 			bHaveWind = true;
 			wind_angle = root["WindAngle"].asInt();
 			//wind_gust_angle = root["GustAngle"].asInt();
-			wind_strength = root["WindStrength"].asFloat() / 3.6f;
-			wind_gust = root["GustStrength"].asFloat() / 3.6f;
+			wind_strength = root["WindStrength"].asFloat() / 3.6F;
+			wind_gust = root["GustStrength"].asFloat() / 3.6F;
 		}
 	}
 
@@ -559,7 +555,7 @@ bool CNetatmo::WriteToHardware(const char *pdata, const unsigned char /*length*/
 {
 	if ((m_thermostatDeviceID.empty()) || (m_thermostatModuleID.empty()))
 	{
-		_log.Log(LOG_ERROR, "NetatmoThermostat: No thermostat found in online devices!");
+		Log(LOG_ERROR, "NetatmoThermostat: No thermostat found in online devices!");
 		return false;
 	}
 
@@ -608,7 +604,7 @@ bool CNetatmo::SetProgramState(const int idx, const int newState)
 			return false;
 		if ((m_thermostatDeviceID[idx].empty()) || (m_thermostatModuleID[idx].empty()))
 		{
-			_log.Log(LOG_ERROR, "NetatmoThermostat: No thermostat found in online devices!");
+			Log(LOG_ERROR, "NetatmoThermostat: No thermostat found in online devices!");
 			return false;
 		}
 	}
@@ -639,7 +635,7 @@ bool CNetatmo::SetProgramState(const int idx, const int newState)
 			thermState = "off"; //The Thermostat is off
 			break;
 		default:
-			_log.Log(LOG_ERROR, "NetatmoThermostat: Invalid thermostat state!");
+			Log(LOG_ERROR, "NetatmoThermostat: Invalid thermostat state!");
 			return false;
 		}
 		ExtraHeaders.push_back("Host: api.netatmo.net");
@@ -657,7 +653,7 @@ bool CNetatmo::SetProgramState(const int idx, const int newState)
 
 		if (!HTTPClient::POST(httpUrl, httpData, ExtraHeaders, sResult))
 		{
-			_log.Log(LOG_ERROR, "NetatmoThermostat: Error setting setpoint state!");
+			Log(LOG_ERROR, "NetatmoThermostat: Error setting setpoint state!");
 			return false;
 		}
 	}
@@ -676,14 +672,14 @@ bool CNetatmo::SetProgramState(const int idx, const int newState)
 			thermState = "hg";
 			break;
 		default:
-			_log.Log(LOG_ERROR, "NetatmoThermostat: Invalid thermostat state!");
+			Log(LOG_ERROR, "NetatmoThermostat: Invalid thermostat state!");
 			return false;
 		}
 		std::string sPostData = "access_token=" + m_accessToken + "&home_id=" + m_Home_ID + "&mode=" + thermState;
 
 		if (!HTTPClient::POST("https://api.netatmo.com/api/setthermmode", sPostData, ExtraHeaders, sResult))
 		{
-			_log.Log(LOG_ERROR, "NetatmoThermostat: Error setting setpoint state!");
+			Log(LOG_ERROR, "NetatmoThermostat: Error setting setpoint state!");
 			return false;
 		}
 	}
@@ -703,7 +699,7 @@ void CNetatmo::SetSetpoint(int idx, const float temp)
 		}
 		if ((m_thermostatDeviceID[idx].empty()) || (m_thermostatModuleID[idx].empty()))
 		{
-			_log.Log(LOG_ERROR, "NetatmoThermostat: No thermostat found in online devices!");
+			Log(LOG_ERROR, "NetatmoThermostat: No thermostat found in online devices!");
 			return;
 		}
 	}
@@ -722,7 +718,7 @@ void CNetatmo::SetSetpoint(int idx, const float temp)
 		tempDest = static_cast<float>(ConvertToCelsius(tempDest));
 	}
 
-	time_t now = mytime(NULL);
+	time_t now = mytime(nullptr);
 	struct tm etime;
 	localtime_r(&now, &etime);
 	time_t end_time;
@@ -765,18 +761,17 @@ void CNetatmo::SetSetpoint(int idx, const float temp)
 	{
 		//find roomid
 		std::string roomID;
-		std::map<int, std::string >::const_iterator ittTherm;
-		for (ittTherm = m_thermostatDeviceID.begin(); ittTherm != m_thermostatDeviceID.end(); ++ittTherm)
+		for (const auto &therm : m_thermostatDeviceID)
 		{
-			if (ittTherm->first == idx)
+			if (therm.first == idx)
 			{
-				roomID = ittTherm->second;
+				roomID = therm.second;
 				break;
 			}
 		}
 		if (roomID.empty())
 		{
-			_log.Log(LOG_ERROR, "NetatmoThermostat: No thermostat found in online devices!");
+			Log(LOG_ERROR, "NetatmoThermostat: No thermostat found in online devices!");
 			return;
 		}
 
@@ -788,12 +783,12 @@ void CNetatmo::SetSetpoint(int idx, const float temp)
 
 	if (!ret)
 	{
-		_log.Log(LOG_ERROR, "NetatmoThermostat: Error setting setpoint!");
+		Log(LOG_ERROR, "NetatmoThermostat: Error setting setpoint!");
 		return;
 	}
 
 	GetThermostatDetails();
-	m_tSetpointUpdateTime = time(NULL) + 60;
+	m_tSetpointUpdateTime = time(nullptr) + 60;
 	m_bForceSetpointUpdate = true;
 }
 
@@ -803,7 +798,7 @@ bool CNetatmo::ParseNetatmoGetResponse(const std::string &sResult, const _eNetat
 	bool ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_STATUS, "Netatmo: Invalid data received...");
+		Log(LOG_STATUS, "Invalid data received...");
 		return false;
 	}
 	bool bHaveDevices = true;
@@ -824,7 +819,7 @@ bool CNetatmo::ParseNetatmoGetResponse(const std::string &sResult, const _eNetat
 		if ((!bIsThermostat) && (!m_bFirstTimeWeatherData) && (m_bPollWeatherData))
 		{
 			//Do not warn if we check if we have a Thermostat device
-			_log.Log(LOG_STATUS, "Netatmo: No Weather Station devices found...");
+			Log(LOG_STATUS, "No Weather Station devices found...");
 		}
 		return false;
 	}
@@ -832,9 +827,8 @@ bool CNetatmo::ParseNetatmoGetResponse(const std::string &sResult, const _eNetat
 	std::vector<_tNetatmoDevice> _netatmo_devices;
 
 	int iDevIndex = 0;
-	for (Json::Value::iterator itDevice = root["body"]["devices"].begin(); itDevice != root["body"]["devices"].end(); ++itDevice)
+	for (auto device : root["body"]["devices"])
 	{
-		Json::Value device = *itDevice;
 		if (!device["_id"].empty())
 		{
 			std::string id = device["_id"].asString();
@@ -859,9 +853,8 @@ bool CNetatmo::ParseNetatmoGetResponse(const std::string &sResult, const _eNetat
 				if (device["modules"].isArray())
 				{
 					//Add modules for this device
-					for (Json::Value::iterator itModule = device["modules"].begin(); itModule != device["modules"].end(); ++itModule)
+					for (auto module : device["modules"])
 					{
-						Json::Value module = *itModule;
 						if (module.isObject())
 						{
 							//New Method (getstationsdata and getthermostatsdata)
@@ -909,7 +902,7 @@ bool CNetatmo::ParseNetatmoGetResponse(const std::string &sResult, const _eNetat
 											std::string setpoint_mode = module["setpoint"]["setpoint_mode"].asString();
 											bool bIsAway = (setpoint_mode == "away");
 											std::string aName = "Away " + mname;
-											SendSwitch(3, (uint8_t)(1 + iDevIndex), 255, bIsAway, 0, aName);
+											SendSwitch(3, (uint8_t)(1 + iDevIndex), 255, bIsAway, 0, aName, m_Name);
 										}
 										//Check if setpoint was just set, and if yes, overrule the previous setpoint
 										if (!module["setpoint"]["setpoint_temp"].empty())
@@ -963,9 +956,8 @@ bool CNetatmo::ParseNetatmoGetResponse(const std::string &sResult, const _eNetat
 	}
 	mRoot = root["body"]["modules"];
 
-	for (Json::Value::iterator itModule = mRoot.begin(); itModule != mRoot.end(); ++itModule)
+	for (auto module : mRoot)
 	{
-		Json::Value module = *itModule;
 		if (module["_id"].empty())
 			continue;
 		std::string id = module["_id"].asString();
@@ -1087,7 +1079,7 @@ void CNetatmo::GetMeterDetails()
 	std::vector<std::string> ExtraHeaders;
 	if (!HTTPClient::GET(httpUrl, ExtraHeaders, sResult))
 	{
-		_log.Log(LOG_ERROR, "Netatmo: Error connecting to Server...");
+		Log(LOG_ERROR, "Error connecting to Server...");
 		return;
 	}
 #endif
@@ -1100,14 +1092,14 @@ void CNetatmo::GetMeterDetails()
 	bRet = ParseJSon(sResult, root);
 	if ((!bRet) || (!root.isObject()))
 	{
-		_log.Log(LOG_ERROR, "Netatmo: Invalid data received...");
+		Log(LOG_ERROR, "Invalid data received...");
 		return;
 	}
 
 	if (!root["error"].empty())
 	{
 		//We received an error
-		_log.Log(LOG_ERROR, "Netatmo: %s", root["error"]["message"].asString().c_str());
+		Log(LOG_ERROR, "%s", root["error"]["message"].asString().c_str());
 		m_isLogged = false;
 		return;
 	}
@@ -1125,20 +1117,20 @@ void CNetatmo::GetMeterDetails()
 			httpUrl = MakeRequestURL(NETYPE_HOMECOACH);
 			if (!HTTPClient::GET(httpUrl, ExtraHeaders, sResult))
 			{
-				_log.Log(LOG_ERROR, "Netatmo: Error connecting to Server...");
+				Log(LOG_ERROR, "Error connecting to Server...");
 				return;
 			}
 #endif
 			bool bRet = ParseJSon(sResult, root);
 			if ((!bRet) || (!root.isObject()))
 			{
-				_log.Log(LOG_ERROR, "Netatmo: Invalid data received...");
+				Log(LOG_ERROR, "Invalid data received...");
 				return;
 			}
 			if (!root["error"].empty())
 			{
 				//We received an error
-				_log.Log(LOG_ERROR, "Netatmo: %s", root["error"]["message"].asString().c_str());
+				Log(LOG_ERROR, "%s", root["error"]["message"].asString().c_str());
 				m_isLogged = false;
 				return;
 			}
@@ -1160,20 +1152,20 @@ void CNetatmo::GetMeterDetails()
 				httpUrl = MakeRequestURL(NETYPE_ENERGY);
 				if (!HTTPClient::GET(httpUrl, ExtraHeaders, sResult))
 				{
-					_log.Log(LOG_ERROR, "Netatmo: Error connecting to Server...");
+					Log(LOG_ERROR, "Error connecting to Server...");
 					return;
 				}
 #endif
 				bRet = ParseJSon(sResult, root);
 				if ((!bRet) || (!root.isObject()))
 				{
-					_log.Log(LOG_ERROR, "Netatmo: Invalid data received...");
+					Log(LOG_ERROR, "Invalid data received...");
 					return;
 				}
 				if (!root["error"].empty())
 				{
 					//We received an error
-					_log.Log(LOG_ERROR, "Netatmo: %s", root["error"]["message"].asString().c_str());
+					Log(LOG_ERROR, "%s", root["error"]["message"].asString().c_str());
 					m_isLogged = false;
 					return;
 				}
@@ -1229,7 +1221,7 @@ void CNetatmo::GetThermostatDetails()
 
 	if (!ret)
 	{
-		_log.Log(LOG_ERROR, "Netatmo: Error connecting to Server...");
+		Log(LOG_ERROR, "Error connecting to Server...");
 		return;
 	}
 #endif
@@ -1264,7 +1256,7 @@ bool CNetatmo::ParseHomeData(const std::string &sResult)
 	bool ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_STATUS, "Netatmo: Invalid data received...");
+		Log(LOG_STATUS, "Invalid data received...");
 		return false;
 	}
 	//Check if we have a home id
@@ -1281,9 +1273,8 @@ bool CNetatmo::ParseHomeData(const std::string &sResult)
 			if (root["body"]["homes"][m_ActHome]["modules"].empty())
 				return false;
 			Json::Value mRoot = root["body"]["homes"][m_ActHome]["modules"];
-			for (Json::Value::iterator itModule = mRoot.begin(); itModule != mRoot.end(); ++itModule)
+			for (auto module : mRoot)
 			{
-				Json::Value module = *itModule;
 				if (!module["id"].empty())
 				{
 					std::string mID = module["id"].asString();
@@ -1297,9 +1288,8 @@ bool CNetatmo::ParseHomeData(const std::string &sResult)
 			if (root["body"]["homes"][m_ActHome]["rooms"].empty())
 				return false;
 			mRoot = root["body"]["homes"][m_ActHome]["rooms"];
-			for (Json::Value::iterator itRoom = mRoot.begin(); itRoom != mRoot.end(); ++itRoom)
+			for (auto room : mRoot)
 			{
-				Json::Value room = *itRoom;
 				if (!room["id"].empty())
 				{
 					std::string rID = room["id"].asString();
@@ -1314,7 +1304,7 @@ bool CNetatmo::ParseHomeData(const std::string &sResult)
 	if ((!m_bFirstTimeWeatherData) && (m_bPollWeatherData))
 	{
 		//Do not warn if we check if we have a Thermostat device
-		_log.Log(LOG_STATUS, "Netatmo: No Weather Station devices found...");
+		Log(LOG_STATUS, "No Weather Station devices found...");
 	}
 	return false;
 }
@@ -1325,7 +1315,7 @@ bool CNetatmo::ParseHomeStatus(const std::string &sResult)
 	bool ret = ParseJSon(sResult, root);
 	if ((!ret) || (!root.isObject()))
 	{
-		_log.Log(LOG_STATUS, "Netatmo: Invalid data received...");
+		Log(LOG_STATUS, "Invalid data received...");
 		return false;
 	}
 	//bool bHaveDevices = true;
@@ -1343,9 +1333,8 @@ bool CNetatmo::ParseHomeStatus(const std::string &sResult)
 		Json::Value mRoot = root["body"]["home"]["modules"];
 
 		int iModuleIndex = 0;
-		for (Json::Value::iterator itModule = mRoot.begin(); itModule != mRoot.end(); ++itModule)
+		for (auto module : mRoot)
 		{
-			Json::Value module = *itModule;
 			if (!module["id"].empty())
 			{
 				std::string id = module["id"].asString();
@@ -1369,7 +1358,7 @@ bool CNetatmo::ParseHomeStatus(const std::string &sResult)
 				{
 					std::string aName = "Status";
 					bool bIsActive = (module["boiler_status"].asString() == "true");
-					SendSwitch(moduleID & 0x00FFFFFF | 0x10000000, 1, 255, (bIsActive == true), 0, aName);
+					SendSwitch((moduleID & 0x00FFFFFF) | 0x10000000, 1, 255, bIsActive, 0, aName, m_Name);
 				}
 				if (!module["battery_level"].empty())
 				{
@@ -1380,13 +1369,13 @@ bool CNetatmo::ParseHomeStatus(const std::string &sResult)
 				{
 					float rf_strength = module["rf_strength"].asFloat();
 					// 90=low, 60=highest
-					if (rf_strength > 90.0f)
-						rf_strength = 90.0f;
-					if (rf_strength < 60.0f)
-						rf_strength = 60.0f;
+					if (rf_strength > 90.0F)
+						rf_strength = 90.0F;
+					if (rf_strength < 60.0F)
+						rf_strength = 60.0F;
 
 					//range is 30
-					float mrf_percentage = (100.0f / 30.0f)*float((90 - rf_strength));
+					float mrf_percentage = (100.0F / 30.0F) * float((90 - rf_strength));
 					if (mrf_percentage != 0)
 					{
 						std::string pName = moduleName + " RF (+Batt)";
@@ -1405,9 +1394,8 @@ bool CNetatmo::ParseHomeStatus(const std::string &sResult)
 			return false;
 		Json::Value mRoot = root["body"]["home"]["rooms"];
 
-		for (Json::Value::iterator itRoom = mRoot.begin(); itRoom != mRoot.end(); ++itRoom)
+		for (auto room : mRoot)
 		{
-			Json::Value room = *itRoom;
 			if (!room["id"].empty())
 			{
 				std::string id = room["id"].asString();
@@ -1431,18 +1419,19 @@ bool CNetatmo::ParseHomeStatus(const std::string &sResult)
 
 				if (!room["therm_measured_temperature"].empty())
 				{
-					SendTempSensor(roomID & 0x00FFFFFF | 0x03000000, 255, room["therm_measured_temperature"].asFloat(), roomName);
+					SendTempSensor((roomID & 0x00FFFFFF) | 0x03000000, 255, room["therm_measured_temperature"].asFloat(), roomName);
 				}
 				if (!room["therm_setpoint_temperature"].empty())
 				{
-					SendSetPointSensor((uint8_t)((roomID & 0X00FF0000 | 0x02000000) >> 16), (roomID & 0XFF00) >> 8, roomID & 0XFF, room["therm_setpoint_temperature"].asFloat(), roomName);
+					SendSetPointSensor((uint8_t)(((roomID & 0x00FF0000) | 0x02000000) >> 16), (roomID & 0XFF00) >> 8, roomID & 0XFF, room["therm_setpoint_temperature"].asFloat(),
+							   roomName);
 				}
 				if (!room["therm_setpoint_mode"].empty())
 				{
 					std::string setpoint_mode = room["therm_setpoint_mode"].asString();
 					bool bIsAway = (setpoint_mode == "away");
 					std::string aName = "Away " + roomName;
-					SendSwitch(roomID & 0x00FFFFFF | 0x01000000, 1, 255, bIsAway, 0, aName);
+					SendSwitch((roomID & 0x00FFFFFF) | 0x01000000, 1, 255, bIsAway, 0, aName, m_Name);
 				}
 			}
 			iDevIndex++;
