@@ -14,6 +14,7 @@ class OTGWBase : public CDomoticzHardwareBase
 		float Room_Setpoint;
 		float Relative_modulation_level;
 		float CH_water_pressure;
+		float DHW_flow_rate;
 		float Room_temperature;
 		float Boiler_water_temperature;
 		float DHW_temperature;
@@ -37,32 +38,34 @@ class OTGWBase : public CDomoticzHardwareBase
 		int A;
 		int B;
 	};
-public:
-	OTGWBase(void);
-	~OTGWBase(void);
+
+      public:
+	OTGWBase();
+	~OTGWBase() override = default;
 	std::string m_szSerialPort;
 	unsigned int m_iBaudRate;
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-	void SetSetpoint(const int idx, const float temp);
-	virtual bool WriteInt(const unsigned char *pData, const unsigned char Len) = 0;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+	void SetSetpoint(int idx, float temp);
+	virtual bool WriteInt(const unsigned char *pData, unsigned char Len) = 0;
 	std::string m_Version;
-protected:
-	void SetModes(const int Mode1, const int Mode2, const int Mode3, const int Mode4, const int Mode5, const int Mode6);
+
+      protected:
+	void SetModes(int Mode1, int Mode2, int Mode3, int Mode4, int Mode5, int Mode6);
 	void ParseData(const unsigned char *pData, int Len);
 	void ParseLine();
-	void UpdateSetPointSensor(const unsigned char Idx, const float Temp, const std::string &defaultname);
-	void UpdateSwitch(const unsigned char Idx, const bool bOn, const std::string &defaultname);
+	void UpdateSetPointSensor(unsigned char Idx, float Temp, const std::string &defaultname);
+	void UpdateSwitch(unsigned char Idx, bool bOn, const std::string &defaultname);
 	bool GetOutsideTemperatureFromDomoticz(float &tvalue);
-	bool SwitchLight(const int idx, const std::string &LCmd, const int svalue);
+	bool SwitchLight(int idx, const std::string &LCmd, int svalue);
 	void GetGatewayDetails();
 	void GetVersion();
 	void SendTime();
 	void SendOutsideTemperature();
-protected:
+
+      protected:
 	unsigned char m_buffer[1028];
 	int m_bufferpos;
 	bool m_bRequestVersion;
 	int m_OutsideTemperatureIdx;
 	float m_OverrideTemperature;
 };
-
