@@ -5,9 +5,21 @@
 #include "../main/localtime_r.h"
 #include "../main/Logger.h"
 
+#include <openssl/bio.h>
+#include <openssl/evp.h>
+/*
+#include <cryptopp/aes.h>
+#include <cryptopp/gcm.h>
+#include <cryptopp/modes.h>
+#include <cryptopp/filters.h>
+*/
+
 #define CRC16_ARC	0x8005
 #define CRC16_ARC_REFL	0xA001
 
+#define GCMTagLength 12
+const std::string _szDecodeAdd = "3000112233445566778899AABBCCDDEEFF";
+
 enum class _eP1MatchType {
 	ID = 0,
 	EXCLMARK,
@@ -71,52 +83,55 @@ enum _eP1Type {
 	P1TYPE_GASUSAGE
 };
 
-typedef struct {
+using P1Match = struct
+{
 	_eP1MatchType matchtype;
 	_eP1Type type;
 	const char* key;
 	const char* topic;
 	int start;
 	int width;
-} P1Match;
+};
 
-P1Match p1_matchlist[] = {
-	{_eP1MatchType::ID,			P1TYPE_SMID,			P1SMID,		"",					0,  0},
-	{_eP1MatchType::EXCLMARK,	P1TYPE_END,				P1EOT,		"",					0,  0},
-	{_eP1MatchType::STD,		P1TYPE_VERSION,			P1VER,		"version",			10,  2},
-	{_eP1MatchType::STD,		P1TYPE_VERSION,			P1VERBE,	"versionBE",		11,  5},
-	{_eP1MatchType::STD,		P1TYPE_POWERUSAGE,		P1PUSG,		"powerusage",		10,  9},
-	{_eP1MatchType::STD,		P1TYPE_POWERDELIV,		P1PDLV,		"powerdeliv",		10,  9},
-	{_eP1MatchType::STD,		P1TYPE_USAGECURRENT,	P1PUC,		"powerusagec",		10,  7},
-	{_eP1MatchType::STD,		P1TYPE_DELIVCURRENT,	P1PDC,		"powerdelivc",		10,  7},
-	{_eP1MatchType::STD,		P1TYPE_VOLTAGEL1,		P1VOLTL1,	"voltagel1",		11,  5},
-	{_eP1MatchType::STD,		P1TYPE_VOLTAGEL2,		P1VOLTL2,	"voltagel2",		11,  5},
-	{_eP1MatchType::STD,		P1TYPE_VOLTAGEL3,		P1VOLTL3,	"voltagel3",		11,  5},
-	{_eP1MatchType::STD,		P1TYPE_AMPERAGEL1,		P1AMPEREL1,	"amperagel1",		11,  3},
-	{_eP1MatchType::STD,		P1TYPE_AMPERAGEL2,		P1AMPEREL2,	"amperagel2",		11,  3},
-	{_eP1MatchType::STD,		P1TYPE_AMPERAGEL3,		P1AMPEREL3,	"amperagel3",		11,  3},
-	{_eP1MatchType::STD,		P1TYPE_POWERUSEL1,		P1POWUSL1,	"powerusel1",		11,  6},
-	{_eP1MatchType::STD,		P1TYPE_POWERUSEL2,		P1POWUSL2,	"powerusel2",		11,  6},
-	{_eP1MatchType::STD,		P1TYPE_POWERUSEL3,		P1POWUSL3,	"powerusel3",		11,  6},
-	{_eP1MatchType::STD,		P1TYPE_POWERDELL1,		P1POWDLL1,	"powerdell1",		11,  6},
-	{_eP1MatchType::STD,		P1TYPE_POWERDELL2,		P1POWDLL2,	"powerdell2",		11,  6},
-	{_eP1MatchType::STD,		P1TYPE_POWERDELL3,		P1POWDLL3,	"powerdell3",		11,  6},
-	{_eP1MatchType::DEVTYPE,	P1TYPE_MBUSDEVICETYPE,	P1MBTYPE,	"mbusdevicetype",	11,  3},
-	{_eP1MatchType::GAS,		P1TYPE_GASUSAGEDSMR4,	P1GUDSMR4,	"gasusage",	 		26,  8},
-	{_eP1MatchType::LINE17,		P1TYPE_GASTIMESTAMP,	P1GTS,		"gastimestamp",		11, 12},
-	{_eP1MatchType::LINE18,		P1TYPE_GASUSAGE,		P1GUDSMR2,	"gasusage",			1,  9}
-}; // must keep DEVTYPE, GAS, LINE17 and LINE18 in this order at end of p1_matchlist
+constexpr std::array<P1Match, 24> p1_matchlist{
+	{
+		{ _eP1MatchType::ID, P1TYPE_SMID, P1SMID, "", 0, 0 },				      //
+		{ _eP1MatchType::EXCLMARK, P1TYPE_END, P1EOT, "", 0, 0 },			      //
+		{ _eP1MatchType::STD, P1TYPE_VERSION, P1VER, "version", 10, 2 },		      //
+		{ _eP1MatchType::STD, P1TYPE_VERSION, P1VERBE, "versionBE", 11, 5 },		      //
+		{ _eP1MatchType::STD, P1TYPE_POWERUSAGE, P1PUSG, "powerusage", 10, 9 },		      //
+		{ _eP1MatchType::STD, P1TYPE_POWERDELIV, P1PDLV, "powerdeliv", 10, 9 },		      //
+		{ _eP1MatchType::STD, P1TYPE_USAGECURRENT, P1PUC, "powerusagec", 10, 7 },	      //
+		{ _eP1MatchType::STD, P1TYPE_DELIVCURRENT, P1PDC, "powerdelivc", 10, 7 },	      //
+		{ _eP1MatchType::STD, P1TYPE_VOLTAGEL1, P1VOLTL1, "voltagel1", 11, 5 },		      //
+		{ _eP1MatchType::STD, P1TYPE_VOLTAGEL2, P1VOLTL2, "voltagel2", 11, 5 },		      //
+		{ _eP1MatchType::STD, P1TYPE_VOLTAGEL3, P1VOLTL3, "voltagel3", 11, 5 },		      //
+		{ _eP1MatchType::STD, P1TYPE_AMPERAGEL1, P1AMPEREL1, "amperagel1", 11, 3 },	      //
+		{ _eP1MatchType::STD, P1TYPE_AMPERAGEL2, P1AMPEREL2, "amperagel2", 11, 3 },	      //
+		{ _eP1MatchType::STD, P1TYPE_AMPERAGEL3, P1AMPEREL3, "amperagel3", 11, 3 },	      //
+		{ _eP1MatchType::STD, P1TYPE_POWERUSEL1, P1POWUSL1, "powerusel1", 11, 6 },	      //
+		{ _eP1MatchType::STD, P1TYPE_POWERUSEL2, P1POWUSL2, "powerusel2", 11, 6 },	      //
+		{ _eP1MatchType::STD, P1TYPE_POWERUSEL3, P1POWUSL3, "powerusel3", 11, 6 },	      //
+		{ _eP1MatchType::STD, P1TYPE_POWERDELL1, P1POWDLL1, "powerdell1", 11, 6 },	      //
+		{ _eP1MatchType::STD, P1TYPE_POWERDELL2, P1POWDLL2, "powerdell2", 11, 6 },	      //
+		{ _eP1MatchType::STD, P1TYPE_POWERDELL3, P1POWDLL3, "powerdell3", 11, 6 },	      //
+		{ _eP1MatchType::DEVTYPE, P1TYPE_MBUSDEVICETYPE, P1MBTYPE, "mbusdevicetype", 11, 3 }, //
+		{ _eP1MatchType::GAS, P1TYPE_GASUSAGEDSMR4, P1GUDSMR4, "gasusage", 26, 8 },	      //
+		{ _eP1MatchType::LINE17, P1TYPE_GASTIMESTAMP, P1GTS, "gastimestamp", 11, 12 },	      //
+		{ _eP1MatchType::LINE18, P1TYPE_GASUSAGE, P1GUDSMR2, "gasusage", 1, 9 },	      //
+	}											      // must keep DEVTYPE, GAS, LINE17 and LINE18 in this order at end of p1_matchlist
+};
 
-P1MeterBase::P1MeterBase(void)
+P1MeterBase::P1MeterBase()
 {
 	m_bDisableCRC = true;
 	m_ratelimit = 0;
 	Init();
 }
 
-
-P1MeterBase::~P1MeterBase(void)
+P1MeterBase::~P1MeterBase()
 {
+	delete[] m_pDecryptBuffer;
 }
 
 void P1MeterBase::Init()
@@ -182,77 +197,97 @@ void P1MeterBase::Init()
 		{
 			m_gasmbuschannel = (char)s_gasmbuschannel[0];
 			m_gasprefix[2] = m_gasmbuschannel;
-			_log.Log(LOG_STATUS, "P1 Smart Meter: Gas meter M-Bus channel %c enforced by 'P1GasMeterChannel' user variable", m_gasmbuschannel);
+			Log(LOG_STATUS, "Gas meter M-Bus channel %c enforced by 'P1GasMeterChannel' user variable", m_gasmbuschannel);
 		}
 	}
+	InitP1EncryptionState();
 }
 
+void P1MeterBase::InitP1EncryptionState()
+{
+	m_p1_encryption_state = P1EcryptionState::waitingForStartByte;
+	m_currentBytePosition = 0;
+	m_changeToNextStateAt = 0;
+	m_dataLength = 0;
+	m_systemTitle.clear();
+	m_frameCounter = 0;
+	m_dataPayload.clear();
+	m_gcmTag.clear();
+	m_gcmTag.reserve(GCMTagLength);
+}
+
+
 bool P1MeterBase::MatchLine()
 {
-	if ((strlen((const char*)& l_buffer) < 1) || (l_buffer[0] == 0x0a))
+	if ((strlen((const char*)&l_buffer) < 1) || (l_buffer[0] == 0x0a))
 		return true; //null value (startup)
 	uint8_t i;
-	uint8_t found = 0;
-	P1Match* t;
+	bool found = false;
+	const P1Match *t;
 	char value[20] = "";
 	std::string vString;
 
-	for (i = 0; (i < sizeof(p1_matchlist) / sizeof(P1Match)) & (!found); i++)
+	for (i = 0; i < p1_matchlist.size(); ++i)
 	{
+		if (found)
+		{
+			break;
+		}
+
 		t = &p1_matchlist[i];
 		switch (t->matchtype)
 		{
 		case _eP1MatchType::ID:
 			// start of data
-			if (strncmp(t->key, (const char*)& l_buffer, strlen(t->key)) == 0)
+			if (strncmp(t->key, (const char*)&l_buffer, strlen(t->key)) == 0)
 			{
 				m_linecount = 1;
-				found = 1;
+				found = true;
 			}
 			continue; // we do not process anything else on this line
 			break;
 		case _eP1MatchType::EXCLMARK:
 			// end of data
-			if (strncmp(t->key, (const char*)& l_buffer, strlen(t->key)) == 0)
+			if (strncmp(t->key, (const char*)&l_buffer, strlen(t->key)) == 0)
 			{
 				l_exclmarkfound = 1;
-				found = 1;
+				found = true;
 			}
 			break;
 		case _eP1MatchType::STD:
-			if (strncmp(t->key, (const char*)& l_buffer, strlen(t->key)) == 0)
-				found = 1;
+			if (strncmp(t->key, (const char*)&l_buffer, strlen(t->key)) == 0)
+				found = true;
 			break;
 		case _eP1MatchType::DEVTYPE:
 			if (m_gasmbuschannel == 0)
 			{
 				vString = (const char*)t->key + 3;
-				if (strncmp(vString.c_str(), (const char*)& l_buffer + 3, strlen(t->key) - 3) == 0)
-					found = 1;
+				if (strncmp(vString.c_str(), (const char*)&l_buffer + 3, strlen(t->key) - 3) == 0)
+					found = true;
 				else
 					i += 100; // skip matches with any other gas lines - we need to find the M0-Bus channel first
 			}
 			break;
 		case _eP1MatchType::GAS:
-			if (strncmp((m_gasprefix + (t->key + 3)).c_str(), (const char*)& l_buffer, strlen(t->key)) == 0)
+			if (strncmp((m_gasprefix + (t->key + 3)).c_str(), (const char*)&l_buffer, strlen(t->key)) == 0)
 			{
 				// verify that 'tariff' indicator is either 1 (Nld) or 3 (Bel)
 				if ((l_buffer[9] & 0xFD) == 0x31)
-					found = 1;
+					found = true;
 			}
 			if (m_p1version >= 4)
 				i += 100; // skip matches with any DSMR v2 gas lines
 			break;
 		case _eP1MatchType::LINE17:
-			if (strncmp((m_gasprefix + (t->key + 3)).c_str(), (const char*)& l_buffer, strlen(t->key)) == 0)
+			if (strncmp((m_gasprefix + (t->key + 3)).c_str(), (const char*)&l_buffer, strlen(t->key)) == 0)
 			{
 				m_linecount = 17;
-				found = 1;
+				found = true;
 			}
 			break;
 		case _eP1MatchType::LINE18:
-			if ((m_linecount == 18) && (strncmp(t->key, (const char*)& l_buffer, strlen(t->key)) == 0))
-				found = 1;
+			if ((m_linecount == 18) && (strncmp(t->key, (const char*)&l_buffer, strlen(t->key)) == 0))
+				found = true;
 			break;
 		} //switch
 
@@ -263,14 +298,14 @@ bool P1MeterBase::MatchLine()
 		{
 			if (m_p1version == 0)
 			{
-				_log.Log(LOG_STATUS, "P1 Smart Meter: Meter is pre DSMR 4.0 - using DSMR 2.2 compatibility");
+				Log(LOG_STATUS, "Meter is pre DSMR 4.0 - using DSMR 2.2 compatibility");
 				m_p1version = 2;
 			}
-			time_t atime = mytime(NULL);
+			time_t atime = mytime(nullptr);
 			if (difftime(atime, m_lastUpdateTime) >= m_ratelimit)
 			{
 				m_lastUpdateTime = atime;
-				sDecodeRXMessage(this, (const unsigned char*)& m_power, "Power", 255);
+				sDecodeRXMessage(this, (const unsigned char *)&m_power, "Power", 255, nullptr);
 				if (m_voltagel1 != -1) {
 					SendVoltageSensor(0, 1, 255, m_voltagel1, "Voltage L1");
 				}
@@ -314,7 +349,7 @@ bool P1MeterBase::MatchLine()
 						// just accept it - we cannot sync to our clock
 						m_lastSharedSendGas = atime;
 						m_lastgasusage = m_gas.gasusage;
-						sDecodeRXMessage(this, (const unsigned char*)& m_gas, "Gas", 255);
+						sDecodeRXMessage(this, (const unsigned char *)&m_gas, "Gas", 255, nullptr);
 					}
 					else if (atime >= m_gasoktime)
 					{
@@ -324,12 +359,12 @@ bool P1MeterBase::MatchLine()
 						sprintf(myts, "%02d%02d%02d%02d%02d%02dW", ltime.tm_year % 100, ltime.tm_mon + 1, ltime.tm_mday, ltime.tm_hour, ltime.tm_min, ltime.tm_sec);
 						if (ltime.tm_isdst)
 							myts[12] = 'S';
-						if ((m_gastimestamp.length() > 13) || (strncmp((const char*)& myts, m_gastimestamp.c_str(), m_gastimestamp.length()) >= 0))
+						if ((m_gastimestamp.length() > 13) || (strncmp((const char*)&myts, m_gastimestamp.c_str(), m_gastimestamp.length()) >= 0))
 						{
 							m_lastSharedSendGas = atime;
 							m_lastgasusage = m_gas.gasusage;
 							m_gasoktime += 300;
-							sDecodeRXMessage(this, (const unsigned char*)& m_gas, "Gas", 255);
+							sDecodeRXMessage(this, (const unsigned char *)&m_gas, "Gas", 255, nullptr);
 						}
 						else // gas clock is ahead
 						{
@@ -351,11 +386,11 @@ bool P1MeterBase::MatchLine()
 							m_gasclockskew = difftime(gtime, atime);
 							if (m_gasclockskew >= 300)
 							{
-								_log.Log(LOG_ERROR, "P1 Smart Meter: Unable to synchronize to the gas meter clock because it is more than 5 minutes ahead of my time");
+								Log(LOG_ERROR, "Unable to synchronize to the gas meter clock because it is more than 5 minutes ahead of my time");
 							}
 							else {
 								m_gasoktime = gtime;
-								_log.Log(LOG_STATUS, "P1 Smart Meter: Gas meter clock is %i seconds ahead - wait for my clock to catch up", (int)m_gasclockskew);
+								Log(LOG_STATUS, "Gas meter clock is %i seconds ahead - wait for my clock to catch up", (int)m_gasclockskew);
 							}
 						}
 					}
@@ -366,21 +401,21 @@ bool P1MeterBase::MatchLine()
 		}
 		else
 		{
-			vString = (const char*)& l_buffer + t->start;
+			vString = (const char*)&l_buffer + t->start;
 			size_t ePos = t->width;
 			ePos = vString.find_first_of("*)");
 
 			if (ePos == std::string::npos)
 			{
 				// invalid message: value not delimited
-				_log.Log(LOG_NORM, "P1 Smart Meter: Dismiss incoming - value is not delimited in line \"%s\"", l_buffer);
+				Log(LOG_NORM, "Dismiss incoming - value is not delimited in line \"%s\"", l_buffer);
 				return false;
 			}
 
 			if (ePos > 19)
 			{
 				// invalid message: line too long
-				_log.Log(LOG_NORM, "P1 Smart Meter: Dismiss incoming - value in line \"%s\" is oversized", l_buffer);
+				Log(LOG_NORM, "Dismiss incoming - value in line \"%s\" is oversized", l_buffer);
 				return false;
 			}
 
@@ -388,7 +423,7 @@ bool P1MeterBase::MatchLine()
 			{
 				strcpy(value, vString.substr(0, ePos).c_str());
 #ifdef _DEBUG
-				_log.Log(LOG_NORM, "P1 Smart Meter: Key: %s, Value: %s", t->topic, value);
+				Log(LOG_NORM, "Key: %s, Value: %s", t->topic, value);
 #endif
 			}
 
@@ -417,7 +452,7 @@ bool P1MeterBase::MatchLine()
 						if (m_p1version < 5)
 							szVersion[0] = 'D';
 					}
-					_log.Log(LOG_STATUS, "P1 Smart Meter: Meter reports as %s", szVersion);
+					Log(LOG_STATUS, "Meter reports as %s", szVersion);
 				}
 				break;
 			case P1TYPE_MBUSDEVICETYPE:
@@ -426,11 +461,11 @@ bool P1MeterBase::MatchLine()
 				{
 					m_gasmbuschannel = (char)l_buffer[2];
 					m_gasprefix[2] = m_gasmbuschannel;
-					_log.Log(LOG_STATUS, "P1 Smart Meter: Found gas meter on M-Bus channel %c", m_gasmbuschannel);
+					Log(LOG_STATUS, "Found gas meter on M-Bus channel %c", m_gasmbuschannel);
 				}
 				break;
 			case P1TYPE_POWERUSAGE:
-				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0f);
+				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0F);
 				if ((l_buffer[8] & 0xFE) == 0x30)
 				{
 					// map tariff IDs 0 (Lux) and 1 (Bel, Nld) both to powerusage1
@@ -448,7 +483,7 @@ bool P1MeterBase::MatchLine()
 				}
 				break;
 			case P1TYPE_POWERDELIV:
-				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0f);
+				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0F);
 				if ((l_buffer[8] & 0xFE) == 0x30)
 				{
 					// map tariff IDs 0 (Lux) and 1 (Bel, Nld) both to powerdeliv1
@@ -466,12 +501,12 @@ bool P1MeterBase::MatchLine()
 				}
 				break;
 			case P1TYPE_USAGECURRENT:
-				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0f);	//Watt
+				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0F); // Watt
 				if (temp_usage < 17250)
 					m_power.usagecurrent = temp_usage;
 				break;
 			case P1TYPE_DELIVCURRENT:
-				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0f);	//Watt;
+				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0F); // Watt;
 				if (temp_usage < 17250)
 					m_power.delivcurrent = temp_usage;
 				break;
@@ -515,32 +550,32 @@ bool P1MeterBase::MatchLine()
 				}
 				break;
 			case P1TYPE_POWERUSEL1:
-				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0f);
+				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0F);
 				if (temp_power < 10000)
 					m_powerusel1 = temp_power; //Power Used L1;
 				break;
 			case P1TYPE_POWERUSEL2:
-				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0f);
+				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0F);
 				if (temp_power < 10000)
 					m_powerusel2 = temp_power; //Power Used L2;
 				break;
 			case P1TYPE_POWERUSEL3:
-				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0f);
+				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0F);
 				if (temp_power < 10000)
 					m_powerusel3 = temp_power; //Power Used L3;
 				break;
 			case P1TYPE_POWERDELL1:
-				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0f);
+				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0F);
 				if (temp_power < 10000)
 					m_powerdell1 = temp_power; //Power Used L1;
 				break;
 			case P1TYPE_POWERDELL2:
-				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0f);
+				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0F);
 				if (temp_power < 10000)
 					m_powerdell2 = temp_power; //Power Used L2;
 				break;
 			case P1TYPE_POWERDELL3:
-				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0f);
+				temp_power = static_cast<float>(strtod(value, &validate) * 1000.0F);
 				if (temp_power < 10000)
 					m_powerdell3 = temp_power; //Power Used L3;
 				break;
@@ -549,7 +584,7 @@ bool P1MeterBase::MatchLine()
 				break;
 			case P1TYPE_GASUSAGE:
 			case P1TYPE_GASUSAGEDSMR4:
-				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0f);
+				temp_usage = (unsigned long)(strtod(value, &validate) * 1000.0F);
 				if (!m_gas.gasusage || m_p1version >= 4)
 					m_gas.gasusage = temp_usage;
 				else if (temp_usage - m_gas.gasusage < 20000)
@@ -560,17 +595,17 @@ bool P1MeterBase::MatchLine()
 			if (ePos > 0 && ((validate - value) != ePos))
 			{
 				// invalid message: value is not a number
-				_log.Log(LOG_NORM, "P1 Smart Meter: Dismiss incoming - value in line \"%s\" is not a number", l_buffer);
+				Log(LOG_NORM, "Dismiss incoming - value in line \"%s\" is not a number", l_buffer);
 				return false;
 			}
 
 			if (t->type == P1TYPE_GASUSAGEDSMR4)
 			{
 				// need to get timestamp from this line as well
-				vString = (const char*)& l_buffer + 11;
+				vString = (const char*)&l_buffer + 11;
 				m_gastimestamp = vString.substr(0, 13);
 #ifdef _DEBUG
-				_log.Log(LOG_NORM, "P1 Smart Meter: Key: gastimestamp, Value: %s", m_gastimestamp.c_str());
+				Log(LOG_NORM, "Key: gastimestamp, Value: %s", m_gastimestamp.c_str());
 #endif
 			}
 		}
@@ -580,7 +615,7 @@ bool P1MeterBase::MatchLine()
 
 
 /*
-/ GB3:	DSMR 4.0 defines a CRC checksum at the end of the message, calculated from
+/ 	DSMR 4.0 defines a CRC checksum at the end of the message, calculated from
 /	and including the message starting character '/' upto and including the message
 /	end character '!'. According to the specs the CRC is a 16bit checksum using the
 /	polynomial x^16 + x^15 + x^2 + 1, however input/output are reflected.
@@ -593,7 +628,7 @@ bool P1MeterBase::CheckCRC()
 	{
 		if (m_p1version == 0)
 		{
-			_log.Log(LOG_STATUS, "P1 Smart Meter: Meter is pre DSMR 4.0 and does not send a CRC checksum - using DSMR 2.2 compatibility");
+			Log(LOG_STATUS, "Meter is pre DSMR 4.0 and does not send a CRC checksum - using DSMR 2.2 compatibility");
 			m_p1version = 2;
 		}
 		// always return true with pre DSMRv4 format message
@@ -603,21 +638,21 @@ bool P1MeterBase::CheckCRC()
 	if (l_buffer[5] != 0)
 	{
 		// trailing characters after CRC
-		_log.Log(LOG_NORM, "P1 Smart Meter: Dismiss incoming - CRC value in message has trailing characters");
+		Log(LOG_NORM, "Dismiss incoming - CRC value in message has trailing characters");
 		return false;
 	}
 
 	if (!m_CRfound)
 	{
-		_log.Log(LOG_NORM, "P1 Smart Meter: You appear to have middleware that changes the message content - skipping CRC validation");
+		Log(LOG_NORM, "You appear to have middleware that changes the message content - skipping CRC validation");
 		return true;
 	}
 
 	// retrieve CRC from the current line
 	char crc_str[5];
-	strncpy(crc_str, (const char*)& l_buffer + 1, 4);
+	strncpy(crc_str, (const char*)&l_buffer + 1, 4);
 	crc_str[4] = 0;
-	uint16_t m_crc16 = (uint16_t)strtoul(crc_str, NULL, 16);
+	uint16_t m_crc16 = (uint16_t)strtoul(crc_str, nullptr, 16);
 
 	// calculate CRC
 	const unsigned char* c_buffer = m_buffer;
@@ -640,14 +675,113 @@ bool P1MeterBase::CheckCRC()
 	}
 	if (crc != m_crc16)
 	{
-		_log.Log(LOG_NORM, "P1 Smart Meter: Dismiss incoming - CRC failed");
+		Log(LOG_NORM, "Dismiss incoming - CRC failed");
 	}
 	return (crc == m_crc16);
 }
 
 
+bool P1MeterBase::ParseP1EncryptedData(const uint8_t p1_byte)
+{
+	switch (m_p1_encryption_state)
+	{
+	case P1EcryptionState::waitingForStartByte:
+		if (p1_byte == 0xDB)
+		{
+			InitP1EncryptionState();
+			m_p1_encryption_state = P1EcryptionState::readSystemTitleLength;
+		}
+		break;
+	case P1EcryptionState::readSystemTitleLength:
+		m_p1_encryption_state = P1EcryptionState::readSystemTitle;
+		// 2 start bytes (position 0 and 1) + system title length
+		m_changeToNextStateAt = 1 + int(p1_byte);
+		m_systemTitle.clear();
+		break;
+	case P1EcryptionState::readSystemTitle:
+		m_systemTitle.insert(m_systemTitle.end(), 1, p1_byte);
+		if (m_currentBytePosition >= m_changeToNextStateAt)
+		{
+			m_p1_encryption_state = P1EcryptionState::readSeparator82;
+			m_changeToNextStateAt++;
+		}
+		break;
+	case P1EcryptionState::readSeparator82:
+		if (p1_byte == 0x82)
+		{
+			m_p1_encryption_state = P1EcryptionState::readPayloadLength; // Ignore separator byte
+			m_changeToNextStateAt += 2;
+		}
+		else {
+			//Missing separator (0x82). Dropping telegram
+			m_p1_encryption_state = P1EcryptionState::waitingForStartByte;
+		}
+		break;
+	case P1EcryptionState::readPayloadLength:
+		m_dataLength <<= 8;
+		m_dataLength |= int(p1_byte);
+		if (m_dataLength > 2000)
+		{
+			//something is not right here
+			m_p1_encryption_state = P1EcryptionState::readSystemTitleLength;
+		}
+		else if (m_currentBytePosition >= m_changeToNextStateAt)
+		{
+			m_p1_encryption_state = P1EcryptionState::readSeparator30;
+			m_changeToNextStateAt++;
+		}
+		break;
+	case P1EcryptionState::readSeparator30:
+		if (p1_byte == 0x30)
+		{
+			m_p1_encryption_state = P1EcryptionState::readFrameCounter;
+			// 4 bytes for frame counter
+			m_changeToNextStateAt += 4;
+		}
+		else {
+			//Missing separator (0x30). Dropping telegram
+			m_p1_encryption_state = P1EcryptionState::waitingForStartByte;
+		}
+		break;
+	case P1EcryptionState::readFrameCounter:
+		m_frameCounter <<= 8;
+		m_frameCounter |= p1_byte;
+		if (m_currentBytePosition >= m_changeToNextStateAt)
+		{
+			m_p1_encryption_state = P1EcryptionState::readPayload;
+			m_changeToNextStateAt += m_dataLength - 17;
+			m_dataPayload.reserve(m_dataLength - 17);
+		}
+		break;
+	case P1EcryptionState::readPayload:
+		m_dataPayload.insert(m_dataPayload.end(), 1, p1_byte);
+		if (m_currentBytePosition >= m_changeToNextStateAt)
+		{
+			m_p1_encryption_state = P1EcryptionState::readGcmTag;
+			m_changeToNextStateAt += GCMTagLength;
+		}
+		break;
+	case P1EcryptionState::readGcmTag:
+		// All input has been read.
+		m_gcmTag.insert(m_gcmTag.end(), 1, p1_byte);
+		if (m_currentBytePosition >= m_changeToNextStateAt)
+		{
+			m_p1_encryption_state = P1EcryptionState::doneReadingTelegram;
+		}
+		break;
+	}
+	m_currentBytePosition++;
+	if (m_p1_encryption_state == P1EcryptionState::doneReadingTelegram)
+	{
+		m_p1_encryption_state = P1EcryptionState::waitingForStartByte;
+		return true;
+	}
+	return false;
+}
+
+
 /*
-/ GB3:	ParseP1Data() can be called with either a complete message (P1MeterTCP) or individual
+/ 	ParseP1Data() can be called with either a complete message (P1MeterTCP) or individual
 /	lines (P1MeterSerial).
 /
 /	While it is technically possible to do a CRC check line by line, we like to keep
@@ -660,8 +794,83 @@ bool P1MeterBase::CheckCRC()
 /	done if the message passes all other validation rules
 */
 
-void P1MeterBase::ParseP1Data(const unsigned char* pData, const int Len, const bool disable_crc, int ratelimit)
+void P1MeterBase::ParseP1Data(const uint8_t* pDataIn, const int LenIn, const bool disable_crc, int ratelimit)
 {
+	const uint8_t* pData = pDataIn;
+	int Len = LenIn;
+
+	if (m_bIsEncrypted)
+	{
+		int tLen = 0;
+		while (tLen < LenIn)
+		{
+			if (ParseP1EncryptedData(pDataIn[tLen]))
+			{
+				try
+				{
+					//We have a complete Telegram
+					std::string iv, cipherText;
+					iv.reserve(m_systemTitle.size() + 4);
+					cipherText.reserve(m_dataPayload.size() + GCMTagLength);
+
+					iv.append(m_systemTitle.begin(), m_systemTitle.end());
+					iv.append(1, (m_frameCounter & 0xFF000000) >> 24);
+					iv.append(1, (m_frameCounter & 0x00FF0000) >> 16);
+					iv.append(1, (m_frameCounter & 0x0000FF00) >> 8);
+					iv.append(1, m_frameCounter & 0x000000FF);
+
+					cipherText.append(m_dataPayload.begin(), m_dataPayload.end());
+					cipherText.append(m_gcmTag.begin(), m_gcmTag.end());
+
+					size_t neededDecryptBufferSize = std::min(2048, static_cast<int>(cipherText.size() + 16));
+					if (neededDecryptBufferSize > m_DecryptBufferSize)
+					{
+						delete[] m_pDecryptBuffer;
+
+						m_DecryptBufferSize = neededDecryptBufferSize;
+						m_pDecryptBuffer = new uint8_t[m_DecryptBufferSize];
+						if (m_pDecryptBuffer == nullptr)
+							return;
+					}
+					memset(m_pDecryptBuffer, 0, m_DecryptBufferSize);
+
+					EVP_CIPHER_CTX* ctx = EVP_CIPHER_CTX_new();
+					if (ctx == nullptr)
+						return;
+					EVP_DecryptInit_ex(ctx, EVP_aes_128_gcm(), nullptr, nullptr, nullptr);
+					EVP_CIPHER_CTX_ctrl(ctx, EVP_CTRL_AEAD_SET_IVLEN, iv.size(), nullptr);
+
+					EVP_DecryptInit_ex(ctx, nullptr, nullptr, (const unsigned char *)m_szHexKey.data(),
+							   (const unsigned char *)iv.c_str());
+
+					int outlen = 0;
+					// std::vector<char> m_szDecodeAdd = HexToBytes(_szDecodeAdd);
+					// EVP_DecryptUpdate(ctx, nullptr, &outlen, (const uint8_t*)m_szDecodeAdd.data(),
+					// m_szDecodeAdd.size());
+					EVP_DecryptUpdate(ctx, (uint8_t*)m_pDecryptBuffer, &outlen, (uint8_t*)cipherText.c_str(), cipherText.size());
+					EVP_CIPHER_CTX_free(ctx);
+					if (outlen <= 0)
+						return;
+/*
+					CryptoPP::GCM< CryptoPP::AES >::Decryption decryptor;
+					decryptor.SetKeyWithIV((uint8_t*)m_szHexKey.data(), 16, (uint8_t*)iv.c_str(), 12);
+					decryptor.ProcessData(m_pDecryptBuffer, (uint8_t*)cipherText.c_str(), cipherText.size());
+*/
+					pData = m_pDecryptBuffer;
+					Len = static_cast<int>(strlen((const char*)m_pDecryptBuffer));
+				}
+				catch (const std::exception& e)
+				{
+					Log(LOG_ERROR, "P1Meter: Error decrypting payload (%s)", e.what());
+				}
+				break;
+			}
+			tLen++;
+		}
+		if (tLen >= LenIn)
+			return; //not ready with payload
+	}
+
 	int ii = 0;
 	m_ratelimit = ratelimit;
 	// a new message should not start with an empty line, but just in case it does (crude check is sufficient here)
@@ -675,7 +884,7 @@ void P1MeterBase::ParseP1Data(const unsigned char* pData, const int Len, const b
 	{
 		if ((l_buffer[0] == 0x21) && !l_exclmarkfound && (m_linecount > 0))
 		{
-			_log.Log(LOG_STATUS, "P1 Smart Meter: WARNING: got new message but buffer still contains unprocessed data from previous message.");
+			Log(LOG_STATUS, "WARNING: got new message but buffer still contains unprocessed data from previous message.");
 			l_buffer[l_bufferpos] = 0;
 			if (disable_crc || CheckCRC())
 			{
@@ -711,7 +920,7 @@ void P1MeterBase::ParseP1Data(const unsigned char* pData, const int Len, const b
 		if ((Len > 400) || (pData[0] == 0x21))
 		{
 			// 400 is an arbitrary chosen number to differentiate between full messages and single line commits
-			_log.Log(LOG_NORM, "P1 Smart Meter: Dismiss incoming - message oversized");
+			Log(LOG_NORM, "Dismiss incoming - message oversized");
 		}
 		m_linecount = 0;
 		return;
