@@ -22,10 +22,6 @@ CPVOutputInput::CPVOutputInput(const int ID, const std::string& SID, const std::
 	Init();
 }
 
-CPVOutputInput::~CPVOutputInput(void)
-{
-}
-
 void CPVOutputInput::Init()
 {
 	m_bHadConsumption = false;
@@ -37,7 +33,7 @@ bool CPVOutputInput::StartHardware()
 
 	Init();
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&CPVOutputInput::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -61,10 +57,10 @@ bool CPVOutputInput::StopHardware()
 void CPVOutputInput::Do_Work()
 {
 	int LastMinute = -1;
-	_log.Log(LOG_STATUS, "PVOutput (Input): Worker started...");
+	Log(LOG_STATUS, "Worker started...");
 	while (!IsStopRequested(1000))
 	{
-		time_t atime = mytime(NULL);
+		time_t atime = mytime(nullptr);
 		m_LastHeartbeat = atime;
 		struct tm ltime;
 		localtime_r(&atime, &ltime);
@@ -74,7 +70,7 @@ void CPVOutputInput::Do_Work()
 			GetMeterDetails();
 		}
 	}
-	_log.Log(LOG_STATUS, "PVOutput (Input): Worker stopped...");
+	Log(LOG_STATUS, "Worker stopped...");
 }
 
 bool CPVOutputInput::WriteToHardware(const char* pdata, const unsigned char length)
@@ -84,9 +80,9 @@ bool CPVOutputInput::WriteToHardware(const char* pdata, const unsigned char leng
 
 void CPVOutputInput::GetMeterDetails()
 {
-	if (m_SID.size() == 0)
+	if (m_SID.empty())
 		return;
-	if (m_KEY.size() == 0)
+	if (m_KEY.empty())
 		return;
 
 	std::string sResult;
@@ -95,14 +91,14 @@ void CPVOutputInput::GetMeterDetails()
 	sstr << "https://pvoutput.org/service/r2/getstatus.jsp?sid=" << m_SID << "&key=" << m_KEY;
 	if (!HTTPClient::GET(sstr.str(), sResult))
 	{
-		_log.Log(LOG_ERROR, "PVOutput (Input): Error login!");
+		Log(LOG_ERROR, "Error login!");
 		return;
 	}
 	std::vector<std::string> splitresult;
 	StringSplit(sResult, ",", splitresult);
 	if (splitresult.size() < 9)
 	{
-		_log.Log(LOG_ERROR, "PVOutput (Input): Invalid Data received!");
+		Log(LOG_ERROR, "Invalid Data received!");
 		return;
 	}
 	/*
@@ -159,13 +155,13 @@ void CPVOutputInput::GetMeterDetails()
 	sstr << "https://pvoutput.org/service/r2/getstatistic.jsp?sid=" << m_SID << "&key=" << m_KEY << "&c=1&df=19700101&dt=26000101";
 	if (!HTTPClient::GET(sstr.str(), sResult))
 	{
-		_log.Log(LOG_ERROR, "PVOutput (Input): Error login!");
+		Log(LOG_ERROR, "Error login!");
 		return;
 	}
 	StringSplit(sResult, ",", splitresult);
 	if (splitresult.size() < 11)
 	{
-		_log.Log(LOG_ERROR, "PVOutput (Input): Invalid Data received!");
+		Log(LOG_ERROR, "Invalid Data received!");
 		return;
 	}
 /*
