@@ -14,24 +14,27 @@ class CPinger : public CDomoticzHardwareBase
 		time_t LastOK;
 		int SensorTimeoutSec;
 	};
-public:
-	CPinger(const int ID, const int PollIntervalsec, const int PingTimeoutms);
-	~CPinger(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-	void AddNode(const std::string &Name, const std::string &IPAddress, const int Timeout);
-	bool UpdateNode(const int ID, const std::string &Name, const std::string &IPAddress, const int Timeout);
-	void RemoveNode(const int ID);
+
+      public:
+	CPinger(int ID, int PollIntervalsec, int PingTimeoutms);
+	~CPinger() override;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+	void AddNode(const std::string &Name, const std::string &IPAddress, int Timeout);
+	bool UpdateNode(int ID, const std::string &Name, const std::string &IPAddress, int Timeout);
+	void RemoveNode(int ID);
 	void RemoveAllNodes();
-	void SetSettings(const int PollIntervalsec, const int PingTimeoutms);
-private:
+	void SetSettings(int PollIntervalsec, int PingTimeoutms);
+
+      private:
 	void Do_Work();
 	bool StartHardware() override;
 	bool StopHardware() override;
 	void DoPingHosts();
 	void Do_Ping_Worker(const PingNode &Node);
-	void UpdateNodeStatus(const PingNode &Node, const bool bPingOK);
+	void UpdateNodeStatus(const PingNode &Node, bool bPingOK);
 	void ReloadNodes();
-private:
+
+      private:
 	int m_iThreadsRunning;
 	int m_iPollInterval;
 	int m_iPingTimeoutms;
@@ -39,4 +42,3 @@ private:
 	std::shared_ptr<std::thread> m_thread;
 	std::mutex m_mutex;
 };
-
