@@ -19,26 +19,28 @@
 
 #define round(a) ( int ) ( a + .5 )
 
-typedef struct tSatelModel {
+using SatelModel = struct
+{
 	unsigned int id;
 	const char* name;
 	unsigned int zones;
 	unsigned int outputs;
-} SatelModel;
+};
 
 #define TOT_MODELS 9
 
-static SatelModel models[TOT_MODELS] =
-{
-	{ 0, "Integra 24", 24, 20 },
-	{ 1, "Integra 32", 32, 32 },
-	{ 2, "Integra 64", 64, 64 },
-	{ 3, "Integra 128", 128, 128 },
-	{ 4, "Integra 128 WRL SIM300", 128, 128 },
-	{ 132, "Integra 128 WRL LEON", 128, 128 },
-	{ 66, "Integra 64 Plus", 64, 64 },
-	{ 67, "Integra 128 Plus", 128, 128 },
-	{ 72, "Integra 256 Plus", 256, 256 },
+constexpr std::array<SatelModel, TOT_MODELS> models{
+	{
+		{ 0, "Integra 24", 24, 20 },		   //
+		{ 1, "Integra 32", 32, 32 },		   //
+		{ 2, "Integra 64", 64, 64 },		   //
+		{ 3, "Integra 128", 128, 128 },		   //
+		{ 4, "Integra 128 WRL SIM300", 128, 128 }, //
+		{ 132, "Integra 128 WRL LEON", 128, 128 }, //
+		{ 66, "Integra 64 Plus", 64, 64 },	   //
+		{ 67, "Integra 128 Plus", 128, 128 },	   //
+		{ 72, "Integra 256 Plus", 256, 256 },	   //
+	}						   //
 };
 
 #define MAX_LENGTH_OF_ANSWER 63 * 2 + 4 + 1
@@ -51,25 +53,17 @@ SatelIntegra::SatelIntegra(const int ID, const std::string &IPAddress, const uns
 	m_IPAddress(IPAddress),
 	m_pollInterval(pollInterval)
 {
-	_log.Log(LOG_STATUS, "Satel Integra: Create instance");
+	Log(LOG_STATUS, "Create instance");
 	m_HwdID = ID;
 	memset(m_newData, 0, sizeof(m_newData));
 
 	// clear last local state of zones and outputs
-	for (unsigned int i = 0; i < 256; ++i)
-	{
-		m_zonesLastState[i] = false;
-		m_outputsLastState[i] = false;
-		m_isOutputSwitch[i] = false;
-		m_isTemperature[i] = false;
-	}
-
-	for (unsigned int i = 0; i < 32; ++i)
-	{
-		m_isPartitions[i] = false;
-		m_armLastState[i] = false;
-	}
-
+	m_zonesLastState = {};
+	m_outputsLastState = {};
+	m_isOutputSwitch = {};
+	m_isTemperature = {};
+	m_isPartitions = {};
+	m_armLastState = {};
 	m_alarmLast = false;
 
 	errorCodes[1] = "requesting user code not found";
@@ -84,9 +78,9 @@ SatelIntegra::SatelIntegra(const int ID, const std::string &IPAddress, const uns
 	errorCodes[18] = "can not arm";
 
 	// decode user code from string to BCD
-	if (userCode.size() == 0)
+	if (userCode.empty())
 	{
-		_log.Log(LOG_STATUS, "Satel Integra: no user code was entered (arm/disarm/switching will not work)");
+		Log(LOG_STATUS, "no user code was entered (arm/disarm/switching will not work)");
 	}
 
 	uint64_t result(0);
@@ -118,7 +112,7 @@ SatelIntegra::SatelIntegra(const int ID, const std::string &IPAddress, const uns
 
 SatelIntegra::~SatelIntegra()
 {
-	_log.Log(LOG_STATUS, "Satel Integra: Destroy instance");
+	Log(LOG_STATUS, "Destroy instance");
 }
 
 bool SatelIntegra::StartHardware()
@@ -126,7 +120,7 @@ bool SatelIntegra::StartHardware()
 	RequestStart();
 
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: Start hardware");
+	Log(LOG_STATUS, "Start hardware");
 #endif
 
 	if (!CheckAddress())
@@ -134,7 +128,7 @@ bool SatelIntegra::StartHardware()
 		return false;
 	}
 
-	m_thread = std::make_shared<std::thread>(&SatelIntegra::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadNameInt(m_thread->native_handle());
 	m_bIsStarted = true;
 	sOnConnected(this);
@@ -158,7 +152,7 @@ void SatelIntegra::Do_Work()
 	if (!GetInfo())
 		return;
 
-	_log.Log(LOG_STATUS, "Satel Integra: worker started");
+	Log(LOG_STATUS, "worker started");
 
 	ReadZonesState(true);
 	ReadAlarm(true);
@@ -182,7 +176,7 @@ void SatelIntegra::Do_Work()
 		heartbeatInterval += interval;
 
 		if (heartbeatInterval >= HEARTBEAT_INTERVAL_MS) {
-			m_LastHeartbeat = mytime(NULL);
+			m_LastHeartbeat = mytime(nullptr);
 			heartbeatInterval = 0;
 		}
 
@@ -190,7 +184,7 @@ void SatelIntegra::Do_Work()
 		{
 			msec_poll_counter = 0;
 #ifdef DEBUG_SatelIntegra
-			_log.Log(LOG_STATUS, "Satel Integra: fetching changed data");
+			Log(LOG_STATUS, "fetching changed data");
 #endif
 
 			if (ReadNewData())
@@ -221,20 +215,20 @@ void SatelIntegra::Do_Work()
 		{
 			msec_temp_counter = 0;
 #ifdef DEBUG_SatelIntegra
-			_log.Log(LOG_STATUS, "Satel Integra: fetching temperature");
+			Log(LOG_STATUS, "fetching temperature");
 #endif
 			ReadTemperatures();
 		}
 	}//while (!IsStopRequested())
 	DestroySocket();
-	_log.Log(LOG_STATUS, "Satel Integra: worker stopped");
+	Log(LOG_STATUS, "worker stopped");
 }
 
 bool SatelIntegra::CheckAddress()
 {
-	if (m_IPAddress.size() == 0 || m_IPPort < 1 || m_IPPort > 65535)
+	if (m_IPAddress.empty() || m_IPPort < 1 || m_IPPort > 65535)
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Empty IP Address or bad Port");
+		Log(LOG_ERROR, "Empty IP Address or bad Port");
 		return false;
 	}
 
@@ -251,15 +245,12 @@ bool SatelIntegra::CheckAddress()
 	else
 	{
 		hostent *he = gethostbyname(m_IPAddress.c_str());
-		if (he == NULL)
+		if (he == nullptr)
 		{
-			_log.Log(LOG_ERROR, "Satel Integra: cannot resolve host name");
+			Log(LOG_ERROR, "cannot resolve host name");
 			return false;
 		}
-		else
-		{
-			memcpy(&(m_addr.sin_addr), he->h_addr_list[0], 4);
-		}
+		memcpy(&(m_addr.sin_addr), he->h_addr_list[0], 4);
 	}
 	return true;
 }
@@ -272,13 +263,13 @@ bool SatelIntegra::ConnectToIntegra()
 	m_socket = socket(AF_INET, SOCK_STREAM, 0);
 	if (m_socket == INVALID_SOCKET)
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Unable to create socket");
+		Log(LOG_ERROR, "Unable to create socket");
 		return false;
 	}
 
 	if (connect(m_socket, (const sockaddr*)&m_addr, sizeof(m_addr)) == SOCKET_ERROR)
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Unable to connect to specified IP Address on specified Port (%s:%d)", m_IPAddress.c_str(), m_IPPort);
+		Log(LOG_ERROR, "Unable to connect to specified IP Address on specified Port (%s:%d)", m_IPAddress.c_str(), m_IPPort);
 		DestroySocket();
 		return false;
 	}
@@ -289,7 +280,7 @@ bool SatelIntegra::ConnectToIntegra()
 #else
 	fcntl(m_socket, F_SETFL, O_NONBLOCK);
 #endif
-	_log.Log(LOG_STATUS, "Satel Integra: connected to %s:%d", m_IPAddress.c_str(), m_IPPort);
+	Log(LOG_STATUS, "connected to %s:%d", m_IPAddress.c_str(), m_IPPort);
 
 	return true;
 }
@@ -299,7 +290,7 @@ void SatelIntegra::DestroySocket()
 	if (m_socket != INVALID_SOCKET)
 	{
 #ifdef DEBUG_SatelIntegra
-		_log.Log(LOG_STATUS, "Satel Integra: destroy socket");
+		Log(LOG_STATUS, "destroy socket");
 #endif
 		closesocket(m_socket);
 		m_socket = INVALID_SOCKET;
@@ -314,11 +305,8 @@ bool SatelIntegra::ReadNewData()
 	{
 		return true;
 	}
-	else
-	{
-		_log.Log(LOG_ERROR, "Satel Integra: Get info about new data is failed");
-	}
 
+	Log(LOG_ERROR, "Get info about new data is failed");
 	return false;
 }
 
@@ -340,13 +328,13 @@ bool SatelIntegra::GetInfo()
 		}
 		if (m_modelIndex > -1)
 		{
-			_log.Log(LOG_STATUS, "Satel Integra: Model %s", models[m_modelIndex].name);
+			Log(LOG_STATUS, "Model %s", models[m_modelIndex].name);
 
 			unsigned char cmd[1];
 			cmd[0] = 0x1A; // RTC
 			if (SendCommand(cmd, 1, buffer, 10) > 0)
 			{
-				_log.Log(LOG_STATUS, "Satel Integra: RTC %.2x%.2x-%.2x-%.2x %.2x:%.2x:%.2x",
+				Log(LOG_STATUS, "RTC %.2x%.2x-%.2x-%.2x %.2x:%.2x:%.2x",
 					buffer[1], buffer[2], buffer[3], buffer[4], buffer[5], buffer[6], buffer[7]);
 
 				unsigned char cmd[1];
@@ -355,28 +343,25 @@ bool SatelIntegra::GetInfo()
 				{
 					m_data32 = ((buffer[12] & 1) == 1) && (m_modelIndex == 72); // supported and required 256 PLUS
 
-					_log.Log(LOG_STATUS, "Satel Integra: ETHM-1 ver. %c.%c%c %c%c%c%c-%c%c-%c%c (32 bytes mode = %s)",
+					Log(LOG_STATUS, "ETHM-1 ver. %c.%c%c %c%c%c%c-%c%c-%c%c (32 bytes mode = %s)",
 						buffer[1], buffer[2], buffer[3], buffer[4], buffer[5], buffer[6], buffer[7], buffer[8], buffer[9], buffer[10], buffer[11], m_data32 ? "true" : "false");
 					return true;
 				}
-				else
-				{
-					_log.Log(LOG_ERROR, "Satel Integra: unknown version of ETHM-1");
-				}
+				Log(LOG_ERROR, "unknown version of ETHM-1");
 			}
 			else
 			{
-				_log.Log(LOG_ERROR, "Satel Integra: Unknown basic status");
+				Log(LOG_ERROR, "Unknown basic status");
 			}
 		}
 		else
 		{
-			_log.Log(LOG_ERROR, "Satel Integra: Unknown model '%02x'", buffer[0]);
+			Log(LOG_ERROR, "Unknown model '%02x'", buffer[0]);
 		}
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Get info about Integra is failed");
+		Log(LOG_ERROR, "Get info about Integra is failed");
 	}
 
 	return false;
@@ -390,7 +375,7 @@ bool SatelIntegra::ReadZonesState(const bool firstTime)
 	}
 
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: Read zones states");
+	Log(LOG_STATUS, "Read zones states");
 #endif
 	unsigned char buffer[33];
 
@@ -418,11 +403,11 @@ bool SatelIntegra::ReadZonesState(const bool firstTime)
 
 				if (firstTime)
 				{
-					m_LastHeartbeat = mytime(NULL);
+					m_LastHeartbeat = mytime(nullptr);
 
 					unsigned char buffer[21];
 #ifdef DEBUG_SatelIntegra
-					_log.Log(LOG_STATUS, "Satel Integra: Reading zone %d name", index + 1);
+					Log(LOG_STATUS, "Reading zone %d name", index + 1);
 #endif
 					unsigned char cmd[3];
 					cmd[0] = 0xEE;
@@ -436,7 +421,7 @@ bool SatelIntegra::ReadZonesState(const bool firstTime)
 					}
 					else
 					{
-						_log.Log(LOG_ERROR, "Satel Integra: Receive info about zone %d failed (probably zone is not used)", index + 1);
+						Log(LOG_ERROR, "Receive info about zone %d failed (probably zone is not used)", index + 1);
 					}
 				}
 				else if (m_zonesLastState[index] != violate)
@@ -449,7 +434,7 @@ bool SatelIntegra::ReadZonesState(const bool firstTime)
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Send 'Read Outputs' failed");
+		Log(LOG_ERROR, "Send 'Read Outputs' failed");
 		return false;
 	}
 
@@ -465,7 +450,7 @@ bool SatelIntegra::ReadTemperatures(const bool firstTime)
 
 	// Read temperatures from ATD100
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: Read zones temperatures");
+	Log(LOG_STATUS, "Read zones temperatures");
 #endif
 
 	unsigned char buffer[33];
@@ -480,7 +465,7 @@ bool SatelIntegra::ReadTemperatures(const bool firstTime)
 		if ((m_isTemperature[index]) && (!IsStopRequested(0)))
 		{
 #ifdef DEBUG_SatelIntegra
-			_log.Log(LOG_STATUS, "Satel Integra: Reading zone %d temperature", index + 1);
+			Log(LOG_STATUS, "Reading zone %d temperature", index + 1);
 #endif
 			unsigned char cmd[2];
 			cmd[0] = 0x7D; // read zone temperature
@@ -493,11 +478,11 @@ bool SatelIntegra::ReadTemperatures(const bool firstTime)
 				{
 					if (firstTime)
 					{
-						m_LastHeartbeat = mytime(NULL);
+						m_LastHeartbeat = mytime(nullptr);
 
 						unsigned char buffer[21];
 #ifdef DEBUG_SatelIntegra
-						_log.Log(LOG_STATUS, "Satel Integra: Reading temperature zone %d name", index + 1);
+						Log(LOG_STATUS, "Reading temperature zone %d name", index + 1);
 #endif
 						unsigned char cmd[3];
 						cmd[0] = 0xEE;
@@ -510,7 +495,7 @@ bool SatelIntegra::ReadTemperatures(const bool firstTime)
 						}
 						else
 						{
-							_log.Log(LOG_ERROR, "Satel Integra: Receive info about zone %d failed", index + 1);
+							Log(LOG_ERROR, "Receive info about zone %d failed", index + 1);
 						}
 					}
 					else
@@ -522,7 +507,7 @@ bool SatelIntegra::ReadTemperatures(const bool firstTime)
 
 			else
 			{
-				_log.Log(LOG_ERROR, "Satel Integra: Send 'Read Temperature' failed");
+				Log(LOG_ERROR, "Send 'Read Temperature' failed");
 				return false;
 			}
 		}
@@ -537,7 +522,7 @@ bool SatelIntegra::ReadOutputsState(const bool firstTime)
 		return false;
 	}
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: Read outputs states");
+	Log(LOG_STATUS, "Read outputs states");
 #endif
 	unsigned char buffer[33];
 
@@ -567,7 +552,7 @@ bool SatelIntegra::ReadOutputsState(const bool firstTime)
 				if (firstTime)
 				{
 #ifdef DEBUG_SatelIntegra
-					_log.Log(LOG_STATUS, "Satel Integra: Reading output %d name", index + 1);
+					Log(LOG_STATUS, "Reading output %d name", index + 1);
 #endif
 					unsigned char buffer[21];
 					unsigned char cmd[3];
@@ -600,13 +585,13 @@ bool SatelIntegra::ReadOutputsState(const bool firstTime)
 						else
 						{
 #ifdef DEBUG_SatelIntegra
-							_log.Log(LOG_STATUS, "Satel Integra: output %d is not used", index + 1);
+							Log(LOG_STATUS, "output %d is not used", index + 1);
 #endif
 						}
 					}
 					else
 					{
-						_log.Log(LOG_ERROR, "Satel Integra: Receive info about output %d failed", index);
+						Log(LOG_ERROR, "Receive info about output %d failed", index);
 					}
 				}
 				else if (m_outputsLastState[index] != outputState)
@@ -618,7 +603,7 @@ bool SatelIntegra::ReadOutputsState(const bool firstTime)
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Send 'Read outputs' failed");
+		Log(LOG_ERROR, "Send 'Read outputs' failed");
 		return false;
 	}
 
@@ -628,7 +613,7 @@ bool SatelIntegra::ReadOutputsState(const bool firstTime)
 bool SatelIntegra::ReadArmState(const bool firstTime)
 {
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: Read arm state");
+	Log(LOG_STATUS, "Read arm state");
 #endif
 	unsigned char buffer[5];
 
@@ -646,11 +631,11 @@ bool SatelIntegra::ReadArmState(const bool firstTime)
 			{
 				if (armed)
 				{
-					_log.Log(LOG_STATUS, "Satel Integra: partition %d arm", index + 1);
+					Log(LOG_STATUS, "partition %d arm", index + 1);
 				}
 				else
 				{
-					_log.Log(LOG_STATUS, "Satel Integra: partition %d not arm", index + 1);
+					Log(LOG_STATUS, "partition %d not arm", index + 1);
 				}
 
 				ReportArmState(index + 1, armed);
@@ -659,7 +644,7 @@ bool SatelIntegra::ReadArmState(const bool firstTime)
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Send 'Get Armed partitions' failed");
+		Log(LOG_ERROR, "Send 'Get Armed partitions' failed");
 		return false;
 	}
 
@@ -669,7 +654,7 @@ bool SatelIntegra::ReadArmState(const bool firstTime)
 bool SatelIntegra::ReadAlarm(const bool firstTime)
 {
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: Read partitions alarms");
+	Log(LOG_STATUS, "Read partitions alarms");
 #endif
 	unsigned char buffer[5];
 
@@ -692,11 +677,11 @@ bool SatelIntegra::ReadAlarm(const bool firstTime)
 		{
 			if (alarm)
 			{
-				_log.Log(LOG_STATUS, "Satel Integra: ALARM !!");
+				Log(LOG_STATUS, "ALARM !!");
 			}
 			else
 			{
-				_log.Log(LOG_STATUS, "Satel Integra: Alarm not set");
+				Log(LOG_STATUS, "Alarm not set");
 			}
 
 			ReportAlarm(alarm);
@@ -704,7 +689,7 @@ bool SatelIntegra::ReadAlarm(const bool firstTime)
 	}
 	else
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Send 'Get Alarm partitions' failed");
+		Log(LOG_ERROR, "Send 'Get Alarm partitions' failed");
 		return false;
 	}
 
@@ -714,7 +699,7 @@ bool SatelIntegra::ReadAlarm(const bool firstTime)
 bool SatelIntegra::ReadEvents()
 {
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: Read events");
+	Log(LOG_STATUS, "Read events");
 #endif
 	unsigned char buffer[15];
 
@@ -746,7 +731,7 @@ bool SatelIntegra::ReadEvents()
 
 void SatelIntegra::ReportZonesViolation(const int Idx, const bool violation)
 {
-	_log.Debug(DEBUG_HARDWARE, "Satel Integra: Report Zone %d = %d", Idx, violation ? 3 : 1);
+	Debug(DEBUG_HARDWARE, "Report Zone %d = %d", Idx, violation ? 3 : 1);
 
 	m_zonesLastState[Idx - 1] = violation;
 
@@ -759,15 +744,14 @@ void SatelIntegra::ReportOutputState(const int Idx, const bool state)
 
 	if ((Idx > 1024) || m_isOutputSwitch[Idx - 1])
 	{
-		SendGeneralSwitch(Idx, 1, 255, state ? gswitch_sOn : gswitch_sOff, 0, "");
+		SendGeneralSwitch(Idx, 1, 255, state ? gswitch_sOn : gswitch_sOff, 0, "", m_Name);
 	}
 	else
 	{
-		char szTmp[10];
-		sprintf(szTmp, "%08X", (int)Idx);
+		std::string sTmp = fmt::format("{:08X}", Idx);
 		std::string devname;
 
-		m_sql.UpdateValue(m_HwdID, szTmp, 1, pTypeGeneral, sTypeTextStatus, 12, 255, 0, state ? "On" : "Off", devname);
+		m_sql.UpdateValue(m_HwdID, sTmp.c_str(), 1, pTypeGeneral, sTypeTextStatus, 12, 255, 0, state ? "On" : "Off", devname);
 	}
 }
 
@@ -775,7 +759,7 @@ void SatelIntegra::ReportArmState(const int Idx, const bool isArm)
 {
 	m_armLastState[Idx - 1] = isArm;
 
-	SendGeneralSwitch(Idx, 2, 255, isArm ? gswitch_sOn : gswitch_sOff, 0, "");
+	SendGeneralSwitch(Idx, 2, 255, isArm ? gswitch_sOn : gswitch_sOff, 0, "", m_Name);
 }
 
 void SatelIntegra::ReportAlarm(const bool isAlarm)
@@ -797,11 +781,11 @@ void SatelIntegra::ReportTemperature(const int Idx, const int temp)
 bool SatelIntegra::ArmPartitions(const int partition, const int mode)
 {
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: arming partition %d", partition);
+	Log(LOG_STATUS, "arming partition %d", partition);
 #endif
 	if (mode > 3)
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: incorrect arm mode %d", mode);
+		Log(LOG_ERROR, "incorrect arm mode %d", mode);
 		return false;
 	}
 
@@ -821,19 +805,19 @@ bool SatelIntegra::ArmPartitions(const int partition, const int mode)
 
 	if (SendCommand(cmd, 13, buffer, 1) == -1) // arm
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Send 'Arm partition %d' failed", partition);
+		Log(LOG_ERROR, "Send 'Arm partition %d' failed", partition);
 		return false;
 	}
 
 	m_armLastState[partition - 1] = true;
-	_log.Log(LOG_STATUS, "Satel Integra: Partition %d armed", partition);
+	Log(LOG_STATUS, "Partition %d armed", partition);
 	return true;
 }
 
 bool SatelIntegra::DisarmPartitions(const int partition)
 {
 #ifdef DEBUG_SatelIntegra
-	_log.Log(LOG_STATUS, "Satel Integra: disarming partition %d", partition);
+	Log(LOG_STATUS, "disarming partition %d", partition);
 #endif
 
 	unsigned char buffer[2];
@@ -852,12 +836,12 @@ bool SatelIntegra::DisarmPartitions(const int partition)
 
 	if (SendCommand(cmd, 13, buffer, 1) == -1) // disarm
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Send 'Disarm partition %d' failed", partition);
+		Log(LOG_ERROR, "Send 'Disarm partition %d' failed", partition);
 		return false;
 	}
 
 	m_armLastState[partition - 1] = false;
-	_log.Log(LOG_STATUS, "Satel Integra: Partition %d disarmed", partition);
+	Log(LOG_STATUS, "Partition %d disarmed", partition);
 	return true;
 }
 
@@ -874,12 +858,9 @@ bool SatelIntegra::WriteToHardware(const char *pdata, const unsigned char length
 			{
 				return ArmPartitions(general->id);
 			}
-			else
-			{
-				return DisarmPartitions(general->id);
-			}
+			return DisarmPartitions(general->id);
 		}
-		else if (general->unitcode == 1) // outputs
+		if (general->unitcode == 1) // outputs
 		{
 			unsigned char buffer[2];
 			unsigned char cmd[41] = { 0 };
@@ -922,15 +903,11 @@ bool SatelIntegra::WriteToHardware(const char *pdata, const unsigned char length
 				{
 					m_outputsLastState[id - 1] = cmnd == gswitch_sOn ? true : false;
 				}
-				_log.Log(LOG_STATUS, "Satel Integra: switched output %d to %s", id, cmnd == gswitch_sOn ? "on" : "off");
+				Log(LOG_STATUS, "switched output %d to %s", id, cmnd == gswitch_sOn ? "on" : "off");
 				return true;
 			}
-			else
-			{
-				_log.Log(LOG_ERROR, "Satel Integra: Switch output %d failed", id);
-				return false;
-			}
-
+			Log(LOG_ERROR, "Switch output %d failed", id);
+			return false;
 		}
 	}
 
@@ -943,12 +920,12 @@ std::string SatelIntegra::ISO2UTF8(const std::string &name)
 	char utf8[] = "\xC4\x85\xC4\x87\xC4\x99\xC5\x82\xC5\x84\xC3\xB3\xC5\x9B\xC5\xBA\xC5\xBC\xC4\x84\xC4\x86\xC4\x98\xC5\x81\xC5\x83\xC3\x93\xC5\x9A\xC5\xB9\xC5\xBB";
 
 	std::string UTF8Name;
-	for (size_t i = 0; i < name.length(); ++i)
+	for (char i : name)
 	{
 		bool changed = false;
 		for (int j = 0; j < sizeof(cp1250); ++j)
 		{
-			if (name[i] == cp1250[j])
+			if (i == cp1250[j])
 			{
 				UTF8Name += utf8[j * 2];
 				UTF8Name += utf8[j * 2 + 1];
@@ -958,7 +935,7 @@ std::string SatelIntegra::ISO2UTF8(const std::string &name)
 		}
 		if (!changed)
 		{
-			UTF8Name += name[i];
+			UTF8Name += i;
 		}
 	}
 	return UTF8Name;
@@ -968,8 +945,7 @@ void SatelIntegra::UpdateZoneName(const int Idx, const unsigned char* name, cons
 {
 	std::vector<std::vector<std::string> > result;
 
-	char szTmp[4];
-	sprintf(szTmp, "%d", (int)Idx);
+	std::string sTmp = fmt::format("{}", Idx);
 
 	std::string shortName((char*)name, 16);
 	std::string::size_type pos = shortName.find_last_not_of(' ');
@@ -983,14 +959,15 @@ void SatelIntegra::UpdateZoneName(const int Idx, const unsigned char* name, cons
 		namePrefix = "Temp";
 	}
 
-	result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Name!='Unknown') AND (Unit=1)", m_HwdID, szTmp);
+	result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Name!='Unknown') AND (Unit=1)", m_HwdID, sTmp.c_str());
 	if (result.empty())
 	{
 		//Assign zone name from Integra
 #ifdef DEBUG_SatelIntegra
-		_log.Log(LOG_STATUS, "Satel Integra: update name for %d to '%s:%s'", Idx, namePrefix.c_str(), shortName.c_str());
+		Log(LOG_STATUS, "update name for %d to '%s:%s'", Idx, namePrefix.c_str(), shortName.c_str());
 #endif
-		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q:%q', SwitchType=%d, Unit=%d WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit=1)", namePrefix.c_str(), shortName.c_str(), STYPE_Contact, partition, m_HwdID, szTmp);
+		m_sql.safe_query("UPDATE DeviceStatus SET Name='%q:%q', SwitchType=%d, Unit=%d WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit=1)", namePrefix.c_str(), shortName.c_str(),
+				 STYPE_Contact, partition, m_HwdID, sTmp.c_str());
 	}
 }
 
@@ -998,22 +975,22 @@ void SatelIntegra::UpdateTempName(const int Idx, const unsigned char* name, cons
 {
 	std::vector<std::vector<std::string> > result;
 
-	char szTmp[4];
-	sprintf(szTmp, "%d", (int)Idx);
+	std::string sTmp = fmt::format("{}", Idx);
 
 	std::string shortName((char*)name, 16);
 	std::string::size_type pos = shortName.find_last_not_of(' ');
 	shortName.erase(pos + 1);
 	shortName = ISO2UTF8(shortName);
 
-	result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Name!='Unknown') AND (Unit=0)", m_HwdID, szTmp);
+	result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Name!='Unknown') AND (Unit=0)", m_HwdID, sTmp.c_str());
 	if (result.empty())
 	{
 		//Assign zone name from Integra
 #ifdef DEBUG_SatelIntegra
-		_log.Log(LOG_STATUS, "Satel Integra: update name for %d to 'Temp:%s'", Idx, shortName.c_str());
+		Log(LOG_STATUS, "update name for %d to 'Temp:%s'", Idx, shortName.c_str());
 #endif
-		m_sql.safe_query("UPDATE DeviceStatus SET Name='Temp:%q', SwitchType=%d, Unit=%d WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit=0)", shortName.c_str(), STYPE_Contact, partition, m_HwdID, szTmp);
+		m_sql.safe_query("UPDATE DeviceStatus SET Name='Temp:%q', SwitchType=%d, Unit=%d WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit=0)", shortName.c_str(), STYPE_Contact, partition,
+				 m_HwdID, sTmp.c_str());
 	}
 }
 
@@ -1021,8 +998,7 @@ void SatelIntegra::UpdateOutputName(const int Idx, const unsigned char* name, co
 {
 	std::vector<std::vector<std::string> > result;
 
-	char szTmp[10];
-	sprintf(szTmp, "%08X", (int)Idx);
+	std::string sTmp = fmt::format("{:08X}", Idx);
 
 	std::string shortName((char*)name, 16);
 
@@ -1035,15 +1011,16 @@ void SatelIntegra::UpdateOutputName(const int Idx, const unsigned char* name, co
 	shortName.erase(pos + 1);
 	shortName = ISO2UTF8(shortName);
 
-	result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Name!='Unknown') AND (Unit=1)", m_HwdID, szTmp);
+	result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Name!='Unknown') AND (Unit=1)", m_HwdID, sTmp.c_str());
 	if (result.empty())
 	{
 		//Assign output name from Integra
 #ifdef DEBUG_SatelIntegra
-		_log.Log(LOG_STATUS, "Satel Integra: update name for %d to '%s'", Idx, shortName.c_str());
+		Log(LOG_STATUS, "update name for %d to '%s'", Idx, shortName.c_str());
 #endif
 
-		m_sql.safe_query("UPDATE DeviceStatus SET Name='Output:%q', SwitchType=%d WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit=1)", shortName.c_str(), switchType, m_HwdID, szTmp);
+		m_sql.safe_query("UPDATE DeviceStatus SET Name='Output:%q', SwitchType=%d WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit=1)", shortName.c_str(), switchType, m_HwdID,
+				 sTmp.c_str());
 	}
 }
 
@@ -1057,26 +1034,25 @@ void SatelIntegra::UpdateAlarmAndArmName()
 	{
 		//Assign name for Alarm
 #ifdef DEBUG_SatelIntegra
-		_log.Log(LOG_STATUS, "Satel Integra: update Alarm name to 'Alarm'");
+		Log(LOG_STATUS, "update Alarm name to 'Alarm'");
 #endif
 		m_sql.safe_query("UPDATE DeviceStatus SET Name='Alarm' WHERE (HardwareID==%d) AND (DeviceID=='Alarm') AND (Unit=2)", m_HwdID);
 	}
 
 	//Arm
-	for (unsigned int i = 0; i < 32; ++i)
+	for (size_t i = 0; m_isPartitions.size(); ++i)
 	{
 		if (m_isPartitions[i])
 		{
-			char szTmp[10];
-			sprintf(szTmp, "%08X", (int)i + 1);
-			result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Name!='Unknown') AND (Unit=2)", m_HwdID, szTmp, i + 1);
+			std::string sTmp = fmt::format("{:08X}", i + 1);
+			result = m_sql.safe_query("SELECT Name FROM DeviceStatus WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Name!='Unknown') AND (Unit=2)", m_HwdID, sTmp.c_str(), i + 1);
 			if (result.empty())
 			{
 				//Assign name for Arm
 #ifdef DEBUG_SatelIntegra
-				_log.Log(LOG_STATUS, "Satel Integra: update Arm name to 'Arm %d partition'", i + 1);
+				Log(LOG_STATUS, "update Arm name to 'Arm %d partition'", i + 1);
 #endif
-				m_sql.safe_query("UPDATE DeviceStatus SET Name='Arm %d partition' WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit=2)", i + 1, m_HwdID, szTmp);
+				m_sql.safe_query("UPDATE DeviceStatus SET Name='Arm %d partition' WHERE (HardwareID==%d) AND (DeviceID=='%q') AND (Unit=2)", i + 1, m_HwdID, sTmp.c_str());
 			}
 		}
 	}
@@ -1092,8 +1068,7 @@ void expandForSpecialValue(std::list<unsigned char> &result)
 	{
 		if (*it == specialValue)
 		{
-			result.insert(++it, 0xF0);
-			it--;
+			it = result.insert(++it, 0xF0);
 		}
 	}
 }
@@ -1127,7 +1102,7 @@ int SatelIntegra::SendCommand(const unsigned char* cmd, const unsigned int cmdLe
 	//Send cmd
 	if (send(m_socket, (const char*)cmdPayload.first, cmdPayload.second, 0) < 0)
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: Send command '%02X' failed", cmdPayload.first[2]);
+		Log(LOG_ERROR, "Send command '%02X' failed", cmdPayload.first[2]);
 		DestroySocket();
 		delete[] cmdPayload.first;
 		return -1;
@@ -1144,9 +1119,9 @@ int SatelIntegra::SendCommand(const unsigned char* cmd, const unsigned int cmdLe
 	struct timeval tv;
 	tv.tv_sec = 3;
 	tv.tv_usec = 0;
-	if (select(m_socket + 1, &rfds, NULL, NULL, &tv) < 0)
+	if (select(m_socket + 1, &rfds, nullptr, nullptr, &tv) < 0)
 	{
-		_log.Log(LOG_ERROR, "Satel Integra: connection lost.");
+		Log(LOG_ERROR, "connection lost.");
 		DestroySocket();
 		return -1;
 	}
@@ -1158,7 +1133,7 @@ int SatelIntegra::SendCommand(const unsigned char* cmd, const unsigned int cmdLe
 		totalRet += ret;
 		if ((ret <= 0) || (totalRet >= MAX_LENGTH_OF_ANSWER))
 		{
-			_log.Log(LOG_ERROR, "Satel Integra: bad data length received (totalRet %d)", totalRet);
+			Log(LOG_ERROR, "bad data length received (totalRet %d)", totalRet);
 			DestroySocket();
 			return -1;
 		}
@@ -1183,7 +1158,7 @@ int SatelIntegra::SendCommand(const unsigned char* cmd, const unsigned int cmdLe
 		{
 			if ((buffer[2] != 0xEF) && ((totalRet - 6) != expectedLength))
 			{
-				_log.Log(LOG_ERROR, "Satel Integra: bad data length received (expectedLength %d, totalRet %d, cmd %X, cmdLength %d)", expectedLength, totalRet - 6, cmd[0], cmdLength);
+				Log(LOG_ERROR, "bad data length received (expectedLength %d, totalRet %d, cmd %X, cmdLength %d)", expectedLength, totalRet - 6, cmd[0], cmdLength);
 				DestroySocket();
 				return -1;
 			}
@@ -1205,52 +1180,32 @@ int SatelIntegra::SendCommand(const unsigned char* cmd, const unsigned int cmdLe
 					{
 						return 0;
 					}
-					else
-					{
-						const char* error = "other errors";
+					const char *error = "other errors";
 
-						std::map<unsigned int, const char*>::iterator it;
-						it = errorCodes.find(buffer[3]);
-						if (it != errorCodes.end())
-						{
-							error = it->second;
-						}
-						_log.Log(LOG_ERROR, "Satel Integra: receive error: %s", error);
-						return -1;
+					auto it = errorCodes.find(buffer[3]);
+					if (it != errorCodes.end())
+					{
+						error = it->second;
 					}
+					Log(LOG_ERROR, "receive error: %s", error);
+					return -1;
 				}
-				else
-				{
-					return answerLength;
-				}
-			}
-			else
-			{
-				_log.Log(LOG_ERROR, "Satel Integra: receive bad CRC");
-				return -1;
+				return answerLength;
 			}
+			Log(LOG_ERROR, "receive bad CRC");
+			return -1;
 		}
-		else
+		if (buffer[0] == 16)
 		{
-			if (buffer[0] == 16)
-			{
-				_log.Log(LOG_ERROR, "Satel Integra: busy");
-				return -1;
-			}
-			else
-			{
-				_log.Log(LOG_ERROR, "Satel Integra: received bad frame (prefix or sufix)");
-				return -1;
-			}
+			Log(LOG_ERROR, "busy");
+			return -1;
 		}
-	}
-	else
-	{
-		_log.Log(LOG_ERROR, "Satel Integra: received frame is too short.");
-		DestroySocket();
+		Log(LOG_ERROR, "received bad frame (prefix or sufix)");
 		return -1;
 	}
-
+	Log(LOG_ERROR, "received frame is too short.");
+	DestroySocket();
+	return -1;
 }
 
 std::pair<unsigned char*, unsigned int> SatelIntegra::getFullFrame(const unsigned char* pCmd, const unsigned int cmdLength)
@@ -1285,5 +1240,5 @@ std::pair<unsigned char*, unsigned int> SatelIntegra::getFullFrame(const unsigne
 		pResult[index] = *it;
 	}
 
-	return std::pair<unsigned char*, unsigned int>(pResult, resultSize);
+	return { pResult, resultSize };
 }
