@@ -8,19 +8,21 @@
 
 class CTE923 : public CDomoticzHardwareBase
 {
-public:
-	explicit CTE923(const int ID);
-	~CTE923(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
-private:
+      public:
+	explicit CTE923(int ID);
+	~CTE923() override = default;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
+
+      private:
 	void Init();
 	bool StartHardware() override;
 	bool StopHardware() override;
 	void Do_Work();
 	void GetSensorDetails();
-private:
+
+      private:
 	std::shared_ptr<std::thread> m_thread;
 };
 
-#endif //WITH_LIBUSB
-#endif //WIN32
+#endif // WITH_LIBUSB
+#endif // WIN32
