@@ -4,21 +4,22 @@
 
 class CWOL : public CDomoticzHardwareBase
 {
-public:
-	CWOL(const int ID, const std::string &BoradcastAddress, const unsigned short Port);
-	~CWOL(void);
-	bool WriteToHardware(const char *pdata, const unsigned char length) override;
+      public:
+	CWOL(int ID, const std::string &BoradcastAddress, unsigned short Port);
+	~CWOL() override;
+	bool WriteToHardware(const char *pdata, unsigned char length) override;
 	void AddNode(const std::string &Name, const std::string &MACAddress);
-	bool UpdateNode(const int ID, const std::string &Name, const std::string &MACAddress);
-	void RemoveNode(const int ID);
+	bool UpdateNode(int ID, const std::string &Name, const std::string &MACAddress);
+	void RemoveNode(int ID);
 	void RemoveAllNodes();
-private:
+
+      private:
 	void Init();
 	bool StartHardware() override;
 	bool StopHardware() override;
 	bool SendWOLPacket(const unsigned char *pPacket);
-private:
+
+      private:
 	std::string m_broadcast_address;
 	unsigned short m_wol_port;
 };
-
