@@ -23,10 +23,15 @@
 
 #define round(a) ( int ) ( a + .5 )
 
-ZWaveBase::ZWaveBase() :
-	m_updateTime(0),
-	m_ControllerCommandStartTime(0)
+ZWaveBase::ZWaveBase()
 {
+	m_bNodeReplaced=true;
+	m_NodeToBeReplaced=0;
+
+	m_bHasNodeFailedDone=false;
+	m_sHasNodeFailedResult="";
+	m_HasNodeFailedIdx=-1;
+
 	m_LastIncludedNode = 0;
 	m_bControllerCommandInProgress = false;
 	m_bControllerCommandCanceled = false;
@@ -35,11 +40,6 @@ ZWaveBase::ZWaveBase() :
 	m_bInitState = true;
 }
 
-
-ZWaveBase::~ZWaveBase(void)
-{
-}
-
 bool ZWaveBase::StartHardware()
 {
 	RequestStart();
@@ -52,7 +52,7 @@ bool ZWaveBase::StartHardware()
 	m_bIsStarted = true;
 
 	//Start worker thread
-	m_thread = std::make_shared<std::thread>(&ZWaveBase::Do_Work, this);
+	m_thread = std::make_shared<std::thread>([this] { Do_Work(); });
 	SetThreadName(m_thread->native_handle(), "ZWaveBase");
 	return (m_thread != nullptr);
 }
@@ -85,7 +85,7 @@ void ZWaveBase::Do_Work()
 			msec_counter = 0;
 			sec_counter++;
 			if (sec_counter % 12 == 0) {
-				m_LastHeartbeat = mytime(NULL);
+				m_LastHeartbeat = mytime(nullptr);
 			}
 		}
 
@@ -103,11 +103,11 @@ void ZWaveBase::Do_Work()
 			GetUpdates();
 			if (m_bControllerCommandInProgress == true)
 			{
-				time_t atime = mytime(NULL);
+				time_t atime = mytime(nullptr);
 				double tdiff = difftime(atime, m_ControllerCommandStartTime);
 				if (tdiff >= CONTROLLER_COMMAND_TIMEOUT)
 				{
-					_log.Log(LOG_STATUS, "ZWave: Stopping Controller command (Timeout!)");
+					Log(LOG_STATUS, "ZWave: Stopping Controller command (Timeout!)");
 					CancelControllerCommand();
 				}
 			}
@@ -126,16 +126,16 @@ std::string ZWaveBase::GenerateDeviceStringID(const _tZWaveDevice* pDevice)
 void ZWaveBase::InsertDevice(_tZWaveDevice device)
 {
 	device.string_id = GenerateDeviceStringID(&device);
-	device.lastreceived = mytime(NULL);
+	device.lastreceived = mytime(nullptr);
 #ifdef _DEBUG
 	bool bNewDevice = (m_devices.find(device.string_id) == m_devices.end());
 	if (bNewDevice)
 	{
-		_log.Log(LOG_NORM, "New device: %s", device.string_id.c_str());
+		Log(LOG_NORM, "New device: %s", device.string_id.c_str());
 	}
 	else
 	{
-		_log.Log(LOG_NORM, "Update device: %s", device.string_id.c_str());
+		Log(LOG_NORM, "Update device: %s", device.string_id.c_str());
 	}
 #endif
 	//insert or update device in internal record
@@ -202,8 +202,8 @@ void ZWaveBase::SendSwitchIfNotExists(const _tZWaveDevice* pDevice)
 		// but instead of returning a single result, checks if there is more than one in memory
 		// device satisfying those criteria
 
-		std::map<std::string, _tZWaveDevice>::iterator itt;
-		for (itt = m_devices.begin(); itt != m_devices.end(); ++itt)
+		auto itt = m_devices.begin();
+		while (itt != m_devices.end())
 		{
 			if (
 				// Node ID1 is not used when searching for switch-like devices, see ID1 = 0; at the start
@@ -234,10 +234,11 @@ void ZWaveBase::SendSwitchIfNotExists(const _tZWaveDevice* pDevice)
 					break;
 				}
 			}
+			++itt;
 		}
 		if (itt != m_devices.end())
 		{
-			_log.Log(
+			Log(
 				LOG_STATUS,
 				"SendSwitchIfNotExists: Device '%s' (%s) with DeviceID '%s' matches '%s' (%s). Domoticz will use the Dimmer (and hide the Switch).",
 				pDevice->string_id.c_str(), pDevice->label.c_str(), szID, itt->second.string_id.c_str(), itt->second.label.c_str());
@@ -253,7 +254,7 @@ void ZWaveBase::SendSwitchIfNotExists(const _tZWaveDevice* pDevice)
 		lcmd.command = Color_LedOff;
 		lcmd.subtype = SubType;
 		lcmd.value = 0;
-		m_mainworker.PushAndWaitRxMessage(this, (const unsigned char*)& lcmd, pDevice->label.c_str(), pDevice->batValue);
+		m_mainworker.PushAndWaitRxMessage(this, (const unsigned char *)&lcmd, pDevice->label.c_str(), pDevice->batValue, m_Name.c_str());
 	}
 	else
 	{
@@ -292,7 +293,7 @@ void ZWaveBase::SendSwitchIfNotExists(const _tZWaveDevice* pDevice)
 		// Update the lcmd with the correct level value.
 		gswitch.level = level;
 
-		m_mainworker.PushAndWaitRxMessage(this, (const unsigned char*)& gswitch, pDevice->label.c_str(), pDevice->batValue);
+		m_mainworker.PushAndWaitRxMessage(this, (const unsigned char *)&gswitch, pDevice->label.c_str(), pDevice->batValue, m_Name.c_str());
 	}
 
 	//Set SwitchType
@@ -310,7 +311,7 @@ unsigned char ZWaveBase::Convert_Battery_To_PercInt(const unsigned char level)
 	return (unsigned char)ret;
 }
 
-void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
+void ZWaveBase::SendDevice2Domoticz(_tZWaveDevice* pDevice)
 {
 	//make device ID
 
@@ -373,10 +374,10 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		// Update the lcmd with the correct level value.
 		gswitch.level = level;
 		gswitch.rssi = 12;
-		sDecodeRXMessage(this, (const unsigned char*)& gswitch, NULL, BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&gswitch, nullptr, BatLevel, m_Name.c_str());
 		return;
 	}
-	else if ((pDevice->devType == ZDTYPE_SWITCH_RGBW) || (pDevice->devType == ZDTYPE_SWITCH_COLOR))
+	if ((pDevice->devType == ZDTYPE_SWITCH_RGBW) || (pDevice->devType == ZDTYPE_SWITCH_COLOR))
 	{
 		//Send as ColorSwitch
 		_tColorSwitch lcmd;
@@ -390,10 +391,12 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		else
 			lcmd.command = Color_LedOn;
 		lcmd.value = 0;
-		sDecodeRXMessage(this, (const unsigned char*)& lcmd, NULL, BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&lcmd, nullptr, BatLevel, m_Name.c_str());
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_POWER)
 	{
+		if ((pDevice->floatValue < -m_sql.m_max_kwh_usage) || (pDevice->floatValue > m_sql.m_max_kwh_usage))
+			return;
 		_tUsageMeter umeter;
 		umeter.id1 = ID1;
 		umeter.id2 = ID2;
@@ -401,33 +404,18 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		umeter.id4 = ID4;
 		umeter.dunit = 2;
 		umeter.fusage = pDevice->floatValue;
-		sDecodeRXMessage(this, (const unsigned char*)& umeter, NULL, BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&umeter, nullptr, BatLevel, nullptr);
 
 		//Search Energy Device
 		const _tZWaveDevice* pEnergyDevice;
-		pEnergyDevice = FindDeviceEx(pDevice->nodeID, pDevice->orgInstanceID, ZDTYPE_SENSOR_POWERENERGYMETER);
-		if (pEnergyDevice == NULL)
+
+		pEnergyDevice = FindDevice(pDevice->nodeID, pDevice->instanceID, COMMAND_CLASS_METER, ZDTYPE_SENSOR_POWERENERGYMETER);
+		if (pEnergyDevice == nullptr)
 		{
-			pEnergyDevice = FindDevice(pDevice->nodeID, pDevice->instanceID, pDevice->indexID, COMMAND_CLASS_METER, ZDTYPE_SENSOR_POWERENERGYMETER);
-			if (pEnergyDevice == NULL)
+			pEnergyDevice = FindDevice(pDevice->nodeID, pDevice->orgInstanceID, ZDTYPE_SENSOR_POWERENERGYMETER);
+			if (pEnergyDevice == nullptr)
 			{
-				pEnergyDevice = FindDevice(pDevice->nodeID, pDevice->instanceID, pDevice->indexID, ZDTYPE_SENSOR_POWERENERGYMETER);
-				if (pEnergyDevice == NULL)
-				{
-					if (
-						(pDevice->Manufacturer_id == 0x010F) &&
-						(
-						((pDevice->Product_type == 0x0200) && (pDevice->Product_id == 0x1000))
-							|| ((pDevice->Product_type == 0x0600) && (pDevice->Product_id == 0x1000))
-							|| ((pDevice->Product_type == 0x0602) && (pDevice->Product_id == 0x1001))
-							|| ((pDevice->Product_type == 0x0602) && (pDevice->Product_id == 0x1003))
-							)
-						)
-					{
-						//Fibaro Wallplug, find energy sensor
-						pEnergyDevice = FindDevice(pDevice->nodeID, -1, -1, ZDTYPE_SENSOR_POWERENERGYMETER);
-					}
-				}
+				pEnergyDevice = FindDevice(pDevice->nodeID, -1, ZDTYPE_SENSOR_POWERENERGYMETER);
 			}
 		}
 		if (pEnergyDevice)
@@ -437,14 +425,59 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 				SendKwhMeter(pEnergyDevice->nodeID, pEnergyDevice->instanceID, BatLevel, pDevice->floatValue, pEnergyDevice->floatValue / pEnergyDevice->scaleMultiply, "kWh Meter");
 			}
 		}
-		else
+		pEnergyDevice = FindDevice(pDevice->nodeID, pDevice->orgInstanceID, ZDTYPE_SENSOR_KVAH);
+		if (pEnergyDevice)
 		{
-			//No kWh meter, send as normal Power device
-			SendWattMeter(pDevice->nodeID, pDevice->instanceID, BatLevel, pDevice->floatValue, "Power Meter");
+			if (pEnergyDevice->bValidValue)
+			{
+				SendKwhMeter(pEnergyDevice->nodeID, 0x40 + pEnergyDevice->orgInstanceID, BatLevel, pDevice->floatValue, pEnergyDevice->floatValue / pEnergyDevice->scaleMultiply, "kVah Meter");
+			}
+		}
+		pEnergyDevice = FindDevice(pDevice->nodeID, pDevice->orgInstanceID, ZDTYPE_SENSOR_KVAR);
+		if (pEnergyDevice)
+		{
+			if (pEnergyDevice->bValidValue)
+			{
+				SendKwhMeter(pEnergyDevice->nodeID, 0x60 + pEnergyDevice->orgInstanceID, BatLevel, pDevice->floatValue, pEnergyDevice->floatValue / pEnergyDevice->scaleMultiply, "kVar Meter");
+			}
+		}
+		pEnergyDevice = FindDevice(pDevice->nodeID, pDevice->orgInstanceID, ZDTYPE_SENSOR_KVARH);
+		if (pEnergyDevice)
+		{
+			if (pEnergyDevice->bValidValue)
+			{
+				SendKwhMeter(pEnergyDevice->nodeID, 0x80 + pEnergyDevice->orgInstanceID, BatLevel, pDevice->floatValue, pEnergyDevice->floatValue / pEnergyDevice->scaleMultiply, "kVarh Meter");
+			}
 		}
 	}
-	else if (pDevice->devType == ZDTYPE_SENSOR_POWERENERGYMETER)
+	else if (
+		(pDevice->devType == ZDTYPE_SENSOR_POWERENERGYMETER)
+		|| (pDevice->devType == ZDTYPE_SENSOR_KVAH)
+		|| (pDevice->devType == ZDTYPE_SENSOR_KVAR)
+		|| (pDevice->devType == ZDTYPE_SENSOR_KVARH)
+		)
 	{
+		// check for possible counter issues
+		if (pDevice->lastSendValue != 0)
+		{
+			float floatChange = (pDevice->floatValue - pDevice->prevFloatValue) / pDevice->scaleMultiply;
+			if ((floatChange < -m_sql.m_max_kwh_usage) || (floatChange > m_sql.m_max_kwh_usage))
+			{
+				if (pDevice->lastreceived - pDevice->lastSendValue < 3600)
+				{
+					// Seems wrong, counters should change by a limited amount.
+					// If it persists, we will accept it after an hour.
+					Log(LOG_STATUS,
+						 "OpenZwave: temporarily ignoring %s power meter counter (NodeID: %d, 0x%02x)",
+						 floatChange < 0 ? "possibly wrapped" : "unreasonably high",
+						 pDevice->nodeID, pDevice->nodeID);
+					return;
+				}
+			}
+		}
+		pDevice->lastSendValue = pDevice->lastreceived;
+		pDevice->prevFloatValue = pDevice->floatValue;
+
 		RBUF tsen;
 		memset(&tsen, 0, sizeof(RBUF));
 
@@ -452,46 +485,46 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		if (
 			(pDevice->Manufacturer_id == 0x010F) &&
 			(
-			((pDevice->Product_type == 0x0200) && (pDevice->Product_id == 0x1000))
+					((pDevice->Product_type == 0x0200) && (pDevice->Product_id == 0x1000))
 				|| ((pDevice->Product_type == 0x0600) && (pDevice->Product_id == 0x1000))
 				|| ((pDevice->Product_type == 0x0602) && (pDevice->Product_id == 0x1001))
 				|| ((pDevice->Product_type == 0x0602) && (pDevice->Product_id == 0x1003))
-				)
-			)
+				|| ((pDevice->Product_type == 0x1701) && (pDevice->Product_id == 0x2000))
+				|| ((pDevice->Product_type == 0x1801) && (pDevice->Product_id == 0x1000))
+			))
 		{
 			//Fibaro Wallplug, find power sensor with idx 4 (idx 1 only reports when plug goes on/off, idx 4 is live power)
-			pPowerDevice = FindDevice(pDevice->nodeID, 4, pDevice->indexID, COMMAND_CLASS_SENSOR_MULTILEVEL, ZDTYPE_SENSOR_POWER);
-			if (pPowerDevice == NULL)
-				pPowerDevice = FindDevice(pDevice->nodeID, pDevice->instanceID, pDevice->indexID, COMMAND_CLASS_METER, ZDTYPE_SENSOR_POWER);
+			pPowerDevice = FindDevice(pDevice->nodeID, 4, COMMAND_CLASS_SENSOR_MULTILEVEL, ZDTYPE_SENSOR_POWER);
 		}
 		else
 		{
-			pPowerDevice = FindDeviceEx(pDevice->nodeID, pDevice->orgInstanceID, ZDTYPE_SENSOR_POWER);
-			if (pPowerDevice == NULL)
-				pPowerDevice = FindDevice(pDevice->nodeID, pDevice->instanceID, pDevice->indexID, COMMAND_CLASS_METER, ZDTYPE_SENSOR_POWER);
+			pPowerDevice = FindDevice(pDevice->nodeID, pDevice->orgInstanceID, ZDTYPE_SENSOR_POWER);
 		}
-		if (pPowerDevice == NULL)
+		if (pPowerDevice == nullptr)
+			pPowerDevice = FindDevice(pDevice->nodeID, pDevice->instanceID, COMMAND_CLASS_METER, ZDTYPE_SENSOR_POWER);
+		if (pPowerDevice == nullptr)
 		{
-			pPowerDevice = FindDevice(pDevice->nodeID, pDevice->instanceID, pDevice->indexID, ZDTYPE_SENSOR_POWER);
-			if (pPowerDevice == NULL)
-				pPowerDevice = FindDevice(pDevice->nodeID, -1, -1, ZDTYPE_SENSOR_POWER);
+			pPowerDevice = FindDevice(pDevice->nodeID, pDevice->instanceID, ZDTYPE_SENSOR_POWER);
+			if (pPowerDevice == nullptr)
+				pPowerDevice = FindDevice(pDevice->nodeID, -1, ZDTYPE_SENSOR_POWER);
 		}
 		bool bHaveValidPowerDevice = false;
 		if (pPowerDevice)
 		{
 			bHaveValidPowerDevice = pPowerDevice->bValidValue;
 		}
-		if (bHaveValidPowerDevice)
-		{
-			SendKwhMeter(pDevice->nodeID, pDevice->instanceID, BatLevel, pPowerDevice->floatValue, pDevice->floatValue / pDevice->scaleMultiply, "kWh Meter");
-		}
-		else
-		{
-			SendKwhMeter(pDevice->nodeID, pDevice->instanceID, BatLevel, 0, pDevice->floatValue / pDevice->scaleMultiply, "kWh Meter");
-		}
+		if (pDevice->devType == ZDTYPE_SENSOR_POWERENERGYMETER)
+			SendKwhMeter(pDevice->nodeID, pDevice->instanceID, BatLevel, (bHaveValidPowerDevice) ? pPowerDevice->floatValue : 0, pDevice->floatValue / pDevice->scaleMultiply, "kWh Meter");
+		else if (pDevice->devType == ZDTYPE_SENSOR_KVAH)
+			SendKwhMeter(pDevice->nodeID, 0x40 + pDevice->orgInstanceID, BatLevel, (bHaveValidPowerDevice) ? pPowerDevice->floatValue : 0, pDevice->floatValue / pDevice->scaleMultiply, "kVah Meter");
+		else if (pDevice->devType == ZDTYPE_SENSOR_KVAR)
+			SendKwhMeter(pDevice->nodeID, 0x60 + pDevice->orgInstanceID, BatLevel, (bHaveValidPowerDevice) ? pPowerDevice->floatValue : 0, pDevice->floatValue / pDevice->scaleMultiply, "kVar Meter");
+		else if (pDevice->devType == ZDTYPE_SENSOR_KVARH)
+			SendKwhMeter(pDevice->nodeID, 0x80 + pDevice->orgInstanceID, BatLevel, (bHaveValidPowerDevice) ? pPowerDevice->floatValue : 0, pDevice->floatValue / pDevice->scaleMultiply, "kVarh Meter");
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_VOLTAGE)
 	{
+		lID = (lID & 0xFFFFFF00) | pDevice->orgInstanceID;
 		SendVoltageSensor(0, lID, BatLevel, pDevice->floatValue, "Voltage");
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_PERCENTAGE)
@@ -507,13 +540,13 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		tsen.CURRENT.packetlength = sizeof(tsen.CURRENT) - 1;
 		tsen.CURRENT.id1 = pDevice->nodeID;
 		tsen.CURRENT.id2 = pDevice->instanceID;
-		int amps = round(pDevice->floatValue * 10.0f);
+		int amps = round(pDevice->floatValue * 10.0F);
 		tsen.CURRENT.ch1h = amps / 256;
 		amps -= (tsen.CURRENT.ch1h * 256);
 		tsen.CURRENT.ch1l = (BYTE)amps;
 		tsen.CURRENT.battery_level = Convert_Battery_To_PercInt(pDevice->batValue);
 		tsen.CURRENT.rssi = 12;
-		sDecodeRXMessage(this, (const unsigned char*)& tsen.CURRENT, NULL, BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&tsen.CURRENT, nullptr, BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_UV)
 	{
@@ -526,7 +559,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		RBUF tsen;
 		memset(&tsen, 0, sizeof(RBUF));
 
-		const _tZWaveDevice* pHumDevice = FindDevice(pDevice->nodeID, -1, -1, ZDTYPE_SENSOR_HUMIDITY);
+		const _tZWaveDevice* pHumDevice = FindDevice(pDevice->nodeID, -1, ZDTYPE_SENSOR_HUMIDITY);
 		if (pHumDevice)
 		{
 			if (!pHumDevice->bValidValue)
@@ -540,7 +573,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 				devName = pDevice->label + std::string("/") + pHumDevice->label;
 			}
 
-			SendTempHumSensor(NodeID, BatLevel, pDevice->floatValue, pHumDevice->intvalue, devName.c_str());
+			SendTempHumSensor(NodeID, BatLevel, pDevice->floatValue, pHumDevice->intvalue, devName);
 		}
 		else
 		{
@@ -555,7 +588,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		RBUF tsen;
 		memset(&tsen, 0, sizeof(RBUF));
 
-		const _tZWaveDevice* pTempDevice = FindDevice(pDevice->nodeID, -1, -1, ZDTYPE_SENSOR_TEMPERATURE);
+		const _tZWaveDevice* pTempDevice = FindDevice(pDevice->nodeID, -1, ZDTYPE_SENSOR_TEMPERATURE);
 		if (pTempDevice)
 		{
 			if (!pTempDevice->bValidValue)
@@ -571,7 +604,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 				devName = pTempDevice->label + std::string("/") + pDevice->label;
 			}
 
-			SendTempHumSensor(NodeID, BatLevel, pTempDevice->floatValue, pDevice->intvalue, devName.c_str());
+			SendTempHumSensor(NodeID, BatLevel, pTempDevice->floatValue, pDevice->intvalue, devName);
 		}
 		else
 		{
@@ -600,7 +633,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		aw -= (tsen.WIND.directionh * 256);
 		tsen.WIND.directionl = (BYTE)(aw);
 
-		int sw = round(pDevice->floatValue * 10.0f);
+		int sw = round(pDevice->floatValue * 10.0F);
 		tsen.WIND.av_speedh = (BYTE)(sw / 256);
 		sw -= (tsen.WIND.av_speedh * 256);
 		tsen.WIND.av_speedl = (BYTE)(sw);
@@ -613,28 +646,28 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		tsen.WIND.temperatureh = 0;
 		tsen.WIND.temperaturel = 0;
 
-		const _tZWaveDevice* pTempDevice = FindDevice(pDevice->nodeID, -1, -1, ZDTYPE_SENSOR_TEMPERATURE);
+		const _tZWaveDevice* pTempDevice = FindDevice(pDevice->nodeID, -1, ZDTYPE_SENSOR_TEMPERATURE);
 		if (pTempDevice)
 		{
 			if (!pTempDevice->bValidValue)
 				return;
 			tsen.WIND.tempsign = (pTempDevice->floatValue >= 0) ? 0 : 1;
 			tsen.WIND.chillsign = (pTempDevice->floatValue >= 0) ? 0 : 1;
-			int at10 = round(std::abs(pTempDevice->floatValue * 10.0f));
+			int at10 = round(std::abs(pTempDevice->floatValue * 10.0F));
 			tsen.WIND.temperatureh = (BYTE)(at10 / 256);
 			tsen.WIND.chillh = (BYTE)(at10 / 256);
 			at10 -= (tsen.WIND.chillh * 256);
 			tsen.WIND.temperaturel = (BYTE)(at10);
 			tsen.WIND.chilll = (BYTE)(at10);
 		}
-		sDecodeRXMessage(this, (const unsigned char*)& tsen.WIND, NULL, BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&tsen.WIND, nullptr, BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_BAROMETER)
 	{
 		if (!pDevice->bValidValue)
 			return;
-		const _tZWaveDevice* pTempDevice = FindDevice(pDevice->nodeID, -1, -1, ZDTYPE_SENSOR_TEMPERATURE);
-		const _tZWaveDevice* pHumDevice = FindDevice(pDevice->nodeID, -1, -1, ZDTYPE_SENSOR_HUMIDITY);
+		const _tZWaveDevice* pTempDevice = FindDevice(pDevice->nodeID, -1, ZDTYPE_SENSOR_TEMPERATURE);
+		const _tZWaveDevice* pHumDevice = FindDevice(pDevice->nodeID, -1, ZDTYPE_SENSOR_HUMIDITY);
 		if (pTempDevice && pHumDevice)
 		{
 			int nforecast = wsbaroforecast_some_clouds;
@@ -663,7 +696,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		lmeter.dunit = 255;
 		lmeter.fLux = pDevice->floatValue;
 		lmeter.battery_level = BatLevel;
-		sDecodeRXMessage(this, (const unsigned char*)& lmeter, (!pDevice->label.empty()) ? pDevice->label.c_str() : "Light", BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&lmeter, (!pDevice->label.empty()) ? pDevice->label.c_str() : "Light", BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_GAS)
 	{
@@ -672,12 +705,12 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		m_p1gas.subtype = sTypeP1Gas;
 		m_p1gas.gasusage = (unsigned long)(pDevice->floatValue * 1000);
 		m_p1gas.ID = lID;
-		sDecodeRXMessage(this, (const unsigned char*)& m_p1gas, (!pDevice->label.empty()) ? pDevice->label.c_str() : "Gas", BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&m_p1gas, (!pDevice->label.empty()) ? pDevice->label.c_str() : "Gas", BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_WATER)
 	{
 		uint16_t NodeID = (pDevice->nodeID << 8) | pDevice->instanceID;
-		SendRainSensor(NodeID, BatLevel, pDevice->floatValue * 1000.0f, "Water");
+		SendRainSensor(NodeID, BatLevel, pDevice->floatValue * 1000.0F, "Water");
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_CO2)
 	{
@@ -706,7 +739,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		tmeter.dunit = 1;
 		tmeter.battery_level = BatLevel;
 		tmeter.temp = pDevice->floatValue;
-		sDecodeRXMessage(this, (const unsigned char*)& tmeter, (!pDevice->label.empty()) ? pDevice->label.c_str() : "Setpoint", BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&tmeter, (!pDevice->label.empty()) ? pDevice->label.c_str() : "Setpoint", BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_THERMOSTAT_CLOCK)
 	{
@@ -715,7 +748,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		gDevice.id = ID4;
 		gDevice.intval1 = lID;
 		gDevice.intval2 = pDevice->intvalue;
-		sDecodeRXMessage(this, (const unsigned char*)& gDevice, "Thermostat Clock", BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&gDevice, "Thermostat Clock", BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_THERMOSTAT_MODE)
 	{
@@ -724,7 +757,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		gDevice.id = ID4;
 		gDevice.intval1 = lID;
 		gDevice.intval2 = pDevice->intvalue;
-		sDecodeRXMessage(this, (const unsigned char*)& gDevice, "Thermostat Mode", BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&gDevice, "Thermostat Mode", BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_THERMOSTAT_FAN_MODE)
 	{
@@ -733,7 +766,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		gDevice.id = ID4;
 		gDevice.intval1 = lID;
 		gDevice.intval2 = pDevice->intvalue;
-		sDecodeRXMessage(this, (const unsigned char*)& gDevice, "Thermostat Fan Mode", BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&gDevice, "Thermostat Fan Mode", BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_THERMOSTAT_OPERATING_STATE)
 	{
@@ -742,7 +775,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		gDevice.id = ID4;
 		gDevice.intval1 = lID;
 		gDevice.intval2 = pDevice->intvalue;
-		sDecodeRXMessage(this, (const unsigned char*)& gDevice, "Thermostat Operating State", BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&gDevice, "Thermostat Operating State", BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_ALARM)
 	{
@@ -753,7 +786,7 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 		gDevice.intval2 = pDevice->intvalue;
 		char szTmp[100];
 		sprintf(szTmp, "Alarm Type: %s %d(0x%02X)", pDevice->label.c_str(), pDevice->Alarm_Type, pDevice->Alarm_Type);
-		sDecodeRXMessage(this, (const unsigned char*)& gDevice, szTmp, BatLevel);
+		sDecodeRXMessage(this, (const unsigned char *)&gDevice, szTmp, BatLevel, nullptr);
 	}
 	else if (pDevice->devType == ZDTYPE_SENSOR_CUSTOM)
 	{
@@ -761,69 +794,44 @@ void ZWaveBase::SendDevice2Domoticz(const _tZWaveDevice* pDevice)
 	}
 }
 
-ZWaveBase::_tZWaveDevice* ZWaveBase::FindDevice(const uint8_t nodeID, const int instanceID, const int indexID)
+ZWaveBase::_tZWaveDevice* ZWaveBase::FindDevice(const uint8_t nodeID, const int instanceID, const _eZWaveDeviceType devType)
 {
-	for (auto& itt : m_devices)
+	for (auto &m : m_devices)
 	{
 		if (
-			(itt.second.nodeID == nodeID) &&
-			(itt.second.instanceID == instanceID) &&
-			(itt.second.indexID == indexID)
+			(m.second.nodeID == nodeID)
+			&& ((m.second.instanceID == instanceID) || (instanceID == -1))
+		    && (m.second.devType == devType)
 			)
-			return &itt.second;
+		{
+			return &m.second;
+		}
 	}
-	return NULL;
+	return nullptr;
 }
 
-//Used for power/energy devices
-ZWaveBase::_tZWaveDevice* ZWaveBase::FindDeviceEx(const uint8_t nodeID, const int instanceID, const _eZWaveDeviceType devType)
+ZWaveBase::_tZWaveDevice *ZWaveBase::FindDevice(const uint8_t nodeID, const int instanceID, const uint8_t CommandClassID, const _eZWaveDeviceType devType)
 {
-	for (auto& itt : m_devices)
+	for (auto &m : m_devices)
 	{
 		if (
-			(itt.second.nodeID == nodeID) &&
-			(itt.second.instanceID == instanceID) &&
-			(itt.second.devType == devType)
+			(m.second.nodeID == nodeID)
+			&& ((m.second.instanceID == instanceID) || (instanceID == -1))
+		    && (m.second.commandClassID == CommandClassID)
+			&& (m.second.devType == devType)
 			)
-			return &itt.second;
+		{
+			return &m.second;
+		}
 	}
-	return NULL;
-}
-
-ZWaveBase::_tZWaveDevice* ZWaveBase::FindDevice(const uint8_t nodeID, const int instanceID, const int indexID, const _eZWaveDeviceType devType)
-{
-	for (auto& itt : m_devices)
-	{
-		if (
-			(itt.second.nodeID == nodeID) &&
-			((itt.second.instanceID == instanceID) || (instanceID == -1)) &&
-			(itt.second.devType == devType)
-			)
-			return &itt.second;
-	}
-	return NULL;
-}
-
-ZWaveBase::_tZWaveDevice* ZWaveBase::FindDevice(const uint8_t nodeID, const int instanceID, const int indexID, const int CommandClassID, const _eZWaveDeviceType devType)
-{
-	for (auto& itt : m_devices)
-	{
-		if (
-			(itt.second.nodeID == nodeID) &&
-			((itt.second.instanceID == instanceID) || (instanceID == -1)) &&
-			(itt.second.commandClassID == CommandClassID) &&
-			(itt.second.devType == devType)
-			)
-			return &itt.second;
-	}
-	return NULL;
+	return nullptr;
 }
 
 bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 {
 	std::lock_guard<std::mutex> l(m_NotificationMutex);
 
-	_tZWaveDevice* pDevice = NULL;
+	_tZWaveDevice *pDevice = nullptr;
 
 	unsigned char packettype = pdata[1];
 	unsigned char subtype = pdata[2];
@@ -866,7 +874,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		int svalue = 0;
 
 		//First find dimmer
-		pDevice = FindDevice(nodeID, instanceID, indexID, ZDTYPE_SWITCH_DIMMER);
+		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SWITCH_DIMMER);
 		if (pDevice)
 		{
 			if ((cmnd == gswitch_sOff) || (cmnd == gswitch_sGroupOff))
@@ -879,23 +887,20 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 			}
 			return SwitchLight(pDevice, instanceID, svalue);
 		}
-		else
+		// find normal
+		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SWITCH_NORMAL);
+		if (pDevice)
 		{
-			//find normal
-			pDevice = FindDevice(nodeID, instanceID, indexID, ZDTYPE_SWITCH_NORMAL);
-			if (pDevice)
-			{
-				if ((cmnd == gswitch_sOff) || (cmnd == gswitch_sGroupOff))
-					svalue = 0;
-				else
-					svalue = 255;
-				return SwitchLight(pDevice, instanceID, svalue);
-			}
-			_log.Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
-			return false;
+			if ((cmnd == gswitch_sOff) || (cmnd == gswitch_sGroupOff))
+				svalue = 0;
+			else
+				svalue = 255;
+			return SwitchLight(pDevice, instanceID, svalue);
 		}
+		Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
+		return false;
 	}
-	else if ((packettype == pTypeThermostat) && (subtype == sTypeThermSetpoint))
+	if ((packettype == pTypeThermostat) && (subtype == sTypeThermSetpoint))
 	{
 		//Set Point
 		const _tThermostat* pMeter = reinterpret_cast<const _tThermostat*>(pdata);
@@ -904,16 +909,16 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		int indexID = pMeter->id1;
 
 		//find normal
-		pDevice = FindDevice(nodeID, instanceID, indexID, ZDTYPE_SENSOR_SETPOINT);
+		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SENSOR_SETPOINT);
 		if (pDevice)
 		{
 			SetThermostatSetPoint(nodeID, instanceID, pDevice->commandClassID, pMeter->temp);
 			return true;
 		}
-		_log.Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
+		Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
 		return false;
 	}
-	else if ((packettype == pTypeGeneral) && (subtype == sTypeZWaveClock))
+	if ((packettype == pTypeGeneral) && (subtype == sTypeZWaveClock))
 	{
 		const _tGeneralDevice* pMeter = reinterpret_cast<const _tGeneralDevice*>(pdata);
 		uint8_t ID1 = (uint8_t)((pMeter->intval1 & 0xFF000000) >> 24);
@@ -925,7 +930,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		uint8_t instanceID = ID4;
 		int indexID = ID1;
 
-		pDevice = FindDevice(nodeID, instanceID, indexID, ZDTYPE_SENSOR_THERMOSTAT_CLOCK);
+		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SENSOR_THERMOSTAT_CLOCK);
 		if (pDevice)
 		{
 			int tintval = pMeter->intval2;
@@ -936,10 +941,10 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 			SetClock(nodeID, instanceID, pDevice->commandClassID, day, hour, minute);
 			return true;
 		}
-		_log.Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
+		Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
 		return false;
 	}
-	else if ((packettype == pTypeGeneral) && (subtype == sTypeZWaveThermostatMode))
+	if ((packettype == pTypeGeneral) && (subtype == sTypeZWaveThermostatMode))
 	{
 		const _tGeneralDevice* pMeter = reinterpret_cast<const _tGeneralDevice*>(pdata);
 		uint8_t ID1 = (uint8_t)((pMeter->intval1 & 0xFF000000) >> 24);
@@ -951,17 +956,17 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		uint8_t instanceID = ID4;
 		int indexID = ID1;
 
-		pDevice = FindDevice(nodeID, instanceID, indexID, ZDTYPE_SENSOR_THERMOSTAT_MODE);
+		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SENSOR_THERMOSTAT_MODE);
 		if (pDevice)
 		{
 			int tMode = pMeter->intval2;
 			SetThermostatMode(nodeID, instanceID, pDevice->commandClassID, tMode);
 			return true;
 		}
-		_log.Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
+		Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
 		return false;
 	}
-	else if ((packettype == pTypeGeneral) && (subtype == sTypeZWaveThermostatFanMode))
+	if ((packettype == pTypeGeneral) && (subtype == sTypeZWaveThermostatFanMode))
 	{
 		const _tGeneralDevice* pMeter = reinterpret_cast<const _tGeneralDevice*>(pdata);
 		uint8_t ID1 = (uint8_t)((pMeter->intval1 & 0xFF000000) >> 24);
@@ -973,17 +978,17 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		uint8_t instanceID = ID4;
 		int indexID = ID1;
 
-		pDevice = FindDevice(nodeID, instanceID, indexID, ZDTYPE_SENSOR_THERMOSTAT_FAN_MODE);
+		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SENSOR_THERMOSTAT_FAN_MODE);
 		if (pDevice)
 		{
 			int tMode = pMeter->intval2;
 			SetThermostatFanMode(nodeID, instanceID, pDevice->commandClassID, tMode);
 			return true;
 		}
-		_log.Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
+		Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
 		return false;
 	}
-	else if (packettype == pTypeColorSwitch)
+	if (packettype == pTypeColorSwitch)
 	{
 		const _tColorSwitch* pLed = reinterpret_cast<const _tColorSwitch*>(pdata);
 		uint8_t ID1 = (uint8_t)((pLed->id & 0xFF000000) >> 24);
@@ -993,7 +998,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		uint8_t nodeID = ID3;
 		uint8_t instanceID = ID4;
 		int indexID = ID1;
-		pDevice = FindDevice(nodeID, instanceID, indexID, ZDTYPE_SWITCH_RGBW);
+		pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SWITCH_RGBW);
 		if (pDevice)
 		{
 			if (pLed->command == Color_LedOff)
@@ -1001,12 +1006,12 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 				instanceID = 2;
 				return SwitchLight(pDevice, instanceID, 0);
 			}
-			else if (pLed->command == Color_LedOn)
+			if (pLed->command == Color_LedOn)
 			{
 				instanceID = 2;
 				return SwitchLight(pDevice, instanceID, 255);
 			}
-			else if (pLed->command == Color_SetBrightnessLevel)
+			if (pLed->command == Color_SetBrightnessLevel)
 			{
 				instanceID = 2;
 				int ivalue = pLed->value;
@@ -1014,7 +1019,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 					ivalue = 99; //99 is fully on
 				return SwitchLight(pDevice, instanceID, ivalue);
 			}
-			else if (pLed->command == Color_SetColorToWhite)
+			if (pLed->command == Color_SetColorToWhite)
 			{
 				instanceID = 3;//red
 				if (!SwitchLight(pDevice, instanceID, 0))
@@ -1030,7 +1035,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 					return false;
 				return true;
 			}
-			else if (pLed->command == Color_SetColor)
+			if (pLed->command == Color_SetColor)
 			{
 				int ivalue = pLed->value;
 				if (ivalue > 99)
@@ -1065,7 +1070,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 					instanceID = 5;//blue
 					if (!SwitchLight(pDevice, instanceID, pLed->color.b))
 						return false;
-					_log.Log(LOG_NORM, "Red: %03d, Green:%03d, Blue:%03d", pLed->color.r, pLed->color.g, pLed->color.b);
+					Log(LOG_NORM, "Red: %03d, Green:%03d, Blue:%03d", pLed->color.r, pLed->color.g, pLed->color.b);
 				}
 				else if (pLed->color.mode == ColorModeCustom)
 				{
@@ -1081,11 +1086,11 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 					instanceID = 6;//white
 					if (!SwitchLight(pDevice, instanceID, pLed->color.ww))
 						return false;
-					_log.Log(LOG_NORM, "Red: %03d, Green:%03d, Blue:%03d", pLed->color.r, pLed->color.g, pLed->color.b);
+					Log(LOG_NORM, "Red: %03d, Green:%03d, Blue:%03d", pLed->color.r, pLed->color.g, pLed->color.b);
 				}
 				else
 				{
-					_log.Log(LOG_STATUS, "ZWave: SetRGBColour - Color mode %d is unhandled, if you have a suggestion for what it should do, please post on the Domoticz forum", pLed->color.mode);
+					Log(LOG_STATUS, "ZWave: SetRGBColour - Color mode %d is unhandled, if you have a suggestion for what it should do, please post on the Domoticz forum", pLed->color.mode);
 					return false;
 				}
 				instanceID = 2;//brightness
@@ -1096,7 +1101,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 		}
 		else
 		{
-			pDevice = FindDevice(nodeID, instanceID, indexID, ZDTYPE_SWITCH_COLOR);
+			pDevice = FindDevice(nodeID, instanceID, ZDTYPE_SWITCH_COLOR);
 			if (pDevice)
 			{
 				std::stringstream sstr;
@@ -1105,12 +1110,12 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 					instanceID = 1;
 					return SwitchLight(pDevice, instanceID, 0);
 				}
-				else if (pLed->command == Color_LedOn)
+				if (pLed->command == Color_LedOn)
 				{
 					instanceID = 1;
 					return SwitchLight(pDevice, instanceID, 255);
 				}
-				else if (pLed->command == Color_SetBrightnessLevel)
+				if (pLed->command == Color_SetBrightnessLevel)
 				{
 					instanceID = 1;
 					int ivalue = pLed->value;
@@ -1118,10 +1123,10 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 						ivalue = 99; //99 is fully on
 					return SwitchLight(pDevice, instanceID, ivalue);
 				}
-				else if (pLed->command == Color_SetColorToWhite)
+				if (pLed->command == Color_SetColorToWhite)
 				{
 					int Brightness = 100;
-					int wWhite = round((255.0f / 100.0f) * float(Brightness));
+					int wWhite = round((255.0F / 100.0F) * float(Brightness));
 					int cWhite = 0;
 					sstr << "#000000"
 						<< std::setw(2) << std::uppercase << std::hex << std::setfill('0') << std::hex << wWhite
@@ -1129,7 +1134,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 					instanceID = 1;
 					return SwitchColor(nodeID, instanceID, sstr.str());
 				}
-				else if (pLed->command == Color_SetColor)
+				if (pLed->command == Color_SetColor)
 				{
 					int red = 0, green = 0, blue = 0, wWhite = 0, cWhite = 0;
 
@@ -1165,7 +1170,7 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 					}
 					else
 					{
-						_log.Log(LOG_STATUS, "ZWave: SetRGBColour - Color mode %d is unhandled, if you have a suggestion for what it should do, please post on the Domoticz forum", pLed->color.mode);
+						Log(LOG_STATUS, "ZWave: SetRGBColour - Color mode %d is unhandled, if you have a suggestion for what it should do, please post on the Domoticz forum", pLed->color.mode);
 						return false;
 					}
 
@@ -1182,13 +1187,13 @@ bool ZWaveBase::WriteToHardware(const char* pdata, const unsigned char length)
 					if (!SwitchColor(nodeID, instanceID, sColor))
 						return false;
 
-					_log.Log(LOG_NORM, "Red: %03d, Green:%03d, Blue:%03d, wWhite:%03d, cWhite:%03d", red, green, blue, wWhite, cWhite);
+					Log(LOG_NORM, "Red: %03d, Green:%03d, Blue:%03d, wWhite:%03d, cWhite:%03d", red, green, blue, wWhite, cWhite);
 					return true;
 				}
 			}
 			else
 			{
-				_log.Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
+				Log(LOG_ERROR, "ZWave: Node not found! (NodeID: %d, 0x%02x)", nodeID, nodeID);
 				return false;
 			}
 		}
