@@ -3,21 +3,24 @@
 #include "ASyncTCP.h"
 #include "ZiBlueBase.h"
 
-class CZiBlueTCP: public CZiBlueBase, ASyncTCP
+class CZiBlueTCP : public CZiBlueBase, ASyncTCP
 {
-public:
-	CZiBlueTCP(const int ID, const std::string &IPAddress, const unsigned short usIPPort);
-	~CZiBlueTCP(void);
-public:
+      public:
+	CZiBlueTCP(int ID, const std::string &IPAddress, unsigned short usIPPort);
+	~CZiBlueTCP() override = default;
+
+      public:
 	// signals
-	boost::signals2::signal<void()>	sDisconnected;
-private:
+	boost::signals2::signal<void()> sDisconnected;
+
+      private:
 	int m_retrycntr;
 	bool StartHardware() override;
 	bool StopHardware() override;
 	bool WriteInt(const std::string &sendString) override;
-	bool WriteInt(const uint8_t *pData, const size_t length) override;
-protected:
+	bool WriteInt(const uint8_t *pData, size_t length) override;
+
+      protected:
 	std::string m_szIPAddress;
 	unsigned short m_usIPPort;
 
@@ -26,8 +29,7 @@ protected:
 	void OnConnect() override;
 	void OnDisconnect() override;
 	void OnData(const unsigned char *pData, size_t length) override;
-	void OnError(const boost::system::error_code& error) override;
+	void OnError(const boost::system::error_code &error) override;
 
 	std::shared_ptr<std::thread> m_thread;
 };
-
