@@ -13,7 +13,6 @@
 #include <arpa/inet.h>
 #include <netdb.h>
 #include <errno.h>
-#include <sys/errno.h>
 #include <unistd.h>
 #include <fcntl.h>
 #include <poll.h>
@@ -30,9 +29,7 @@
 #define SUCCESS	 0
 #define FAILURE	 1
 
-
-csocket::csocket() : m_socketState(CLOSED),
-					 m_remotePort(0)
+csocket::csocket()
 {
 	m_socket = 0;
 }
@@ -65,22 +62,19 @@ int csocket::resolveHost(const std::string& szRemoteHostName, struct sockaddr_in
 		return FAILURE;
 
 	struct addrinfo *addr;
-	if (getaddrinfo(szRemoteHostName.c_str() , "0", 0, &addr) == 0)
+	if (getaddrinfo(szRemoteHostName.c_str(), "0", nullptr, &addr) == 0)
 	{
 		struct sockaddr_in *saddr = (((struct sockaddr_in *)addr->ai_addr));
 		sa.sin_family = saddr->sin_family;
 		memcpy(&sa, saddr, sizeof(sockaddr_in));
 		return SUCCESS;
 	}
-	else
-	{
-		sa.sin_family = AF_INET;
-		if (inet_pton(sa.sin_family, szRemoteHostName.c_str(), &sa.sin_addr) == 1)
-			return SUCCESS;
-		sa.sin_family = AF_INET6;
-		if (inet_pton(sa.sin_family, szRemoteHostName.c_str(), &sa.sin_addr) == 1)
-			return SUCCESS;
-	}
+	sa.sin_family = AF_INET;
+	if (inet_pton(sa.sin_family, szRemoteHostName.c_str(), &sa.sin_addr) == 1)
+		return SUCCESS;
+	sa.sin_family = AF_INET6;
+	if (inet_pton(sa.sin_family, szRemoteHostName.c_str(), &sa.sin_addr) == 1)
+		return SUCCESS;
 
 	return FAILURE;
 }
@@ -197,7 +191,7 @@ int csocket::connect( const char* remoteHost, const unsigned int remotePort )
 	}
 
 	// restore blocking mode on socket
-	long socketMode = fcntl(m_socket, F_GETFL, NULL);
+	long socketMode = fcntl(m_socket, F_GETFL, nullptr);
 	socketMode &= (~O_NONBLOCK);
 	fcntl(m_socket, F_SETFL, socketMode);
 
@@ -220,7 +214,7 @@ int csocket::canRead( bool* readyToRead, float waitTime )
 
 	timeval timeout;
 
-	if ( waitTime <= 0.0f )
+	if (waitTime <= 0.0F)
 	{
 		timeout.tv_sec = 0;
 		timeout.tv_usec = 0;
@@ -228,10 +222,10 @@ int csocket::canRead( bool* readyToRead, float waitTime )
 	else
 	{
 		timeout.tv_sec = static_cast<int>((waitTime));
-		timeout.tv_usec = static_cast<int>((1000000.0f * (waitTime - (float)timeout.tv_sec)));
+		timeout.tv_usec = static_cast<int>((1000000.0F * (waitTime - (float)timeout.tv_sec)));
 	}
 
-	int n = select(m_socket + 1, &fds, NULL, NULL, &timeout);
+	int n = select(m_socket + 1, &fds, nullptr, nullptr, &timeout);
 	if (n < 0)
 	{
 		m_socketState = ERRORED;
@@ -329,8 +323,7 @@ int csocket::write( const char* pDataBuffer, unsigned int numBytesToWrite )
 	return(numBytesToWrite - numBytesRemaining);
 }
 
-
-csocket::SocketState csocket::getState( void ) const
+csocket::SocketState csocket::getState() const
 {
 	return m_socketState;
 }
