@@ -14,20 +14,21 @@ namespace Plugins {
 	class CPluginMessageBase
 	{
 	public:
-		virtual ~CPluginMessageBase(void) {};
+	  virtual ~CPluginMessageBase() = default;
+	  ;
 
-		CPlugin*	m_pPlugin;
-		std::string	m_Name;
-		int			m_HwdID;
-		int			m_Unit;
-		bool		m_Delay;
-		time_t		m_When;
+	  CPlugin *m_pPlugin;
+	  std::string m_Name;
+	  int m_HwdID;
+	  int m_Unit;
+	  bool m_Delay;
+	  time_t m_When;
 
 	protected:
 		CPluginMessageBase(CPlugin* pPlugin) : m_pPlugin(pPlugin), m_HwdID(pPlugin->m_HwdID), m_Unit(-1), m_Delay(false)
 		{
 			m_Name = __func__;
-			m_When = time(0);
+			m_When = time(nullptr);
 		};
 		virtual void ProcessLocked() = 0;
 	public:
@@ -46,7 +47,7 @@ namespace Plugins {
 	class CHasConnection
 	{
 	public:
-		CHasConnection(PyObject* Connection) : m_pConnection(Connection)
+		CHasConnection(CConnection *Connection) : m_pConnection(Connection)
 		{
 			Py_XINCREF(m_pConnection);
 		};
@@ -54,30 +55,38 @@ namespace Plugins {
 		{
 			Py_XDECREF(m_pConnection);
 		}
-		PyObject*	m_pConnection;
+		CConnection *m_pConnection;
 	};
 
 	class InitializeMessage : public CPluginMessageBase
 	{
 	public:
 		InitializeMessage(CPlugin* pPlugin) : CPluginMessageBase(pPlugin) { m_Name = __func__; };
-		virtual void Process()
+		void Process() override
 		{
 			std::lock_guard<std::mutex> l(PythonMutex);
 			m_pPlugin->Initialise();
 		};
-		virtual void ProcessLocked() {};
+		void ProcessLocked() override{};
 	};
 
 	// Base callback message class
 	class CCallbackBase : public CPluginMessageBase
 	{
 	protected:
-		std::string	m_Callback;
-		virtual void ProcessLocked() = 0;
-	public:
-		CCallbackBase(CPlugin* pPlugin, const std::string &Callback) : CPluginMessageBase(pPlugin), m_Callback(Callback) {};
-		virtual void Callback(PyObject* pParams) { if (m_Callback.length()) m_pPlugin->Callback(m_Callback, pParams); };
+		PyNewRef	m_Target;
+		std::string m_Callback;
+		void ProcessLocked() override = 0;
+
+	      public:
+		CCallbackBase(CPlugin* pPlugin, const std::string &Callback) : CPluginMessageBase(pPlugin), m_Target(pPlugin->PythonModule()), m_Callback(Callback)
+		{
+			if (m_Target)
+			{
+				Py_INCREF(m_Target);
+			}
+		};
+		virtual void Callback(PyObject* pParams) { if (m_Callback.length()) m_pPlugin->Callback(m_Target, m_Callback, pParams); };
 		virtual const char* PythonName() { return m_Callback.c_str(); };
 	};
 
@@ -86,11 +95,11 @@ namespace Plugins {
 	public:
 		onStartCallback(CPlugin* pPlugin) : CCallbackBase(pPlugin, "onStart") { m_Name = __func__; };
 	protected:
-		virtual void ProcessLocked()
-		{
-			m_pPlugin->Start();
-			Callback(NULL);
-		};
+	  void ProcessLocked() override
+	  {
+		  m_pPlugin->Start();
+		  Callback(nullptr);
+	  };
 	};
 
 	class onHeartbeatCallback : public CCallbackBase
@@ -98,10 +107,10 @@ namespace Plugins {
 	public:
 		onHeartbeatCallback(CPlugin* pPlugin) : CCallbackBase(pPlugin, "onHeartbeat") { m_Name = __func__; };
 	protected:
-		virtual void ProcessLocked()
-		{
-			Callback(NULL);
-		};
+	  void ProcessLocked() override
+	  {
+		  Callback(nullptr);
+	  };
 	};
 
 #ifdef _WIN32
@@ -134,31 +143,65 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	class onConnectCallback : public CCallbackBase, public CHasConnection
 	{
 	public:
-		onConnectCallback(CPlugin* pPlugin, PyObject* Connection) : CCallbackBase(pPlugin, "onConnect"), CHasConnection(Connection) { m_Name = __func__; };
-		onConnectCallback(CPlugin* pPlugin, PyObject* Connection, const int Code, const std::string &Text) : CCallbackBase(pPlugin, "onConnect"), CHasConnection(Connection), m_Status(Code), m_Text(Text) { m_Name = __func__; };
+		onConnectCallback(CPlugin* pPlugin, CConnection* Connection, const int Code, const std::string &Text) : CCallbackBase(pPlugin, "onConnect"), CHasConnection(Connection), m_Status(Code), m_Text(Text)
+		{
+			m_Name = __func__;
+			if (Connection->Target)
+			{
+				m_Target += Connection->Target;
+			}
+		};
 		int						m_Status;
 		std::string				m_Text;
 	protected:
-		virtual void ProcessLocked()
-		{
+	  void ProcessLocked() override
+	  {
 #ifdef _WIN32
 			std::string textUTF8 = get_utf8_from_ansi(m_Text, GetACP());
 #else
 			std::string textUTF8 = m_Text; // TODO: Is it safe to assume non-Windows will always be UTF-8?
 #endif
-			Callback(Py_BuildValue("Ois", m_pConnection, m_Status, textUTF8.c_str()));  // 0 is success else socket failure code
+			PyNewRef pParams = Py_BuildValue("Ois", m_pConnection, m_Status, textUTF8.c_str());
+			Callback(pParams);
+	  };
+	};
+
+	class onTimeoutCallback : public CCallbackBase, public CHasConnection
+	{
+    public:
+		onTimeoutCallback(CPlugin *pPlugin, CConnection *Connection): CCallbackBase(pPlugin, "onTimeout"), CHasConnection(Connection) 
+		{
+			m_Name = __func__;
+			if (Connection->Target)
+			{
+				m_Target += Connection->Target;
+			}
+		};
+    protected:
+		virtual void ProcessLocked() override
+		{
+			PyNewRef pParams = Py_BuildValue("(O)", m_pConnection);
+			Callback(pParams);
 		};
 	};
 
 	class onDisconnectCallback : public CCallbackBase, public CHasConnection
 	{
 	public:
-		onDisconnectCallback(CPlugin* pPlugin, PyObject* Connection) : CCallbackBase(pPlugin, "onDisconnect"), CHasConnection(Connection) { m_Name = __func__; };
-	protected:
-		virtual void ProcessLocked()
+		onDisconnectCallback(CPlugin* pPlugin, CConnection* Connection) : CCallbackBase(pPlugin, "onDisconnect"), CHasConnection(Connection)
 		{
-			Callback(Py_BuildValue("(O)", m_pConnection));  // 0 is success else socket failure code
+			m_Name = __func__;
+			if (Connection->Target)
+			{
+				m_Target += Connection->Target;
+			}
 		};
+	protected:
+	  void ProcessLocked() override
+	  {
+		  PyNewRef pParams = Py_BuildValue("(O)", m_pConnection);
+		  Callback(pParams);
+	  };
 	};
 
 	class onDeviceAddedCallback : public CCallbackBase
@@ -166,13 +209,13 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	public:
 		onDeviceAddedCallback(CPlugin* pPlugin, int Unit) : CCallbackBase(pPlugin, "onDeviceAdded") { m_Unit = Unit; };
 	protected:
-		virtual void ProcessLocked()
-		{
-			m_pPlugin->onDeviceAdded(m_Unit);
+	  void ProcessLocked() override
+	  {
+		  m_pPlugin->onDeviceAdded(m_Unit);
 
-			PyObject*	pParams = Py_BuildValue("(i)", m_Unit);
-			Callback(pParams);
-		};
+		  PyNewRef	pParams = Py_BuildValue("(i)", m_Unit);
+		  Callback(pParams);
+	  };
 	};
 
 	class onDeviceModifiedCallback : public CCallbackBase
@@ -180,13 +223,13 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	public:
 		onDeviceModifiedCallback(CPlugin* pPlugin, int Unit) : CCallbackBase(pPlugin, "onDeviceModified") { m_Unit = Unit; };
 	protected:
-		virtual void ProcessLocked()
-		{
-			m_pPlugin->onDeviceModified(m_Unit);
+	  void ProcessLocked() override
+	  {
+		  m_pPlugin->onDeviceModified(m_Unit);
 
-			PyObject*	pParams = Py_BuildValue("(i)", m_Unit);
-			Callback(pParams);
-		};
+		  PyNewRef pParams = Py_BuildValue("(i)", m_Unit);
+		  Callback(pParams);
+	  };
 	};
 
 	class onDeviceRemovedCallback : public CCallbackBase
@@ -194,13 +237,13 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	public:
 		onDeviceRemovedCallback(CPlugin* pPlugin, int Unit) : CCallbackBase(pPlugin, "onDeviceRemoved") { m_Unit = Unit; };
 	protected:
-		virtual void ProcessLocked()
-		{
-			PyObject*	pParams = Py_BuildValue("(i)", m_Unit);
-			Callback(pParams);
+	  void ProcessLocked() override
+	  {
+		  PyNewRef pParams = Py_BuildValue("(i)", m_Unit);
+		  Callback(pParams);
 
-			m_pPlugin->onDeviceRemoved(m_Unit);
-		};
+		  m_pPlugin->onDeviceRemoved(m_Unit);
+	  };
 	};
 
 	class onCommandCallback : public CCallbackBase
@@ -210,7 +253,7 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 		{
 			m_Name = __func__;
 			m_Unit = Unit;
-			m_fLevel = -273.15f;
+			m_fLevel = -273.15F;
 			m_Command = Command;
 			m_iLevel = level;
 			m_iColor = color;
@@ -230,19 +273,19 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 		float					m_fLevel;
 
 	protected:
-		virtual void ProcessLocked()
-		{
-			PyObject*	pParams;
-			if (m_fLevel != -273.15f)
-			{
-				pParams = Py_BuildValue("isfs", m_Unit, m_Command.c_str(), m_fLevel, "");
-			}
-			else
-			{
-				pParams = Py_BuildValue("isis", m_Unit, m_Command.c_str(), m_iLevel, m_iColor.c_str());
-			}
-			Callback(pParams);
-		};
+	  void ProcessLocked() override
+	  {
+		  PyNewRef pParams;
+		  if (m_fLevel != -273.15F)
+		  {
+			  pParams = Py_BuildValue("isfs", m_Unit, m_Command.c_str(), m_fLevel, "");
+		  }
+		  else
+		  {
+			  pParams = Py_BuildValue("isis", m_Unit, m_Command.c_str(), m_iLevel, m_iColor.c_str());
+		  }
+		  Callback(pParams);
+	  };
 	};
 
 	class onSecurityEventCallback : public CCallbackBase
@@ -259,55 +302,67 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 		std::string		m_Description;
 
 	protected:
-		virtual void ProcessLocked()
-		{
-			PyObject*	pParams = Py_BuildValue("iis", m_Unit, m_iLevel, m_Description.c_str());
-			Callback(pParams);
-		};
+	  void ProcessLocked() override
+	  {
+		  PyNewRef pParams = Py_BuildValue("iis", m_Unit, m_iLevel, m_Description.c_str());
+		  Callback(pParams);
+	  };
 	};
 
 	class onMessageCallback : public CCallbackBase, public CHasConnection
 	{
 	public:
-		onMessageCallback(CPlugin* pPlugin, PyObject* Connection, const std::string& Buffer) : CCallbackBase(pPlugin, "onMessage"), CHasConnection(Connection), m_Data(NULL)
+		onMessageCallback(CPlugin *pPlugin, CConnection *Connection, const std::string &Buffer) : CCallbackBase(pPlugin, "onMessage"), CHasConnection(Connection), m_Data(nullptr)
 		{
 			m_Name = __func__;
 			m_Buffer.reserve(Buffer.length());
-			m_Buffer.assign((const byte*)Buffer.c_str(), (const byte*)Buffer.c_str()+Buffer.length());
+			m_Buffer.assign((const byte *)Buffer.c_str(), (const byte *)Buffer.c_str() + Buffer.length());
+			if (Connection->Target)
+			{
+				m_Target += Connection->Target;
+			}
 		};
-		onMessageCallback(CPlugin* pPlugin, PyObject* Connection, const std::vector<byte>& Buffer) : CCallbackBase(pPlugin, "onMessage"), CHasConnection(Connection), m_Data(NULL)
+		onMessageCallback(CPlugin *pPlugin, CConnection *Connection, const std::vector<byte> &Buffer): CCallbackBase(pPlugin, "onMessage"), CHasConnection(Connection), m_Data(nullptr)
 		{
 			m_Name = __func__;
 			m_Buffer = Buffer;
+			if (Connection->Target)
+			{
+				m_Target += Connection->Target;
+			}
 		};
-		onMessageCallback(CPlugin* pPlugin, PyObject* Connection, PyObject*	pData) : CCallbackBase(pPlugin, "onMessage"), CHasConnection(Connection)
+		onMessageCallback(CPlugin* pPlugin, CConnection* Connection, PyObject*	pData) : CCallbackBase(pPlugin, "onMessage"), CHasConnection(Connection)
 		{
 			m_Name = __func__;
 			m_Data = pData;
+			if (Connection->Target)
+			{
+				m_Target += Connection->Target;
+			}
 		};
 		std::vector<byte>		m_Buffer;
 		PyObject*				m_Data;
 
 	protected:
-		virtual void ProcessLocked()
-		{
-			PyObject*	pParams = NULL;
+	  void ProcessLocked() override
+	  {
+		  PyNewRef pParams = nullptr;
 
-			// Data is stored in a single vector of bytes
-			if (m_Buffer.size())
-			{
-				pParams = Py_BuildValue("Oy#", m_pConnection, &m_Buffer[0], m_Buffer.size());
-				Callback(pParams);
-			}
+		  // Data is stored in a single vector of bytes
+		  if (!m_Buffer.empty())
+		  {
+			  pParams = Py_BuildValue("Oy#", m_pConnection, &m_Buffer[0], m_Buffer.size());
+			  Callback(pParams);
+		  }
 
-			// Data is in a dictionary
-			if (m_Data)
-			{
-				pParams = Py_BuildValue("OO", m_pConnection, m_Data);
-				Callback(pParams);
-				Py_XDECREF(m_Data);
-			}
-		}
+		  // Data is in a dictionary
+		  if (m_Data)
+		  {
+			  pParams = Py_BuildValue("OO", m_pConnection, m_Data);
+			  Callback(pParams);
+			  Py_XDECREF(m_Data);
+		  }
+	  }
 	};
 
 	class onNotificationCallback : public CCallbackBase
@@ -341,11 +396,11 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 		std::string				m_ImageFile;
 
 	protected:
-		virtual void ProcessLocked()
-		{
-			PyObject*	pParams = Py_BuildValue("ssssiss", m_SuppliedName.c_str(), m_Subject.c_str(), m_Text.c_str(), m_Status.c_str(), m_Priority, m_Sound.c_str(), m_ImageFile.c_str());
-			Callback(pParams);
-		};
+	  void ProcessLocked() override
+	  {
+		  PyNewRef pParams = Py_BuildValue("ssssiss", m_SuppliedName.c_str(), m_Subject.c_str(), m_Text.c_str(), m_Status.c_str(), m_Priority, m_Sound.c_str(), m_ImageFile.c_str());
+		  Callback(pParams);
+	  };
 	};
 
 	class onStopCallback : public CCallbackBase
@@ -353,21 +408,23 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	public:
 		onStopCallback(CPlugin* pPlugin) : CCallbackBase(pPlugin, "onStop") { m_Name = __func__; };
 	protected:
-		virtual void ProcessLocked()
-		{
-			Callback(NULL);
-			m_pPlugin->Stop();
-		};
+	  void ProcessLocked() override
+	  {
+		  Callback(nullptr);
+		  m_pPlugin->Stop();
+	  };
 	};
 
 	// Base directive message class
 	class CDirectiveBase : public CPluginMessageBase
 	{
 	protected:
-		virtual void ProcessLocked() = 0;
+	  void ProcessLocked() override = 0;
+
 	public:
 		CDirectiveBase(CPlugin* pPlugin) : CPluginMessageBase(pPlugin) {};
-		virtual void Process() {
+		void Process() override
+		{
 			std::lock_guard<std::mutex> l(PythonMutex);
 			m_pPlugin->RestoreThread();
 			ProcessLocked();
@@ -378,36 +435,48 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	class ProtocolDirective : public CDirectiveBase, public CHasConnection
 	{
 	public:
-		ProtocolDirective(CPlugin* pPlugin, PyObject* Connection) : CDirectiveBase(pPlugin), CHasConnection(Connection) { m_Name = __func__; };
-		virtual void ProcessLocked() { m_pPlugin->ConnectionProtocol(this); };
+		ProtocolDirective(CPlugin* pPlugin, CConnection* Connection) : CDirectiveBase(pPlugin), CHasConnection(Connection) { m_Name = __func__; };
+		void ProcessLocked() override
+		{
+			m_pPlugin->ConnectionProtocol(this);
+		};
 	};
 
 	class ConnectDirective : public CDirectiveBase, public CHasConnection
 	{
 	public:
-		ConnectDirective(CPlugin* pPlugin, PyObject* Connection) : CDirectiveBase(pPlugin), CHasConnection(Connection) { m_Name = __func__; };
-		virtual void ProcessLocked() { m_pPlugin->ConnectionConnect(this); };
+		ConnectDirective(CPlugin* pPlugin, CConnection* Connection) : CDirectiveBase(pPlugin), CHasConnection(Connection) { m_Name = __func__; };
+		void ProcessLocked() override
+		{
+			m_pPlugin->ConnectionConnect(this);
+		};
 	};
 
 	class ListenDirective : public CDirectiveBase, public CHasConnection
 	{
 	public:
-		ListenDirective(CPlugin* pPlugin, PyObject* Connection) : CDirectiveBase(pPlugin), CHasConnection(Connection) { m_Name = __func__; };
-		virtual void ProcessLocked() { m_pPlugin->ConnectionListen(this); };
+		ListenDirective(CPlugin* pPlugin, CConnection* Connection) : CDirectiveBase(pPlugin), CHasConnection(Connection) { m_Name = __func__; };
+		void ProcessLocked() override
+		{
+			m_pPlugin->ConnectionListen(this);
+		};
 	};
 
 	class DisconnectDirective : public CDirectiveBase, public CHasConnection
 	{
 	public:
-		DisconnectDirective(CPlugin* pPlugin, PyObject* Connection) : CDirectiveBase(pPlugin), CHasConnection(Connection) { m_Name = __func__; };
-		virtual void ProcessLocked() { m_pPlugin->ConnectionDisconnect(this); };
+		DisconnectDirective(CPlugin* pPlugin, CConnection* Connection) : CDirectiveBase(pPlugin), CHasConnection(Connection) { m_Name = __func__; };
+		void ProcessLocked() override
+		{
+			m_pPlugin->ConnectionDisconnect(this);
+		};
 	};
 
 	class WriteDirective : public CDirectiveBase, public CHasConnection
 	{
 	public:
 		PyObject*		m_Object;
-		WriteDirective(CPlugin* pPlugin, PyObject* Connection, PyObject* pData, const int Delay) : CDirectiveBase(pPlugin), CHasConnection(Connection)
+		WriteDirective(CPlugin* pPlugin, CConnection* Connection, PyObject* pData, const int Delay) : CDirectiveBase(pPlugin), CHasConnection(Connection)
 		{
 			m_Name = __func__;
 			m_Object = pData;
@@ -419,20 +488,26 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 				m_Delay=true;
 			}
 		};
-		~WriteDirective()
+		~WriteDirective() override
 		{
 			if (m_Object)
 				Py_DECREF(m_Object);
 		}
 
-		virtual void ProcessLocked() { m_pPlugin->ConnectionWrite(this); };
+		void ProcessLocked() override
+		{
+			m_pPlugin->ConnectionWrite(this);
+		};
 	};
 
 	class SettingsDirective : public CDirectiveBase
 	{
 	public:
 		SettingsDirective(CPlugin* pPlugin) : CDirectiveBase(pPlugin) { m_Name = __func__; };
-		virtual void ProcessLocked() { m_pPlugin->LoadSettings(); };
+		void ProcessLocked() override
+		{
+			m_pPlugin->LoadSettings();
+		};
 	};
 
 	class PollIntervalDirective : public CDirectiveBase
@@ -440,7 +515,10 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	public:
 		PollIntervalDirective(CPlugin* pPlugin, const int PollInterval) : CDirectiveBase(pPlugin), m_Interval(PollInterval) { m_Name = __func__; };
 		int						m_Interval;
-		virtual void ProcessLocked() {m_pPlugin->PollInterval(m_Interval); };
+		void ProcessLocked() override
+		{
+			m_pPlugin->PollInterval(m_Interval);
+		};
 	};
 
 	class NotifierDirective : public CDirectiveBase
@@ -448,14 +526,18 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	public:
 		NotifierDirective(CPlugin* pPlugin, const char* Name) : CDirectiveBase(pPlugin), m_NotifierName(Name) { m_Name = __func__; };
 		std::string		m_NotifierName;
-		virtual void ProcessLocked() { m_pPlugin->Notifier(m_NotifierName); };
+		void ProcessLocked() override
+		{
+			m_pPlugin->Notifier(m_NotifierName);
+		};
 	};
 
 	// Base event message class
 	class CEventBase : public CPluginMessageBase
 	{
 	protected:
-		virtual void ProcessLocked() = 0;
+	  void ProcessLocked() override = 0;
+
 	public:
 		CEventBase(CPlugin* pPlugin) : CPluginMessageBase(pPlugin) {};
 	};
@@ -463,7 +545,7 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	class ReadEvent : public CEventBase, public CHasConnection
 	{
 	public:
-		ReadEvent(CPlugin* pPlugin, PyObject* Connection, const int ByteCount, const unsigned char* Data, const int ElapsedMs = -1) : CEventBase(pPlugin), CHasConnection(Connection)
+		ReadEvent(CPlugin* pPlugin, CConnection* Connection, const int ByteCount, const unsigned char* Data, const int ElapsedMs = -1) : CEventBase(pPlugin), CHasConnection(Connection)
 		{
 			m_Name = __func__;
 			m_ElapsedMs = ElapsedMs;
@@ -472,7 +554,7 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 		};
 		std::vector<byte>		m_Buffer;
 		int						m_ElapsedMs;
-		virtual void ProcessLocked()
+		void ProcessLocked() override
 		{
 			m_pPlugin->WriteDebugBuffer(m_Buffer, true);
 			m_pPlugin->ConnectionRead(this);
@@ -482,9 +564,12 @@ static std::string get_utf8_from_ansi(const std::string &utf8, int codepage)
 	class DisconnectedEvent : public CEventBase, public CHasConnection
 	{
 	public:
-		DisconnectedEvent(CPlugin* pPlugin, PyObject* Connection) : CEventBase(pPlugin), CHasConnection(Connection), bNotifyPlugin(true) { m_Name = __func__; };
-		DisconnectedEvent(CPlugin* pPlugin, PyObject* Connection, bool NotifyPlugin) : CEventBase(pPlugin), CHasConnection(Connection), bNotifyPlugin(NotifyPlugin) { m_Name = __func__; };
-		virtual void ProcessLocked() { m_pPlugin->DisconnectEvent(this); };
+		DisconnectedEvent(CPlugin* pPlugin, CConnection* Connection) : CEventBase(pPlugin), CHasConnection(Connection), bNotifyPlugin(true) { m_Name = __func__; };
+		DisconnectedEvent(CPlugin* pPlugin, CConnection* Connection, bool NotifyPlugin) : CEventBase(pPlugin), CHasConnection(Connection), bNotifyPlugin(NotifyPlugin) { m_Name = __func__; };
+		void ProcessLocked() override
+		{
+			m_pPlugin->DisconnectEvent(this);
+		};
 		bool	bNotifyPlugin;
 	};
-}
+} // namespace Plugins
