@@ -244,13 +244,12 @@ bool HTTPClient::GETBinary(const std::string &url, const std::vector<std::string
 		if (TimeOut != -1)
 			curl_easy_setopt(curl, CURLOPT_TIMEOUT, TimeOut);
 
-		struct curl_slist *headers = NULL;
-		if (ExtraHeaders.size() > 0)
+		struct curl_slist *headers = nullptr;
+		if (!ExtraHeaders.empty())
 		{
-			std::vector<std::string>::const_iterator itt;
-			for (itt = ExtraHeaders.begin(); itt != ExtraHeaders.end(); ++itt)
+			for (const auto &header : ExtraHeaders)
 			{
-				headers = curl_slist_append(headers, (*itt).c_str());
+				headers = curl_slist_append(headers, header.c_str());
 			}
 			curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers);
 		}
@@ -286,7 +285,8 @@ bool HTTPClient::GETBinary(const std::string &url, const std::vector<std::string
 
 		curl_easy_cleanup(curl);
 
-		if (headers != NULL) {
+		if (headers != nullptr)
+		{
 			curl_slist_free_all(headers); /* free the header list */
 		}
 
@@ -323,13 +323,12 @@ bool HTTPClient::POSTBinary(const std::string &url, const std::string &postdata,
 		curl_easy_setopt(curl, CURLOPT_URL, url.c_str());
 		curl_easy_setopt(curl, CURLOPT_POST, 1);
 
-		struct curl_slist *headers = NULL;
-		if (ExtraHeaders.size() > 0)
+		struct curl_slist *headers = nullptr;
+		if (!ExtraHeaders.empty())
 		{
-			std::vector<std::string>::const_iterator itt;
-			for (itt = ExtraHeaders.begin(); itt != ExtraHeaders.end(); ++itt)
+			for (const auto &header : ExtraHeaders)
 			{
-				headers = curl_slist_append(headers, (*itt).c_str());
+				headers = curl_slist_append(headers, header.c_str());
 			}
 			curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers);
 		}
@@ -357,7 +356,7 @@ bool HTTPClient::POSTBinary(const std::string &url, const std::string &postdata,
 
 		curl_easy_cleanup(curl);
 
-		if (headers != NULL)
+		if (headers != nullptr)
 		{
 			curl_slist_free_all(headers); /* free the header list */
 		}
@@ -393,13 +392,12 @@ std::vector<std::string> &vHeaderData, const long TimeOut)
 		//curl_easy_setopt(curl, CURLOPT_PUT, 1);
 		curl_easy_setopt(curl, CURLOPT_CUSTOMREQUEST, "PUT");
 
-		struct curl_slist *headers = NULL;
-		if (ExtraHeaders.size() > 0)
+		struct curl_slist *headers = nullptr;
+		if (!ExtraHeaders.empty())
 		{
-			std::vector<std::string>::const_iterator itt;
-			for (itt = ExtraHeaders.begin(); itt != ExtraHeaders.end(); ++itt)
+			for (const auto &header : ExtraHeaders)
 			{
-				headers = curl_slist_append(headers, (*itt).c_str());
+				headers = curl_slist_append(headers, header.c_str());
 			}
 			curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers);
 		}
@@ -427,7 +425,7 @@ std::vector<std::string> &vHeaderData, const long TimeOut)
 
 		curl_easy_cleanup(curl);
 
-		if (headers != NULL)
+		if (headers != nullptr)
 		{
 			curl_slist_free_all(headers); /* free the header list */
 		}
@@ -463,13 +461,12 @@ std::vector<std::string> &vHeaderData, const long TimeOut)
 		//curl_easy_setopt(curl, CURLOPT_PUT, 1);
 		curl_easy_setopt(curl, CURLOPT_CUSTOMREQUEST, "DELETE");
 
-		struct curl_slist *headers = NULL;
-		if (ExtraHeaders.size() > 0)
+		struct curl_slist *headers = nullptr;
+		if (!ExtraHeaders.empty())
 		{
-			std::vector<std::string>::const_iterator itt;
-			for (itt = ExtraHeaders.begin(); itt != ExtraHeaders.end(); ++itt)
+			for (const auto &header : ExtraHeaders)
 			{
-				headers = curl_slist_append(headers, (*itt).c_str());
+				headers = curl_slist_append(headers, header.c_str());
 			}
 			curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers);
 		}
@@ -497,7 +494,7 @@ std::vector<std::string> &vHeaderData, const long TimeOut)
 
 		curl_easy_cleanup(curl);
 
-		if (headers != NULL)
+		if (headers != nullptr)
 		{
 			curl_slist_free_all(headers); /* free the header list */
 		}
@@ -540,13 +537,12 @@ bool HTTPClient::GETBinarySingleLine(const std::string &url, const std::vector<s
 			curl_easy_setopt(curl, CURLOPT_TIMEOUT, TimeOut);
 		}
 
-		struct curl_slist *headers = NULL;
-		if (ExtraHeaders.size() > 0)
+		struct curl_slist *headers = nullptr;
+		if (!ExtraHeaders.empty())
 		{
-			std::vector<std::string>::const_iterator itt;
-			for (itt = ExtraHeaders.begin(); itt != ExtraHeaders.end(); ++itt)
+			for (const auto &header : ExtraHeaders)
 			{
-				headers = curl_slist_append(headers, (*itt).c_str());
+				headers = curl_slist_append(headers, header.c_str());
 			}
 			curl_easy_setopt(curl, CURLOPT_HTTPHEADER, headers);
 		}
@@ -579,7 +575,8 @@ bool HTTPClient::GETBinarySingleLine(const std::string &url, const std::vector<s
 
 		curl_easy_cleanup(curl);
 
-		if (headers != NULL) {
+		if (headers != nullptr)
+		{
 			curl_slist_free_all(headers); /* free the header list */
 		}
 		return bOK;
