@@ -16,7 +16,8 @@ namespace http {
 
 			// called from mainworker():
 #ifdef WWW_ENABLE_SSL
-			bool StartServers(server_settings & web_settings, ssl_server_settings & secure_web_settings, const std::string &serverpath, const bool bIgnoreUsernamePassword, tcp::server::CTCPServer *sharedServer);
+			bool StartServers(server_settings &web_settings, ssl_server_settings &secure_web_settings, const std::string &serverpath, bool bIgnoreUsernamePassword,
+					  tcp::server::CTCPServer *sharedServer);
 #else
 			bool StartServers(server_settings & web_settings, const std::string &serverpath, const bool bIgnoreUsernamePassword, tcp::server::CTCPServer *sharedServer);
 #endif
@@ -26,26 +27,15 @@ namespace http {
 			CProxyClient *GetProxyForMaster(DomoticzTCP *master);
 			void RemoveMaster(DomoticzTCP *master);
 #endif
-			void SetWebCompressionMode(const _eWebCompressionMode gzmode);
-			void SetAuthenticationMethod(const _eAuthenticationMethod amethod);
+			void SetWebCompressionMode(_eWebCompressionMode gzmode);
+			void SetAuthenticationMethod(_eAuthenticationMethod amethod);
 			void SetWebTheme(const std::string &themename);
 			void SetWebRoot(const std::string &webRoot);
 			void ClearUserPasswords();
 			// called from OTGWBase()
-			void GetJSonDevices(
-				Json::Value &root,
-				const std::string &rused,
-				const std::string &rfilter,
-				const std::string &order,
-				const std::string &rowid,
-				const std::string &planID,
-				const std::string &floorID,
-				const bool bDisplayHidden,
-				const bool bDisplayDisabled,
-				const bool bFetchFavorites,
-				const time_t LastUpdate,
-				const std::string &username,
-				const std::string &hardwareid = "");
+			void GetJSonDevices(Json::Value &root, const std::string &rused, const std::string &rfilter, const std::string &order, const std::string &rowid, const std::string &planID,
+					    const std::string &floorID, bool bDisplayHidden, bool bDisplayDisabled, bool bFetchFavorites, time_t LastUpdate, const std::string &username,
+					    const std::string &hardwareid = "");
 			// called from CSQLHelper
 			void ReloadCustomSwitchIcons();
 			std::string our_listener_port;
