@@ -53,14 +53,14 @@ typedef unsigned char       BYTE;
 #include <sstream>
 #include <string>
 #include <thread>
+#include <cmath>
 
 // third-party
 #include <json/json.h>
 #include "RFXtrx.h"
+#include <fmt/core.h>
 
 // rarely changing project-specific
 #include "concurrent_queue.h"
 #include "localtime_r.h"
-#include "Logger.h"
-#include "Noncopyable.h"
 #include "StoppableTask.h"
