@@ -13,10 +13,6 @@ CNotificationLogitechMediaServer::CNotificationLogitechMediaServer() : CNotifica
 	SetupConfig(std::string("LmsDuration"), &_Duration);
 }
 
-CNotificationLogitechMediaServer::~CNotificationLogitechMediaServer()
-{
-}
-
 bool CNotificationLogitechMediaServer::SendMessageImplementation(
 	const uint64_t Idx,
 	const std::string &Name,
@@ -36,7 +32,8 @@ bool CNotificationLogitechMediaServer::SendMessageImplementation(
 	CDomoticzHardwareBase *pHardware = m_mainworker.GetHardwareByType(HTYPE_LogitechMediaServer);
 	CLogitechMediaServer* pLMS = dynamic_cast<CLogitechMediaServer*>(pHardware);
 
-	if (pHardware == NULL) {
+	if (pHardware == nullptr)
+	{
 		std::stringstream logline;
 		logline << "Error sending notification: 'Logitech Media Server' not found in Hardware-list";
 		_log.Log(LOG_ERROR, "%s", logline.str().c_str());
@@ -47,9 +44,8 @@ bool CNotificationLogitechMediaServer::SendMessageImplementation(
 	std::vector<std::string> results;
 	StringSplit(_PlayerMac, ";", results);
 
-	for (int i = 0; i < (int)results.size(); i++)
+	for (const auto &sPlayerId : results)
 	{
-		std::string sPlayerId = results[i];
 		pLMS->SendText(sPlayerId, sSubject, Text, _Duration);
 	}
 	return true;
