@@ -9,10 +9,6 @@ CNotificationProwl::CNotificationProwl() : CNotificationBase(std::string("prowl"
 	SetupConfig(std::string("ProwlAPI"), _apikey);
 }
 
-CNotificationProwl::~CNotificationProwl()
-{
-}
-
 bool CNotificationProwl::SendMessageImplementation(
 	const uint64_t Idx,
 	const std::string &Name,
@@ -40,5 +36,5 @@ bool CNotificationProwl::SendMessageImplementation(
 
 bool CNotificationProwl::IsConfigured()
 {
-	return _apikey != "";
+	return !_apikey.empty();
 }
