@@ -14,6 +14,8 @@
 #define __STDC_FORMAT_MACROS
 #include <inttypes.h>
 
+extern CFibaroPush m_fibaropush;
+
 CFibaroPush::CFibaroPush()
 {
 	m_PushType = PushType::PUSHTYPE_FIBARO;
@@ -23,7 +25,8 @@ CFibaroPush::CFibaroPush()
 void CFibaroPush::Start()
 {
 	UpdateActive();
-	m_sConnection = m_mainworker.sOnDeviceReceived.connect(boost::bind(&CFibaroPush::OnDeviceReceived, this, _1, _2, _3, _4));
+	ReloadPushLinks(m_PushType);
+	m_sConnection = m_mainworker.sOnDeviceReceived.connect([this](auto id, auto idx, const auto &name, auto rx) { OnDeviceReceived(id, idx, name, rx); });
 }
 
 void CFibaroPush::Stop()
@@ -41,18 +44,25 @@ void CFibaroPush::UpdateActive()
 
 void CFibaroPush::OnDeviceReceived(const int m_HwdID, const uint64_t DeviceRowIdx, const std::string &DeviceName, const unsigned char *pRXCommand)
 {
-	m_DeviceRowIdx = DeviceRowIdx;
 	if (m_bLinkActive)
 	{
-		DoFibaroPush();
+		DoFibaroPush(DeviceRowIdx);
 	}
 }
 
-void CFibaroPush::DoFibaroPush()
+void CFibaroPush::DoFibaroPush(const uint64_t DeviceRowIdx)
 {
-	std::string fibaroIP = "";
-	std::string fibaroUsername = "";
-	std::string fibaroPassword = "";
+	std::vector<std::vector<std::string>> result;
+	result = m_sql.safe_query("SELECT A.DeviceRowID, A.DelimitedValue, B.ID, B.Type, B.SubType, B.nValue, B.sValue, A.TargetType, A.TargetVariable, A.TargetDeviceID, A.TargetProperty, "
+				  "A.IncludeUnit, B.SwitchType FROM PushLink as A, DeviceStatus as B "
+				  "WHERE (A.PushType==%d AND A.DeviceRowID == '%" PRIu64 "' AND A.Enabled = '1' AND A.DeviceRowID==B.ID)",
+				  PushType::PUSHTYPE_FIBARO, DeviceRowIdx);
+	if (result.empty())
+		return;
+
+	std::string fibaroIP;
+	std::string fibaroUsername;
+	std::string fibaroPassword;
 	int iIsVersion4 = 0;
 	m_sql.GetPreferencesVar("FibaroIP", fibaroIP);
 	m_sql.GetPreferencesVar("FibaroUsername", fibaroUsername);
@@ -68,147 +78,134 @@ void CFibaroPush::DoFibaroPush()
 	}
 	bool bIsV4 = (iIsVersion4 != 0);
 
-	if (
-		(fibaroIP == "") ||
-		(fibaroUsername == "") ||
-		(fibaroPassword == "")
-		)
+	if ((fibaroIP.empty()) || (fibaroUsername.empty()) || (fibaroPassword.empty()))
 		return;
-	std::vector<std::vector<std::string> > result;
-	result = m_sql.safe_query(
-		"SELECT A.DeviceRowID, A.DelimitedValue, B.ID, B.Type, B.SubType, B.nValue, B.sValue, A.TargetType, A.TargetVariable, A.TargetDeviceID, A.TargetProperty, A.IncludeUnit, B.SwitchType FROM PushLink as A, DeviceStatus as B "
-		"WHERE (A.PushType==%d AND A.DeviceRowID == '%" PRIu64 "' AND A.Enabled = '1' AND A.DeviceRowID==B.ID)",
-		PushType::PUSHTYPE_FIBARO,
-		m_DeviceRowIdx);
-	if (!result.empty())
+	for (const auto &sd : result)
 	{
 		std::string sendValue;
-		std::vector<std::vector<std::string> >::const_iterator itt;
-		for (itt = result.begin(); itt != result.end(); ++itt)
-		{
-			std::vector<std::string> sd = *itt;
-			int delpos = atoi(sd[1].c_str());
-			int dType = atoi(sd[3].c_str());
-			int dSubType = atoi(sd[4].c_str());
-			int nValue = atoi(sd[5].c_str());
-			std::string sValue = sd[6].c_str();
-			int targetType = atoi(sd[7].c_str());
-			std::string targetVariable = sd[8].c_str();
-			int targetDeviceID = atoi(sd[9].c_str());
-			std::string targetProperty = sd[10].c_str();
-			int includeUnit = atoi(sd[11].c_str());
-			int metertype = atoi(sd[12].c_str());
-			std::string lstatus = "";
+		int delpos = atoi(sd[1].c_str());
+		int dType = atoi(sd[3].c_str());
+		int dSubType = atoi(sd[4].c_str());
+		int nValue = atoi(sd[5].c_str());
+		std::string sValue = sd[6];
+		int targetType = atoi(sd[7].c_str());
+		std::string targetVariable = sd[8];
+		int targetDeviceID = atoi(sd[9].c_str());
+		std::string targetProperty = sd[10];
+		int includeUnit = atoi(sd[11].c_str());
+		int metertype = atoi(sd[12].c_str());
+		std::string lstatus;
 
-			if ((targetType == 0) || (targetType == 1)) {
-				if (delpos == 0) {
-					int llevel = 0;
-					bool bHaveDimmer = false;
-					bool bHaveGroupCmd = false;
-					int maxDimLevel = 0;
-					GetLightStatus(dType, dSubType, (_eSwitchType)metertype, nValue, sValue, lstatus, llevel, bHaveDimmer, maxDimLevel, bHaveGroupCmd);
-					sendValue = lstatus;
-				}
-				else if (delpos > 0) {
-					std::vector<std::string> strarray;
-					if (sValue.find(";") != std::string::npos) {
-						StringSplit(sValue, ";", strarray);
-						if (int(strarray.size()) >= delpos)
-						{
-							std::string rawsendValue = strarray[delpos - 1].c_str();
-							sendValue = ProcessSendValue(rawsendValue, delpos, nValue, includeUnit, dType, dSubType, metertype);
-						}
-					}
-					else
-						sendValue = ProcessSendValue(sValue, delpos, nValue, includeUnit, dType, dSubType, metertype);
-				}
-			}
-			else { // scenes/reboot, only on/off
+		if ((targetType == 0) || (targetType == 1)) {
+			if (delpos == 0) {
 				int llevel = 0;
 				bool bHaveDimmer = false;
 				bool bHaveGroupCmd = false;
 				int maxDimLevel = 0;
-				GetLightStatus(dType, dSubType, STYPE_OnOff, nValue, sValue, lstatus, llevel, bHaveDimmer, maxDimLevel, bHaveGroupCmd);
+				GetLightStatus(dType, dSubType, (_eSwitchType)metertype, nValue, sValue, lstatus, llevel, bHaveDimmer, maxDimLevel, bHaveGroupCmd);
 				sendValue = lstatus;
 			}
-			if (sendValue != "") {
-				std::string sResult;
-				std::stringstream sPostData;
-				std::stringstream Url;
-				std::vector<std::string> ExtraHeaders;
-
-				Url << "http://";
-
-				if (bIsV4) {
-					// Create basic authentication header
-					std::stringstream sstr;
-					sstr << fibaroUsername << ":" << fibaroPassword;
-					std::string m_AccessToken = base64_encode(sstr.str());
-					ExtraHeaders.push_back("Authorization:Basic " + m_AccessToken);
-				}
-				else {
-					Url << fibaroUsername << ":" << fibaroPassword << "@"; // Add user name in url for earlier than V4
-				}
-
-				Url << fibaroIP << "/";
-
-				sendValue = CURLEncode::URLEncode(sendValue);
-
-				if (targetType == 0) {
-					Url << "api/globalVariables";
-
-					if (bIsV4)
-						Url << "/" << targetVariable;
-
-					sPostData << "{\"name\": \"" << targetVariable << "\", \"value\": \"" << sendValue << "\"";
-
-					if (bIsV4)
-						sPostData << ", \"invokeScenes\": true";
-
-					sPostData << " }";
-
-					if (fibaroDebugActive) {
-						_log.Log(LOG_NORM, "FibaroLink: sending global variable %s with value: %s", targetVariable.c_str(), sendValue.c_str());
-					}
-					if (!HTTPClient::PUT(Url.str(), sPostData.str(), ExtraHeaders, sResult))
+			else if (delpos > 0) {
+				std::vector<std::string> strarray;
+				if (sValue.find(';') != std::string::npos)
+				{
+					StringSplit(sValue, ";", strarray);
+					if (int(strarray.size()) >= delpos)
 					{
-						_log.Log(LOG_ERROR, "Error sending data to Fibaro!");
+						std::string rawsendValue = strarray[delpos - 1];
+						sendValue = ProcessSendValue(DeviceRowIdx, rawsendValue, delpos, nValue, includeUnit, dType, dSubType, metertype);
+					}
+				}
+				else
+					sendValue = ProcessSendValue(DeviceRowIdx, sValue, delpos, nValue, includeUnit, dType, dSubType, metertype);
+			}
+		}
+		else { // scenes/reboot, only on/off
+			int llevel = 0;
+			bool bHaveDimmer = false;
+			bool bHaveGroupCmd = false;
+			int maxDimLevel = 0;
+			GetLightStatus(dType, dSubType, STYPE_OnOff, nValue, sValue, lstatus, llevel, bHaveDimmer, maxDimLevel, bHaveGroupCmd);
+			sendValue = lstatus;
+		}
+		if (sendValue.empty())
+			continue;
 
-					}
+		std::string sResult;
+		std::stringstream sPostData;
+		std::stringstream Url;
+		std::vector<std::string> ExtraHeaders;
+
+		Url << "http://";
+
+		if (bIsV4) {
+			// Create basic authentication header
+			std::stringstream sstr;
+			sstr << fibaroUsername << ":" << fibaroPassword;
+			std::string m_AccessToken = base64_encode(sstr.str());
+			ExtraHeaders.push_back("Authorization:Basic " + m_AccessToken);
+		}
+		else {
+			Url << fibaroUsername << ":" << fibaroPassword << "@"; // Add user name in url for earlier than V4
+		}
+
+		Url << fibaroIP << "/";
+
+		sendValue = CURLEncode::URLEncode(sendValue);
+
+		if (targetType == 0) {
+			Url << "api/globalVariables";
+
+			if (bIsV4)
+				Url << "/" << targetVariable;
+
+			sPostData << R"({"name": ")" << targetVariable << R"(", "value": ")" << sendValue << "\"";
+
+			if (bIsV4)
+				sPostData << ", \"invokeScenes\": true";
+
+			sPostData << " }";
+
+			if (fibaroDebugActive) {
+				_log.Log(LOG_NORM, "FibaroLink: sending global variable %s with value: %s", targetVariable.c_str(), sendValue.c_str());
+			}
+			if (!HTTPClient::PUT(Url.str(), sPostData.str(), ExtraHeaders, sResult))
+			{
+				_log.Log(LOG_ERROR, "Error sending data to Fibaro!");
+
+			}
+		}
+		else if (targetType == 1) {
+			Url << "api/callAction?deviceid=" << targetDeviceID << "&name=setProperty&arg1=" << targetProperty << "&arg2=" << sendValue;
+			if (fibaroDebugActive) {
+				_log.Log(LOG_NORM, "FibaroLink: sending value %s to property %s of virtual device id %d", sendValue.c_str(), targetProperty.c_str(), targetDeviceID);
+			}
+			if (!HTTPClient::GET(Url.str(), ExtraHeaders, sResult))
+			{
+				_log.Log(LOG_ERROR, "Error sending data to Fibaro!");
+			}
+		}
+		else if (targetType == 2) {
+			if (((delpos == 0) && (lstatus == "Off")) || ((delpos == 1) && (lstatus == "On"))) {
+				Url << "api/sceneControl?id=" << targetDeviceID << "&action=start";
+				if (fibaroDebugActive) {
+					_log.Log(LOG_NORM, "FibaroLink: activating scene %d", targetDeviceID);
 				}
-				else if (targetType == 1) {
-					Url << "api/callAction?deviceid=" << targetDeviceID << "&name=setProperty&arg1=" << targetProperty << "&arg2=" << sendValue;
-					if (fibaroDebugActive) {
-						_log.Log(LOG_NORM, "FibaroLink: sending value %s to property %s of virtual device id %d", sendValue.c_str(), targetProperty.c_str(), targetDeviceID);
-					}
-					if (!HTTPClient::GET(Url.str(), ExtraHeaders, sResult))
-					{
-						_log.Log(LOG_ERROR, "Error sending data to Fibaro!");
-					}
+				if (!HTTPClient::GET(Url.str(), ExtraHeaders, sResult))
+				{
+					_log.Log(LOG_ERROR, "Error sending data to Fibaro!");
 				}
-				else if (targetType == 2) {
-					if (((delpos == 0) && (lstatus == "Off")) || ((delpos == 1) && (lstatus == "On"))) {
-						Url << "api/sceneControl?id=" << targetDeviceID << "&action=start";
-						if (fibaroDebugActive) {
-							_log.Log(LOG_NORM, "FibaroLink: activating scene %d", targetDeviceID);
-						}
-						if (!HTTPClient::GET(Url.str(), ExtraHeaders, sResult))
-						{
-							_log.Log(LOG_ERROR, "Error sending data to Fibaro!");
-						}
-					}
+			}
+		}
+		else if (targetType == 3) {
+			if (((delpos == 0) && (lstatus == "Off")) || ((delpos == 1) && (lstatus == "On"))) {
+				Url << "api/settings/reboot";
+				if (fibaroDebugActive) {
+					_log.Log(LOG_NORM, "FibaroLink: reboot");
 				}
-				else if (targetType == 3) {
-					if (((delpos == 0) && (lstatus == "Off")) || ((delpos == 1) && (lstatus == "On"))) {
-						Url << "api/settings/reboot";
-						if (fibaroDebugActive) {
-							_log.Log(LOG_NORM, "FibaroLink: reboot");
-						}
-						if (!HTTPClient::POST(Url.str(), sPostData.str(), ExtraHeaders, sResult))
-						{
-							_log.Log(LOG_ERROR, "Error sending data to Fibaro!");
-						}
-					}
+				if (!HTTPClient::POST(Url.str(), sPostData.str(), ExtraHeaders, sResult))
+				{
+					_log.Log(LOG_ERROR, "Error sending data to Fibaro!");
 				}
 			}
 		}
@@ -232,21 +229,14 @@ namespace http {
 			std::string linkactive = request::findValue(&req, "linkactive");
 			std::string isversion4 = request::findValue(&req, "isversion4");
 			std::string debugenabled = request::findValue(&req, "debugenabled");
-			if (
-				(remote == "") ||
-				(username == "") ||
-				(password == "") ||
-				(linkactive == "") ||
-				(isversion4 == "") ||
-				(debugenabled == "")
-				)
+			if ((remote.empty()) || (username.empty()) || (password.empty()) || (linkactive.empty()) || (isversion4.empty()) || (debugenabled.empty()))
 				return;
 			int ilinkactive = atoi(linkactive.c_str());
 			int iisversion4 = atoi(isversion4.c_str());
 			int idebugenabled = atoi(debugenabled.c_str());
-			m_sql.UpdatePreferencesVar("FibaroIP", remote.c_str());
-			m_sql.UpdatePreferencesVar("FibaroUsername", username.c_str());
-			m_sql.UpdatePreferencesVar("FibaroPassword", password.c_str());
+			m_sql.UpdatePreferencesVar("FibaroIP", remote);
+			m_sql.UpdatePreferencesVar("FibaroUsername", username);
+			m_sql.UpdatePreferencesVar("FibaroPassword", password);
 			m_sql.UpdatePreferencesVar("FibaroActive", ilinkactive);
 			m_sql.UpdatePreferencesVar("FibaroVersion4", iisversion4);
 			m_sql.UpdatePreferencesVar("FibaroDebug", idebugenabled);
@@ -309,11 +299,9 @@ namespace http {
 			result = m_sql.safe_query("SELECT A.ID,A.DeviceRowID,A.Delimitedvalue,A.TargetType,A.TargetVariable,A.TargetDeviceID,A.TargetProperty,A.Enabled, B.Name, A.IncludeUnit FROM PushLink as A, DeviceStatus as B WHERE (A.PushType==%d AND A.DeviceRowID==B.ID)", CBasePush::PushType::PUSHTYPE_FIBARO);
 			if (!result.empty())
 			{
-				std::vector<std::vector<std::string> >::const_iterator itt;
 				int ii = 0;
-				for (itt = result.begin(); itt != result.end(); ++itt)
+				for (const auto &sd : result)
 				{
-					std::vector<std::string> sd = *itt;
 					root["result"][ii]["idx"] = sd[0];
 					root["result"][ii]["DeviceID"] = sd[1];
 					root["result"][ii]["Delimitedvalue"] = sd[2];
@@ -349,11 +337,11 @@ namespace http {
 			std::string targetproperty = request::findValue(&req, "targetproperty");
 			std::string linkactive = request::findValue(&req, "linkactive");
 			std::string includeunit = request::findValue(&req, "includeunit");
-			if ((targettypei == 0) && (targetvariable == ""))
+			if ((targettypei == 0) && (targetvariable.empty()))
 				return;
-			if ((targettypei == 1) && ((targetdeviceid == "") || (targetproperty == "")))
+			if ((targettypei == 1) && ((targetdeviceid.empty()) || (targetproperty.empty())))
 				return;
-			if ((targettypei == 2) && (targetdeviceid == ""))
+			if ((targettypei == 2) && (targetdeviceid.empty()))
 				return;
 			if (idx == "0") {
 				m_sql.safe_query(
@@ -383,6 +371,7 @@ namespace http {
 					idx.c_str()
 				);
 			}
+			m_fibaropush.ReloadPushLinks(CBasePush::PushType::PUSHTYPE_FIBARO);
 			root["status"] = "OK";
 			root["title"] = "SaveFibaroLink";
 		}
@@ -396,11 +385,12 @@ namespace http {
 			}
 
 			std::string idx = request::findValue(&req, "idx");
-			if (idx == "")
+			if (idx.empty())
 				return;
 			m_sql.safe_query("DELETE FROM PushLink WHERE (ID=='%q')", idx.c_str());
+			m_fibaropush.ReloadPushLinks(CBasePush::PushType::PUSHTYPE_FIBARO);
 			root["status"] = "OK";
 			root["title"] = "DeleteFibaroLink";
 		}
-	}
-}
\ No newline at end of file
+	} // namespace server
+} // namespace http
