@@ -4,8 +4,8 @@
 namespace http {
 	namespace server {
 		class CWebsocketHandler;
-	}
-}
+	} // namespace server
+} // namespace http
 
 class CWebSocketPush : public CBasePush
 {
@@ -13,8 +13,8 @@ public:
 	explicit CWebSocketPush(http::server::CWebsocketHandler *sock);
 	void Start();
 	void Stop();
-	void ListenTo(const unsigned long long DeviceRowIdx);
-	void UnlistenTo(const unsigned long long DeviceRowIdx);
+	void ListenTo(unsigned long long DeviceRowIdx);
+	void UnlistenTo(unsigned long long DeviceRowIdx);
 	void ClearListenTable();
 	void ListenToRoomplan();
 	void UnlistenToRoomplan();
@@ -23,11 +23,13 @@ public:
 	void onRoomplanChanged();
 	void onDeviceTableChanged(); // device added, or deleted
 	// etc, we need a notification of all changes that need to be reflected in the UI
-	bool WeListenTo(const unsigned long long DeviceRowIdx);
-private:
-	void OnDeviceReceived(const int m_HwdID, const unsigned long long DeviceRowIdx, const std::string &DeviceName, const unsigned char *pRXCommand);
-	void OnNotificationReceived(const std::string &Subject, const std::string &Text, const std::string &ExtraData, const int Priority, const std::string & Sound, const bool bFromNotification);
-	void OnSceneChange(const unsigned long long SceneRowIdx, const std::string& SceneName);
+	bool WeListenTo(unsigned long long DeviceRowIdx);
+
+      private:
+	void OnDeviceReceived(int m_HwdID, unsigned long long DeviceRowIdx, const std::string &DeviceName, const unsigned char *pRXCommand);
+	void OnDeviceUpdate(int m_HwdID, unsigned long long DeviceRowIdx);
+	void OnNotificationReceived(const std::string &Subject, const std::string &Text, const std::string &ExtraData, int Priority, const std::string &Sound, bool bFromNotification);
+	void OnSceneChange(unsigned long long SceneRowIdx, const std::string &SceneName);
 	bool listenRoomplan;
 	bool listenDeviceTable;
 	std::vector<unsigned long long> listenIdxs;
