@@ -9,7 +9,6 @@
 //
 #include "stdafx.h"
 #include "connection.hpp"
-#include <boost/bind.hpp>
 #include <boost/algorithm/string.hpp>
 #include "connection_manager.hpp"
 #include "request_handler.hpp"
@@ -23,51 +22,49 @@ namespace http {
 		extern time_t last_write_time(const std::string& path);
 
 		// this is the constructor for plain connections
-		connection::connection(boost::asio::io_service& io_service,
-			connection_manager& manager,
-			request_handler& handler,
-			int read_timeout) :
-			connection_manager_(manager),
-			request_handler_(handler),
-			read_timeout_(read_timeout),
-			read_timer_(io_service, boost::posix_time::seconds(read_timeout)),
-			websocket_parser(boost::bind(&connection::MyWrite, this, _1), handler.Get_myWebem(), boost::bind(&connection::WS_Write, this, _1)),
-			status_(INITIALIZING),
-			default_abandoned_timeout_(20 * 60), // 20mn before stopping abandoned connection
-			abandoned_timer_(io_service, boost::posix_time::seconds(default_abandoned_timeout_)),
-			default_max_requests_(20),
-			send_buffer_(NULL)
+		connection::connection(boost::asio::io_service &io_service, connection_manager &manager, request_handler &handler, int read_timeout)
+			: send_buffer_(nullptr)
+			, read_timeout_(read_timeout)
+			, read_timer_(io_service, boost::posix_time::seconds(read_timeout))
+			, default_abandoned_timeout_(20 * 60)
+			// 20mn before stopping abandoned connection
+			, abandoned_timer_(io_service, boost::posix_time::seconds(default_abandoned_timeout_))
+			, connection_manager_(manager)
+			, request_handler_(handler)
+			, status_(INITIALIZING)
+			, default_max_requests_(20)
+			, websocket_parser([this](auto &&r) { MyWrite(r); }, handler.Get_myWebem(), [this](auto &&r) { WS_Write(r); })
 		{
 			secure_ = false;
 			keepalive_ = false;
 			write_in_progress = false;
 			connection_type = ConnectionType::connection_http;
 #ifdef WWW_ENABLE_SSL
-			sslsocket_ = NULL;
+			sslsocket_ = nullptr;
 #endif
 			socket_ = new boost::asio::ip::tcp::socket(io_service);
 		}
 
 #ifdef WWW_ENABLE_SSL
 		// this is the constructor for secure connections
-		connection::connection(boost::asio::io_service& io_service,
-			connection_manager& manager, request_handler& handler, int read_timeout, boost::asio::ssl::context& context) :
-			connection_manager_(manager),
-			request_handler_(handler),
-			read_timeout_(read_timeout),
-			read_timer_(io_service, boost::posix_time::seconds(read_timeout)),
-			websocket_parser(boost::bind(&connection::MyWrite, this, _1), handler.Get_myWebem(), boost::bind(&connection::WS_Write, this, _1)),
-			status_(INITIALIZING),
-			default_abandoned_timeout_(20 * 60), // 20mn before stopping abandoned connection
-			abandoned_timer_(io_service, boost::posix_time::seconds(default_abandoned_timeout_)),
-			default_max_requests_(20),
-			send_buffer_(NULL)
+		connection::connection(boost::asio::io_service &io_service, connection_manager &manager, request_handler &handler, int read_timeout, boost::asio::ssl::context &context)
+			: send_buffer_(nullptr)
+			, read_timeout_(read_timeout)
+			, read_timer_(io_service, boost::posix_time::seconds(read_timeout))
+			, default_abandoned_timeout_(20 * 60)
+			// 20mn before stopping abandoned connection
+			, abandoned_timer_(io_service, boost::posix_time::seconds(default_abandoned_timeout_))
+			, connection_manager_(manager)
+			, request_handler_(handler)
+			, status_(INITIALIZING)
+			, default_max_requests_(20)
+			, websocket_parser([this](auto &&r) { MyWrite(r); }, handler.Get_myWebem(), [this](auto &&r) { WS_Write(r); })
 		{
 			secure_ = true;
 			keepalive_ = false;
 			write_in_progress = false;
 			connection_type = ConnectionType::connection_http;
-			socket_ = NULL;
+			socket_ = nullptr;
 			sslsocket_ = new ssl_socket(io_service, context);
 		}
 #endif
@@ -79,9 +76,7 @@ namespace http {
 			if (secure_) {
 				return sslsocket_->lowest_layer();
 			}
-			else {
-				return socket_->lowest_layer();
-			}
+			return socket_->lowest_layer();
 		}
 #else
 		// alternative: get the attached client socket of this connection if ssl is not compiled in
@@ -113,9 +108,7 @@ namespace http {
 #ifdef WWW_ENABLE_SSL
 				status_ = WAITING_HANDSHAKE;
 				// with ssl, we first need to complete the handshake before reading
-				sslsocket_->async_handshake(boost::asio::ssl::stream_base::server,
-					boost::bind(&connection::handle_handshake, shared_from_this(),
-						boost::asio::placeholders::error));
+				sslsocket_->async_handshake(boost::asio::ssl::stream_base::server, [self = shared_from_this()](auto &&err) { self->handle_handshake(err); });
 #endif
 			}
 			else {
@@ -209,18 +202,12 @@ namespace http {
 			if (secure_) {
 #ifdef WWW_ENABLE_SSL
 				// Perform secure read
-				sslsocket_->async_read_some(buf,
-					boost::bind(&connection::handle_read, shared_from_this(),
-						boost::asio::placeholders::error,
-						boost::asio::placeholders::bytes_transferred));
+				sslsocket_->async_read_some(buf, [self = shared_from_this()](auto &&err, auto bytes) { self->handle_read(err, bytes); });
 #endif
 			}
 			else {
 				// Perform plain read
-				socket_->async_read_some(buf,
-					boost::bind(&connection::handle_read, shared_from_this(),
-						boost::asio::placeholders::error,
-						boost::asio::placeholders::bytes_transferred));
+				socket_->async_read_some(buf, [self = shared_from_this()](auto &&err, auto bytes) { self->handle_read(err, bytes); });
 			}
 		}
 
@@ -234,11 +221,11 @@ namespace http {
 			write_buffer = buf;
 			if (secure_) {
 #ifdef WWW_ENABLE_SSL
-				boost::asio::async_write(*sslsocket_, boost::asio::buffer(write_buffer), boost::bind(&connection::handle_write, shared_from_this(), boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
+				boost::asio::async_write(*sslsocket_, boost::asio::buffer(write_buffer), [self = shared_from_this()](auto &&err, auto bytes) { self->handle_write(err, bytes); });
 #endif
 			}
 			else {
-				boost::asio::async_write(*socket_, boost::asio::buffer(write_buffer), boost::bind(&connection::handle_write, shared_from_this(), boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
+				boost::asio::async_write(*socket_, boost::asio::buffer(write_buffer), [self = shared_from_this()](auto &&err, auto bytes) { self->handle_write(err, bytes); });
 			}
 
 		}
@@ -288,22 +275,23 @@ namespace http {
 				};
 				if (secure_) {
 #ifdef WWW_ENABLE_SSL
-					boost::asio::async_write(*sslsocket_, boost::asio::buffer(send_buffer_, bread), boost::bind(&connection::handle_write_file, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
+					boost::asio::async_write(*sslsocket_, boost::asio::buffer(send_buffer_, bread),
+								 [self = shared_from_this()](auto &&err, auto bytes) { self->handle_write_file(err, bytes); });
 #endif
 				}
 				else {
-					boost::asio::async_write(*socket_, boost::asio::buffer(send_buffer_, bread), boost::bind(&connection::handle_write_file, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
+					boost::asio::async_write(*socket_, boost::asio::buffer(send_buffer_, bread),
+								 [self = shared_from_this()](auto &&err, auto bytes) { self->handle_write_file(err, bytes); });
 				}
 				return;
 			}
 
 			if (sendfile_.is_open())
 				sendfile_.close();
-			if (send_buffer_)
-				delete[] send_buffer_;
-			send_buffer_ = NULL;
+
+			delete[] send_buffer_;
+			send_buffer_ = nullptr;
 			connection_manager_.stop(shared_from_this());
-			return;
 		}
 
 		bool connection::send_file(const std::string& filename, std::string& attachment_name, reply& rep)
@@ -327,11 +315,11 @@ namespace http {
 
 			reply::add_header(&rep, "Cache-Control", "max-age=0, private");
 			reply::add_header(&rep, "Accept-Ranges", "bytes");
-			reply::add_header(&rep, "Date", convert_to_http_date(time(NULL)));
+			reply::add_header(&rep, "Date", convert_to_http_date(time(nullptr)));
 			reply::add_header(&rep, "Last-Modified", convert_to_http_date(ftime));
 			reply::add_header(&rep, "Server", "Apache/2.2.22");
 
-			std::size_t last_dot_pos = filename.find_last_of(".");
+			std::size_t last_dot_pos = filename.find_last_of('.');
 			if (last_dot_pos != std::string::npos) {
 				std::string file_extension = filename.substr(last_dot_pos + 1);
 				std::string mime_type = mime_types::extension_to_type(file_extension);
@@ -353,11 +341,11 @@ namespace http {
 
 			if (secure_) {
 #ifdef WWW_ENABLE_SSL
-				boost::asio::async_write(*sslsocket_, boost::asio::buffer(write_buffer), boost::bind(&connection::handle_write_file, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
+				boost::asio::async_write(*sslsocket_, boost::asio::buffer(write_buffer), [self = shared_from_this()](auto &&err, auto bytes) { self->handle_write_file(err, bytes); });
 #endif
 			}
 			else {
-				boost::asio::async_write(*socket_, boost::asio::buffer(write_buffer), boost::bind(&connection::handle_write_file, this, boost::asio::placeholders::error, boost::asio::placeholders::bytes_transferred));
+				boost::asio::async_write(*socket_, boost::asio::buffer(write_buffer), [self = shared_from_this()](auto &&err, auto bytes) { self->handle_write_file(err, bytes); });
 			}
 			return true;
 		}
@@ -396,7 +384,7 @@ namespace http {
 					}
 					catch (...)
 					{
-						_log.Log(LOG_ERROR, "Exception parsing http request.");
+						_log.Log(LOG_ERROR, "Exception parsing HTTP. Address: %s", host_endpoint_address_.c_str());
 					}
 
 					if (result) {
@@ -404,7 +392,7 @@ namespace http {
 						_buf.consume(sizeread);
 						reply_.reset();
 						const char* pConnection = request_.get_req_header(&request_, "Connection");
-						keepalive_ = pConnection != NULL && boost::iequals(pConnection, "Keep-Alive");
+						keepalive_ = pConnection != nullptr && boost::iequals(pConnection, "Keep-Alive");
 						request_.keep_alive = keepalive_;
 						request_.host_address = host_endpoint_address_;
 						request_.host_port = host_endpoint_port_;
@@ -459,14 +447,7 @@ namespace http {
 					}
 					else if (!result)
 					{
-/*
-This does not seem to print the correct request
-						begin = boost::asio::buffer_cast<const char*>(_buf.data());
-						std::string sRequest(begin, begin + _buf.size());
-
-						_log.Log(LOG_ERROR, "Error parsing http request. (%s)", sRequest.c_str());
-*/
-						_log.Log(LOG_ERROR, "Error parsing http request.");
+						_log.Log(LOG_ERROR, "Error parsing http request address: %s", host_endpoint_address_.c_str());
 						keepalive_ = false;
 						reply_ = reply::stock_reply(reply::bad_request);
 						MyWrite(reply_.to_string(request_.method));
@@ -559,17 +540,17 @@ This does not seem to print the correct request
 		connection::~connection()
 		{
 			// free up resources, delete the socket pointers
-			if (socket_) delete socket_;
+			delete socket_;
 #ifdef WWW_ENABLE_SSL
-			if (sslsocket_) delete sslsocket_;
+			delete sslsocket_;
 #endif
-			if (send_buffer_) delete[] send_buffer_;
+			delete[] send_buffer_;
 		}
 
 		// schedule read timeout timer
 		void connection::set_read_timeout() {
 			read_timer_.expires_from_now(boost::posix_time::seconds(read_timeout_));
-			read_timer_.async_wait(boost::bind(&connection::handle_read_timeout, shared_from_this(), boost::asio::placeholders::error));
+			read_timer_.async_wait([self = shared_from_this()](auto &&err) { self->handle_read_timeout(err); });
 		}
 
 		/// simply cancel read timeout timer
@@ -612,7 +593,7 @@ This does not seem to print the correct request
 		/// schedule abandoned timeout timer
 		void connection::set_abandoned_timeout() {
 			abandoned_timer_.expires_from_now(boost::posix_time::seconds(default_abandoned_timeout_));
-			abandoned_timer_.async_wait(boost::bind(&connection::handle_abandoned_timeout, shared_from_this(), boost::asio::placeholders::error));
+			abandoned_timer_.async_wait([self = shared_from_this()](auto &&err) { self->handle_abandoned_timeout(err); });
 		}
 
 		/// simply cancel abandoned timeout timer
