@@ -1,6 +1,8 @@
 #include "stdafx.h"
 #ifndef NOCLOUD
 #include "proxyclient.h"
+
+#include <utility>
 #include "../hardware/DomoticzTCP.h"
 #include "../main/Logger.h"
 #include "../main/SQLHelper.h"
@@ -29,7 +31,7 @@ namespace http {
 
 		CProxyClient::CProxyClient() : ASyncTCP(PROXY_SECURE)
 		{
-			m_pDomServ = NULL;
+			m_pDomServ = nullptr;
 			/* use default value for tcp timeouts */
 			SetTimeout(PROXY_TIMEOUT);
 		}
@@ -41,7 +43,8 @@ namespace http {
 			m_sql.GetPreferencesVar("MyDomoticzUserId", _apikey);
 			m_sql.GetPreferencesVar("MyDomoticzPassword", _password);
 			m_sql.GetPreferencesVar("MyDomoticzSubsystems", _allowed_subsystems);
-			if (_password != "") {
+			if (!_password.empty())
+			{
 				_password = base64_decode(_password);
 			}
 			readbuf.clear();
@@ -106,9 +109,7 @@ namespace http {
 		{
 			// generate random websocket key
 			unsigned char random[16];
-			for (int i = 0; i < sizeof(random); i++) {
-				random[i] = rand();
-			}
+			std::generate(std::begin(random), std::end(random), rand);
 			websocket_key = base64_encode(random, sizeof(random));
 			std::string request = "GET /proxycereal HTTP/1.1\r\nHost: my.domoticz.com\r\nConnection: Upgrade\r\nUpgrade: websocket\r\nOrigin: Domoticz\r\nSec-Websocket-Version: 13\r\nSec-Websocket-Protocol: MyDomoticz\r\nSec-Websocket-Key: " + websocket_key + "\r\n\r\n";
 			write(request);
@@ -150,11 +151,12 @@ namespace http {
 
 		std::string CProxyClient::GetResponseHeaders(const http::server::reply &reply_)
 		{
-			std::string result = "";
-			for (std::size_t i = 0; i < reply_.headers.size(); ++i) {
-				result += reply_.headers[i].name;
+			std::string result;
+			for (const auto &header : reply_.headers)
+			{
+				result += header.name;
 				result += ": ";
-				result += reply_.headers[i].value;
+				result += header.value;
 				result += "\r\n";
 			}
 			return result;
@@ -167,7 +169,7 @@ namespace http {
 				return;
 			}
 			// response variables
-			boost::asio::mutable_buffers_1 _buf(NULL, 0);
+			boost::asio::mutable_buffers_1 _buf(nullptr, 0);
 			/// The reply to be sent back to the client.
 			http::server::reply reply_;
 
@@ -176,7 +178,8 @@ namespace http {
 			if (pdu->m_subsystem == SUBSYSTEM_HTTP) {
 				// "normal web request", get parameters
 
-				if (pdu->m_requestbody.size() > 0) {
+				if (!pdu->m_requestbody.empty())
+				{
 					request = "POST ";
 				}
 				else {
@@ -268,7 +271,7 @@ namespace http {
 				return;
 			}
 			long authenticated;
-			std::string reason = "";
+			std::string reason;
 
 			sharedData.AddConnectedServer(pdu->m_ipparam);
 			if (pdu->m_protocol_version > 4) {
@@ -349,7 +352,7 @@ namespace http {
 			// todo: make a map of websocket connections. There can be more than one.
 			// open new virtual websocket connection
 			// todo: different request_url's can have different websocket handlers
-			websocket_handlers[pdu->m_requestid] = new CWebsocketHandler(m_pWebEm, boost::bind(&CProxyClient::WS_Write, this, pdu->m_requestid, _1));
+			websocket_handlers[pdu->m_requestid] = new CWebsocketHandler(m_pWebEm, [this, pdu](auto &&d) { WS_Write(pdu->m_requestid, d); });
 			websocket_handlers[pdu->m_requestid]->Start();
 		}
 
@@ -450,9 +453,10 @@ namespace http {
 		{
 			_log.Log(LOG_NORM, "Proxy: disconnected");
 			// stop and destroy all open websocket handlers
-			for (std::map<unsigned long long, CWebsocketHandler *>::iterator it = websocket_handlers.begin(); it != websocket_handlers.end(); ++it) {
-				it->second->Stop();
-				delete it->second;
+			for (auto &websocket_handler : websocket_handlers)
+			{
+				websocket_handler.second->Stop();
+				delete websocket_handler.second;
 			}
 			websocket_handlers.clear();
 		}
@@ -467,10 +471,6 @@ namespace http {
 			m_pDomServ = domserv;
 		}
 
-		CProxyClient::~CProxyClient()
-		{
-		}
-
 		void CProxyClient::Connect(http::server::cWebem *webEm)
 		{
 			m_pWebEm = webEm;
@@ -486,12 +486,7 @@ namespace http {
 		bool CProxyClient::Enabled()
 		{
 			Reset();
-			return (_apikey != "" && _password != "" && _allowed_subsystems != 0);
-		}
-
-
-		CProxyManager::CProxyManager()
-		{
+			return (!_apikey.empty() && !_password.empty() && _allowed_subsystems != 0);
 		}
 
 		CProxyManager::~CProxyManager()
@@ -532,9 +527,9 @@ namespace http {
 		void CProxyClient::ConnectToDomoticz(std::string instancekey, std::string username, std::string password, DomoticzTCP *master, int protocol_version)
 		{
 			ProxyPdu_SERV_CONNECT response;
-			response.m_ipparam = instancekey;
-			response.m_usernameparam = username;
-			response.m_passwordparam = password;
+			response.m_ipparam = std::move(instancekey);
+			response.m_usernameparam = std::move(username);
+			response.m_passwordparam = std::move(password);
 			response.m_protocol_version = protocol_version;
 			MyWrite(response.ToBinary());
 		}
@@ -566,7 +561,7 @@ namespace http {
 			return _instanceid;
 		}
 
-		bool CProxySharedData::AddConnectedIp(std::string ip)
+		bool CProxySharedData::AddConnectedIp(const std::string &ip)
 		{
 			if (connectedips_.find(ip) == connectedips_.end())
 			{
@@ -578,7 +573,7 @@ namespace http {
 			return false;
 		}
 
-		bool CProxySharedData::AddConnectedServer(std::string ip)
+		bool CProxySharedData::AddConnectedServer(const std::string &ip)
 		{
 			if (connectedservers_.find(ip) == connectedservers_.end())
 			{
@@ -592,11 +587,9 @@ namespace http {
 
 		void CProxySharedData::AddTCPClient(DomoticzTCP *client)
 		{
-			for (std::vector<DomoticzTCP *>::iterator it = TCPClients.begin(); it != TCPClients.end(); ++it) {
-				if ((*it) == client) {
+			for (auto &TCPClient : TCPClients)
+				if (TCPClient == client)
 					return;
-				}
-			}
 			int size = TCPClients.size();
 			TCPClients.resize(size + 1);
 			TCPClients[size] = client;
@@ -618,38 +611,31 @@ namespace http {
 
 		DomoticzTCP *CProxySharedData::findSlaveConnection(const std::string &token)
 		{
-			for (unsigned int i = 0; i < TCPClients.size(); i++) {
-				if (TCPClients[i]->CompareToken(token)) {
-					return TCPClients[i];
-				}
-			}
-			return NULL;
+			for (auto &TCPClient : TCPClients)
+				if (TCPClient->CompareToken(token))
+					return TCPClient;
+			return nullptr;
 		}
 
 		DomoticzTCP *CProxySharedData::findSlaveById(const std::string &instanceid)
 		{
-			for (unsigned int i = 0; i < TCPClients.size(); i++) {
-				if (TCPClients[i]->CompareId(instanceid)) {
-					return TCPClients[i];
-				}
-			}
-			return NULL;
+			for (auto &TCPClient : TCPClients)
+				if (TCPClient->CompareId(instanceid))
+					return TCPClient;
+			return nullptr;
 		}
 
 		void CProxySharedData::RestartTCPClients()
 		{
-			for (unsigned int i = 0; i < TCPClients.size(); i++) {
-				if (!TCPClients[i]->isConnected()) {
-					TCPClients[i]->ConnectInternalProxy();
-				}
-			}
+			for (auto &TCPClient : TCPClients)
+				if (!TCPClient->isConnected())
+					TCPClient->ConnectInternalProxy();
 		}
 
 		void CProxySharedData::StopTCPClients()
 		{
-			for (unsigned int i = 0; i < TCPClients.size(); i++) {
-				TCPClients[i]->DisconnectProxy();
-			}
+			for (auto &TCPClient : TCPClients)
+				TCPClient->DisconnectProxy();
 		}
 
 		/* pdu handlers not in use (server side) */
@@ -657,6 +643,6 @@ namespace http {
 		PDUFUNCTION(NONE) {}
 		PDUFUNCTION(RESPONSE) {}
 		PDUFUNCTION(WS_SEND) {}
-	}
-}
+	} // namespace server
+} // namespace http
 #endif
