@@ -77,6 +77,10 @@ define(['app'], function (app) {
 
 		DeleteLink = function(idx)
 		{
+			if ($('#linkparamstable #linkdelete').attr("class") == "btnstyle3-dis") {
+				return;
+			}
+		
 			bootbox.confirm($.t("Are you sure you want to remove this link?"), function(result) {
 				if (result==true) {
 					$.ajax({
@@ -95,6 +99,11 @@ define(['app'], function (app) {
 
 		AddLink = function(type)
 		{
+			if (type == "u") {
+				if ($('#linkparamstable #linkupdate').attr("class") == "btnstyle3-dis") {
+					return;
+				}
+			}
 			var idx = $.linkIdx;
 			if (type == "a") {idx="0"};
 			var deviceid = $("#linkparamstable #devicename option:selected").val();
@@ -176,20 +185,6 @@ define(['app'], function (app) {
 			 success: function(data) {   
 			  if (typeof data.result != 'undefined') {
 				$.each(data.result, function(i,item){
-					var enabled = $.t('No');
-					if (item.Enabled == 1)
-						enabled = $.t('Yes');
-					var DelimitedValue = "";
-					if (item.Delimitedvalue == 0) {
-						DelimitedValue = $.t('Status');
-					}
-					else {
-						DelimitedValue = $.t(GetDeviceValueOptionWording(item.DeviceID,item.Delimitedvalue));
-					}
-					var TargetType = $.t('On Value Change');
-					if (item.TargetType==1) 
-						TargetType = $.t('Direct');
-
 					var addId = oTable.fnAddData( {
 						"DT_RowId": item.idx,
 						"DeviceID": item.DeviceID,
@@ -198,9 +193,9 @@ define(['app'], function (app) {
 						"Delimitedvalue": item.Delimitedvalue,
 						"0": item.DeviceID,
 						"1": item.Name,
-						"2": DelimitedValue,
-						"3": TargetType,
-						"4": enabled
+						"2": $.t(item.Delimitedname),
+						"3": (item.TargetType==0) ? $.t('On Value Change') : $.t('Direct'),
+						"4": (item.Enabled == 1) ? $.t("Yes") : $.t("No")
 					} );
 				});
 			  }
@@ -209,22 +204,6 @@ define(['app'], function (app) {
 		  $('#modal').hide();
 		}
 
-		GetDeviceValueOptionWording = function(idx,pos)
-		{
-			var wording = "";
-			$.ajax({
-			 url: "json.htm?type=command&param=getdevicevalueoptionwording&idx="+idx+"&pos="+pos,
-			 async: false, 
-			 dataType: 'json',
-			 success: function(data) {   
-			  if (typeof data.wording != 'undefined') {
-					wording = data.wording;
-			  }
-			  }
-		   });
-		   return wording;
-		}
-
 		ShowLinks = function()
 		{
 			$('#influxmain').i18n();
@@ -233,34 +212,6 @@ define(['app'], function (app) {
 			  "oTableTools": {
 				"sRowSelect": "single"
 			  },
-			  "fnDrawCallback": function (oSettings) {
-				var nTrs = this.fnGetNodes();
-				$(nTrs).click(
-					function(){
-						$(nTrs).removeClass('row_selected');
-						$(this).addClass('row_selected');
-						$('#linkparamstable #linkupdate').attr("class", "btnstyle3");
-						$('#linkparamstable #linkdelete').attr("class", "btnstyle3");
-						var anSelected = fnGetSelected( oTable );
-						if ( anSelected.length !== 0 ) {
-							var data = oTable.fnGetData( anSelected[0] );
-							var idx= data["DT_RowId"];
-							$.linkIdx=idx;	
-							$("#linkparamstable #linkupdate").attr("href", "javascript:AddLink('u')");
-							$("#linkparamstable #linkdelete").attr("href", "javascript:DeleteLink(" + idx + ")");
-							$("#linkparamstable #combotargettype").val(data["TargetType"]);
-							$("#linkparamstable #devicename").val(data["DeviceID"]); 
-							ValueSelectorUpdate();
-							$("#linkparamstable #combosendvalue").val(data["Delimitedvalue"]);
-							if (data["Enabled"] == 1) {
-								$('#linkparamstable #linkenabled').prop('checked', true);
-							}
-							else {
-								$('#linkparamstable #linkenabled').prop('checked', false);
-							}
-						}
-				});
-			  },    
 			  "aaSorting": [[ 0, "desc" ]],
 			  "bSortClasses": false,
 			  "bProcessing": true,
@@ -271,6 +222,42 @@ define(['app'], function (app) {
 			  "sPaginationType": "full_numbers",
 			  language: $.DataTableLanguage
 			} );
+			
+			/* Add a click handler to the rows - this could be used as a callback */
+            $("#iflinktable tbody").off();
+            $("#iflinktable tbody").on('click', 'tr', function () {
+                if ($(this).hasClass('row_selected')) {
+                    $(this).removeClass('row_selected');
+					$('#linkparamstable #linkupdate').attr("class", "btnstyle3-dis");
+					$('#linkparamstable #linkdelete').attr("class", "btnstyle3-dis");
+                }
+                else {
+					$('#linkparamstable #linkupdate').attr("class", "btnstyle3");
+					$('#linkparamstable #linkdelete').attr("class", "btnstyle3");
+                    var oTable = $('#iflinktable').dataTable();
+                    oTable.$('tr.row_selected').removeClass('row_selected');
+                    $(this).addClass('row_selected');
+                    var anSelected = fnGetSelected(oTable);
+                    if (anSelected.length !== 0) {
+                        var data = oTable.fnGetData(anSelected[0]);
+                        var idx = data["DT_RowId"];
+						$.linkIdx=idx;	
+						$("#linkparamstable #linkupdate").attr("href", "javascript:AddLink('u')");
+						$("#linkparamstable #linkdelete").attr("href", "javascript:DeleteLink(" + idx + ")");
+						$("#linkparamstable #combotargettype").val(data["TargetType"]);
+						$("#linkparamstable #devicename").val(data["DeviceID"]); 
+						ValueSelectorUpdate();
+						$("#linkparamstable #combosendvalue").val(data["Delimitedvalue"]);
+						if (data["Enabled"] == 1) {
+							$('#linkparamstable #linkenabled').prop('checked', true);
+						}
+						else {
+							$('#linkparamstable #linkenabled').prop('checked', false);
+						}
+                    }
+                }
+            });
+
 			RefreshLinkTable();
 		}
 
